-- MariaDB dump 10.19  Distrib 10.5.22-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: heat
-- ------------------------------------------------------
-- Server version	10.5.22-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `event`
--

DROP TABLE IF EXISTS `event`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `event` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `uuid` varchar(36) DEFAULT NULL,
  `stack_id` varchar(36) NOT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `resource_action` varchar(255) DEFAULT NULL,
  `resource_status` varchar(255) DEFAULT NULL,
  `resource_name` varchar(255) DEFAULT NULL,
  `physical_resource_id` varchar(255) DEFAULT NULL,
  `resource_status_reason` varchar(255) DEFAULT NULL,
  `resource_type` varchar(255) DEFAULT NULL,
  `resource_properties` blob DEFAULT NULL,
  `rsrc_prop_data_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uuid` (`uuid`),
  KEY `stack_id` (`stack_id`),
  KEY `ev_rsrc_prop_data_ref` (`rsrc_prop_data_id`),
  CONSTRAINT `ev_rsrc_prop_data_ref` FOREIGN KEY (`rsrc_prop_data_id`) REFERENCES `resource_properties_data` (`id`),
  CONSTRAINT `event_ibfk_1` FOREIGN KEY (`stack_id`) REFERENCES `stack` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2805 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `event`
--

LOCK TABLES `event` WRITE;
/*!40000 ALTER TABLE `event` DISABLE KEYS */;
INSERT INTO `event` VALUES (1,'4b4097ee-4459-4b23-9ece-c9149fe9d4d9','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:50:58',NULL,'CREATE','IN_PROGRESS','overcloud','55d3b7c3-cd20-479e-abcc-7e199d80ba59','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2,'7325627a-7713-4439-b192-52b943399924','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:00',NULL,'CREATE','IN_PROGRESS','NodeUserData','overcloud-NodeUserData-f6la2ggesuuj','state changed','OS::TripleO::NodeUserData',NULL,NULL),(3,'89c07be8-f7ea-48e1-8163-fa0084c3d188','205ec3b7-c94f-4feb-84f4-c6a473ef7f85','2026-06-15 07:51:00',NULL,'CREATE','IN_PROGRESS','overcloud-NodeUserData-f6la2ggesuuj','205ec3b7-c94f-4feb-84f4-c6a473ef7f85','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(4,'c91b1cc7-77c1-4b72-9e7e-e372a4b8547c','205ec3b7-c94f-4feb-84f4-c6a473ef7f85','2026-06-15 07:51:00',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeUserData-f6la2ggesuuj-userdata-pyoe7shk3wzl','state changed','OS::Heat::MultipartMime',NULL,NULL),(5,'b5496def-0bbe-477f-98de-4d65b968e733','205ec3b7-c94f-4feb-84f4-c6a473ef7f85','2026-06-15 07:51:00',NULL,'CREATE','COMPLETE','userdata','a2f31dc1-6697-4ca0-ab0d-5640195ce519','state changed','OS::Heat::MultipartMime',NULL,NULL),(6,'cde4a224-e400-4843-a84e-70b0e4e5d43a','205ec3b7-c94f-4feb-84f4-c6a473ef7f85','2026-06-15 07:51:00',NULL,'CREATE','COMPLETE','overcloud-NodeUserData-f6la2ggesuuj','205ec3b7-c94f-4feb-84f4-c6a473ef7f85','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(7,'8c6374ab-2b05-48eb-8075-256cc27e86ab','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:01',NULL,'CREATE','IN_PROGRESS','ServiceNetMap','overcloud-ServiceNetMap-27cdhc54d72z','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(8,'db53559d-dc28-4151-833a-cc970087f51c','e098d73b-bc66-4b46-88ba-a05a4579300d','2026-06-15 07:51:01',NULL,'CREATE','IN_PROGRESS','overcloud-ServiceNetMap-27cdhc54d72z','e098d73b-bc66-4b46-88ba-a05a4579300d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(9,'e671d828-a5db-4175-ba03-5d379d6eea60','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:01',NULL,'CREATE','COMPLETE','NodeUserData','205ec3b7-c94f-4feb-84f4-c6a473ef7f85','state changed','OS::TripleO::NodeUserData',NULL,NULL),(10,'f989f14f-7734-4a14-a6c7-dc490c7faad4','e098d73b-bc66-4b46-88ba-a05a4579300d','2026-06-15 07:51:01',NULL,'CREATE','IN_PROGRESS','ServiceNetMapValue','overcloud-ServiceNetMap-27cdhc54d72z-ServiceNetMapValue-7efshdw6vi2e','state changed','OS::Heat::Value',NULL,1),(11,'6a0d5415-47f5-482c-933b-bde16dc91ea8','e098d73b-bc66-4b46-88ba-a05a4579300d','2026-06-15 07:51:01',NULL,'CREATE','COMPLETE','ServiceNetMapValue','overcloud-ServiceNetMap-27cdhc54d72z-ServiceNetMapValue-7efshdw6vi2e','state changed','OS::Heat::Value',NULL,1),(12,'380ffa30-4090-450b-8c46-d304ab31e4d7','e098d73b-bc66-4b46-88ba-a05a4579300d','2026-06-15 07:51:01',NULL,'CREATE','COMPLETE','overcloud-ServiceNetMap-27cdhc54d72z','e098d73b-bc66-4b46-88ba-a05a4579300d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(13,'4e37a287-ba5e-433d-86fa-89400e3841e1','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:02',NULL,'CREATE','IN_PROGRESS','CellControllerComputeRoleUserData','overcloud-CellControllerComputeRoleUserData-fkyyzz2xh4vj','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(14,'cb5505dd-5f62-4d6f-8cc4-37ccc1f60e78','e4db2e7c-c4f3-4e6a-a016-355fa80d9c2b','2026-06-15 07:51:02',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeRoleUserData-fkyyzz2xh4vj','e4db2e7c-c4f3-4e6a-a016-355fa80d9c2b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(15,'adbb11e3-3874-409d-86df-a3b00a2e635c','e4db2e7c-c4f3-4e6a-a016-355fa80d9c2b','2026-06-15 07:51:02',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerComputeRoleUserData-fkyyzz2xh4vj-userdata-5eecvgwtbytz','state changed','OS::Heat::MultipartMime',NULL,NULL),(16,'9fa8cdde-c75c-4fc3-a409-9711987afffb','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:02',NULL,'CREATE','COMPLETE','ServiceNetMap','e098d73b-bc66-4b46-88ba-a05a4579300d','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(17,'8b4ed92f-8daf-4249-bb23-8543bf85ed84','e4db2e7c-c4f3-4e6a-a016-355fa80d9c2b','2026-06-15 07:51:02',NULL,'CREATE','COMPLETE','userdata','5c6c2b53-3aa2-4abc-96ff-1cc9e41ff4d0','state changed','OS::Heat::MultipartMime',NULL,NULL),(18,'b135e40c-495a-4d19-ac1b-89becb80a18a','e4db2e7c-c4f3-4e6a-a016-355fa80d9c2b','2026-06-15 07:51:02',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeRoleUserData-fkyyzz2xh4vj','e4db2e7c-c4f3-4e6a-a016-355fa80d9c2b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(19,'5aa40088-af99-4205-864d-1bee03062a45','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-blg4kk7t7l77','state changed','OS::Heat::Value',NULL,4),(20,'7cf8e94c-42fd-484f-a7a3-fa7efec1a2ac','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-blg4kk7t7l77','state changed','OS::Heat::Value',NULL,4),(21,'0f765609-c504-4d53-960f-a5d2a85c69a0','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-ll2bix3nl4l2','state changed','OS::Heat::Value',NULL,6),(22,'2de55a1b-7a35-4e3b-b8cd-df1e18432be9','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-ll2bix3nl4l2','state changed','OS::Heat::Value',NULL,6),(23,'53537a37-2ce7-406b-bee1-c5f612236a49','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-h5rvfup6h6aj','state changed','OS::Heat::Value',NULL,8),(24,'80ea2848-920e-4962-8fed-432534518170','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-h5rvfup6h6aj','state changed','OS::Heat::Value',NULL,8),(25,'c3bde7d0-cab9-4b95-98c6-4489fa9e872a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-zrxzxftw5pz2','state changed','OS::Heat::Value',NULL,9),(26,'672a37b1-d690-4095-8bea-9cb44d5325c8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-zrxzxftw5pz2','state changed','OS::Heat::Value',NULL,9),(27,'8ac356d6-3c1b-4e07-97d3-33959c70f4d5','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-bqztsnj5hjh2','state changed','OS::Heat::Value',NULL,11),(28,'5fe95ec1-aa14-41bd-a010-db09a27377dc','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-bqztsnj5hjh2','state changed','OS::Heat::Value',NULL,11),(29,'80de313f-4c79-4c2a-87db-c9a49be1023f','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','ControlVirtualIP','overcloud-ControlVirtualIP-s5iw2gog6poq','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,15),(30,'6caea6b3-0d01-4c35-9471-d0802ac11fce','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-vyk7gdlsiuef','state changed','OS::Heat::Value',NULL,16),(31,'21852e10-e22f-4acc-9ae1-d54fd379342a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-ha7dk6eo65zu','state changed','OS::Heat::Value',NULL,17),(32,'e27f8d23-c8c4-4f10-8dec-56562e2c9142','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-vyk7gdlsiuef','state changed','OS::Heat::Value',NULL,16),(33,'4285dd26-fd36-4ed7-ae39-06782c5cfd7b','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-xcsqqf5zkomj','state changed','OS::Heat::Value',NULL,18),(34,'69042df1-a5cd-4058-97a2-0e8f32b4465e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-ha7dk6eo65zu','state changed','OS::Heat::Value',NULL,17),(35,'7f810cec-741a-4599-8d24-b996a0669029','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-xcsqqf5zkomj','state changed','OS::Heat::Value',NULL,18),(36,'61de251c-e5a2-4665-a46b-1a9e576ba9c8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','CellControllerRoleUserData','overcloud-CellControllerRoleUserData-kamd6o3nswja','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(37,'3580f627-c14d-4f7c-83b7-ceb3dad8e052','c22cb029-1159-40c7-bb19-c5ce52c75ad9','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControlVirtualIP-s5iw2gog6poq','c22cb029-1159-40c7-bb19-c5ce52c75ad9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(38,'a770bc9f-b9d1-4340-aa43-a1d105139c14','c96c97fe-299f-4b0d-a55e-af6ec95d55da','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerRoleUserData-kamd6o3nswja','c96c97fe-299f-4b0d-a55e-af6ec95d55da','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(39,'75a0c561-8b61-427f-8d41-5b3bac36f127','c22cb029-1159-40c7-bb19-c5ce52c75ad9','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','overcloud-ControlVirtualIP-s5iw2gog6poq','c22cb029-1159-40c7-bb19-c5ce52c75ad9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(40,'efb6b3f6-e9d1-4f4b-8eee-f0051b1a68c5','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','CellControllerComputeRoleUserData','e4db2e7c-c4f3-4e6a-a016-355fa80d9c2b','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(41,'843a354e-2a56-406e-9d78-f29115f1c1fb','c96c97fe-299f-4b0d-a55e-af6ec95d55da','2026-06-15 07:51:03',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerRoleUserData-kamd6o3nswja-userdata-fliy4k3qlqut','state changed','OS::Heat::MultipartMime',NULL,NULL),(42,'9bb2c21d-1c08-4996-90d4-a961b663a490','c96c97fe-299f-4b0d-a55e-af6ec95d55da','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','userdata','4511d998-1783-4699-ad4c-7430e1e21583','state changed','OS::Heat::MultipartMime',NULL,NULL),(43,'44f4406e-6d2e-4aa2-8544-f0e3e4b7fb49','c96c97fe-299f-4b0d-a55e-af6ec95d55da','2026-06-15 07:51:03',NULL,'CREATE','COMPLETE','overcloud-CellControllerRoleUserData-kamd6o3nswja','c96c97fe-299f-4b0d-a55e-af6ec95d55da','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(44,'c089721d-a974-4662-b642-31b8261815b8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:04',NULL,'CREATE','IN_PROGRESS','ControllerRoleUserData','overcloud-ControllerRoleUserData-j46nywvbvfx4','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(45,'d51b66ae-948e-4d81-aa8a-44fae4e5057a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:04',NULL,'CREATE','COMPLETE','CellControllerRoleUserData','c96c97fe-299f-4b0d-a55e-af6ec95d55da','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(46,'411d0d9f-9900-4f54-8cb3-958c8c6adb40','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:04',NULL,'CREATE','COMPLETE','ControlVirtualIP','c22cb029-1159-40c7-bb19-c5ce52c75ad9','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,15),(47,'278e6576-426d-41a7-ac6a-d8866e89f812','e0f89317-827d-449e-bff9-4a52c606a324','2026-06-15 07:51:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerRoleUserData-j46nywvbvfx4','e0f89317-827d-449e-bff9-4a52c606a324','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(48,'3bf5e106-3dcc-4c6e-ab01-67f0c2d8aefa','e0f89317-827d-449e-bff9-4a52c606a324','2026-06-15 07:51:04',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ControllerRoleUserData-j46nywvbvfx4-userdata-v3qrxzmqq3z5','state changed','OS::Heat::MultipartMime',NULL,NULL),(49,'02605128-5b36-46bf-a18c-be5b22dcc802','e0f89317-827d-449e-bff9-4a52c606a324','2026-06-15 07:51:04',NULL,'CREATE','COMPLETE','userdata','cf3d07eb-2ebd-4487-b53b-cfa77f9ea98b','state changed','OS::Heat::MultipartMime',NULL,NULL),(50,'39128d67-ebee-40d1-906e-aabc16060f98','e0f89317-827d-449e-bff9-4a52c606a324','2026-06-15 07:51:04',NULL,'CREATE','COMPLETE','overcloud-ControllerRoleUserData-j46nywvbvfx4','e0f89317-827d-449e-bff9-4a52c606a324','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(51,'1056d781-f81c-45bc-95e1-eb64b44cf75a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:05',NULL,'CREATE','IN_PROGRESS','Networks','overcloud-Networks-obiegxe3rnyv','state changed','OS::TripleO::Network',NULL,24),(52,'4855df27-bc06-4423-92eb-f9e71fe9198e','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:05',NULL,'CREATE','IN_PROGRESS','overcloud-Networks-obiegxe3rnyv','977b18e5-4b7d-4463-9419-43d69e4942a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(53,'bda36412-7b6f-4455-b26b-3d890407b2f2','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:05',NULL,'CREATE','IN_PROGRESS','NetworkCidrMap','overcloud-Networks-obiegxe3rnyv-NetworkCidrMap-pcgwewctnotq','state changed','OS::Heat::Value',NULL,26),(54,'672e5394-62d4-42ef-84c5-2cbaedce19aa','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:05',NULL,'CREATE','COMPLETE','NetworkCidrMap','overcloud-Networks-obiegxe3rnyv-NetworkCidrMap-pcgwewctnotq','state changed','OS::Heat::Value',NULL,26),(55,'f7571e13-8aa8-4bab-818b-9e6ed29f639c','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:05',NULL,'CREATE','IN_PROGRESS','ObjectStorageRoleUserData','overcloud-ObjectStorageRoleUserData-3rmvuzeem6ty','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(56,'9e90de07-407d-4c1d-8c72-e03233c3b7ae','6b68f4ec-244c-482c-96d9-9751eff79a33','2026-06-15 07:51:05',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageRoleUserData-3rmvuzeem6ty','6b68f4ec-244c-482c-96d9-9751eff79a33','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(57,'11fbc8eb-117b-4022-8dab-838555fcd327','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:05',NULL,'CREATE','COMPLETE','ControllerRoleUserData','e0f89317-827d-449e-bff9-4a52c606a324','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(58,'2d0db102-94cc-4193-8b27-2505f60958cd','6b68f4ec-244c-482c-96d9-9751eff79a33','2026-06-15 07:51:05',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ObjectStorageRoleUserData-3rmvuzeem6ty-userdata-br6dimr57z5e','state changed','OS::Heat::MultipartMime',NULL,NULL),(59,'d9b0a68b-07cd-4738-ace6-2752619fbdda','6b68f4ec-244c-482c-96d9-9751eff79a33','2026-06-15 07:51:05',NULL,'CREATE','COMPLETE','userdata','6f29f0a6-3983-4225-b509-5c9a37ec4608','state changed','OS::Heat::MultipartMime',NULL,NULL),(60,'e0114e1a-3075-4c9f-96bf-256e4176b74d','6b68f4ec-244c-482c-96d9-9751eff79a33','2026-06-15 07:51:05',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageRoleUserData-3rmvuzeem6ty','6b68f4ec-244c-482c-96d9-9751eff79a33','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(61,'7026a81c-70a9-4ca9-8b8d-8052063e36a2','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:06',NULL,'CREATE','IN_PROGRESS','NetworkExtraConfig','overcloud-Networks-obiegxe3rnyv-NetworkExtraConfig-tnawxeqyyu3q','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(62,'9af03291-fdcb-45e4-bd78-11940cfdfc48','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:06',NULL,'CREATE','COMPLETE','NetworkExtraConfig','a3415620-ef4f-4f5b-a16a-ec9bdb8df4a6','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(63,'d8f0e425-6314-4d8d-b5a3-4554cd950d45','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:06',NULL,'CREATE','IN_PROGRESS','NetworkerRoleUserData','overcloud-NetworkerRoleUserData-v7sduujkrujs','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(64,'1952437a-a287-4bf7-903d-edb93cbedad8','c155f202-6708-416f-942b-cb65a84337a5','2026-06-15 07:51:06',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerRoleUserData-v7sduujkrujs','c155f202-6708-416f-942b-cb65a84337a5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(65,'c3651aa1-0327-44ff-a044-ffbbdbda51e0','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:06',NULL,'CREATE','COMPLETE','ObjectStorageRoleUserData','6b68f4ec-244c-482c-96d9-9751eff79a33','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(66,'063ab66c-30cd-4842-84e2-bbc379328f36','c155f202-6708-416f-942b-cb65a84337a5','2026-06-15 07:51:06',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NetworkerRoleUserData-v7sduujkrujs-userdata-xr5gerka6wmq','state changed','OS::Heat::MultipartMime',NULL,NULL),(67,'bd62b2c9-34a6-4bd0-a82a-a744369f954b','c155f202-6708-416f-942b-cb65a84337a5','2026-06-15 07:51:06',NULL,'CREATE','COMPLETE','userdata','114ebaec-407a-4cd4-ba9e-d5f59ce37559','state changed','OS::Heat::MultipartMime',NULL,NULL),(68,'98643f28-f8bc-495c-a5ec-56cc5371b853','c155f202-6708-416f-942b-cb65a84337a5','2026-06-15 07:51:06',NULL,'CREATE','COMPLETE','overcloud-NetworkerRoleUserData-v7sduujkrujs','c155f202-6708-416f-942b-cb65a84337a5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(69,'7d7676ba-d418-4129-88ff-8e8ea3f42ac7','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:07',NULL,'CREATE','IN_PROGRESS','NetworkAttributesMap','overcloud-Networks-obiegxe3rnyv-NetworkAttributesMap-pappm5f5fynp','state changed','OS::Heat::Value',NULL,29),(70,'ccc59e8b-8757-45ce-b6d4-dd80f592be81','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:07',NULL,'CREATE','COMPLETE','NetworkAttributesMap','overcloud-Networks-obiegxe3rnyv-NetworkAttributesMap-pappm5f5fynp','state changed','OS::Heat::Value',NULL,29),(71,'cc00dbbf-77cf-4af6-9bf0-f170342db9ea','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:07',NULL,'CREATE','IN_PROGRESS','NodeAdminUserData','overcloud-NodeAdminUserData-nudwkttaqm5m','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(72,'bacfce3a-16fa-42d2-a509-9634c86bd9c3','ac576021-fee1-4a5f-919d-34c91334d791','2026-06-15 07:51:07',NULL,'CREATE','IN_PROGRESS','overcloud-NodeAdminUserData-nudwkttaqm5m','ac576021-fee1-4a5f-919d-34c91334d791','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(73,'a9d12b51-2c70-4e6b-8f1f-d8d8b1089559','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:07',NULL,'CREATE','COMPLETE','NetworkerRoleUserData','c155f202-6708-416f-942b-cb65a84337a5','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(74,'8297494f-c412-4d10-8bce-e1bfc6812595','ac576021-fee1-4a5f-919d-34c91334d791','2026-06-15 07:51:07',NULL,'CREATE','IN_PROGRESS','user_config','overcloud-NodeAdminUserData-nudwkttaqm5m-user_config-gj3hbzp6hkym','state changed','OS::Heat::CloudConfig',NULL,30),(75,'8acceeab-f101-40ab-9168-f5bf3c78fab0','ac576021-fee1-4a5f-919d-34c91334d791','2026-06-15 07:51:07',NULL,'CREATE','COMPLETE','user_config','f9964419-4aec-430f-ab10-de97b56906c5','state changed','OS::Heat::CloudConfig',NULL,30),(76,'affd4e9a-e5b6-45e7-ab19-f718e192be0e','ac576021-fee1-4a5f-919d-34c91334d791','2026-06-15 07:51:07',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeAdminUserData-nudwkttaqm5m-userdata-z35kidghv6kl','state changed','OS::Heat::MultipartMime',NULL,32),(77,'1e79d8c8-7b5e-4d01-a833-5ea2ff345b87','ac576021-fee1-4a5f-919d-34c91334d791','2026-06-15 07:51:07',NULL,'CREATE','COMPLETE','userdata','93671d39-53fe-4429-98b1-3a194c32d656','state changed','OS::Heat::MultipartMime',NULL,32),(78,'5d89fd09-ea85-4897-acbc-f5c1c9caefd4','ac576021-fee1-4a5f-919d-34c91334d791','2026-06-15 07:51:07',NULL,'CREATE','COMPLETE','overcloud-NodeAdminUserData-nudwkttaqm5m','ac576021-fee1-4a5f-919d-34c91334d791','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(79,'53a498b2-06d7-4e31-ae18-a9c8af42de85','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:08',NULL,'CREATE','IN_PROGRESS','NetworkIpVersionMap','overcloud-Networks-obiegxe3rnyv-NetworkIpVersionMap-phjpdnc2spdv','state changed','OS::Heat::Value',NULL,33),(80,'2a9db187-5595-44d5-94d6-ca310eba25cb','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:08',NULL,'CREATE','COMPLETE','NetworkIpVersionMap','overcloud-Networks-obiegxe3rnyv-NetworkIpVersionMap-phjpdnc2spdv','state changed','OS::Heat::Value',NULL,33),(81,'e3bcf5c4-b0c9-4d61-93cd-d9e876895a85','977b18e5-4b7d-4463-9419-43d69e4942a0','2026-06-15 07:51:08',NULL,'CREATE','COMPLETE','overcloud-Networks-obiegxe3rnyv','977b18e5-4b7d-4463-9419-43d69e4942a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(82,'fe44fb68-6fcf-436c-be35-49fc8b0b5322','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:08',NULL,'CREATE','IN_PROGRESS','BlockStorageRoleUserData','overcloud-BlockStorageRoleUserData-q4qcqxt4lxyw','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(83,'0dd5c8d9-52e1-44e7-8f77-4c3cce41a3e8','66623b6e-1dea-492f-8a1d-1858a4865596','2026-06-15 07:51:08',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageRoleUserData-q4qcqxt4lxyw','66623b6e-1dea-492f-8a1d-1858a4865596','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(84,'ddadf433-1b3d-4da5-a99e-c16c4241db32','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:08',NULL,'CREATE','COMPLETE','NodeAdminUserData','ac576021-fee1-4a5f-919d-34c91334d791','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(85,'ccbd5341-322b-4234-869b-91d485c9fa2e','66623b6e-1dea-492f-8a1d-1858a4865596','2026-06-15 07:51:08',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-BlockStorageRoleUserData-q4qcqxt4lxyw-userdata-cpscojc26hzn','state changed','OS::Heat::MultipartMime',NULL,NULL),(86,'2a24dbf8-1d43-455e-b88b-bf1bef8bbd85','66623b6e-1dea-492f-8a1d-1858a4865596','2026-06-15 07:51:08',NULL,'CREATE','COMPLETE','userdata','ca65ee05-a824-4d49-afa5-504b839fb91b','state changed','OS::Heat::MultipartMime',NULL,NULL),(87,'7bff147a-6735-4074-808e-8fca82994d82','66623b6e-1dea-492f-8a1d-1858a4865596','2026-06-15 07:51:08',NULL,'CREATE','COMPLETE','overcloud-BlockStorageRoleUserData-q4qcqxt4lxyw','66623b6e-1dea-492f-8a1d-1858a4865596','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(88,'73cb2875-dbc8-4ddc-acdd-2fcf6e4c190d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','COMPLETE','Networks','977b18e5-4b7d-4463-9419-43d69e4942a0','state changed','OS::TripleO::Network',NULL,24),(89,'63c64833-e76d-45ff-bb0d-3eb525ecab01','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','NetCidrMapValue','overcloud-NetCidrMapValue-6ge65pi2ax2z','state changed','OS::Heat::Value',NULL,38),(90,'4029a2fc-af4a-47a4-b31e-722346c11954','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','COMPLETE','NetCidrMapValue','overcloud-NetCidrMapValue-6ge65pi2ax2z','state changed','OS::Heat::Value',NULL,38),(91,'1e787b7d-068c-4649-94eb-e658e740156e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkConfig','overcloud-CellControllerNetworkConfig-kun55yjetmuf','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(92,'0177afcf-05d1-4086-a162-55e23c09e2b3','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','COMPLETE','CellControllerNetworkConfig','05cd2618-1a7d-41cf-a90f-86e1bf4af27f','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(93,'77a2578a-ecdd-40a4-996f-c3ae44f3047d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','StorageMgmtVirtualIP','overcloud-StorageMgmtVirtualIP-uasmtxzae6ih','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,39),(94,'b8bde585-8518-45b1-ac37-1dc32dbd254e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','CephStorageRoleUserData','overcloud-CephStorageRoleUserData-c4pk64r52g23','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(95,'98c6f0bf-388f-44c5-89fd-51b5b28af3a8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','ControllerNetworkConfig','overcloud-ControllerNetworkConfig-yzcji6e5lvld','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(96,'19ecefd5-76ee-4225-8a43-e10a2bd47dc5','2a21a343-492d-482d-84aa-8f6cce219020','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','overcloud-StorageMgmtVirtualIP-uasmtxzae6ih','2a21a343-492d-482d-84aa-8f6cce219020','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(97,'3391f1df-c778-4248-8c6f-57fa18804d0f','2a21a343-492d-482d-84aa-8f6cce219020','2026-06-15 07:51:09',NULL,'CREATE','COMPLETE','overcloud-StorageMgmtVirtualIP-uasmtxzae6ih','2a21a343-492d-482d-84aa-8f6cce219020','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(98,'d756cc45-ce5f-4611-84fd-062298ef67aa','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','COMPLETE','ControllerNetworkConfig','401d6653-c2a2-4271-a4e6-b1a38bc91ed1','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(99,'b489228d-e349-4386-9ea1-1bfd2c07d267','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','PublicVirtualIP','overcloud-PublicVirtualIP-bjkezlhi54bf','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,41),(100,'c219162d-101b-4a63-bb0c-a5882e7c0a77','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-n2brgfy657sd','state changed','OS::Heat::Value',NULL,42),(101,'d49b7c51-2669-446b-a360-58c71521e06a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','COMPLETE','BlockStorageRoleUserData','66623b6e-1dea-492f-8a1d-1858a4865596','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(102,'0777a232-4a41-451f-a0b4-5fad690435e2','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','COMPLETE','StorageMgmtVirtualIP','2a21a343-492d-482d-84aa-8f6cce219020','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,39),(103,'dd787c2f-9f0a-4e75-99f7-a67065b6129a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','COMPLETE','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-n2brgfy657sd','state changed','OS::Heat::Value',NULL,42),(104,'6ea75c0e-88e8-4103-ba6f-5f0b48fa70f2','0fb78ed5-eefb-40e6-b66b-5fb644063ef8','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','overcloud-PublicVirtualIP-bjkezlhi54bf','0fb78ed5-eefb-40e6-b66b-5fb644063ef8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(105,'be00cc3b-f471-48fe-ae3d-83eb45694b74','259e9bfd-e3cd-4201-bd3a-aec723716d31','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageRoleUserData-c4pk64r52g23','259e9bfd-e3cd-4201-bd3a-aec723716d31','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(106,'a05ff55b-0e3d-46bb-8fc5-f38f5bf0c30b','0fb78ed5-eefb-40e6-b66b-5fb644063ef8','2026-06-15 07:51:09',NULL,'CREATE','COMPLETE','overcloud-PublicVirtualIP-bjkezlhi54bf','0fb78ed5-eefb-40e6-b66b-5fb644063ef8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(107,'6f0dc76b-93bc-4876-a340-34dbcea4e3ab','259e9bfd-e3cd-4201-bd3a-aec723716d31','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CephStorageRoleUserData-c4pk64r52g23-userdata-2dg3mi5hfg2k','state changed','OS::Heat::MultipartMime',NULL,NULL),(108,'673be584-0cde-4183-b486-7f16bd79fb1c','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:09',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkConfig','overcloud-CephStorageNetworkConfig-as73dikycbzd','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(109,'95f44bb5-975d-4123-9476-4fc9be4b3c5e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkConfig','overcloud-ObjectStorageNetworkConfig-35gnazcn4yvq','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(110,'60315af8-82ba-40dc-9e00-1131747386f0','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','CephStorageNetworkConfig','05ff9937-343d-4523-a760-18589703e314','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(111,'0cdf7165-6e8f-4d35-b3f4-072aab981edf','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','InternalApiVirtualIP','overcloud-InternalApiVirtualIP-dxmhlbmkpjpy','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,47),(112,'d643c03a-c95d-43d6-8e72-92c81a5732c4','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkConfig','overcloud-CellControllerComputeNetworkConfig-ttcwqztxqgqy','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(113,'2c070f9c-3bf6-416c-aecf-d6297c486d9a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','ComputeNetworkConfig','overcloud-ComputeNetworkConfig-xtfmq3aevw6g','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(114,'81754b9c-c0ac-41f3-80ef-ae2ade81fb4d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','ObjectStorageNetworkConfig','55f0c697-55a7-4de1-8d32-3d6025c304f8','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(115,'5977483e-b9fe-41d5-8a70-7b13040020d4','259e9bfd-e3cd-4201-bd3a-aec723716d31','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','userdata','713d3a12-64ce-4e5e-aecb-0adbe0293176','state changed','OS::Heat::MultipartMime',NULL,NULL),(116,'e0781a8c-c127-4660-bc59-d04a0423393d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','StorageVirtualIP','overcloud-StorageVirtualIP-3qenccwkl3iw','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,46),(117,'bc9ade82-c88c-4142-9830-5bdec66bbdbf','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkConfig','overcloud-NetworkerNetworkConfig-jcgs2u433ttr','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(118,'2352b990-39bd-455f-a5b6-bf2f6cccfcd3','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkConfig','6f06aed3-8585-41e1-82f6-82d354d4bede','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(119,'2c58ee25-ae42-46a3-8652-c9988dbb749c','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','ComputeNetworkConfig','369cff52-047c-49a2-896d-5320286b3c70','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(120,'300b2514-0438-4796-8f8c-3b2d9e4ae0d8','30622678-14f2-4164-9e30-3531e5d3a7a5','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','overcloud-InternalApiVirtualIP-dxmhlbmkpjpy','30622678-14f2-4164-9e30-3531e5d3a7a5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(121,'dfafb08b-5e7c-4768-80ef-e6145bf5c42a','259e9bfd-e3cd-4201-bd3a-aec723716d31','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','overcloud-CephStorageRoleUserData-c4pk64r52g23','259e9bfd-e3cd-4201-bd3a-aec723716d31','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(122,'9b6f3e30-6706-40a9-a3a5-d032b959bad7','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','NetworkerNetworkConfig','a0cdc807-0610-4633-8b42-51bafb4fabe4','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(123,'28eaffa5-40ad-485b-ba01-21670dd7b903','30622678-14f2-4164-9e30-3531e5d3a7a5','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','overcloud-InternalApiVirtualIP-dxmhlbmkpjpy','30622678-14f2-4164-9e30-3531e5d3a7a5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(124,'283e9df8-41d0-41d5-9cd1-4c71b994d804','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkConfig','overcloud-BlockStorageNetworkConfig-tphtwr2rao7f','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(125,'9d085b71-98e3-4b56-9e96-e926e61f68d7','b9635ed2-68de-48fc-873f-07d844da54b0','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','overcloud-StorageVirtualIP-3qenccwkl3iw','b9635ed2-68de-48fc-873f-07d844da54b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(126,'f6658a81-4557-42cb-a6cb-a020ab4e0437','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','BlockStorageNetworkConfig','aee9c95b-08a5-4671-9854-1df98e9b9b64','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(127,'56ce0183-969b-4836-a90f-aeef0886d6b0','b9635ed2-68de-48fc-873f-07d844da54b0','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','overcloud-StorageVirtualIP-3qenccwkl3iw','b9635ed2-68de-48fc-873f-07d844da54b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(128,'52c36ad0-24fb-4ae8-bac9-16173e6f4a5a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','IN_PROGRESS','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-uvyb2v5j4cix','state changed','OS::Heat::Value',NULL,49),(129,'de0f0bef-e193-4a62-8f67-5d52f0075bd9','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-uvyb2v5j4cix','state changed','OS::Heat::Value',NULL,49),(130,'296fb747-c875-415b-8736-90d936b959b9','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:10',NULL,'CREATE','COMPLETE','PublicVirtualIP','0fb78ed5-eefb-40e6-b66b-5fb644063ef8','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,41),(131,'133cfb45-8728-4c85-8e7c-8f1abdecefa2','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:11',NULL,'CREATE','COMPLETE','CephStorageRoleUserData','259e9bfd-e3cd-4201-bd3a-aec723716d31','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(132,'d3523f5b-f0cf-4740-ad60-f0c5d65d11cf','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:11',NULL,'CREATE','COMPLETE','InternalApiVirtualIP','30622678-14f2-4164-9e30-3531e5d3a7a5','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,47),(133,'fd24d4aa-6794-49dd-b98d-5457a451ed74','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:11',NULL,'CREATE','COMPLETE','StorageVirtualIP','b9635ed2-68de-48fc-873f-07d844da54b0','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,46),(134,'b94bd16a-2b08-4f31-b72b-ea89f94c1a18','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:11',NULL,'CREATE','IN_PROGRESS','VipMap','overcloud-VipMap-c2uc4vsagq2f','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,55),(135,'49aba184-96e2-4b47-bb99-12c67262b811','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:11',NULL,'CREATE','IN_PROGRESS','NodeTimesyncUserData','overcloud-NodeTimesyncUserData-jmzhy5m4govo','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(136,'8095413f-966f-42f7-82d8-a41e5d7dbbb7','bd919d6c-b33a-45c5-a706-2a50ec7cfce2','2026-06-15 07:51:11',NULL,'CREATE','IN_PROGRESS','overcloud-VipMap-c2uc4vsagq2f','bd919d6c-b33a-45c5-a706-2a50ec7cfce2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(137,'0f7e28d8-2519-474f-ba7b-a39bd32cf031','45340f96-99b0-4d2d-996e-3c804cdb2f9c','2026-06-15 07:51:11',NULL,'CREATE','IN_PROGRESS','overcloud-NodeTimesyncUserData-jmzhy5m4govo','45340f96-99b0-4d2d-996e-3c804cdb2f9c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(138,'81fd2951-0ff2-4ac6-972a-9974e6863a3c','bd919d6c-b33a-45c5-a706-2a50ec7cfce2','2026-06-15 07:51:11',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-VipMap-c2uc4vsagq2f-NetIpMapValue-punfhouyasj7','state changed','OS::Heat::Value',NULL,56),(139,'6c15384b-1362-4702-ba01-8ce41d6605e6','bd919d6c-b33a-45c5-a706-2a50ec7cfce2','2026-06-15 07:51:11',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-VipMap-c2uc4vsagq2f-NetIpMapValue-punfhouyasj7','state changed','OS::Heat::Value',NULL,56),(140,'109c1faa-829e-4c3c-8dab-c00be32b8921','bd919d6c-b33a-45c5-a706-2a50ec7cfce2','2026-06-15 07:51:11',NULL,'CREATE','COMPLETE','overcloud-VipMap-c2uc4vsagq2f','bd919d6c-b33a-45c5-a706-2a50ec7cfce2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(141,'20e30aa1-573d-444f-aee8-053533aa7cb0','45340f96-99b0-4d2d-996e-3c804cdb2f9c','2026-06-15 07:51:11',NULL,'CREATE','IN_PROGRESS','timesync_chrony','overcloud-NodeTimesyncUserData-jmzhy5m4govo-timesync_chrony-q7blt67tlvmo','state changed','OS::Heat::SoftwareConfig',NULL,57),(142,'640e27d9-1a5f-4e3e-a5ef-65eb35b1f007','45340f96-99b0-4d2d-996e-3c804cdb2f9c','2026-06-15 07:51:11',NULL,'CREATE','COMPLETE','timesync_chrony','fda3e790-dd85-440a-9f4f-58b0ce895da2','state changed','OS::Heat::SoftwareConfig',NULL,57),(143,'5cdb80cf-a240-4889-a061-e09d29269dba','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:12',NULL,'CREATE','IN_PROGRESS','ComputeRoleUserData','overcloud-ComputeRoleUserData-mv4kuh3izzbi','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(144,'bb848c07-7de7-4f0b-b904-a7c1a16a096e','d99f081b-8453-4d20-b60f-2d16687373b3','2026-06-15 07:51:12',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeRoleUserData-mv4kuh3izzbi','d99f081b-8453-4d20-b60f-2d16687373b3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(145,'13b8c972-4df6-4a8c-b5dd-9a7fab766e66','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:12',NULL,'CREATE','COMPLETE','VipMap','bd919d6c-b33a-45c5-a706-2a50ec7cfce2','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,55),(146,'99e0b216-d5ea-4395-adb8-f87a506460ff','d99f081b-8453-4d20-b60f-2d16687373b3','2026-06-15 07:51:12',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ComputeRoleUserData-mv4kuh3izzbi-userdata-hlzgk7kt54en','state changed','OS::Heat::MultipartMime',NULL,NULL),(147,'4668fe12-0b2d-4a29-af43-f52147ad5284','d99f081b-8453-4d20-b60f-2d16687373b3','2026-06-15 07:51:12',NULL,'CREATE','COMPLETE','userdata','834f1bf8-d2aa-4935-aa5c-eaee1e18e66c','state changed','OS::Heat::MultipartMime',NULL,NULL),(148,'4e75e7d3-144a-4728-8a0d-c08dd858746a','45340f96-99b0-4d2d-996e-3c804cdb2f9c','2026-06-15 07:51:12',NULL,'CREATE','IN_PROGRESS','timesync_sync','overcloud-NodeTimesyncUserData-jmzhy5m4govo-timesync_sync-lx4hizuckwyo','state changed','OS::Heat::SoftwareConfig',NULL,59),(149,'6bd65be9-12db-417e-bd82-287803f356ac','d99f081b-8453-4d20-b60f-2d16687373b3','2026-06-15 07:51:12',NULL,'CREATE','COMPLETE','overcloud-ComputeRoleUserData-mv4kuh3izzbi','d99f081b-8453-4d20-b60f-2d16687373b3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(150,'8512381c-a091-4f84-97cd-4b564c99c29b','45340f96-99b0-4d2d-996e-3c804cdb2f9c','2026-06-15 07:51:12',NULL,'CREATE','COMPLETE','timesync_sync','7e42e528-8e7b-4eda-ace4-3fe7eb2d653b','state changed','OS::Heat::SoftwareConfig',NULL,59),(151,'e0c0e4c3-7b3c-4bf7-8550-ef2f932b1695','45340f96-99b0-4d2d-996e-3c804cdb2f9c','2026-06-15 07:51:13',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeTimesyncUserData-jmzhy5m4govo-userdata-uka6seajs2ut','state changed','OS::Heat::MultipartMime',NULL,60),(152,'9bf83b6d-3b3d-4247-b3ea-c1163af91064','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:13',NULL,'CREATE','IN_PROGRESS','VipHosts','overcloud-VipHosts-oclzy7epphlf','state changed','OS::Heat::Value',NULL,61),(153,'0b719dc0-8e7d-4d78-b821-f404c43590a6','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:13',NULL,'CREATE','COMPLETE','VipHosts','overcloud-VipHosts-oclzy7epphlf','state changed','OS::Heat::Value',NULL,61),(154,'9cf88071-2861-426a-ae12-4296beadc339','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:13',NULL,'CREATE','IN_PROGRESS','EndpointMap','overcloud-EndpointMap-k4aqgwakqlau','state changed','OS::TripleO::EndpointMap',NULL,62),(155,'8db678f6-7b14-4d2b-84c9-28f5b6583b37','45340f96-99b0-4d2d-996e-3c804cdb2f9c','2026-06-15 07:51:13',NULL,'CREATE','COMPLETE','userdata','70ab4e93-c8e0-4f27-8969-0d4d2f7e0dee','state changed','OS::Heat::MultipartMime',NULL,60),(156,'f25b04e0-217d-47ec-937d-16ea85d564a9','45340f96-99b0-4d2d-996e-3c804cdb2f9c','2026-06-15 07:51:13',NULL,'CREATE','COMPLETE','overcloud-NodeTimesyncUserData-jmzhy5m4govo','45340f96-99b0-4d2d-996e-3c804cdb2f9c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(157,'ca660a75-d2ea-4261-a581-c87f04e6de45','3f443ea6-cf01-4be1-8239-5cda79da1b0f','2026-06-15 07:51:13',NULL,'CREATE','IN_PROGRESS','overcloud-EndpointMap-k4aqgwakqlau','3f443ea6-cf01-4be1-8239-5cda79da1b0f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(158,'45cfa962-4079-41e0-a3be-fbada5ce9ff3','3f443ea6-cf01-4be1-8239-5cda79da1b0f','2026-06-15 07:51:13',NULL,'CREATE','COMPLETE','overcloud-EndpointMap-k4aqgwakqlau','3f443ea6-cf01-4be1-8239-5cda79da1b0f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(159,'5aa3b6a9-0895-48ab-8ec5-16178fbb4f9c','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:13',NULL,'CREATE','IN_PROGRESS','CloudNames','overcloud-CloudNames-cowrmyx7lngr','state changed','OS::Heat::Value',NULL,65),(160,'5840398d-0968-4144-8b6c-8b91c9d04191','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:13',NULL,'CREATE','COMPLETE','CloudNames','overcloud-CloudNames-cowrmyx7lngr','state changed','OS::Heat::Value',NULL,65),(161,'ab3151e0-d86a-4867-8474-92f9519452ff','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:13',NULL,'CREATE','COMPLETE','ComputeRoleUserData','d99f081b-8453-4d20-b60f-2d16687373b3','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(162,'a9ddf62f-a126-4180-8969-9834f11852f9','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:13',NULL,'CREATE','COMPLETE','NodeTimesyncUserData','45340f96-99b0-4d2d-996e-3c804cdb2f9c','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(163,'ce442fe5-feef-43f1-b158-25c5a3c03d9f','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','BlockStorageUserData','overcloud-BlockStorageUserData-i5ouf4kt7vzo','state changed','OS::Heat::MultipartMime',NULL,68),(164,'7e6a71e4-db69-48b1-88a7-a6afb11c0889','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','ObjectStorageUserData','overcloud-ObjectStorageUserData-d5azobx422pu','state changed','OS::Heat::MultipartMime',NULL,70),(165,'b41af7e2-8043-44cd-9bd2-f548ae02b228','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','CellControllerUserData','overcloud-CellControllerUserData-lyyahwd4xeff','state changed','OS::Heat::MultipartMime',NULL,69),(166,'c6c11a7b-1baf-4cd3-9933-122060af6910','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','NetworkerUserData','overcloud-NetworkerUserData-zcsvccclikbg','state changed','OS::Heat::MultipartMime',NULL,71),(167,'a0539397-a67c-4526-8393-b283654b106d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','ControllerUserData','overcloud-ControllerUserData-hlli4nef7w4b','state changed','OS::Heat::MultipartMime',NULL,72),(168,'70fad39c-8bf8-43dd-b5e5-d844fc375d7e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','ComputeUserData','overcloud-ComputeUserData-od7ro6dh62fx','state changed','OS::Heat::MultipartMime',NULL,73),(169,'1e5e917a-a0fb-431d-9e5c-2380312e440d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','CephStorageUserData','overcloud-CephStorageUserData-eikoyuvy4uj5','state changed','OS::Heat::MultipartMime',NULL,75),(170,'9653ae64-451f-4477-941e-3aca175b9cb2','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','ObjectStorageUserData','a17d11d5-58af-4f69-8184-65a57e59cf40','state changed','OS::Heat::MultipartMime',NULL,70),(171,'8a398ce6-7480-4d26-9151-2f62bf43948f','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','BlockStorageUserData','14582487-bc19-4125-b583-dee1f81edb01','state changed','OS::Heat::MultipartMime',NULL,68),(172,'c089a3bd-aac4-4d75-a0ce-e806ff17108e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','CellControllerUserData','ba19cf1e-3a03-4a21-b29e-c096be95e2b2','state changed','OS::Heat::MultipartMime',NULL,69),(173,'0ede9c64-096c-43b0-b553-d1d0334a86d0','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','EndpointMap','3f443ea6-cf01-4be1-8239-5cda79da1b0f','state changed','OS::TripleO::EndpointMap',NULL,62),(174,'582f8f41-0a1f-45c3-99ee-e8f217827f55','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','ComputeUserData','71990642-319e-497c-b4d1-b147b6ad3a13','state changed','OS::Heat::MultipartMime',NULL,73),(175,'658bd172-108f-4730-ba2a-b1e46f53e6b1','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','CellControllerComputeUserData','overcloud-CellControllerComputeUserData-pdr76xhhuqhl','state changed','OS::Heat::MultipartMime',NULL,76),(176,'0dd840df-ac30-41c3-9d6f-e6ef9d5e6d9a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','NetworkerUserData','138acc5d-826b-4f68-bd84-91baf86a1598','state changed','OS::Heat::MultipartMime',NULL,71),(177,'01395368-15cb-4260-b6ce-085c1a0c3118','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','ControllerUserData','9d952468-6f93-4a55-9785-e9eb782225de','state changed','OS::Heat::MultipartMime',NULL,72),(178,'145d9fe0-2f3d-4e91-876c-cac1a9ab4941','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','CephStorageUserData','0bd476f9-8ac2-42ba-b286-2c8aaa09eed2','state changed','OS::Heat::MultipartMime',NULL,75),(179,'c0e1a42b-fbfe-49a3-b860-1f5e867866b2','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','CellControllerComputeUserData','8b738190-acef-4fb4-83d5-bbd98afd6eec','state changed','OS::Heat::MultipartMime',NULL,76),(180,'9362f7fb-842c-4194-8be7-c67e9bdc4ff6','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','EndpointMapData','overcloud-EndpointMapData-cu6aru2lwxrh','state changed','OS::Heat::Value',NULL,78),(181,'4ce81799-1d5c-42f5-9c76-ad9344c46a94','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','COMPLETE','EndpointMapData','overcloud-EndpointMapData-cu6aru2lwxrh','state changed','OS::Heat::Value',NULL,78),(182,'11891ff2-a9a9-434c-8000-5ba32e8f37be','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChain','overcloud-CellControllerServiceChain-eywspxywvnoq','state changed','OS::TripleO::CellControllerServices',NULL,79),(183,'e07f9968-1fb3-4264-884b-d5e01d34a503','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','ControllerServiceChain','overcloud-ControllerServiceChain-3mxwxvzexbje','state changed','OS::TripleO::ControllerServices',NULL,80),(184,'8c11ca72-d781-449f-b3a5-bccc39cea712','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChain','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il','state changed','OS::TripleO::CellControllerComputeServices',NULL,81),(185,'47feeefe-2abb-4461-a021-5d28244e33f6','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChain','overcloud-CephStorageServiceChain-gf7lcqbgayzg','state changed','OS::TripleO::CephStorageServices',NULL,82),(186,'2ea0c9a4-bd61-4acb-98e0-b66a8f72aaf1','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(187,'c4cb5c32-6ec7-4760-810d-1dcee36fd037','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:14',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-eywspxywvnoq','083d5969-d65f-4f0d-8d36-056facb15a02','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(188,'50b88db0-d6bc-4ffc-b583-08017f264278','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','ComputeServiceChain','overcloud-ComputeServiceChain-ksxcyuw5eues','state changed','OS::TripleO::ComputeServices',NULL,85),(189,'ac2af7f6-a301-475b-9782-8de277580034','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChain','overcloud-BlockStorageServiceChain-6nx6qw4qifzt','state changed','OS::TripleO::BlockStorageServices',NULL,83),(190,'4672338c-d805-4fb8-8c9b-2d2c539db25b','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il','f3891abd-9a78-47e9-902a-d2408b51871f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(191,'fc96697d-a07c-46e5-893d-d2dc852bfb4e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChain','overcloud-NetworkerServiceChain-32fwuham33h5','state changed','OS::TripleO::NetworkerServices',NULL,87),(192,'8b8099d9-ea90-451f-8d30-7bb52f94aefc','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-gf7lcqbgayzg','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(193,'8e330c84-0aa0-49df-9379-9d466128f615','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChain','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26','state changed','OS::TripleO::ObjectStorageServices',NULL,86),(194,'e4bff8ae-a980-43dc-bfeb-b4c261b6c939','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues','a81298ba-a349-4da1-81a9-2679f5c46619','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(195,'ce01920b-31d0-44a9-95ef-8da1ce88ccdc','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-6nx6qw4qifzt','d3ad9fcc-7e7a-49a2-b295-70444233dc08','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(196,'d3109463-97c5-468c-8807-19aa9282e5ae','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-32fwuham33h5','6361a07a-d347-4df1-af2e-fef20d5cad97','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(197,'a18ff8dc-58c7-452a-92a4-5142a7b6d59a','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26','3f53eaef-4b77-4a54-9954-097a13391509','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(198,'86e4300f-7547-4221-a070-b7ac01aeb91b','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn','state changed','OS::Heat::ResourceChain',NULL,88),(199,'14031515-d779-42de-a1f9-b20f3ad34f54','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp','state changed','OS::Heat::ResourceChain',NULL,89),(200,'7302f1a2-e751-47bf-8133-470859f6dfda','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:15',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceChain-qvbqhb3xuc36','state changed','OS::Heat::ResourceChain',NULL,90),(201,'73f79e98-946c-4a22-b250-eecd765a9ec6','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceChain-2skucslflxwj','state changed','OS::Heat::ResourceChain',NULL,91),(202,'05b8a4c2-f91d-43a2-943a-326b1277b022','d53fdba4-42f0-480a-9cd0-f5cffbb12b5a','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceChain-qvbqhb3xuc36','d53fdba4-42f0-480a-9cd0-f5cffbb12b5a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(203,'3f2adc8d-c700-4339-98c7-a9ac41900e9a','d53fdba4-42f0-480a-9cd0-f5cffbb12b5a','2026-06-15 07:51:16',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceChain-qvbqhb3xuc36','d53fdba4-42f0-480a-9cd0-f5cffbb12b5a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(204,'53139f68-8438-4ac4-85fd-c540da2cb321','d8c59edc-8e69-410d-aa52-7789ec69e74f','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceChain-2skucslflxwj','d8c59edc-8e69-410d-aa52-7789ec69e74f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(205,'bf4278be-6c61-4d09-b6fe-d141c70cef48','d8c59edc-8e69-410d-aa52-7789ec69e74f','2026-06-15 07:51:16',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceChain-2skucslflxwj','d8c59edc-8e69-410d-aa52-7789ec69e74f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(206,'92e1ad5f-514a-46dd-9c78-c4ffa3be9459','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceChain-4cwpzdy5dj4v','state changed','OS::Heat::ResourceChain',NULL,92),(207,'07642d34-43a5-493b-b60e-cb1f4dc32988','56ca3f77-1ac7-477f-ba56-1cf9eda6b7c0','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceChain-4cwpzdy5dj4v','56ca3f77-1ac7-477f-ba56-1cf9eda6b7c0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(208,'c7d88370-40fa-4a37-bf7e-66077ea1f0db','56ca3f77-1ac7-477f-ba56-1cf9eda6b7c0','2026-06-15 07:51:16',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceChain-4cwpzdy5dj4v','56ca3f77-1ac7-477f-ba56-1cf9eda6b7c0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(209,'0c2c95ff-7d6c-48aa-9156-243286aa0b94','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceChain-iwe425ikih4q','state changed','OS::Heat::ResourceChain',NULL,93),(210,'93c7f3e8-316e-4b62-af3f-6d67e74113ce','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp','71a179de-ee93-4230-b66f-816668a8b4d7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(211,'54be7a86-d5a9-4c27-bde2-4905f81d4a32','0367adac-f911-427b-934e-d137548c2b06','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceChain-iwe425ikih4q','0367adac-f911-427b-934e-d137548c2b06','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(212,'f7c15c44-f83e-4f2f-8cc7-7b5076127b0b','0367adac-f911-427b-934e-d137548c2b06','2026-06-15 07:51:16',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceChain-iwe425ikih4q','0367adac-f911-427b-934e-d137548c2b06','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(213,'366130b2-99a8-4348-9703-2b972493b431','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceChain-ficmwmpn7zi2','state changed','OS::Heat::ResourceChain',NULL,94),(214,'e827f213-e345-4f45-b467-0c26164bf445','c0bdd42e-641f-4296-969b-bb7295ca5938','2026-06-15 07:51:16',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceChain-ficmwmpn7zi2','c0bdd42e-641f-4296-969b-bb7295ca5938','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(215,'b2cbb9fc-900e-4e52-be76-5d19ba20c90e','c0bdd42e-641f-4296-969b-bb7295ca5938','2026-06-15 07:51:16',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceChain-ficmwmpn7zi2','c0bdd42e-641f-4296-969b-bb7295ca5938','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(216,'6360572f-4b12-494a-bfde-b9cc2202ee9d','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceChain-n7e5rt7fdkx7','state changed','OS::Heat::ResourceChain',NULL,95),(217,'1da46b76-cfef-4d07-b11d-2035b16fb7da','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','1','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-1-un6sgqnvquym','state changed','OS::TripleO::Services::CACerts',NULL,96),(218,'e8fa1147-3416-475d-aae1-d52759188795','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ServiceChain','d53fdba4-42f0-480a-9cd0-f5cffbb12b5a','state changed','OS::Heat::ResourceChain',NULL,90),(219,'f16728ed-345d-4484-907e-fd71e49fa9d6','f85c10f7-7d9a-4202-94db-9e015dd35fdf','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-1-un6sgqnvquym','f85c10f7-7d9a-4202-94db-9e015dd35fdf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(220,'d2f7ff42-6f02-4e6c-8494-c9405f633a46','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ServiceChain','d8c59edc-8e69-410d-aa52-7789ec69e74f','state changed','OS::Heat::ResourceChain',NULL,91),(221,'ff1d810d-4b73-431b-8795-fdf4859ffeb8','f85c10f7-7d9a-4202-94db-9e015dd35fdf','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-1-un6sgqnvquym','f85c10f7-7d9a-4202-94db-9e015dd35fdf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(222,'b178ed6d-5d99-42d6-9f2e-3f7fa9b42dd9','01fdc005-718a-4f21-9e46-18b4a60606d5','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceChain-n7e5rt7fdkx7','01fdc005-718a-4f21-9e46-18b4a60606d5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(223,'fc88d92c-57c5-4016-b73d-734bc0fafef2','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ExternalUpdateTasks-o4gondmfpz3r','state changed','OS::Heat::Value',NULL,97),(224,'de88eec1-e0ef-45a1-aa32-5d3790296f69','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-MonitoringSubscriptionsConfig-wisqlmjm462z','state changed','OS::Heat::Value',NULL,98),(225,'618d63b3-477c-4fae-9a8d-f88dbb949f8e','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PreDeployStepTasks-2kjzymptapro','state changed','OS::Heat::Value',NULL,99),(226,'da746402-f61e-4473-91d4-28c5a484e1d5','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ExternalUpdateTasks-o4gondmfpz3r','state changed','OS::Heat::Value',NULL,97),(227,'bd6140c8-0f31-4403-a55c-4e1459b673ce','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ExternalPostDeployTasks-qwmqqfc6ykyw','state changed','OS::Heat::Value',NULL,100),(228,'2cdecea5-1878-44bc-87f4-67bf6eff9ff8','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-HostFirewallTasks-oqrf34nbewz3','state changed','OS::Heat::Value',NULL,101),(229,'af05c755-d5bf-4ec5-9ebc-be431ceb42e0','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-MonitoringSubscriptionsConfig-wisqlmjm462z','state changed','OS::Heat::Value',NULL,98),(230,'18ad9cd4-1c96-4b69-b958-d9e0abe4ecb4','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-HostFirewallTasks-oqrf34nbewz3','state changed','OS::Heat::Value',NULL,101),(231,'97ada2f7-1ad5-4ab5-8a04-30cfd8f11909','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-DockerConfigScripts-l22i26sgul2o','state changed','OS::Heat::Value',NULL,102),(232,'156c6057-5545-4db8-8903-9059679d21ea','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn','dca2769f-7b59-42dc-a901-0e9fad841673','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(233,'b0060d5e-b7de-4681-a875-b34d814c4e49','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-KeystoneResourcesConfigs-utvp5ohrlsbf','state changed','OS::Heat::Value',NULL,104),(234,'06d1c591-4a9f-436e-81a5-0fd90da2d6bd','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ServiceChain','56ca3f77-1ac7-477f-ba56-1cf9eda6b7c0','state changed','OS::Heat::ResourceChain',NULL,92),(235,'3f05a68a-66ba-4ed5-a173-f4aa00ee77aa','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ExternalPostDeployTasks-qwmqqfc6ykyw','state changed','OS::Heat::Value',NULL,100),(236,'ca28f209-a611-4778-ae50-b41050887112','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-HostFirewallTasks-6hvwe5vpcnjr','state changed','OS::Heat::Value',NULL,103),(237,'f7fe8458-ab86-4f32-a6ce-a0e2695c1237','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-UpgradeTasks-6slwpwyecaxo','state changed','OS::Heat::Value',NULL,105),(238,'b8f51967-4f78-4ed1-a4a8-f2d899e57ae5','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-PuppetStepConfig-5d4zup2yu3lh','state changed','OS::Heat::Value',NULL,106),(239,'6f2620f4-c45c-4280-a40e-ac8e3e873736','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-DockerConfigScripts-l22i26sgul2o','state changed','OS::Heat::Value',NULL,102),(240,'ebe11356-3ea7-4993-9244-015ea081bbdc','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-KeystoneResourcesConfigs-utvp5ohrlsbf','state changed','OS::Heat::Value',NULL,104),(241,'75289f82-09d5-440f-8d06-5128b3d39401','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ExternalDeployTasks-jsd62qy623cw','state changed','OS::Heat::Value',NULL,107),(242,'1fde0fbd-2abe-4cea-a4c8-2d16305c2ae4','01fdc005-718a-4f21-9e46-18b4a60606d5','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceChain-n7e5rt7fdkx7','01fdc005-718a-4f21-9e46-18b4a60606d5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(243,'cbd6b5bc-06ae-4506-af7b-0fbaeb492ca2','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PreDeployStepTasks-2kjzymptapro','state changed','OS::Heat::Value',NULL,99),(244,'0aca7759-de5d-4757-a518-a674732ffb91','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ExternalDeployTasks-jsd62qy623cw','state changed','OS::Heat::Value',NULL,107),(245,'ce3aef88-0f80-4639-8a7e-b278d2197888','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-PuppetStepConfig-5d4zup2yu3lh','state changed','OS::Heat::Value',NULL,106),(246,'3605e355-0fad-4173-b813-2cb165bc8bbf','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-PostUpgradeTasks-vhwbe3t7opiw','state changed','OS::Heat::Value',NULL,108),(247,'9b0a7b63-0b76-4976-b8bd-a14a5a7a0c1f','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-AnsibleGroupVars-uwdgsyutj3jv','state changed','OS::Heat::Value',NULL,110),(248,'cbb23e49-d912-48cd-8bd8-2084a407b89b','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-UpgradeTasks-6slwpwyecaxo','state changed','OS::Heat::Value',NULL,105),(249,'b1a1cca1-4704-4e62-8e0b-8c7fedc05a00','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PuppetStepConfig-bskhfvpzrxuc','state changed','OS::Heat::Value',NULL,111),(250,'f8829112-8271-49a2-83f6-b4bb372ba38f','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-AnsibleGroupVars-uwdgsyutj3jv','state changed','OS::Heat::Value',NULL,110),(251,'f1cb51f5-8292-46c7-a2d2-4dd9831a42bd','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PuppetConfig-s7e4yjevengf','state changed','OS::Heat::Value',NULL,113),(252,'c24e1344-5eff-4d07-bc9a-dfc263c57b60','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PostUpgradeTasks-uhp3eg2ibkra','state changed','OS::Heat::Value',NULL,112),(253,'e227a2ca-9f26-4d26-a1a1-2c490d59132f','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PuppetStepConfig-bskhfvpzrxuc','state changed','OS::Heat::Value',NULL,111),(254,'16e34fac-7dc6-416e-a502-5db4d90475c2','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceNames-qufdpkqlhiiy','state changed','OS::Heat::Value',NULL,114),(255,'ed38afb6-82c0-479c-bea5-b7140ce0fde6','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-PostUpgradeTasks-vhwbe3t7opiw','state changed','OS::Heat::Value',NULL,108),(256,'474c4739-f5d0-4c8d-81fa-9a3cc76ab2c1','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceNames-qufdpkqlhiiy','state changed','OS::Heat::Value',NULL,114),(257,'25b9735e-52c3-4dca-8ed2-750fea495ba6','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-DockerPuppetTasks-mdr4kuv42jhc','state changed','OS::Heat::Value',NULL,115),(258,'a88a2234-22d4-4775-a9e3-65a094031134','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PuppetConfig-s7e4yjevengf','state changed','OS::Heat::Value',NULL,113),(259,'08b05268-4c38-4b79-9feb-8a991a4fe2e9','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ServiceChain','0367adac-f911-427b-934e-d137548c2b06','state changed','OS::Heat::ResourceChain',NULL,93),(260,'21f8b715-9cd6-47f7-bff4-da4cb0ebc4e5','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-KeystoneResourcesConfigs-4v5ziov5reca','state changed','OS::Heat::Value',NULL,117),(261,'365e84e6-85da-4206-8832-fe08eb0c4f51','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PostUpgradeTasks-uhp3eg2ibkra','state changed','OS::Heat::Value',NULL,112),(262,'b84b707a-a554-4a59-899f-18a3a9f7a49b','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-FirewallRules-6dofgqzvdv6i','state changed','OS::Heat::Value',NULL,116),(263,'8401912a-8bfc-47b5-a08d-28efacfac050','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-DockerPuppetTasks-mdr4kuv42jhc','state changed','OS::Heat::Value',NULL,115),(264,'464a879b-0892-4305-9e97-c931bc54c6d4','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ExternalPostDeployTasks-xl23jfgrvdyt','state changed','OS::Heat::Value',NULL,119),(265,'8fca8291-f9c2-4df2-b8fd-93e1c0bebe92','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-UpdateTasks-qk4coygbybrb','state changed','OS::Heat::Value',NULL,120),(266,'062c6ef7-775e-47f2-a39e-721aadca7c85','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PreUpgradeRollingTasks-njdssrigjyyv','state changed','OS::Heat::Value',NULL,118),(267,'ec298730-0201-4eb9-b812-143fbd0cc00d','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-KeystoneResourcesConfigs-4v5ziov5reca','state changed','OS::Heat::Value',NULL,117),(268,'4b4e99e4-9db4-4a80-af1c-ff5ae733b80f','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ExternalPostDeployTasks-xl23jfgrvdyt','state changed','OS::Heat::Value',NULL,119),(269,'144efe72-a42a-4b4b-bb7d-b4e57856ff17','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-HostPrepTasks-chlu5bzcfkse','state changed','OS::Heat::Value',NULL,122),(270,'eda34166-8efd-4341-ae2d-06670c64c26b','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-FirewallRules-6dofgqzvdv6i','state changed','OS::Heat::Value',NULL,116),(271,'02b60dd9-87e5-4198-99e6-394e86b9b988','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PostUpdateTasks-n52kr3ggblyp','state changed','OS::Heat::Value',NULL,121),(272,'b04e8e28-ea39-49a1-94bb-9f9c009c0612','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-UpdateTasks-qk4coygbybrb','state changed','OS::Heat::Value',NULL,120),(273,'858e1d94-2620-44cb-9672-8a1c4ae5d74e','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ExternalUpdateTasks-traa2zyi7fps','state changed','OS::Heat::Value',NULL,123),(274,'e78c455e-95e5-4aef-847b-1ce00ee8c675','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PreUpgradeRollingTasks-njdssrigjyyv','state changed','OS::Heat::Value',NULL,118),(275,'c920d9ff-37fd-4d4c-ad99-0541dbdaee62','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceNames-3lmtmvmuhtju','state changed','OS::Heat::Value',NULL,124),(276,'ddf0b0fd-81aa-4301-b870-46fc0d1a3307','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PostUpdateTasks-wscxluvqyefc','state changed','OS::Heat::Value',NULL,125),(277,'a89b5b86-e550-49c5-873c-1647b75a9455','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-HostPrepTasks-chlu5bzcfkse','state changed','OS::Heat::Value',NULL,122),(278,'2090edee-046e-45fc-b2e2-65c1d51ce8ea','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-GlobalConfigSettings-ddi3xedvdi6d','state changed','OS::Heat::Value',NULL,126),(279,'03617e51-d4fc-4607-91dc-efe754f18496','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ExternalUpdateTasks-traa2zyi7fps','state changed','OS::Heat::Value',NULL,123),(280,'fe109c95-78ae-4877-9165-1e3fef5d7d04','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-UpgradeBatchTasks-lzw46obtt23n','state changed','OS::Heat::Value',NULL,109),(281,'75a6a7b4-97da-43e7-8b37-0718af027a14','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PostUpdateTasks-n52kr3ggblyp','state changed','OS::Heat::Value',NULL,121),(282,'497836b2-c1d9-4818-9d49-e1a3de8dda68','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-PuppetConfig-pvg7irysjzbo','state changed','OS::Heat::Value',NULL,127),(283,'854bd6d3-04ea-4fb6-888c-adb64203cafb','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PostUpdateTasks-wscxluvqyefc','state changed','OS::Heat::Value',NULL,125),(284,'fdab2225-877f-4d66-a040-374116da9d63','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-GlobalConfigSettings-ddi3xedvdi6d','state changed','OS::Heat::Value',NULL,126),(285,'da3a81b9-2078-40aa-a0ff-b3fc8a93afd5','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ScaleTasks-uo7odqwzprez','state changed','OS::Heat::Value',NULL,129),(286,'8b61032c-369d-4d0f-a2e2-d6c9e47cc899','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-UpdateTasks-e6sgtm6wnbao','state changed','OS::Heat::Value',NULL,128),(287,'28e22dc9-e4ac-423a-94ed-0bbbd1669974','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceNames-3lmtmvmuhtju','state changed','OS::Heat::Value',NULL,124),(288,'6f67f028-d77b-4754-9901-fe26d5a5ec1d','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-PuppetConfig-pvg7irysjzbo','state changed','OS::Heat::Value',NULL,127),(289,'42518249-2910-4860-a916-88d8c918f4c8','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-IpaRegistrationTasks-gowyvfit7fjy','state changed','OS::Heat::Value',NULL,132),(290,'bc0fa55a-f414-44e7-ae80-fe38261b3cd7','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ScaleTasks-uo7odqwzprez','state changed','OS::Heat::Value',NULL,129),(291,'bdbfb887-3056-48a1-a4f6-81f3c348035f','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-HostFirewallTasks-6hvwe5vpcnjr','state changed','OS::Heat::Value',NULL,103),(292,'9fb928e4-15dc-4f53-94aa-ba88c1813849','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceConfigSettings-vhwspghk2pad','state changed','OS::Heat::Value',NULL,131),(293,'2b3997ac-846b-4c00-95c8-d913c1bb791a','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ScaleTasks-k5hploif3jgk','state changed','OS::Heat::Value',NULL,133),(294,'e59c9618-1ba5-4a54-8f44-12140065df4a','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-IpaRegistrationTasks-gowyvfit7fjy','state changed','OS::Heat::Value',NULL,132),(295,'7483546a-17be-4330-874c-91e839a63184','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-HostFirewallTasks-4zvqd2khtj65','state changed','OS::Heat::Value',NULL,134),(296,'8de75798-cfa7-458d-b7ed-8178794d2274','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-UpdateTasks-e6sgtm6wnbao','state changed','OS::Heat::Value',NULL,128),(297,'687235c1-671f-49c9-9d45-77afeefa749c','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-DeployStepsTasks-qyh4s4ttr5pg','state changed','OS::Heat::Value',NULL,135),(298,'40a9002b-c3d6-4791-bdf7-f29b3d69ad95','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ContainerPuppetTasks-2pco3hd4xy5c','state changed','OS::Heat::Value',NULL,136),(299,'246ce7e9-ef72-48b3-b541-1b8de0435ccc','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ServiceChain','c0bdd42e-641f-4296-969b-bb7295ca5938','state changed','OS::Heat::ResourceChain',NULL,94),(300,'6b8cf671-9982-4c86-96f9-538297e7c03d','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ScaleTasks-k5hploif3jgk','state changed','OS::Heat::Value',NULL,133),(301,'63fc4b77-8f6c-44cc-8abf-faca490555e3','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-DockerPuppetTasks-cy262oghmt6u','state changed','OS::Heat::Value',NULL,139),(302,'841fda91-dabf-4af1-8708-66f7502e885f','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-HostFirewallTasks-4zvqd2khtj65','state changed','OS::Heat::Value',NULL,134),(303,'f995c18f-3d9e-4486-a6a5-dd93b8436b69','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-FirewallFrontendRules-wtyt72trt4yb','state changed','OS::Heat::Value',NULL,140),(304,'72a3cd79-3ffc-4444-ae41-0785e6d334e5','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceConfigSettings-vhwspghk2pad','state changed','OS::Heat::Value',NULL,131),(305,'61285dda-b95d-4128-829e-2818c0cee6d8','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ExternalUpgradeTasks-yyihrykl3v2c','state changed','OS::Heat::Value',NULL,147),(306,'9ea94968-276b-4c25-8aba-0d42f4318199','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-DockerPuppetTasks-cy262oghmt6u','state changed','OS::Heat::Value',NULL,139),(307,'8eaa24ea-dfb0-48b6-85eb-8e2765a91183','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ContainerPuppetTasks-2pco3hd4xy5c','state changed','OS::Heat::Value',NULL,136),(308,'b19edc79-bc3d-4786-9d04-7b7f916af5fb','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceNames-gew2x2rdrdrg','state changed','OS::Heat::Value',NULL,145),(309,'8cc8dcf1-c17c-4721-bfe2-cf76b452ff41','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceServerMetadataHook-2k53zvk4yv7m','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,144),(310,'99dc6931-227f-4fe7-bb88-0b90d88829f6','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-KollaConfig-csgxdqvkm2zt','state changed','OS::Heat::Value',NULL,130),(311,'07e8168d-67f2-461e-8f19-46784cec10b8','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-GlobalConfigSettings-h5a5nvl6nbw3','state changed','OS::Heat::Value',NULL,143),(312,'10d53536-7699-42a0-834e-cd864c10ea60','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-FirewallFrontendRules-wtyt72trt4yb','state changed','OS::Heat::Value',NULL,140),(313,'c33ea3e8-f739-480f-b714-9819a31d6375','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ExternalUpgradeTasks-yyihrykl3v2c','state changed','OS::Heat::Value',NULL,147),(314,'4358358c-adde-4e68-b7d8-b52b5c6fb965','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-DeployStepsTasks-qyh4s4ttr5pg','state changed','OS::Heat::Value',NULL,135),(315,'2cffa510-8e5f-4527-948b-47a98e705545','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceNames-gew2x2rdrdrg','state changed','OS::Heat::Value',NULL,145),(316,'7f4ad5b2-efda-4b96-b63b-90d397d9540b','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-DockerConfigScripts-modlkzrp7i3i','state changed','OS::Heat::Value',NULL,148),(317,'c9293263-50ce-4daa-89b9-bc8bb418c836','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceServerMetadataHook-jvbr7wozsx7x','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,152),(318,'daff4bb6-19f8-4ef6-8da2-971d18781fc0','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-DockerConfigScripts-modlkzrp7i3i','state changed','OS::Heat::Value',NULL,148),(319,'93fe3180-bbb8-47e9-9c52-aa6fe34b4d97','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PostUpdateTasks-qvd4c74f57tc','state changed','OS::Heat::Value',NULL,149),(320,'d4e65297-fc7e-422e-b64d-6fbd186772b4','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:17',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ScaleTasks-qnvfbbrj7kbo','state changed','OS::Heat::Value',NULL,153),(321,'81e98877-31d8-46b8-805b-792f4d8003ff','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-GlobalConfigSettings-h5a5nvl6nbw3','state changed','OS::Heat::Value',NULL,143),(322,'7c8269db-bda6-4ae6-98d1-bbcf7a2c3158','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PostUpgradeTasks-fyco2wn5hs2v','state changed','OS::Heat::Value',NULL,137),(323,'cc1b47cb-8a03-4966-9f78-7518a37b7ff6','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ContainerPuppetTasks-yl7vevmytt77','state changed','OS::Heat::Value',NULL,138),(324,'60fb2aed-9c3f-45bd-a832-294d679acc4f','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-FirewallRules-3gkd47jm3whc','state changed','OS::Heat::Value',NULL,154),(325,'455c131d-346f-4b56-87d5-59ee62ed7122','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-DeployStepsTasks-nugbpmkdftdi','state changed','OS::Heat::Value',NULL,142),(326,'5e0d0d3d-497a-4830-8d2b-1245e277a1fc','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PreUpgradeRollingTasks-qnpuebf27sgz','state changed','OS::Heat::Value',NULL,146),(327,'9d09d40e-5adf-4388-a01d-6ffed306ed00','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-UpgradeBatchTasks-lzw46obtt23n','state changed','OS::Heat::Value',NULL,109),(328,'874ba8fb-f534-41c5-bcab-d3360c19e07e','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-32fwuham33h5-MonitoringSubscriptionsConfig-72hj5c63rhjk','state changed','OS::Heat::Value',NULL,158),(329,'ecf5eb95-b816-46a4-9000-629c312a0a1e','09d33756-25d5-4359-96a6-bed3e17ee044','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceServerMetadataHook-2k53zvk4yv7m','09d33756-25d5-4359-96a6-bed3e17ee044','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(330,'92a1783f-e8b4-4249-8160-777ba8c4a0c2','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PostUpdateTasks-qvd4c74f57tc','state changed','OS::Heat::Value',NULL,149),(331,'8712f6d0-97eb-4c3f-acbb-8f20883712e9','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-DockerConfig-iocoxd5rjqqi','state changed','OS::Heat::Value',NULL,159),(332,'3df3f515-40cc-4f16-9faf-ee7b7f1fcc50','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-UpgradeTasks-fveazlwqpndh','state changed','OS::Heat::Value',NULL,160),(333,'ae3c1043-d2c1-4180-a369-5c6f78694112','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-MonitoringSubscriptionsConfig-jdgojomhtxtp','state changed','OS::Heat::Value',NULL,150),(334,'490a73ff-020f-409b-9c9d-81334f1dc72b','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ScaleTasks-qnvfbbrj7kbo','state changed','OS::Heat::Value',NULL,153),(335,'1bff0d3d-382a-4489-a7e3-4ff2f2176cb0','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ScaleTasks-2dsrnry7klex','state changed','OS::Heat::Value',NULL,161),(336,'b08dec8a-37a4-4032-84ba-6d84b4255206','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-FirewallRules-5owtqdnekywe','state changed','OS::Heat::Value',NULL,151),(337,'ae06529c-ba6b-4b1c-a44f-1501ef54b40a','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-KollaConfig-pnbok5c6xvnr','state changed','OS::Heat::Value',NULL,164),(338,'f5d1f40f-ee69-4963-a9ed-18d97f0e1f57','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','3','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,162),(339,'b63613d2-399e-4807-b206-f3dc9addb83f','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-32fwuham33h5-MonitoringSubscriptionsConfig-72hj5c63rhjk','state changed','OS::Heat::Value',NULL,158),(340,'9b7a6eba-3362-4651-b280-c757ccc59066','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-FirewallRules-3gkd47jm3whc','state changed','OS::Heat::Value',NULL,154),(341,'1451f6e3-825c-4192-b7c5-4403a944b65e','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-DockerConfig-kjipsuopfajd','state changed','OS::Heat::Value',NULL,156),(342,'89c21efa-3414-41d4-ac74-9e382f7e5fd9','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ExternalPostDeployTasks-snnf2i3teswb','state changed','OS::Heat::Value',NULL,165),(343,'4145eb14-74cb-41cd-a06b-3e227f446d0e','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-AnsibleGroupVars-eq5vwlhqwbdr','state changed','OS::Heat::Value',NULL,157),(344,'6353cf4b-bfd7-4e17-b555-6cf31da9b9e5','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-DockerConfig-iocoxd5rjqqi','state changed','OS::Heat::Value',NULL,159),(345,'6fec10b1-76d7-4047-af4b-3e1220f9fa75','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-IpaRegistrationTasks-p534uwofxzyu','state changed','OS::Heat::Value',NULL,155),(346,'43d2ec83-f286-4882-b863-e3a7f693fa5c','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-UpgradeTasks-fveazlwqpndh','state changed','OS::Heat::Value',NULL,160),(347,'4bd11877-f526-47b0-aed8-b7b8bbd2db33','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceConfigSettings-cd7gu5qrcaes','state changed','OS::Heat::Value',NULL,166),(348,'19ada39f-ad73-4cf0-8012-eb7fda483f79','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-NetworkerServiceChain-32fwuham33h5-KollaConfig-62aygayu3qlp','state changed','OS::Heat::Value',NULL,167),(349,'9dc8cc45-8e8c-4c65-8074-35f0a06faf56','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ScaleTasks-2dsrnry7klex','state changed','OS::Heat::Value',NULL,161),(350,'e2f43d5b-f9f4-44f3-ad60-993a2929402c','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-DeployStepsTasks-g7qtxweqj46e','state changed','OS::Heat::Value',NULL,169),(351,'23aaae39-bbc3-4841-aaa0-f9434ebdc150','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-KollaConfig-pnbok5c6xvnr','state changed','OS::Heat::Value',NULL,164),(352,'c9f06ff6-b38c-463a-893e-6b3d843d83d3','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-KollaConfig-csgxdqvkm2zt','state changed','OS::Heat::Value',NULL,130),(353,'982bd391-6d0d-46e7-93cb-e84124620411','c585bce4-52a4-488c-a7f7-e5093df33263','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceServerMetadataHook-jvbr7wozsx7x','c585bce4-52a4-488c-a7f7-e5093df33263','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(354,'c275443e-6c2e-4d5d-96b4-692ef1ad3ebb','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-DockerPuppetTasks-45gt4ayouoaa','state changed','OS::Heat::Value',NULL,170),(355,'99f42e5b-95ec-456c-bf59-657bc1e1c75d','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ScaleTasks-fbgr6pdzaugg','state changed','OS::Heat::Value',NULL,172),(356,'7129f06a-734a-4084-b3b3-e4e45b0b2c3b','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceServerMetadataHook-d4h4wtmeehju','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,163),(357,'3d4bf881-ac61-4442-8be2-0fdc92cbb161','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceConfigSettings-cd7gu5qrcaes','state changed','OS::Heat::Value',NULL,166),(358,'b883e8da-5e43-4704-b453-4426381dd6e1','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ExternalPostDeployTasks-snnf2i3teswb','state changed','OS::Heat::Value',NULL,165),(359,'bc44648d-ccac-4e58-9efc-491e64baa50b','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','1','f85c10f7-7d9a-4202-94db-9e015dd35fdf','state changed','OS::TripleO::Services::CACerts',NULL,96),(360,'1fea915e-c02f-49e3-a608-ba1e1af5a249','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-NetworkerServiceChain-32fwuham33h5-KollaConfig-62aygayu3qlp','state changed','OS::Heat::Value',NULL,167),(361,'57f4e0c5-573a-46fb-8668-387aafe2d5e0','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PreUpgradeRollingTasks-yz4x6h6vuphl','state changed','OS::Heat::Value',NULL,173),(362,'b22c57e1-700a-4497-a34c-cd94c80bd7d0','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ExternalUpgradeTasks-wbtvwah6kxpu','state changed','OS::Heat::Value',NULL,178),(363,'aa5a7722-f5dd-4d5c-ab42-fd3d7a66767a','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ExternalDeployTasks-x2wkfrprt7qm','state changed','OS::Heat::Value',NULL,175),(364,'a119e59b-2586-42e1-9a21-8a46c7fa92b7','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-DockerPuppetTasks-45gt4ayouoaa','state changed','OS::Heat::Value',NULL,170),(365,'284364b4-e1ba-49a0-b10e-04764a51f56f','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-FirewallFrontendRules-34w2gbeud6ue','state changed','OS::Heat::Value',NULL,174),(366,'3628f22f-a552-4270-b5b4-412191ec5d1f','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ContainerPuppetTasks-wzk2ejdhwoew','state changed','OS::Heat::Value',NULL,181),(367,'77a0700d-c296-4d36-9132-aba871767675','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ScaleTasks-fbgr6pdzaugg','state changed','OS::Heat::Value',NULL,172),(368,'dbd360c6-c4b6-4167-9719-36b63ecd3cc7','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-DeployStepsTasks-g7qtxweqj46e','state changed','OS::Heat::Value',NULL,169),(369,'2690d302-ea6a-47cd-ba9f-a4aeca7e9c20','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-UpgradeBatchTasks-rgreky3nwjdt','state changed','OS::Heat::Value',NULL,179),(370,'020b9649-3be4-429a-9428-0ea607ffe9d0','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-HostFirewallTasks-2atugdyn2mnv','state changed','OS::Heat::Value',NULL,182),(371,'44324529-6a98-45ac-9d6b-4e72061e96e8','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-DockerConfigScripts-avxtqqvringc','state changed','OS::Heat::Value',NULL,168),(372,'2f39a2da-3589-43e3-91cc-e7218f6d05c3','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PostUpgradeTasks-fyco2wn5hs2v','state changed','OS::Heat::Value',NULL,137),(373,'ab8fa434-92e9-4093-b9be-ffacd86c6388','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PreUpgradeRollingTasks-yz4x6h6vuphl','state changed','OS::Heat::Value',NULL,173),(374,'116e34cb-4a17-4594-87d0-af24ca4d54d3','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ExternalUpgradeTasks-wbtvwah6kxpu','state changed','OS::Heat::Value',NULL,178),(375,'3705e93a-04ed-4574-9e27-08901edc8879','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ExternalDeployTasks-x2wkfrprt7qm','state changed','OS::Heat::Value',NULL,175),(376,'2fd86acb-fb7b-4ab4-b8d1-d9f4e09bb898','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ContainerPuppetTasks-yl7vevmytt77','state changed','OS::Heat::Value',NULL,138),(377,'8dbfa195-8c4d-4ad4-b415-353349d6d1ae','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ContainerPuppetTasks-wzk2ejdhwoew','state changed','OS::Heat::Value',NULL,181),(378,'3d595617-117b-4cdc-b4d6-52dc1a5e2bc0','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-NetworkerServiceChain-32fwuham33h5-FirewallRules-zvd72mmug2ys','state changed','OS::Heat::Value',NULL,185),(379,'84b43c67-ee39-4b1c-9012-86c4017241ea','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceServerMetadataHook-u42fnc4s4242','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,184),(380,'d0940507-01fc-42a6-ba09-0cf5666078ac','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-HostFirewallTasks-2atugdyn2mnv','state changed','OS::Heat::Value',NULL,182),(381,'408bb03d-e338-4798-9cca-ef3ed034b8de','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-MonitoringSubscriptionsConfig-iavngsh5v4yp','state changed','OS::Heat::Value',NULL,188),(382,'a09fa12f-65ee-4faa-925c-36f52d05d23d','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-NetworkerServiceChain-32fwuham33h5-UpgradeBatchTasks-4wlehkiayn3g','state changed','OS::Heat::Value',NULL,171),(383,'3cd014bd-97c4-403f-a4f3-926db6eeb4b5','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-KollaConfig-vvhv764p7ca3','state changed','OS::Heat::Value',NULL,186),(384,'1b84f1fd-ad2a-4efd-a07b-457fe3cbb12d','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-FirewallFrontendRules-34w2gbeud6ue','state changed','OS::Heat::Value',NULL,174),(385,'2274e2ec-5e96-421a-8e05-f282bfcad89c','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PuppetStepConfig-mbf57cyorrs6','state changed','OS::Heat::Value',NULL,187),(386,'bd8f1790-01a5-4935-b3d9-51941b562eed','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-MonitoringSubscriptionsConfig-jdgojomhtxtp','state changed','OS::Heat::Value',NULL,150),(387,'28b3416a-3d12-4954-ac80-aa925af54211','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PreDeployStepTasks-62xan26l3g7v','state changed','OS::Heat::Value',NULL,177),(388,'8b8f0484-17dc-47d3-8c8f-a8466fde3abb','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ExternalDeployTasks-omjwqlr3ipbj','state changed','OS::Heat::Value',NULL,176),(389,'fbc3359a-e02d-487a-8a0b-935d7d949f30','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ContainerPuppetTasks-uqzt3sscbr5q','state changed','OS::Heat::Value',NULL,191),(390,'85fb734f-abe1-4c3e-a237-deb96f085e1b','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-NetworkerServiceChain-32fwuham33h5-FirewallRules-zvd72mmug2ys','state changed','OS::Heat::Value',NULL,185),(391,'539a3206-d7df-4624-a936-7921b5c9e7dd','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-MonitoringSubscriptionsConfig-iavngsh5v4yp','state changed','OS::Heat::Value',NULL,188),(392,'7bfb185e-9ec1-4081-8069-85347feaf9be','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-NetworkerServiceChain-32fwuham33h5-DockerConfig-ye6b7pdrki7b','state changed','OS::Heat::Value',NULL,180),(393,'f33e3ca3-696c-495a-b3e1-88820a3a97b4','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-UpgradeBatchTasks-rgreky3nwjdt','state changed','OS::Heat::Value',NULL,179),(394,'a2a02afc-a979-4983-a959-bdc3540c86f1','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-MonitoringSubscriptionsConfig-6xrei3qp6x6f','state changed','OS::Heat::Value',NULL,193),(395,'ffdc953b-5806-4bc3-a40b-47a27f9d7bb4','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-PreUpgradeRollingTasks-qnpuebf27sgz','state changed','OS::Heat::Value',NULL,146),(396,'9baa3772-22a4-445b-a4ea-a29713933f3b','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-KollaConfig-vvhv764p7ca3','state changed','OS::Heat::Value',NULL,186),(397,'0ee2b7df-8f54-47cb-abec-0c163bce999e','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ExternalUpgradeTasks-yx3wl2irayj6','state changed','OS::Heat::Value',NULL,195),(398,'96b175d9-5fa5-4382-bed4-7e1d77dc89df','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-FirewallRules-5owtqdnekywe','state changed','OS::Heat::Value',NULL,151),(399,'aca6c06a-66b3-4b4f-b102-110e4a5a804c','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerServiceChain-eywspxywvnoq-DockerConfigScripts-r4aygxvufkmj','state changed','OS::Heat::Value',NULL,183),(400,'987bd505-80a9-4bea-a5d2-0ab726580246','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ExternalUpdateTasks-4mzmm55qrudq','state changed','OS::Heat::Value',NULL,192),(401,'512797b0-33e8-4d3d-b81f-0ae35b920828','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-DeployStepsTasks-nugbpmkdftdi','state changed','OS::Heat::Value',NULL,142),(402,'9257acf2-3535-43c0-bea6-264603076b63','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-AnsibleGroupVars-eq5vwlhqwbdr','state changed','OS::Heat::Value',NULL,157),(403,'116b188a-9b69-4609-9188-84e9a8cf5fca','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ContainerPuppetTasks-uqzt3sscbr5q','state changed','OS::Heat::Value',NULL,191),(404,'036ee2d0-b007-40ea-a600-97e218865ec0','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ExternalUpdateTasks-wk3hbrxmpy5e','state changed','OS::Heat::Value',NULL,196),(405,'912c0be1-ac0a-4626-9c6c-088f00ff5a40','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-GlobalConfigSettings-hicx5meywyun','state changed','OS::Heat::Value',NULL,198),(406,'56744fda-5959-40fc-b06e-5e558086e6f4','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-IpaRegistrationTasks-p534uwofxzyu','state changed','OS::Heat::Value',NULL,155),(407,'cd4b1294-2971-4fba-b949-8fbdae98fbed','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-DockerConfig-kjipsuopfajd','state changed','OS::Heat::Value',NULL,156),(408,'a3169802-1568-4f59-a56d-0edb36e41f47','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-NetworkerServiceChain-32fwuham33h5-PuppetConfig-cv5f42v3n5t2','state changed','OS::Heat::Value',NULL,189),(409,'db4f6a36-e832-4686-8d4b-db6de0e76339','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PuppetStepConfig-mbf57cyorrs6','state changed','OS::Heat::Value',NULL,187),(410,'9a37c567-16e6-4c9d-bd28-75e01e360200','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-NetworkerServiceChain-32fwuham33h5-FirewallFrontendRules-k5hpfdxodc4y','state changed','OS::Heat::Value',NULL,197),(411,'21badda2-ceca-4e2c-a87d-a7e31b90cbd5','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ExternalUpgradeTasks-yx3wl2irayj6','state changed','OS::Heat::Value',NULL,195),(412,'778aeecf-ab31-48dd-95ac-7a8830a87bbe','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-NetworkerServiceChain-32fwuham33h5-DockerConfigScripts-goetghb4fv32','state changed','OS::Heat::Value',NULL,200),(413,'1e0d9a87-0ea1-4971-aeff-5df1e104a0c8','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ExternalUpdateTasks-4mzmm55qrudq','state changed','OS::Heat::Value',NULL,192),(414,'cae2a12d-f40c-427b-ab33-521cc4155978','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-NetworkerServiceChain-32fwuham33h5-PreDeployStepTasks-o2aahzwpa37z','state changed','OS::Heat::Value',NULL,202),(415,'529efa78-679e-46b9-a9bb-1194b8984a5e','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-UpgradeBatchTasks-6ynjmyjsvt7t','state changed','OS::Heat::Value',NULL,203),(416,'6035ce79-891f-4ef2-add7-bb71d30979ff','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-MonitoringSubscriptionsConfig-6xrei3qp6x6f','state changed','OS::Heat::Value',NULL,193),(417,'5e0d8713-4d2c-425b-900f-3b035b6235d8','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-KollaConfig-4ffv7zbwo7st','state changed','OS::Heat::Value',NULL,201),(418,'57cc0039-2805-4de1-bc52-c3bd29508f8b','a1585c75-4629-4374-bb82-d44119c255d9','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceServerMetadataHook-d4h4wtmeehju','a1585c75-4629-4374-bb82-d44119c255d9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(419,'e9c62c52-f3e0-4869-a87e-712f97537de6','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-GlobalConfigSettings-hicx5meywyun','state changed','OS::Heat::Value',NULL,198),(420,'e1e4ef17-7cd1-4b9e-8150-1a05dcc2daa6','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-KeystoneResourcesConfigs-cwxthwf3isfr','state changed','OS::Heat::Value',NULL,205),(421,'ca2caee4-b455-45a1-9370-c284b220cb52','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-NetworkerServiceChain-32fwuham33h5-FirewallFrontendRules-k5hpfdxodc4y','state changed','OS::Heat::Value',NULL,197),(422,'5061880d-ca06-4d85-9e3c-95f7faa5e8ef','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceServerMetadataHook-u42fnc4s4242','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(423,'3a275748-798a-4785-aaab-196e978bb714','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PuppetConfig-rufghqnlvioz','state changed','OS::Heat::Value',NULL,207),(424,'f17834f4-8c56-48c7-aa64-2684a169b02a','09d33756-25d5-4359-96a6-bed3e17ee044','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceServerMetadataHook-2k53zvk4yv7m-IncomingMetadataSettings-4ygixxvanv2f','state changed','OS::Heat::Value',NULL,208),(425,'b4d90ab5-39b1-4957-84c9-a20bb3a3443a','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-NetworkerServiceChain-32fwuham33h5-DockerConfigScripts-goetghb4fv32','state changed','OS::Heat::Value',NULL,200),(426,'85bb84bb-fd49-4fcb-b76e-e3c1846f4489','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-KollaConfig-4ffv7zbwo7st','state changed','OS::Heat::Value',NULL,201),(427,'54012984-59c2-4e32-a8c4-485e5b7685a2','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ExternalUpdateTasks-wk3hbrxmpy5e','state changed','OS::Heat::Value',NULL,196),(428,'b0efa93b-e93b-4c88-b34c-a0d90a428dea','c585bce4-52a4-488c-a7f7-e5093df33263','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceServerMetadataHook-jvbr7wozsx7x-IncomingMetadataSettings-ikmb7nc4llyk','state changed','OS::Heat::Value',NULL,209),(429,'9777d5fd-20de-489b-9adb-7d7ac4fa2201','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-DockerPuppetTasks-t77xqt6zhkqa','state changed','OS::Heat::Value',NULL,190),(430,'499fb67c-18ff-43f2-99cf-19405c327b83','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-UpgradeTasks-mjcixno7y4qg','state changed','OS::Heat::Value',NULL,206),(431,'9edc94d1-f3c8-4695-942f-21973fb27a21','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PuppetConfig-rufghqnlvioz','state changed','OS::Heat::Value',NULL,207),(432,'dc09f489-58ca-48e4-a4ee-9e9c32011018','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-KeystoneResourcesConfigs-cwxthwf3isfr','state changed','OS::Heat::Value',NULL,205),(433,'882caae3-12a6-40ce-b903-5971fee97327','c585bce4-52a4-488c-a7f7-e5093df33263','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceServerMetadataHook-jvbr7wozsx7x-IncomingMetadataSettings-ikmb7nc4llyk','state changed','OS::Heat::Value',NULL,209),(434,'3859da82-ebe3-4e48-937f-17f46e325d7d','09d33756-25d5-4359-96a6-bed3e17ee044','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceServerMetadataHook-2k53zvk4yv7m-IncomingMetadataSettings-4ygixxvanv2f','state changed','OS::Heat::Value',NULL,208),(435,'ead40a64-9530-48d0-8f54-918fd543da37','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-UpgradeBatchTasks-6ynjmyjsvt7t','state changed','OS::Heat::Value',NULL,203),(436,'39a2e613-a597-43d2-92c5-3956fb741a1b','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-NetworkerServiceChain-32fwuham33h5-HostPrepTasks-eq455xgg7eop','state changed','OS::Heat::Value',NULL,212),(437,'edada46d-f0a9-4045-8af1-5af42c2d3b4c','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-NetworkerServiceChain-32fwuham33h5-PreDeployStepTasks-o2aahzwpa37z','state changed','OS::Heat::Value',NULL,202),(438,'de131eba-fb6b-4db5-960f-d92d996de7ee','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-FirewallFrontendRules-ztis6fghymf5','state changed','OS::Heat::Value',NULL,213),(439,'c4f9837b-173e-4c24-a876-f4e28006fada','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-32fwuham33h5-KeystoneResourcesConfigs-hfdkba5u3g2t','state changed','OS::Heat::Value',NULL,216),(440,'c1e2eda9-5726-4e36-a7ad-6fbbf6af43bb','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-32fwuham33h5-PreUpgradeRollingTasks-j7rjbnarfaco','state changed','OS::Heat::Value',NULL,214),(441,'ff7d4299-e607-4ad8-9e25-5aa2b1f5b192','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-UpgradeTasks-mjcixno7y4qg','state changed','OS::Heat::Value',NULL,206),(442,'fc4fc157-8c0b-42d2-ac7b-3fbdda9e661c','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-NetworkerServiceChain-32fwuham33h5-UpdateTasks-gfnqv5d36plf','state changed','OS::Heat::Value',NULL,218),(443,'a1df4101-0d15-4660-a39b-8abc2e934d30','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-32fwuham33h5-KeystoneResourcesConfigs-hfdkba5u3g2t','state changed','OS::Heat::Value',NULL,216),(444,'48b6014a-ed94-42c5-b94d-e0e1da6a8444','c585bce4-52a4-488c-a7f7-e5093df33263','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceServerMetadataHook-jvbr7wozsx7x-CompactServices-mx2ypbyn3hd7','state changed','OS::Heat::Value',NULL,219),(445,'c3fb8653-c280-4247-9243-4ec1d212b83d','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-NetworkerServiceChain-32fwuham33h5-HostPrepTasks-eq455xgg7eop','state changed','OS::Heat::Value',NULL,212),(446,'d4ffa192-021c-45a2-a6ef-78d780e2730d','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-DockerConfigScripts-avxtqqvringc','state changed','OS::Heat::Value',NULL,168),(447,'8bdb7bd1-4eb7-4ab3-8744-ed30fc4d01c4','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-NetworkerServiceChain-32fwuham33h5-HostFirewallTasks-vhmutxqzozlo','state changed','OS::Heat::Value',NULL,199),(448,'3cc15d90-f8ed-467b-b9e0-2e204a9f8013','09d33756-25d5-4359-96a6-bed3e17ee044','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceServerMetadataHook-2k53zvk4yv7m-CompactServices-jsytb6vtgbln','state changed','OS::Heat::Value',NULL,222),(449,'d6c9b438-79de-44df-9efa-6e89ac5817b1','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-FirewallFrontendRules-ztis6fghymf5','state changed','OS::Heat::Value',NULL,213),(450,'f3b57827-7eb3-48b9-8cb7-f4324833d662','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','5','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-5-67szciqqtyrs','state changed','OS::TripleO::Services::IpaClient',NULL,211),(451,'9292d343-8a84-4862-b0f9-3e26f0f17d77','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-IpaRegistrationTasks-2vvadmaqea62','state changed','OS::Heat::Value',NULL,210),(452,'f083c16b-d184-4df1-bec8-ed35d293a33d','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-32fwuham33h5-PreUpgradeRollingTasks-j7rjbnarfaco','state changed','OS::Heat::Value',NULL,214),(453,'b203a6ac-88a4-4bb3-8f3e-194240f24bb5','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-DockerConfig-llyoziqzb4nh','state changed','OS::Heat::Value',NULL,225),(454,'baa87969-b48c-4457-b17a-2bf70dacd146','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-NetworkerServiceChain-32fwuham33h5-UpgradeTasks-d34iyfqhs5r6','state changed','OS::Heat::Value',NULL,224),(455,'e5419e4f-6868-4dd4-a94e-e9c03bff4c10','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ServiceChain','01fdc005-718a-4f21-9e46-18b4a60606d5','state changed','OS::Heat::ResourceChain',NULL,95),(456,'250b95d6-7e26-48ee-b108-0e8ed587a26f','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-NetworkerServiceChain-32fwuham33h5-UpgradeBatchTasks-4wlehkiayn3g','state changed','OS::Heat::Value',NULL,171),(457,'6afec32b-e6fc-4d53-8ac0-1da00e0dd044','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-PreDeployStepTasks-62xan26l3g7v','state changed','OS::Heat::Value',NULL,177),(458,'9f111f1c-dc43-4c40-ace2-de8d504b6c69','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-NetworkerServiceChain-32fwuham33h5-UpdateTasks-gfnqv5d36plf','state changed','OS::Heat::Value',NULL,218),(459,'dc18c6c1-8e90-4a96-ae43-0de4f933cf40','c585bce4-52a4-488c-a7f7-e5093df33263','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceServerMetadataHook-jvbr7wozsx7x-IndividualServices-plolqagrmths','state changed','OS::Heat::Value',NULL,226),(460,'6e7169c1-5b14-4cf5-932a-e676d92b25b0','c585bce4-52a4-488c-a7f7-e5093df33263','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceServerMetadataHook-jvbr7wozsx7x-CompactServices-mx2ypbyn3hd7','state changed','OS::Heat::Value',NULL,219),(461,'685f8760-3ebf-4138-bb51-fbd4637ab873','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-DockerConfig-ufnqaoqhbyue','state changed','OS::Heat::Value',NULL,227),(462,'49144932-8485-46cb-af09-54efc3f75b29','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-AnsibleGroupVars-5hkks52yqqeo','state changed','OS::Heat::Value',NULL,215),(463,'7c280711-ddb4-4c51-99f6-eac742bdd3e8','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PreDeployStepTasks-7cuwphmh6i5k','state changed','OS::Heat::Value',NULL,229),(464,'624f6e6e-138c-4636-a246-192dfd3dc375','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerServiceChain-eywspxywvnoq-DockerConfig-llyoziqzb4nh','state changed','OS::Heat::Value',NULL,225),(465,'c47b5919-2fcb-43cf-846a-4dabe24b586c','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ExternalDeployTasks-omjwqlr3ipbj','state changed','OS::Heat::Value',NULL,176),(466,'4ecb2f0a-8a45-42ed-958b-b3addfedf705','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ExternalPostDeployTasks-guul6hi436pb','state changed','OS::Heat::Value',NULL,228),(467,'72b6f208-86e7-44b9-a2d8-6508aa757115','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PreDeployStepTasks-7cuwphmh6i5k','state changed','OS::Heat::Value',NULL,229),(468,'dedeead7-4316-40e4-afdb-da6437f2f104','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-NetworkerServiceChain-32fwuham33h5-UpgradeTasks-d34iyfqhs5r6','state changed','OS::Heat::Value',NULL,224),(469,'20652695-20ba-4565-95fc-6335baa02994','09d33756-25d5-4359-96a6-bed3e17ee044','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceServerMetadataHook-2k53zvk4yv7m-CompactServices-jsytb6vtgbln','state changed','OS::Heat::Value',NULL,222),(470,'bf616c48-7918-4123-97e9-cd1b5a7ace72','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-HostPrepTasks-dmgurpu56c3u','state changed','OS::Heat::Value',NULL,231),(471,'07315e8d-0c95-443b-8b15-0bd3cacd223d','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-NetworkerServiceChain-32fwuham33h5-AnsibleGroupVars-lh6zo4iaaat7','state changed','OS::Heat::Value',NULL,230),(472,'9713cc71-b66c-4d07-ac6f-2b41c209d8fb','c585bce4-52a4-488c-a7f7-e5093df33263','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceServerMetadataHook-jvbr7wozsx7x-IndividualServices-plolqagrmths','state changed','OS::Heat::Value',NULL,226),(473,'a450dfa2-71fa-4428-9ba1-f3867e0fb1f4','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-DockerConfig-ufnqaoqhbyue','state changed','OS::Heat::Value',NULL,227),(474,'0d836625-1d42-4276-8752-253155767390','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-HostPrepTasks-3ujjn7x6ca57','state changed','OS::Heat::Value',NULL,217),(475,'5f4c3497-afab-4a3d-8e2d-8f6e17ff15f6','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-32fwuham33h5-ExternalPostDeployTasks-guul6hi436pb','state changed','OS::Heat::Value',NULL,228),(476,'37002f25-2670-4f7d-ae08-9bf480d5218d','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-NetworkerServiceChain-32fwuham33h5-IpaRegistrationTasks-fzu5n7dudrrq','state changed','OS::Heat::Value',NULL,234),(477,'b5d02202-235b-4568-bb72-be2ca76620bc','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-NetworkerServiceChain-32fwuham33h5-PostUpgradeTasks-ftqfdysqwrwh','state changed','OS::Heat::Value',NULL,235),(478,'7d8dc0f1-3d09-430f-8c9d-72e6f7d0f1d9','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:18',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ExternalDeployTasks-q6xfxw7hrbtg','state changed','OS::Heat::Value',NULL,221),(479,'ad931f64-07f0-4898-b275-853afe2b88ca','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerServiceChain-eywspxywvnoq-DockerConfigScripts-r4aygxvufkmj','state changed','OS::Heat::Value',NULL,183),(480,'535c58c3-e0e8-49ec-8233-96c369ee8b9a','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:18',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-NetworkerServiceChain-32fwuham33h5-AnsibleGroupVars-lh6zo4iaaat7','state changed','OS::Heat::Value',NULL,230),(481,'e46a9773-2027-4fa8-9ca7-fb46a901f751','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-HostPrepTasks-dmgurpu56c3u','state changed','OS::Heat::Value',NULL,231),(482,'049d4fa6-fbfc-4597-8f8c-5c00a93fb3a7','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-NetworkerServiceChain-32fwuham33h5-IpaRegistrationTasks-fzu5n7dudrrq','state changed','OS::Heat::Value',NULL,234),(483,'4d5481f9-c002-4250-add1-3cf12906407d','c585bce4-52a4-488c-a7f7-e5093df33263','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceServerMetadataHook-jvbr7wozsx7x','c585bce4-52a4-488c-a7f7-e5093df33263','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(484,'cfb0e290-c187-479b-b59a-25eb158fd3f0','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PuppetStepConfig-x4mjwxsr5p5k','state changed','OS::Heat::Value',NULL,236),(485,'05e7c501-2a14-472d-adb8-a9be0c274a64','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-NetworkerServiceChain-32fwuham33h5-PostUpdateTasks-xchdtpjdw2jc','state changed','OS::Heat::Value',NULL,239),(486,'1082ca55-d659-48f5-8caf-23a37a86689a','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-PreDeployStepTasks-u2slowtvi642','state changed','OS::Heat::Value',NULL,238),(487,'b84bc51b-a438-4a98-a9d2-cfe7b818cd83','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-NetworkerServiceChain-32fwuham33h5-PuppetConfig-cv5f42v3n5t2','state changed','OS::Heat::Value',NULL,189),(488,'bf192719-0d07-49e7-9a25-89328f005d0c','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-NetworkerServiceChain-32fwuham33h5-PostUpgradeTasks-ftqfdysqwrwh','state changed','OS::Heat::Value',NULL,235),(489,'2b028b79-415c-4e86-9a13-b513f1710cde','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-NetworkerServiceChain-32fwuham33h5-DockerPuppetTasks-bweclei3j4pn','state changed','OS::Heat::Value',NULL,244),(490,'e930dd6c-81d5-41bd-a244-1bc8bd712f97','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PuppetConfig-bhfbc23qk4dt','state changed','OS::Heat::Value',NULL,240),(491,'ae557766-7773-4f05-b5e4-ad748ca99e12','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceServerMetadataHook-u42fnc4s4242-IncomingMetadataSettings-zumioatbonhj','state changed','OS::Heat::Value',NULL,242),(492,'7dc70f2f-7c56-4fac-b8fe-5e926e6083f9','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-DockerPuppetTasks-t77xqt6zhkqa','state changed','OS::Heat::Value',NULL,190),(493,'d16aa8d5-7a70-45be-ab4d-76501c6cdc1e','3cc10c45-f05a-405e-aff1-d4eb192115a1','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh','3cc10c45-f05a-405e-aff1-d4eb192115a1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(494,'514ff1f0-252b-4989-bfcf-116593120cc6','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-NetworkerServiceChain-32fwuham33h5-PostUpdateTasks-xchdtpjdw2jc','state changed','OS::Heat::Value',NULL,239),(495,'44276ce2-965c-437e-a3d4-1862297e48d8','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceConfigSettings-jliv2ifxkylj','state changed','OS::Heat::Value',NULL,245),(496,'ee2ca427-d9b8-4f68-811a-6ae164613944','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-NetworkerServiceChain-32fwuham33h5-DockerConfig-ye6b7pdrki7b','state changed','OS::Heat::Value',NULL,180),(497,'ea8b31c4-0839-4e67-abe0-de65e0511b03','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PuppetStepConfig-x4mjwxsr5p5k','state changed','OS::Heat::Value',NULL,236),(498,'b56c1ada-28ce-446b-9e1a-5632e27c6906','a1585c75-4629-4374-bb82-d44119c255d9','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceServerMetadataHook-d4h4wtmeehju-IncomingMetadataSettings-tajddnivjxdg','state changed','OS::Heat::Value',NULL,246),(499,'4d4aa04c-04ea-4cd5-8df1-b899e87dfae1','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PuppetConfig-bhfbc23qk4dt','state changed','OS::Heat::Value',NULL,240),(500,'dcf0f4c6-67d0-480e-9462-6aa508738d92','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-PreDeployStepTasks-u2slowtvi642','state changed','OS::Heat::Value',NULL,238),(501,'556e3391-3951-47a6-8495-9927c8218f92','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ServiceConfigSettings-jliv2ifxkylj','state changed','OS::Heat::Value',NULL,245),(502,'4f11f6b7-6f3d-4545-a340-47a1422e809a','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-NetworkerServiceChain-32fwuham33h5-DockerPuppetTasks-bweclei3j4pn','state changed','OS::Heat::Value',NULL,244),(503,'8b122148-34b7-4b7a-a082-fc3b2a5f07cd','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-NetworkerServiceChain-32fwuham33h5-GlobalConfigSettings-26emg2rnte2k','state changed','OS::Heat::Value',NULL,248),(504,'059f298a-07ca-4d0f-8634-60e81b66c236','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceServerMetadataHook-u42fnc4s4242-IncomingMetadataSettings-zumioatbonhj','state changed','OS::Heat::Value',NULL,242),(505,'783cda51-9933-41d5-be2d-a376bd71dd7e','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-NetworkerServiceChain-32fwuham33h5-PuppetStepConfig-ghsfeh7hm27d','state changed','OS::Heat::Value',NULL,233),(506,'f79d2b84-cf27-488d-a85c-70eaaa1de830','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-UpgradeBatchTasks-pgqbw2lhquvv','state changed','OS::Heat::Value',NULL,232),(507,'f5e2b297-0f27-4f9d-b7b6-531a668b1632','7fb9a6a8-bd36-44b3-8387-0f45d30c73be','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-5-67szciqqtyrs','7fb9a6a8-bd36-44b3-8387-0f45d30c73be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(508,'43455d26-5fff-41bf-b47f-b21309f361bb','a1585c75-4629-4374-bb82-d44119c255d9','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceServerMetadataHook-d4h4wtmeehju-IncomingMetadataSettings-tajddnivjxdg','state changed','OS::Heat::Value',NULL,246),(509,'387c2418-3486-433d-a670-5c0ddf0e2728','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-NetworkerServiceChain-32fwuham33h5-GlobalConfigSettings-26emg2rnte2k','state changed','OS::Heat::Value',NULL,248),(510,'c3d0b3ec-527e-4586-b292-c77a186eb688','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-NetworkerServiceChain-32fwuham33h5-HostFirewallTasks-vhmutxqzozlo','state changed','OS::Heat::Value',NULL,199),(511,'e2ff0049-2986-4a2e-a5d3-93f60a5166ca','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceServerMetadataHook-u42fnc4s4242-CompactServices-3itgelvmy4tz','state changed','OS::Heat::Value',NULL,252),(512,'f201d697-de7f-4fe2-8e5d-81d0c82cf6bc','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-UpdateTasks-yupkmnubb5ne','state changed','OS::Heat::Value',NULL,243),(513,'813cf692-2fed-4a52-9b8f-700ce8cd09ae','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ExternalUpgradeTasks-xjyb5qs2ubpy','state changed','OS::Heat::Value',NULL,237),(514,'d7fb4ad9-4664-4e88-a569-39e95f9c580d','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','CompactServices','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceServerMetadataHook-u42fnc4s4242-CompactServices-3itgelvmy4tz','state changed','OS::Heat::Value',NULL,252),(515,'d07ba496-c0ab-4cc1-b7c6-2bed670af58d','7fb9a6a8-bd36-44b3-8387-0f45d30c73be','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-5-67szciqqtyrs','7fb9a6a8-bd36-44b3-8387-0f45d30c73be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(516,'a2f151ad-64fc-4a2f-ad1c-af108d9290e9','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceServerMetadataHook-u42fnc4s4242-IndividualServices-mshklczwecdn','state changed','OS::Heat::Value',NULL,255),(517,'efc41cef-50bb-4932-8d9f-3fb0e303d8ee','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-IpaRegistrationTasks-2vvadmaqea62','state changed','OS::Heat::Value',NULL,210),(518,'0e928201-0d99-4090-b292-1dbfbf70aff7','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceServerMetadataHook-u42fnc4s4242-IndividualServices-mshklczwecdn','state changed','OS::Heat::Value',NULL,255),(519,'14a3a5d3-196b-4f97-8227-952f40154f13','a1585c75-4629-4374-bb82-d44119c255d9','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceServerMetadataHook-d4h4wtmeehju-CompactServices-uifxzho6mzgm','state changed','OS::Heat::Value',NULL,257),(520,'d18c95e6-3ac4-49c2-a66a-b22f1e50c3e1','a1585c75-4629-4374-bb82-d44119c255d9','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceServerMetadataHook-d4h4wtmeehju-IndividualServices-cy56fbazgem4','state changed','OS::Heat::Value',NULL,258),(521,'9576995f-6b66-4055-9149-f036ff7346f0','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceServerMetadataHook-u42fnc4s4242','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(522,'4a81fa8c-64df-475f-a26e-0ea019a9a772','a1585c75-4629-4374-bb82-d44119c255d9','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','CompactServices','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceServerMetadataHook-d4h4wtmeehju-CompactServices-uifxzho6mzgm','state changed','OS::Heat::Value',NULL,257),(523,'beff5e99-92dc-47b6-8419-0f2591ed7e92','a1585c75-4629-4374-bb82-d44119c255d9','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceServerMetadataHook-d4h4wtmeehju-IndividualServices-cy56fbazgem4','state changed','OS::Heat::Value',NULL,258),(524,'317f513a-4bf8-4684-a30f-7f4860f4bbfd','a1585c75-4629-4374-bb82-d44119c255d9','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ServiceServerMetadataHook-d4h4wtmeehju','a1585c75-4629-4374-bb82-d44119c255d9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(525,'cc20f4df-e72f-420e-ae73-9d766bfb6faa','09d33756-25d5-4359-96a6-bed3e17ee044','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceServerMetadataHook-2k53zvk4yv7m-IndividualServices-buysahbchxzb','state changed','OS::Heat::Value',NULL,250),(526,'66a86941-32a8-4227-85a0-3774af520e72','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceConfigSettings-zegwpd77ynhi','state changed','OS::Heat::Value',NULL,249),(527,'d7111150-bd79-4454-9350-10ec69fdd749','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PostUpgradeTasks-pxbabrp24h7i','state changed','OS::Heat::Value',NULL,251),(528,'5212c9ea-5583-4558-8a32-3e4c2b2432c1','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-HostPrepTasks-3ujjn7x6ca57','state changed','OS::Heat::Value',NULL,217),(529,'ea1f981d-00b9-459d-a7e6-432996005749','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c585bce4-52a4-488c-a7f7-e5093df33263','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,152),(530,'53e8534a-e66a-48ac-94cb-9b8639488c50','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-AnsibleGroupVars-5hkks52yqqeo','state changed','OS::Heat::Value',NULL,215),(531,'409e03f5-22fd-45ef-8ade-613e7e620a41','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceNames-yxn5hi4olz7o','state changed','OS::Heat::Value',NULL,254),(532,'687bac11-2a80-43c3-b7f7-cfc9ad46a5c0','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CephStorageServiceChain-gf7lcqbgayzg-FirewallFrontendRules-6lhnxugykdha','state changed','OS::Heat::Value',NULL,262),(533,'7a971e29-1e6f-416d-9fa5-c37a5694844a','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CephStorageServiceChain-gf7lcqbgayzg-FirewallFrontendRules-6lhnxugykdha','state changed','OS::Heat::Value',NULL,262),(534,'bac72644-85ef-494a-adf2-997d5eb044b1','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-BlockStorageServiceChain-6nx6qw4qifzt-ExternalDeployTasks-q6xfxw7hrbtg','state changed','OS::Heat::Value',NULL,221),(535,'e1eaa7f9-1984-405c-b85e-0aa8600a6b9e','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','0','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-0-hwv33qtaovtu','state changed','OS::TripleO::Services::BootParams',NULL,260),(536,'25b7a5b0-8266-4c9e-ac42-01dffcbefbae','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-NetworkerServiceChain-32fwuham33h5-DeployStepsTasks-5kfp4vfs5wt3','state changed','OS::Heat::Value',NULL,259),(537,'7155cb32-96aa-43f1-b982-9f75ba995d7f','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-UpgradeBatchTasks-pgqbw2lhquvv','state changed','OS::Heat::Value',NULL,232),(538,'93fe0108-c0ff-4ffb-8d17-f3260058948c','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-NetworkerServiceChain-32fwuham33h5-PuppetStepConfig-ghsfeh7hm27d','state changed','OS::Heat::Value',NULL,233),(539,'b9e3b562-4a8b-4edb-aed5-5dc1485e6cf5','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-DeployStepsTasks-nqd5lcbhwamu','state changed','OS::Heat::Value',NULL,261),(540,'3a64025e-26fa-4346-b874-839b4a86397c','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-UpdateTasks-yupkmnubb5ne','state changed','OS::Heat::Value',NULL,243),(541,'fdfa4be8-97e1-4723-90d5-9892df8b8fce','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-ExternalUpgradeTasks-xjyb5qs2ubpy','state changed','OS::Heat::Value',NULL,237),(542,'93d890dd-630c-4b19-a95d-f09adce59f0a','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerServiceChain-eywspxywvnoq-FirewallFrontendRules-t5d4yuwangpf','state changed','OS::Heat::Value',NULL,264),(543,'303948fc-af47-4832-ad24-60dbda4c7936','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ExternalUpgradeTasks-umjjuacx5xq6','state changed','OS::Heat::Value',NULL,265),(544,'e21cacc2-7935-46a4-a3af-66c1995f4bf9','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerServiceChain-eywspxywvnoq-FirewallFrontendRules-t5d4yuwangpf','state changed','OS::Heat::Value',NULL,264),(545,'b7700580-10bc-4f85-81b0-611201add950','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ExternalUpgradeTasks-umjjuacx5xq6','state changed','OS::Heat::Value',NULL,265),(546,'f936c5a5-29ff-41b9-bff0-07741517e757','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','5','7fb9a6a8-bd36-44b3-8387-0f45d30c73be','state changed','OS::TripleO::Services::IpaClient',NULL,211),(547,'ec1989bf-0610-4d38-8de1-b4780e670f65','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceConfigSettings-zegwpd77ynhi','state changed','OS::Heat::Value',NULL,249),(548,'a836fc0f-139d-4c27-a2ec-337503be8647','09d33756-25d5-4359-96a6-bed3e17ee044','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceServerMetadataHook-2k53zvk4yv7m-IndividualServices-buysahbchxzb','state changed','OS::Heat::Value',NULL,250),(549,'454d3fde-5f65-4986-8182-9e51b2e0c708','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il-PostUpgradeTasks-pxbabrp24h7i','state changed','OS::Heat::Value',NULL,251),(550,'b43c7c37-4b88-44db-b11c-f438432b787e','c4d01e48-9e4b-4bec-9a5e-9674ed93923f','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-0-hwv33qtaovtu','c4d01e48-9e4b-4bec-9a5e-9674ed93923f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(551,'8406adc9-138d-42cf-a507-5049fcfec36d','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ExternalUpdateTasks-lryg7vicskh6','state changed','OS::Heat::Value',NULL,263),(552,'cbf0aca6-21ba-41ae-9154-4fc26ab72243','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-UpgradeBatchTasks-wfxhny4eyblj','state changed','OS::Heat::Value',NULL,266),(553,'5fe54617-1573-4e6e-906e-bfca4d98bec5','c4d01e48-9e4b-4bec-9a5e-9674ed93923f','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-0-hwv33qtaovtu-RoleParametersValue-7izfufblyapv','state changed','OS::Heat::Value',NULL,267),(554,'c27aeb4f-c005-4023-ac4a-9e9a8d5a9277','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-NetworkerServiceChain-32fwuham33h5-ServiceNames-yxn5hi4olz7o','state changed','OS::Heat::Value',NULL,254),(555,'e955a041-afbf-49dd-94f0-04b0a253c302','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-UpgradeBatchTasks-wfxhny4eyblj','state changed','OS::Heat::Value',NULL,266),(556,'6c73f703-41e5-45f8-85ee-0c223b7f31fa','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','1c9f0faf-8bd3-44c4-9cda-6bb66e4ab805','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,184),(557,'3de5f2a6-90b3-4b64-ab5c-19dbad9f137b','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-NetworkerServiceChain-32fwuham33h5-DeployStepsTasks-5kfp4vfs5wt3','state changed','OS::Heat::Value',NULL,259),(558,'42d5956c-789c-4697-8faa-1f7123d1da89','c4d01e48-9e4b-4bec-9a5e-9674ed93923f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-0-hwv33qtaovtu-RoleParametersValue-7izfufblyapv','state changed','OS::Heat::Value',NULL,267),(559,'1e51af3e-83e6-4d91-85a6-698e8dbfc959','c4d01e48-9e4b-4bec-9a5e-9674ed93923f','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-0-hwv33qtaovtu','c4d01e48-9e4b-4bec-9a5e-9674ed93923f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(560,'f5757bee-292b-4dc7-9123-c9c0946a4ad3','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-DeployStepsTasks-nqd5lcbhwamu','state changed','OS::Heat::Value',NULL,261),(561,'364d07ff-f86c-4ad4-b0cd-4efdbc00c0a2','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-IpaRegistrationTasks-k4hqsboksuc5','state changed','OS::Heat::Value',NULL,269),(562,'d161270a-f13d-4a38-8ec6-e67ca392be69','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-IpaRegistrationTasks-k4hqsboksuc5','state changed','OS::Heat::Value',NULL,269),(563,'c3066bef-de03-4d4a-bc2f-48d1943ddd57','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ExternalPostDeployTasks-ieqgmfyl6eya','state changed','OS::Heat::Value',NULL,271),(564,'27951629-7e07-4f98-bd2a-e02bda311aa2','09d33756-25d5-4359-96a6-bed3e17ee044','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26-ServiceServerMetadataHook-2k53zvk4yv7m','09d33756-25d5-4359-96a6-bed3e17ee044','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(565,'45521f59-b592-4f91-9208-7345f648d636','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ExternalUpgradeTasks-rpzsqn4lqa6p','state changed','OS::Heat::Value',NULL,268),(566,'81bb996d-d81e-46f0-9bfa-d41fc13f0485','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ExternalUpdateTasks-lryg7vicskh6','state changed','OS::Heat::Value',NULL,263),(567,'5c033162-5ab7-406b-9415-b4ccbd10eaed','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','0','c4d01e48-9e4b-4bec-9a5e-9674ed93923f','state changed','OS::TripleO::Services::BootParams',NULL,260),(568,'d73cce8f-36b7-45f2-88e7-5df065f4efa5','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ExternalPostDeployTasks-ieqgmfyl6eya','state changed','OS::Heat::Value',NULL,271),(569,'57f59727-d86d-41e0-b224-e01688a90b58','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ContainerPuppetTasks-otguwm7szf5g','state changed','OS::Heat::Value',NULL,272),(570,'93474be8-6239-4bcc-a050-6e278dbf7e3e','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PostUpgradeTasks-uqqqkwkmoyxx','state changed','OS::Heat::Value',NULL,273),(571,'13fdd2cb-8bff-4eb4-9fca-666ac69dabf8','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ContainerPuppetTasks-otguwm7szf5g','state changed','OS::Heat::Value',NULL,272),(572,'27019919-2902-444d-bef2-769560912885','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:19',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PostUpgradeTasks-uqqqkwkmoyxx','state changed','OS::Heat::Value',NULL,273),(573,'6410916b-643b-4d6a-8549-67ea2f409fcf','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','2','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-2-wskff3e5mamq','state changed','OS::TripleO::Services::Collectd',NULL,276),(574,'c2037235-be60-4693-a471-000443bf094a','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','9','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-9-b4l5pwiy2doc','state changed','OS::TripleO::Services::MySQLClient',NULL,275),(575,'893948af-218a-4527-a920-1b84f0d3f10c','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','a1585c75-4629-4374-bb82-d44119c255d9','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,163),(576,'ea0a44f3-2e07-461c-a341-8c7c02d23841','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ExternalUpgradeTasks-rpzsqn4lqa6p','state changed','OS::Heat::Value',NULL,268),(577,'0a56fc10-54a2-40aa-a5ad-b23bc6923cc2','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-UpdateTasks-3gcpu4usvili','state changed','OS::Heat::Value',NULL,279),(578,'dfe76f98-d102-4453-a0be-ec693600a708','f3891abd-9a78-47e9-902a-d2408b51871f','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-nkfzoeqis4il','f3891abd-9a78-47e9-902a-d2408b51871f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(579,'424c41f0-3e80-4ce7-ad73-488c3f6ed463','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-UpdateTasks-3gcpu4usvili','state changed','OS::Heat::Value',NULL,279),(580,'587875f1-eabe-4904-98bf-e77e9123ea22','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','09d33756-25d5-4359-96a6-bed3e17ee044','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,144),(581,'1f19672b-f75a-4a67-b96a-cd87eb96073f','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PuppetConfig-54op2ek3js4h','state changed','OS::Heat::Value',NULL,280),(582,'1b1731cc-19ae-41cd-94d3-54e79d362263','3f53eaef-4b77-4a54-9954-097a13391509','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-i7u2gsdxsu26','3f53eaef-4b77-4a54-9954-097a13391509','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(583,'4aa35525-499b-4131-b053-507311e16244','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PuppetConfig-54op2ek3js4h','state changed','OS::Heat::Value',NULL,280),(584,'ae611b50-dcac-4bdb-9909-d2ce106e3fae','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-DeployStepsTasks-a6p7qkhjzotm','state changed','OS::Heat::Value',NULL,278),(585,'c0ade50b-803a-45f9-9b58-37665baae2ac','6dc590f6-f03f-46f8-809d-911e87899eb4','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-9-b4l5pwiy2doc','6dc590f6-f03f-46f8-809d-911e87899eb4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(586,'444f6e01-2108-48fd-93e8-a26e54455322','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','4','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,281),(587,'b64a1812-2584-4527-b1bc-fc1ce06d73e0','6dc590f6-f03f-46f8-809d-911e87899eb4','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-9-b4l5pwiy2doc','6dc590f6-f03f-46f8-809d-911e87899eb4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(588,'8eadb482-701c-44fd-9b85-fad8905f898f','6a31163c-c98a-44a9-bf74-8b02a4b12653','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-2-wskff3e5mamq','6a31163c-c98a-44a9-bf74-8b02a4b12653','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(589,'731c10d3-4a8e-453b-87fc-dc4ec90b1978','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CephStorageServiceChain-gf7lcqbgayzg-AnsibleGroupVars-o5hsr34ybgn6','state changed','OS::Heat::Value',NULL,283),(590,'d420c91b-6ccc-4c61-806c-ff78aad1dcc8','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CephStorageServiceChain-gf7lcqbgayzg-AnsibleGroupVars-o5hsr34ybgn6','state changed','OS::Heat::Value',NULL,283),(591,'0a6fd0fd-8675-4709-8bbc-058c76bbc95a','6a31163c-c98a-44a9-bf74-8b02a4b12653','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-2-wskff3e5mamq-ContainersCommon-wwwnxopxpui3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(592,'c089e410-6bf8-435b-b268-e0f32e42279f','d3ad9fcc-7e7a-49a2-b295-70444233dc08','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-6nx6qw4qifzt','d3ad9fcc-7e7a-49a2-b295-70444233dc08','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(593,'c643cdf0-2511-47c9-b3b5-39a820a6b9cb','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerServiceChain-eywspxywvnoq-FirewallRules-6wc5xnzb5ld4','state changed','OS::Heat::Value',NULL,282),(594,'887f1946-79c8-4d8d-a9c5-625af6fe0740','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-DeployStepsTasks-a6p7qkhjzotm','state changed','OS::Heat::Value',NULL,278),(595,'1dbefd4b-b0d9-46ff-a439-943f556df1b0','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerServiceChain-eywspxywvnoq-AnsibleGroupVars-gzud6w6qwuz6','state changed','OS::Heat::Value',NULL,284),(596,'b70a7312-dec8-464f-b740-77c9388a08c6','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','9','6dc590f6-f03f-46f8-809d-911e87899eb4','state changed','OS::TripleO::Services::MySQLClient',NULL,275),(597,'407401ed-5219-44c4-b1b2-45ce57f77a66','6361a07a-d347-4df1-af2e-fef20d5cad97','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-32fwuham33h5','6361a07a-d347-4df1-af2e-fef20d5cad97','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(598,'0b74b258-c5c9-482b-8802-7ee6d3920f25','4b562423-f371-4db4-bd07-ab3c589b097f','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-2-wskff3e5mamq-ContainersCommon-wwwnxopxpui3','4b562423-f371-4db4-bd07-ab3c589b097f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(599,'0ff1d68a-378c-4c17-a3e1-6531ac9fa602','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerServiceChain-eywspxywvnoq-AnsibleGroupVars-gzud6w6qwuz6','state changed','OS::Heat::Value',NULL,284),(600,'fe5dd9f3-75c2-41e7-b93b-098baddb30c0','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-PostUpdateTasks-aqn6svryl6h7','state changed','OS::Heat::Value',NULL,285),(601,'d66768c8-dffe-41ce-b870-db205b1457ca','4b562423-f371-4db4-bd07-ab3c589b097f','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-2-wskff3e5mamq-ContainersCommon-wwwnxopxpui3','4b562423-f371-4db4-bd07-ab3c589b097f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(602,'484b0b32-83fc-438d-a37b-4a7bc4e50701','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-PostUpdateTasks-aqn6svryl6h7','state changed','OS::Heat::Value',NULL,285),(603,'14a97309-8343-4ecd-84cd-86b8770e1a06','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PreUpgradeRollingTasks-z3ffi6qbjodm','state changed','OS::Heat::Value',NULL,286),(604,'a1e0be5f-14fa-4cf6-b850-d8bb7d40e6e5','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu','a54cd05b-e3c4-4100-be06-26857f315e37','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(605,'11fc9cd7-452e-4353-a694-f4a6a032a678','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerServiceChain-eywspxywvnoq-FirewallRules-6wc5xnzb5ld4','state changed','OS::Heat::Value',NULL,282),(606,'d1d24bce-18cd-4207-8194-31c1b6223421','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','BlockStorageServiceChain','d3ad9fcc-7e7a-49a2-b295-70444233dc08','state changed','OS::TripleO::BlockStorageServices',NULL,83),(607,'ff5fd5eb-2178-4d60-b763-fc11e5502ddd','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-HostPrepTasks-evr3f32d6shc','state changed','OS::Heat::Value',NULL,287),(608,'2317a60f-ea8d-45e3-a22d-fbe5676520c7','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-HostPrepTasks-evr3f32d6shc','state changed','OS::Heat::Value',NULL,287),(609,'fa3aa571-4d0f-47ad-8f70-e6e63a10b624','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ContainerPuppetTasks-ngxgjfe3n5qm','state changed','OS::Heat::Value',NULL,288),(610,'2cce15c2-c00e-40da-9926-cb9762a5db59','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceNames-qvfkp7iqfcn6','state changed','OS::Heat::Value',NULL,291),(611,'d13c38f4-07e8-4986-a426-e368b336b475','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ContainerPuppetTasks-ngxgjfe3n5qm','state changed','OS::Heat::Value',NULL,288),(612,'eaf417dc-f817-458e-9c94-a070b90e3c89','3cc10c45-f05a-405e-aff1-d4eb192115a1','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh-ContainersCommon-5py2vpqzb7s4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(613,'ce789f4a-b4fd-4ef3-8439-735a1210f635','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PreUpgradeRollingTasks-z3ffi6qbjodm','state changed','OS::Heat::Value',NULL,286),(614,'dbcc2801-92ac-475d-8a9e-c2a102b76c66','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceNames-qvfkp7iqfcn6','state changed','OS::Heat::Value',NULL,291),(615,'5feb1ccd-4459-4618-a437-573633e1a678','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-PreUpgradeRollingTasks-htvjweghcopc','state changed','OS::Heat::Value',NULL,290),(616,'5614ad9a-bcf5-47a3-b67b-d6f774136e45','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','13','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,293),(617,'dae72005-02c9-42f1-9264-ac32879f71c8','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ExternalDeployTasks-i2gdl2o7ytqk','state changed','OS::Heat::Value',NULL,294),(618,'6dbe2e81-7e79-441b-a180-045aeeabfe06','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-PreUpgradeRollingTasks-htvjweghcopc','state changed','OS::Heat::Value',NULL,290),(619,'c6161027-49d2-4f2d-9540-9f6924d575bc','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PuppetStepConfig-slxdw2twcsyh','state changed','OS::Heat::Value',NULL,297),(620,'ea45635a-1df4-42ea-b0bd-02be3feb8d7a','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-ExternalDeployTasks-i2gdl2o7ytqk','state changed','OS::Heat::Value',NULL,294),(621,'314f0cec-a0fd-44f7-8e5a-738b031f2937','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PuppetStepConfig-slxdw2twcsyh','state changed','OS::Heat::Value',NULL,297),(622,'26f0c07b-16b6-43f9-887d-c0c6b7aadbed','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerServiceChain-eywspxywvnoq-GlobalConfigSettings-j2vkfwrd24m3','state changed','OS::Heat::Value',NULL,299),(623,'f96f8de3-4697-43d8-bb53-1d1c4d72e4ff','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CephStorageServiceChain-gf7lcqbgayzg-FirewallRules-p5u2qt2sf7gy','state changed','OS::Heat::Value',NULL,295),(624,'72d94637-942d-4c32-bdfa-4077b9b02f02','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(625,'4a2d395f-03ee-4e2f-8d76-49725a16f8d6','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerServiceChain-eywspxywvnoq-GlobalConfigSettings-j2vkfwrd24m3','state changed','OS::Heat::Value',NULL,299),(626,'5db0926a-3bf6-4fc5-85b8-0ade694328cd','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceNames-okoeskyyhhn6','state changed','OS::Heat::Value',NULL,307),(627,'ab41e8d5-003b-4ad1-ba4d-400042685f75','2ff834e4-6ad4-4761-a8d3-adc6fe6168b0','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh-ContainersCommon-5py2vpqzb7s4','2ff834e4-6ad4-4761-a8d3-adc6fe6168b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(628,'f1751931-33f0-4e7b-bd18-af47588572c0','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-UpdateTasks-gsokbkk44w7a','state changed','OS::Heat::Value',NULL,309),(629,'6e782861-28d1-410a-b4bc-c2c6c3ec6a05','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CephStorageServiceChain-gf7lcqbgayzg-FirewallRules-p5u2qt2sf7gy','state changed','OS::Heat::Value',NULL,295),(630,'19684402-1171-4f02-aa0f-d37ddc3336d5','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceNames-okoeskyyhhn6','state changed','OS::Heat::Value',NULL,307),(631,'d991b504-701a-4779-aca0-6c49f5399ecf','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-DockerPuppetTasks-3jbsu4h67ovl','state changed','OS::Heat::Value',NULL,313),(632,'6364da4a-61bd-4485-a675-46b74822be2b','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-UpdateTasks-gsokbkk44w7a','state changed','OS::Heat::Value',NULL,309),(633,'094cfcfb-8c53-47ac-a21f-bee1cb08d9ae','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PreDeployStepTasks-k3ulr3lxkz7k','state changed','OS::Heat::Value',NULL,314),(634,'37eac702-c009-42e0-b8cf-fe586dab3ad1','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-IpaRegistrationTasks-jke42y7ad6zs','state changed','OS::Heat::Value',NULL,311),(635,'fad56266-5a28-4433-93ea-88fc3ff485b0','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-UpgradeTasks-dkn7lqw5es4o','state changed','OS::Heat::Value',NULL,315),(636,'27737f34-c807-451c-b8ce-c9332e80164b','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ExternalPostDeployTasks-ocbjwyjpmbcp','state changed','OS::Heat::Value',NULL,317),(637,'4f65ec6d-7090-482b-92cb-53807984ee9d','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-DockerPuppetTasks-3jbsu4h67ovl','state changed','OS::Heat::Value',NULL,313),(638,'a7803fcb-5ed3-444c-9186-c2c8448c40c5','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ExternalPostDeployTasks-ocbjwyjpmbcp','state changed','OS::Heat::Value',NULL,317),(639,'8991abb5-8905-4e5d-b877-82e1aacca619','2ff834e4-6ad4-4761-a8d3-adc6fe6168b0','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh-ContainersCommon-5py2vpqzb7s4','2ff834e4-6ad4-4761-a8d3-adc6fe6168b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(640,'b8260db5-a9bb-4792-88e7-01c457b995ca','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceConfigSettings-dzzvxkevgvv7','state changed','OS::Heat::Value',NULL,319),(641,'1ce780d7-6866-45a6-8141-bfc33661a92c','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-IpaRegistrationTasks-jke42y7ad6zs','state changed','OS::Heat::Value',NULL,311),(642,'66600f3f-b867-4858-b924-8c7cbbed606a','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerServiceChain-eywspxywvnoq-UpgradeTasks-dkn7lqw5es4o','state changed','OS::Heat::Value',NULL,315),(643,'f47b289b-23b6-459e-84f9-3d516b156a5a','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-UpgradeTasks-xd7mtvqt5wpq','state changed','OS::Heat::Value',NULL,320),(644,'f856f2ca-96d6-4d4c-9ecb-c2a3251e7dbe','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:20',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PreDeployStepTasks-k3ulr3lxkz7k','state changed','OS::Heat::Value',NULL,314),(645,'d5bb4654-1d7c-4127-b80e-d3f95460bb55','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:20',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-eywspxywvnoq-KeystoneResourcesConfigs-4fprjs563ikc','state changed','OS::Heat::Value',NULL,321),(646,'179aafb5-3959-4c65-b303-34965ac2db7c','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceServerMetadataHook-h4egjofwml6y','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,324),(647,'83584580-3a7c-444a-9ebd-79169afb0011','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-UpgradeTasks-xd7mtvqt5wpq','state changed','OS::Heat::Value',NULL,320),(648,'45777a79-6ae4-4086-88fe-3296f7f94265','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceConfigSettings-dzzvxkevgvv7','state changed','OS::Heat::Value',NULL,319),(649,'23ca1efe-408e-4bf1-a7b1-3c930dcc1d18','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-HostPrepTasks-pafx54azswkz','state changed','OS::Heat::Value',NULL,327),(650,'d0a2a967-0226-4271-a245-927e73acb469','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-HostPrepTasks-pafx54azswkz','state changed','OS::Heat::Value',NULL,327),(651,'99c52896-e6ca-4372-830d-4835dbb54b0d','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-eywspxywvnoq-KeystoneResourcesConfigs-4fprjs563ikc','state changed','OS::Heat::Value',NULL,321),(652,'079a733f-aa4d-47b8-a02e-82febc497837','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceConfigSettings-e74mxb6lgllw','state changed','OS::Heat::Value',NULL,330),(653,'3caa934a-19a7-4ad3-9ffb-32b52fafa78d','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ExternalDeployTasks-taz6jisgpdeo','state changed','OS::Heat::Value',NULL,332),(654,'83318183-837a-4d27-935f-4323b00e9cf4','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ExternalDeployTasks-taz6jisgpdeo','state changed','OS::Heat::Value',NULL,332),(655,'f5ec15ae-7fd6-46fc-84a5-f0a90cd64f4e','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn-RoleParametersValue-orgzdnwfpmz7','state changed','OS::Heat::Value',NULL,333),(656,'3dfb2a90-d259-4adb-9938-80870b6fda93','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceConfigSettings-e74mxb6lgllw','state changed','OS::Heat::Value',NULL,330),(657,'8bd18e35-4e88-431f-ae99-c5f4d28e53be','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-KollaConfig-arizrnmee3ew','state changed','OS::Heat::Value',NULL,335),(658,'548e7aac-18bc-4b8d-b607-b4fdec16b65f','78e5276b-49e8-429a-b086-70db48d04637','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceServerMetadataHook-h4egjofwml6y','78e5276b-49e8-429a-b086-70db48d04637','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(659,'b66933bb-3afe-43de-9323-21132b9c63f2','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-KollaConfig-arizrnmee3ew','state changed','OS::Heat::Value',NULL,335),(660,'061cad41-c110-4fe8-8cc2-a905f2260288','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceServerMetadataHook-fli6ldh3x4sm','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,337),(661,'1c8bf713-144b-4539-ac90-5ced66097b61','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn-RoleParametersValue-orgzdnwfpmz7','state changed','OS::Heat::Value',NULL,333),(662,'de5402bd-4163-45aa-8b7c-96245e01ae54','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerServiceBase-hdlocjxmu6t7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,339),(663,'29ea75e9-aae6-4398-88ac-ddba88b1f1fb','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-MonitoringSubscriptionsConfig-ihjreepvj3pr','state changed','OS::Heat::Value',NULL,340),(664,'c4ae65e7-af4b-43e9-9909-591bc212df31','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-MonitoringSubscriptionsConfig-ihjreepvj3pr','state changed','OS::Heat::Value',NULL,340),(665,'0599c56a-7dca-4ae1-9da3-547086de0427','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-HostFirewallTasks-jg4f4tnro4ah','state changed','OS::Heat::Value',NULL,342),(666,'af6cb158-a4b9-48db-b2b1-0f103285040f','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CephStorageServiceChain-gf7lcqbgayzg-GlobalConfigSettings-nkoth6k2ytrp','state changed','OS::Heat::Value',NULL,345),(667,'179b97d2-a411-4afe-adfa-36e70ec4517c','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-HostFirewallTasks-jg4f4tnro4ah','state changed','OS::Heat::Value',NULL,342),(668,'dea7c6ac-b4c3-4349-b718-1cadea8d84d7','5da34e1e-7501-4500-bad0-fa084762ca8d','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerServiceBase-hdlocjxmu6t7','5da34e1e-7501-4500-bad0-fa084762ca8d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(669,'1bd67405-3f7d-491a-a678-a1a6054c6bf3','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChain','f3891abd-9a78-47e9-902a-d2408b51871f','state changed','OS::TripleO::CellControllerComputeServices',NULL,81),(670,'f8f1a46b-63b9-46d6-bf37-c785a4165936','92106d75-4175-4011-9949-63efc5c453bb','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceServerMetadataHook-fli6ldh3x4sm','92106d75-4175-4011-9949-63efc5c453bb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(671,'ce6164fc-95b2-4d55-9c7f-bc976c5dd5c1','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','ObjectStorageServiceChain','3f53eaef-4b77-4a54-9954-097a13391509','state changed','OS::TripleO::ObjectStorageServices',NULL,86),(672,'0404e8b6-d60b-4cf2-8e9b-18edc587e248','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CephStorageServiceChain-gf7lcqbgayzg-DockerConfigScripts-6plvks7gvp5q','state changed','OS::Heat::Value',NULL,348),(673,'7dc0ee35-6cce-471d-bc93-45ab321517f7','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CephStorageServiceChain-gf7lcqbgayzg-GlobalConfigSettings-nkoth6k2ytrp','state changed','OS::Heat::Value',NULL,345),(674,'1ba17981-f8d6-432a-9234-73acd213fea8','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CephStorageServiceChain-gf7lcqbgayzg-DockerConfigScripts-6plvks7gvp5q','state changed','OS::Heat::Value',NULL,348),(675,'c57855a7-d0f8-4532-ad82-7b10c7adf475','5da34e1e-7501-4500-bad0-fa084762ca8d','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerServiceBase-hdlocjxmu6t7','5da34e1e-7501-4500-bad0-fa084762ca8d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(676,'6e149650-1f6a-40ec-9c74-4a5ff3edb85a','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-DockerConfig-oquqswlu3iyu','state changed','OS::Heat::Value',NULL,350),(677,'19b6562e-28ab-413a-81ed-3696def34669','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ScaleTasks-6wy24u7c2ztg','state changed','OS::Heat::Value',NULL,347),(678,'068e3daf-ae4b-4283-a293-cbf3d3555774','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CephStorageServiceChain-gf7lcqbgayzg-DockerConfig-oquqswlu3iyu','state changed','OS::Heat::Value',NULL,350),(679,'e32920be-3297-4bbf-aacb-e3525f2d7cd2','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','CeilometerServiceBase','5da34e1e-7501-4500-bad0-fa084762ca8d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,339),(680,'e6818630-015e-45cb-9cc2-6c354f673886','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-gf7lcqbgayzg-KeystoneResourcesConfigs-g7rralrvg3wh','state changed','OS::Heat::Value',NULL,353),(681,'0bf0aab2-b183-4aa9-9679-b4620e1d4e8a','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-gf7lcqbgayzg-KeystoneResourcesConfigs-g7rralrvg3wh','state changed','OS::Heat::Value',NULL,353),(682,'35246ec4-e414-4fd1-a190-9e0bef4026d4','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PostUpdateTasks-dqngnq2r5txn','state changed','OS::Heat::Value',NULL,360),(683,'c55c5640-a589-45ef-bbc8-3b9f96fc622a','6a31163c-c98a-44a9-bf74-8b02a4b12653','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-2-wskff3e5mamq-RoleParametersValue-7fe7qntozmzc','state changed','OS::Heat::Value',NULL,362),(684,'1a584654-8d8e-4b5b-af82-dc5c908af3d9','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ScaleTasks-6wy24u7c2ztg','state changed','OS::Heat::Value',NULL,347),(685,'345101f8-b51b-425a-8711-1fa69cdb8a34','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-PostUpdateTasks-dqngnq2r5txn','state changed','OS::Heat::Value',NULL,360),(686,'e0682567-7577-4d4a-be1b-17c611c4d19a','6a31163c-c98a-44a9-bf74-8b02a4b12653','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-2-wskff3e5mamq-RoleParametersValue-7fe7qntozmzc','state changed','OS::Heat::Value',NULL,362),(687,'3d90f0de-3f43-4b78-a14b-74bfc89faa5a','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ExternalUpdateTasks-i5bjdlqc7ije','state changed','OS::Heat::Value',NULL,364),(688,'63641dbe-d86d-4780-afe5-a7b6d09b453c','78e5276b-49e8-429a-b086-70db48d04637','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceServerMetadataHook-h4egjofwml6y-IncomingMetadataSettings-gd7ryacii2fo','state changed','OS::Heat::Value',NULL,369),(689,'c9f25b0c-1279-429c-a8eb-1594bd548883','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ExternalUpdateTasks-i5bjdlqc7ije','state changed','OS::Heat::Value',NULL,364),(690,'2771c985-8b97-422c-9dcb-b7193509827b','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','NetworkerServiceChain','6361a07a-d347-4df1-af2e-fef20d5cad97','state changed','OS::TripleO::NetworkerServices',NULL,87),(691,'4a382ae9-1ac2-4f2b-972d-61015099743f','78e5276b-49e8-429a-b086-70db48d04637','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceServerMetadataHook-h4egjofwml6y-IncomingMetadataSettings-gd7ryacii2fo','state changed','OS::Heat::Value',NULL,369),(692,'06b9ccd3-974e-4cbc-8714-54716d913d33','6a31163c-c98a-44a9-bf74-8b02a4b12653','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','ContainersCommon','4b562423-f371-4db4-bd07-ab3c589b097f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(693,'a4b701a9-921c-4394-8af2-2b4bcf16a35d','92106d75-4175-4011-9949-63efc5c453bb','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceServerMetadataHook-fli6ldh3x4sm-IncomingMetadataSettings-hbd6bkbg5gfw','state changed','OS::Heat::Value',NULL,379),(694,'a8010371-1db1-4d37-8a53-dde89a1cd591','78e5276b-49e8-429a-b086-70db48d04637','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceServerMetadataHook-h4egjofwml6y-CompactServices-vtyej2pvc6ey','state changed','OS::Heat::Value',NULL,381),(695,'1311a365-954d-4ca5-b6b8-64befe0f70d0','92106d75-4175-4011-9949-63efc5c453bb','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceServerMetadataHook-fli6ldh3x4sm-IncomingMetadataSettings-hbd6bkbg5gfw','state changed','OS::Heat::Value',NULL,379),(696,'7d773ff9-fa8f-4092-a8fa-b48bb8369d05','78e5276b-49e8-429a-b086-70db48d04637','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceServerMetadataHook-h4egjofwml6y-CompactServices-vtyej2pvc6ey','state changed','OS::Heat::Value',NULL,381),(697,'6eeb1700-7f11-4e15-a9ad-0259fed90698','3cc10c45-f05a-405e-aff1-d4eb192115a1','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh-CeilometerServiceBase-it6ifdr57nee','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,385),(698,'5a01cec1-a0de-473d-ac49-8e9111f4008a','78e5276b-49e8-429a-b086-70db48d04637','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceServerMetadataHook-h4egjofwml6y-IndividualServices-otoho45miqrm','state changed','OS::Heat::Value',NULL,384),(699,'ea5b6ab5-bc77-4196-a2aa-2dbbfee23604','92106d75-4175-4011-9949-63efc5c453bb','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceServerMetadataHook-fli6ldh3x4sm-IndividualServices-cwl2fkvm6oa6','state changed','OS::Heat::Value',NULL,390),(700,'ed0b1108-c563-48f2-9103-888e9ad5ca03','78e5276b-49e8-429a-b086-70db48d04637','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceServerMetadataHook-h4egjofwml6y-IndividualServices-otoho45miqrm','state changed','OS::Heat::Value',NULL,384),(701,'83e9c223-6beb-40db-892c-3a9d0d410750','b2bb5dc9-478a-48dc-aede-11efddf11d70','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh-CeilometerServiceBase-it6ifdr57nee','b2bb5dc9-478a-48dc-aede-11efddf11d70','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(702,'83984f30-7f46-41d4-b9bc-68efe7a02b97','92106d75-4175-4011-9949-63efc5c453bb','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceServerMetadataHook-fli6ldh3x4sm-IndividualServices-cwl2fkvm6oa6','state changed','OS::Heat::Value',NULL,390),(703,'df9b1238-7473-435d-9438-47e0b7aea9fc','b2bb5dc9-478a-48dc-aede-11efddf11d70','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh-CeilometerServiceBase-it6ifdr57nee','b2bb5dc9-478a-48dc-aede-11efddf11d70','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(704,'068ec64b-81cc-4238-a9ff-6dcafb95e539','78e5276b-49e8-429a-b086-70db48d04637','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-eywspxywvnoq-ServiceServerMetadataHook-h4egjofwml6y','78e5276b-49e8-429a-b086-70db48d04637','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(705,'cf75147a-936f-4b8b-8c5f-76764e27d4e6','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-f4iq2wm46w2l','state changed','OS::Heat::Value',NULL,388),(706,'842fccef-7796-416b-b3f7-f3b6955fc846','6a31163c-c98a-44a9-bf74-8b02a4b12653','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-2-wskff3e5mamq','6a31163c-c98a-44a9-bf74-8b02a4b12653','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(707,'a372802e-b6ca-4477-a86b-03109278c6ad','92106d75-4175-4011-9949-63efc5c453bb','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceServerMetadataHook-fli6ldh3x4sm-CompactServices-ufd26fkyj5bf','state changed','OS::Heat::Value',NULL,396),(708,'57632d7b-12f6-45f5-be0d-7890d8e4887d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-f4iq2wm46w2l','state changed','OS::Heat::Value',NULL,388),(709,'aceb18f2-0da8-45d6-8998-85ca22859052','92106d75-4175-4011-9949-63efc5c453bb','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceServerMetadataHook-fli6ldh3x4sm-CompactServices-ufd26fkyj5bf','state changed','OS::Heat::Value',NULL,396),(710,'a3c9c5e4-5136-4307-bf73-2e44e4f6f588','92106d75-4175-4011-9949-63efc5c453bb','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-gf7lcqbgayzg-ServiceServerMetadataHook-fli6ldh3x4sm','92106d75-4175-4011-9949-63efc5c453bb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(711,'b62c9fe9-fd99-46da-9b9c-4daf5e3e7d56','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:21',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-3e4dc47xngzm','state changed','OS::Heat::Value',NULL,452),(712,'e0842899-035f-41c2-b8d5-fd44edd6c642','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-3e4dc47xngzm','state changed','OS::Heat::Value',NULL,452),(713,'8b3a256d-ddd7-47f4-84cd-434e82fbde9b','3cc10c45-f05a-405e-aff1-d4eb192115a1','2026-06-15 07:51:21',NULL,'CREATE','COMPLETE','ContainersCommon','2ff834e4-6ad4-4761-a8d3-adc6fe6168b0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(714,'a45c204e-52a3-4893-be86-18c70635020d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','BlockStorage','overcloud-BlockStorage-ir4mjrhdm4xk','state changed','OS::Heat::ResourceGroup',NULL,476),(715,'7618bc66-3b49-48f0-9818-8e399a4331a1','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-upv7d2drbadw','state changed','OS::Heat::Value',NULL,477),(716,'38506b24-c72d-4324-9574-a6ee4af9dd66','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-upv7d2drbadw','state changed','OS::Heat::Value',NULL,477),(717,'96e0dc2f-d9d0-48e7-ae88-f39e180cda36','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn-ContainersCommon-gs4x67ntessf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(718,'50fc09b3-496d-4e08-98c2-9e70609425a8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-upt6nl35iu7d','state changed','OS::Heat::Value',NULL,481),(719,'669c72df-cda0-489c-bfe8-731dfbe1a23e','1c67e1f7-f87a-4ec2-b123-7a2cf39c96a3','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorage-ir4mjrhdm4xk','1c67e1f7-f87a-4ec2-b123-7a2cf39c96a3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(720,'e846cbec-13a3-4f20-af84-3187b7059495','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-upt6nl35iu7d','state changed','OS::Heat::Value',NULL,481),(721,'2281170b-624b-45e3-a555-98163786c177','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','CeilometerAgentCentralBase','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,483),(722,'4611b26a-f3ac-43cf-9c73-b42fd3a394e9','1c67e1f7-f87a-4ec2-b123-7a2cf39c96a3','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','overcloud-BlockStorage-ir4mjrhdm4xk','1c67e1f7-f87a-4ec2-b123-7a2cf39c96a3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(723,'232bbd16-a338-45c1-afc9-5039e2be289e','200ae4ef-4969-4a5a-963f-e54f7a39028a','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm','200ae4ef-4969-4a5a-963f-e54f7a39028a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(724,'d3f7abd5-0a06-42f1-bd0b-dc4f7b13b2ea','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNames','overcloud-NetworkerServiceNames-shmrelkxig5s','state changed','OS::Heat::Value',NULL,484),(725,'1a6f78cb-cd80-4e8b-9ec2-403454843c88','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','78e5276b-49e8-429a-b086-70db48d04637','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,324),(726,'7f9e8768-a27d-4f51-8fc3-829324fcfa46','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-y6s2orhqnx6b','state changed','OS::Heat::Value',NULL,485),(727,'49a86237-3f16-4e77-b5d1-c9020ff18d23','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','2','6a31163c-c98a-44a9-bf74-8b02a4b12653','state changed','OS::TripleO::Services::Collectd',NULL,276),(728,'b65ba755-297d-4252-9325-91e10a819161','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','NetworkerServiceNames','overcloud-NetworkerServiceNames-shmrelkxig5s','state changed','OS::Heat::Value',NULL,484),(729,'53661604-95e4-4d0c-9e31-5e42fd86e63a','53a36c45-6852-463a-9f85-0428cc7de37f','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn-ContainersCommon-gs4x67ntessf','53a36c45-6852-463a-9f85-0428cc7de37f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(730,'68e67fd9-6aa8-4b7f-8426-c77a495901d2','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','BlockStorage','1c67e1f7-f87a-4ec2-b123-7a2cf39c96a3','state changed','OS::Heat::ResourceGroup',NULL,476),(731,'8ccc7c50-f6ff-411d-a095-3341f784f70b','083d5969-d65f-4f0d-8d36-056facb15a02','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-eywspxywvnoq','083d5969-d65f-4f0d-8d36-056facb15a02','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(732,'5d8972db-3b73-40a8-a706-c013e36bc832','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-y6s2orhqnx6b','state changed','OS::Heat::Value',NULL,485),(733,'c60dee19-1c40-40d7-8566-2620e08c6d76','53a36c45-6852-463a-9f85-0428cc7de37f','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn-ContainersCommon-gs4x67ntessf','53a36c45-6852-463a-9f85-0428cc7de37f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(734,'9dde0938-9061-43af-80c7-d45b02a51bb2','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','ContainersCommon','53a36c45-6852-463a-9f85-0428cc7de37f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(735,'4f3f1cd8-f302-4310-b851-6c7c749dc898','200ae4ef-4969-4a5a-963f-e54f7a39028a','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm-CeilometerServiceBase-qg4ohczgrswp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,487),(736,'d719c5b8-e621-4110-a64d-266621d4f733','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-p3yq57e3rtvu','state changed','OS::Heat::Value',NULL,489),(737,'afae9f0d-39ff-4594-aefe-645029e09eed','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','92106d75-4175-4011-9949-63efc5c453bb','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,337),(738,'9bb4861e-809d-47dc-94fd-4c4c4669a076','c8eb9047-1278-4900-a625-e92273a7c381','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm-CeilometerServiceBase-qg4ohczgrswp','c8eb9047-1278-4900-a625-e92273a7c381','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(739,'66624547-bf31-4d2c-96b5-1bcb712d41e1','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-gf7lcqbgayzg','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(740,'527de2e0-00ef-44ca-9f89-fda914cce119','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-p3yq57e3rtvu','state changed','OS::Heat::Value',NULL,489),(741,'d9bddecf-d309-4086-88f3-b314267ca36b','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','CephStorageServiceChain','5946fb62-4ab4-4fb3-80e6-d569e6a9fe15','state changed','OS::TripleO::CephStorageServices',NULL,82),(742,'f3864427-408c-4a7c-b14d-abc152a37276','3cc10c45-f05a-405e-aff1-d4eb192115a1','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh-RoleParametersValue-gslkpasqyxum','state changed','OS::Heat::Value',NULL,492),(743,'94d5c327-e75a-41c2-bed0-bf25dae8d4e8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-6dkufu6qjg3s','state changed','OS::Heat::Value',NULL,493),(744,'7a2d928a-fa2d-469b-aa1e-6dc9e17b63fc','c8eb9047-1278-4900-a625-e92273a7c381','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm-CeilometerServiceBase-qg4ohczgrswp','c8eb9047-1278-4900-a625-e92273a7c381','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(745,'d3dedb15-b324-4c93-a65c-4dccc13ffc3a','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','6','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-6-77lsp3zgkwaa','state changed','OS::TripleO::Services::Iscsid',NULL,494),(746,'5db2daf0-e8c5-47f3-ac64-3fe156f07196','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','Networker','overcloud-Networker-3e6lmi4nqci2','state changed','OS::Heat::ResourceGroup',NULL,495),(747,'21bd4ee8-fda9-46f8-8d35-ddca5d365bad','3cc10c45-f05a-405e-aff1-d4eb192115a1','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','CeilometerServiceBase','b2bb5dc9-478a-48dc-aede-11efddf11d70','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,385),(748,'a1b672ee-b1c9-4a52-ac19-fd59c9c02d08','3cc10c45-f05a-405e-aff1-d4eb192115a1','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh-RoleParametersValue-gslkpasqyxum','state changed','OS::Heat::Value',NULL,492),(749,'13e54404-d363-443f-94fb-0ed8e8625586','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-w7xcmwndkfxi','state changed','OS::Heat::Value',NULL,499),(750,'ea9483dd-9886-4a46-ad14-d4d227b42fea','3cc10c45-f05a-405e-aff1-d4eb192115a1','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-3-3rc5d4lwezkh','3cc10c45-f05a-405e-aff1-d4eb192115a1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(751,'5d79b92b-21c5-4d8e-bc2e-4246f6d4f40d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-6dkufu6qjg3s','state changed','OS::Heat::Value',NULL,493),(752,'d4693115-6d95-43ad-bc84-0705d848de97','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-w7xcmwndkfxi','state changed','OS::Heat::Value',NULL,499),(753,'9a649d4b-a951-4de9-acf8-7da610e5070f','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','CellControllerCompute','overcloud-CellControllerCompute-3bkincirwd4a','state changed','OS::Heat::ResourceGroup',NULL,503),(754,'f6e520b5-b418-45cc-93d7-d931fac94dfc','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','BlockStorageServers','overcloud-BlockStorageServers-3jkv5cayxz3q','state changed','OS::Heat::Value',NULL,504),(755,'df9b88c6-246d-4823-bc87-ebf9af337dc6','ae7c5e37-452d-4fc1-86d8-f32a6f76d827','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-6-77lsp3zgkwaa','ae7c5e37-452d-4fc1-86d8-f32a6f76d827','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(756,'09f00d9d-d3d1-4bfc-ad69-0c16619a1462','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','BlockStorageServers','overcloud-BlockStorageServers-3jkv5cayxz3q','state changed','OS::Heat::Value',NULL,504),(757,'ce62bc38-c419-40de-916e-cc61e683d7a8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','ObjectStorage','overcloud-ObjectStorage-urs3otfmaf5f','state changed','OS::Heat::ResourceGroup',NULL,514),(758,'2b91419f-2c82-468c-9be1-e0e56944f6fa','ae7c5e37-452d-4fc1-86d8-f32a6f76d827','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-6-77lsp3zgkwaa-ContainersCommon-xzepu236qlbu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(759,'d12754fe-78bb-4b84-8036-243d48cdb329','5b20b499-edf4-45ea-8618-bf60d314084f','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerCompute-3bkincirwd4a','5b20b499-edf4-45ea-8618-bf60d314084f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(760,'5ec3e0e6-0da4-4b5c-a03d-63c594839adb','d7408bf8-e1cc-4d0c-9f3a-001b355ffd57','2026-06-15 07:51:22',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-6-77lsp3zgkwaa-ContainersCommon-xzepu236qlbu','d7408bf8-e1cc-4d0c-9f3a-001b355ffd57','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(761,'4594c63a-e0ec-49c3-a7f2-f9b65d459fcb','5b20b499-edf4-45ea-8618-bf60d314084f','2026-06-15 07:51:22',NULL,'CREATE','COMPLETE','overcloud-CellControllerCompute-3bkincirwd4a','5b20b499-edf4-45ea-8618-bf60d314084f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(762,'f7d4dc69-29c3-4732-a65a-4541449fc986','760500bf-e9c6-4fe2-b8cb-c298e09f36ae','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','overcloud-Networker-3e6lmi4nqci2','760500bf-e9c6-4fe2-b8cb-c298e09f36ae','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(763,'ea459fcf-2620-41ec-9005-702a06f12e6b','d7408bf8-e1cc-4d0c-9f3a-001b355ffd57','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-6-77lsp3zgkwaa-ContainersCommon-xzepu236qlbu','d7408bf8-e1cc-4d0c-9f3a-001b355ffd57','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(764,'2e3982f9-69b6-49fd-8b77-9727ff489b6d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','BlockStorageIpListMap','overcloud-BlockStorageIpListMap-4v6vqdc2dpps','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,516),(765,'06d2f844-6275-4cf6-81a7-2a8bdfe0320d','c5ca2788-55f3-4b42-9d1a-359b25e8782c','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorage-urs3otfmaf5f','c5ca2788-55f3-4b42-9d1a-359b25e8782c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(766,'595b7c20-90f6-4662-b296-f0ca10cd2f90','760500bf-e9c6-4fe2-b8cb-c298e09f36ae','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','overcloud-Networker-3e6lmi4nqci2','760500bf-e9c6-4fe2-b8cb-c298e09f36ae','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(767,'f2be2416-5966-4592-864c-e31bf56d55eb','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','0','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-0-4hlqg7ovpkb7','state changed','OS::TripleO::Services::BootParams',NULL,518),(768,'7aabb1c5-a9fb-4800-8025-56fa64cff247','c5ca2788-55f3-4b42-9d1a-359b25e8782c','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','overcloud-ObjectStorage-urs3otfmaf5f','c5ca2788-55f3-4b42-9d1a-359b25e8782c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(769,'7e0b8a60-6462-4d82-a095-fd805ec072ad','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','ObjectStorage','c5ca2788-55f3-4b42-9d1a-359b25e8782c','state changed','OS::Heat::ResourceGroup',NULL,514),(770,'5b755aa7-7e61-45e1-ac63-8904eba49809','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','SshdBase','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn-SshdBase-vqxy4ewrvzsb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,522),(771,'35f74e5b-14bb-4cd7-b54d-8ad78b9dbb21','4b1b6b60-1249-48c6-9e1d-4da41c50cc3e','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-0-4hlqg7ovpkb7','4b1b6b60-1249-48c6-9e1d-4da41c50cc3e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(772,'5f303c20-8c43-4468-bc4d-d1769a65659b','712f389b-f053-48c9-9e42-a35cf11963f3','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageIpListMap-4v6vqdc2dpps','712f389b-f053-48c9-9e42-a35cf11963f3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(773,'af5f7af7-6613-4d71-b28a-685aff08c3d7','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-RoleParametersValue-hbfb43wmujcs','state changed','OS::Heat::Value',NULL,528),(774,'10f97c80-b2dc-4fa3-b1ff-65fc942a346e','16260d2c-c25f-4350-a8a2-89d73a40751d','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn-SshdBase-vqxy4ewrvzsb','16260d2c-c25f-4350-a8a2-89d73a40751d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(775,'ce6ddc30-9fff-49ea-95e5-086cd663ca33','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-RoleParametersValue-hbfb43wmujcs','state changed','OS::Heat::Value',NULL,528),(776,'8914896f-cd46-4322-b7a2-a400b6f7ba7b','4b1b6b60-1249-48c6-9e1d-4da41c50cc3e','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-0-4hlqg7ovpkb7-RoleParametersValue-df3izom4rkot','state changed','OS::Heat::Value',NULL,535),(777,'eeda4e14-d1ef-4850-8f06-0565426b5d2c','16260d2c-c25f-4350-a8a2-89d73a40751d','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn-SshdBase-vqxy4ewrvzsb','16260d2c-c25f-4350-a8a2-89d73a40751d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(778,'c81a2772-495f-40b8-9076-e442ed4e3a8b','4b1b6b60-1249-48c6-9e1d-4da41c50cc3e','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-0-4hlqg7ovpkb7-RoleParametersValue-df3izom4rkot','state changed','OS::Heat::Value',NULL,535),(779,'d9938b46-f88c-43e1-8f42-9fafee67e89d','4b1b6b60-1249-48c6-9e1d-4da41c50cc3e','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-0-4hlqg7ovpkb7','4b1b6b60-1249-48c6-9e1d-4da41c50cc3e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(780,'86596a8f-ace6-4df9-ab19-1da7e3de3bc2','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','SshdBase','16260d2c-c25f-4350-a8a2-89d73a40751d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,522),(781,'b25c283a-1ac1-4fb3-a4b1-23251cfeb7d3','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-13-ydwv3mj4eyfn','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(782,'df7cfa63-e60b-41eb-a532-111ba0fad07e','712f389b-f053-48c9-9e42-a35cf11963f3','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-BlockStorageIpListMap-4v6vqdc2dpps-EnabledServicesValue-of5ah4464ad4','state changed','OS::Heat::Value',NULL,542),(783,'c1c94566-ef52-42de-80a0-1bb7e9c9c52d','712f389b-f053-48c9-9e42-a35cf11963f3','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-BlockStorageIpListMap-4v6vqdc2dpps-EnabledServicesValue-of5ah4464ad4','state changed','OS::Heat::Value',NULL,542),(784,'7965979d-6644-46ed-9c1d-06f79f3c173b','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','3','3cc10c45-f05a-405e-aff1-d4eb192115a1','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,162),(785,'75ee6d32-afd0-4c89-b18f-81a748ac33c9','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-25mgsps4ltkd','state changed','OS::Heat::Value',NULL,544),(786,'0ee83517-009e-4e6c-a873-e0656c7b6955','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-25mgsps4ltkd','state changed','OS::Heat::Value',NULL,544),(787,'d5fe9232-442f-43d3-8479-b4dfc9ccaf6f','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','CellControllerServiceChain','083d5969-d65f-4f0d-8d36-056facb15a02','state changed','OS::TripleO::CellControllerServices',NULL,79),(788,'d750dbf5-f467-4f27-94aa-bb88a560b5e4','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','ObjectStorageServers','overcloud-ObjectStorageServers-hp2kohaqqw5j','state changed','OS::Heat::Value',NULL,548),(789,'7e54391c-daad-4459-82c7-9361395644d3','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','ObjectStorageServers','overcloud-ObjectStorageServers-hp2kohaqqw5j','state changed','OS::Heat::Value',NULL,548),(790,'adf8a5bd-df01-4635-82fa-332bf53f01e8','200ae4ef-4969-4a5a-963f-e54f7a39028a','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm-RoleParametersValue-3hh7llbcwwps','state changed','OS::Heat::Value',NULL,553),(791,'4d5030e6-c534-4008-be0b-131bbc12f6d1','200ae4ef-4969-4a5a-963f-e54f7a39028a','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm-RoleParametersValue-3hh7llbcwwps','state changed','OS::Heat::Value',NULL,553),(792,'a02d4bad-9a1d-40a8-9ebd-e38660bfc209','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','ObjectStorageIpListMap','overcloud-ObjectStorageIpListMap-tnz4nhne5d4h','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,558),(793,'55c87b05-bc9d-482f-8d2f-f09ac4b8fa0c','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','7','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-7-4xikp2dnhy6j','state changed','OS::TripleO::Services::Kernel',NULL,561),(794,'6e3f2f8e-e8a9-4ca3-95ff-5258ca0f183f','200ae4ef-4969-4a5a-963f-e54f7a39028a','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','CeilometerServiceBase','c8eb9047-1278-4900-a625-e92273a7c381','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,487),(795,'b5025777-a4c1-4910-b356-f7d0bdd01fc3','8704e290-4231-47e9-a00d-a1f0e7aa106f','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageIpListMap-tnz4nhne5d4h','8704e290-4231-47e9-a00d-a1f0e7aa106f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(796,'99ce860b-d92b-425e-b0a8-69e9a0d5b78c','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-y2nlpeasrlaq','state changed','OS::Heat::Value',NULL,569),(797,'297510b1-85bc-4cb8-bff0-6c78ae93e800','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-y2nlpeasrlaq','state changed','OS::Heat::Value',NULL,569),(798,'f0fd403b-ff71-4512-8e38-d558e21a874b','c42149a1-920c-4720-a75b-71d3711848e1','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-7-4xikp2dnhy6j','c42149a1-920c-4720-a75b-71d3711848e1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(799,'ae95e710-cceb-4318-9700-2c7b7171acfb','8704e290-4231-47e9-a00d-a1f0e7aa106f','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ObjectStorageIpListMap-tnz4nhne5d4h-NetIpMapValue-4ah5zlgo3q7s','state changed','OS::Heat::Value',NULL,570),(800,'d8a50df9-4f57-4f7a-a627-f207c066965e','c42149a1-920c-4720-a75b-71d3711848e1','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-7-4xikp2dnhy6j-RoleParametersValue-tvkpydywszfo','state changed','OS::Heat::Value',NULL,573),(801,'d5183579-456f-4a1b-a9ac-1b7e3909c90a','8704e290-4231-47e9-a00d-a1f0e7aa106f','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ObjectStorageIpListMap-tnz4nhne5d4h-NetIpMapValue-4ah5zlgo3q7s','state changed','OS::Heat::Value',NULL,570),(802,'5d1583e9-4ed2-4ae2-ac87-619c3cc10e99','c42149a1-920c-4720-a75b-71d3711848e1','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-7-4xikp2dnhy6j-RoleParametersValue-tvkpydywszfo','state changed','OS::Heat::Value',NULL,573),(803,'58f7d006-49bc-400d-9b48-e4e1fe86d6fe','c42149a1-920c-4720-a75b-71d3711848e1','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-7-4xikp2dnhy6j','c42149a1-920c-4720-a75b-71d3711848e1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(804,'0eb302ba-a8e5-4662-9ab3-0f957f76a9ee','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','13','a0cb0e3f-401d-40c3-88e4-3680241c3dbc','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,293),(805,'e226bd9e-fe9e-4fec-b3af-91dbf9356bd1','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNames','overcloud-CephStorageServiceNames-j2vd6cw23yut','state changed','OS::Heat::Value',NULL,575),(806,'207c9eaf-c095-4a7c-b31a-67f4561b2f2d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','CephStorageServiceNames','overcloud-CephStorageServiceNames-j2vd6cw23yut','state changed','OS::Heat::Value',NULL,575),(807,'8476ea66-ebbc-45f1-9619-040b94e48eab','ae7c5e37-452d-4fc1-86d8-f32a6f76d827','2026-06-15 07:51:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-6-77lsp3zgkwaa-RoleParametersValue-qw6s4iygvwfl','state changed','OS::Heat::Value',NULL,581),(808,'93ba2599-893a-488b-be9a-0bbdcf8b4421','ae7c5e37-452d-4fc1-86d8-f32a6f76d827','2026-06-15 07:51:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-6-77lsp3zgkwaa-RoleParametersValue-qw6s4iygvwfl','state changed','OS::Heat::Value',NULL,581),(809,'963dcdb7-80bf-475b-ab14-4cea35184d9d','ae7c5e37-452d-4fc1-86d8-f32a6f76d827','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','ContainersCommon','d7408bf8-e1cc-4d0c-9f3a-001b355ffd57','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(810,'a3e0089d-ab39-481e-bc64-8a5b679c88b8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','Networker','760500bf-e9c6-4fe2-b8cb-c298e09f36ae','state changed','OS::Heat::ResourceGroup',NULL,495),(811,'8b6d610d-6572-4828-abf8-d2a5718fbb4b','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','CellControllerCompute','5b20b499-edf4-45ea-8618-bf60d314084f','state changed','OS::Heat::ResourceGroup',NULL,503),(812,'07440750-53a7-4b35-9377-927d7b9c0884','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','2','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,585),(813,'88fa77d0-d28b-432c-b48e-84d5eb747177','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','CephStorage','overcloud-CephStorage-z3422il4sh5y','state changed','OS::Heat::ResourceGroup',NULL,586),(814,'de615238-283f-4563-9c9a-5d3dc2fd9e34','ae7c5e37-452d-4fc1-86d8-f32a6f76d827','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-6-77lsp3zgkwaa','ae7c5e37-452d-4fc1-86d8-f32a6f76d827','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(815,'cd9e7630-adca-4a92-865c-4efd281670a3','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-ContainersCommon-xp2nx57ipw5q','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(816,'1633ca01-a926-4e30-8dbd-58f3f5c9e3a0','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(817,'a057ed7c-d718-43a7-8755-423e40371f9f','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','0','4b1b6b60-1249-48c6-9e1d-4da41c50cc3e','state changed','OS::TripleO::Services::BootParams',NULL,518),(818,'ae326ed3-599a-4668-9212-00b2e15f81a3','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','17','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-17-vv24iex5vab5','state changed','OS::TripleO::Services::Snmp',NULL,591),(819,'3e5331f0-a687-456a-ada3-f6a75359365f','b00be456-1f12-4aa2-9f39-dcabba14e91c','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-17-vv24iex5vab5','b00be456-1f12-4aa2-9f39-dcabba14e91c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(820,'1d25c197-1c18-42fa-a80a-e206b13bf566','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-yf5u4nqh4ovk','state changed','OS::Heat::Value',NULL,594),(821,'2f881dff-31fd-44a1-b78c-6bf5998bd4eb','b00be456-1f12-4aa2-9f39-dcabba14e91c','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-17-vv24iex5vab5','b00be456-1f12-4aa2-9f39-dcabba14e91c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(822,'9ad23a2a-6bf1-47f6-99df-bd1b1ff755e8','5a719a5a-c2ce-4286-9156-c98ef2ad40a0','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-ContainersCommon-xp2nx57ipw5q','5a719a5a-c2ce-4286-9156-c98ef2ad40a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(823,'660c2aa9-e966-4ae2-99a7-6b593c196cc4','ef5546ee-cc88-4a34-8955-79224e310b43','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorage-z3422il4sh5y','ef5546ee-cc88-4a34-8955-79224e310b43','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(824,'d3c33113-8a0f-49af-b3c8-db13c7c10292','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-yf5u4nqh4ovk','state changed','OS::Heat::Value',NULL,594),(825,'65b2b5fb-ca26-41fa-b3f8-d39095774dd3','712f389b-f053-48c9-9e42-a35cf11963f3','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-BlockStorageIpListMap-4v6vqdc2dpps-NetIpMapValue-ssfdxa4xedgu','state changed','OS::Heat::Value',NULL,597),(826,'b046f47f-ee5a-4716-8550-c74c79b42cda','ef5546ee-cc88-4a34-8955-79224e310b43','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','overcloud-CephStorage-z3422il4sh5y','ef5546ee-cc88-4a34-8955-79224e310b43','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(827,'c9b60280-362c-4c97-b1f7-e12e825e03f9','712f389b-f053-48c9-9e42-a35cf11963f3','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-BlockStorageIpListMap-4v6vqdc2dpps-NetIpMapValue-ssfdxa4xedgu','state changed','OS::Heat::Value',NULL,597),(828,'1f4b19d3-4478-40a0-9e9e-575fe32f83e9','712f389b-f053-48c9-9e42-a35cf11963f3','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','overcloud-BlockStorageIpListMap-4v6vqdc2dpps','712f389b-f053-48c9-9e42-a35cf11963f3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(829,'93610069-f219-4f2b-a9ec-9154b17a56eb','5a719a5a-c2ce-4286-9156-c98ef2ad40a0','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-ContainersCommon-xp2nx57ipw5q','5a719a5a-c2ce-4286-9156-c98ef2ad40a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(830,'2084c414-88ff-415c-b7ce-3241df1c0b9d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServers','overcloud-CellControllerComputeServers-i7carthqe5h2','state changed','OS::Heat::Value',NULL,610),(831,'e2bb263f-a8e3-486d-9ef1-483fbb5ddc40','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','NetworkerServers','overcloud-NetworkerServers-zwshudewhp26','state changed','OS::Heat::Value',NULL,611),(832,'2440ca7c-eaa0-45b5-aec0-d54e49f5fe83','200ae4ef-4969-4a5a-963f-e54f7a39028a','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm-ContainersCommon-z5db37qq7w7y','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(833,'822dd9e6-28ee-48b5-9710-afbde823236f','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi-ContainersCommon-bzpigdshpsru','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(834,'c1bbe9c6-72c6-4d5b-a6d6-7b2d7e7df7a1','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','CellControllerComputeServers','overcloud-CellControllerComputeServers-i7carthqe5h2','state changed','OS::Heat::Value',NULL,610),(835,'c8c614fd-08fa-4979-a819-dd9f917e3d9f','3e8f85d5-e92d-4b06-9b8d-7ed5eb7d084d','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm-ContainersCommon-z5db37qq7w7y','3e8f85d5-e92d-4b06-9b8d-7ed5eb7d084d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(836,'502c61ab-55cc-4e4c-a372-0d3eca09f502','3e8f85d5-e92d-4b06-9b8d-7ed5eb7d084d','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm-ContainersCommon-z5db37qq7w7y','3e8f85d5-e92d-4b06-9b8d-7ed5eb7d084d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(837,'cf5c1b0b-8277-4db0-82cf-8cd6afb26a75','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','CellControllerComputeIpListMap','overcloud-CellControllerComputeIpListMap-rkg7hplgaxxx','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,618),(838,'513ee706-696d-4aee-8844-728527ccdf39','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','4','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb','state changed','OS::TripleO::Services::CinderApi',NULL,617),(839,'6219689d-cc27-49a8-bcef-2d995efa7f52','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','NetworkerServers','overcloud-NetworkerServers-zwshudewhp26','state changed','OS::Heat::Value',NULL,611),(840,'9ab137c5-f5af-47c9-bffa-ab2b53407673','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-fgu4ycgcedon','state changed','OS::Heat::Value',NULL,619),(841,'6cb68da7-8f52-4d27-81f3-735dc2971974','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-fgu4ycgcedon','state changed','OS::Heat::Value',NULL,619),(842,'d27d52b7-0e56-41d3-ae9f-92d8e89679b4','71c35bae-c34e-43ff-b4fa-429e9f3b9e65','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi-ContainersCommon-bzpigdshpsru','71c35bae-c34e-43ff-b4fa-429e9f3b9e65','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(843,'1c99334e-9604-440d-8105-06724d697356','71c35bae-c34e-43ff-b4fa-429e9f3b9e65','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi-ContainersCommon-bzpigdshpsru','71c35bae-c34e-43ff-b4fa-429e9f3b9e65','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(844,'1c581c1f-ca85-49f3-aaf6-c5a1a8b219be','8704e290-4231-47e9-a00d-a1f0e7aa106f','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ObjectStorageIpListMap-tnz4nhne5d4h-EnabledServicesValue-au2ub4zeu37r','state changed','OS::Heat::Value',NULL,625),(845,'c32c1644-73f1-41c0-a5d6-e5c3d5f41b64','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','7','c42149a1-920c-4720-a75b-71d3711848e1','state changed','OS::TripleO::Services::Kernel',NULL,561),(846,'82611b7c-aea7-453c-bc41-be6b757d6f0a','7c55ade7-f328-44ef-aa20-15a58e56988f','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeIpListMap-rkg7hplgaxxx','7c55ade7-f328-44ef-aa20-15a58e56988f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(847,'b513a7ec-edf8-428e-b4f2-8ddef6975494','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','ContainersCommon','71c35bae-c34e-43ff-b4fa-429e9f3b9e65','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(848,'729a9a21-8df5-477d-baae-859299d377df','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-j7fdjomuaj2n','state changed','OS::Heat::Value',NULL,626),(849,'73b0488b-a321-4b1a-a2c5-21b8d56e8623','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-j7fdjomuaj2n','state changed','OS::Heat::Value',NULL,626),(850,'a2a6372f-6a27-43b1-b7af-f616cd7d1914','8704e290-4231-47e9-a00d-a1f0e7aa106f','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ObjectStorageIpListMap-tnz4nhne5d4h-EnabledServicesValue-au2ub4zeu37r','state changed','OS::Heat::Value',NULL,625),(851,'a0a380fd-90fc-4d56-aaf9-bbc70e4578b7','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(852,'b967318e-4b1d-447b-8696-fe63a2b0e322','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','NetworkerIpListMap','overcloud-NetworkerIpListMap-v2ttfhlnz5ti','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,627),(853,'92b521ef-438a-4d9c-80bc-f711b4c3f157','8704e290-4231-47e9-a00d-a1f0e7aa106f','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageIpListMap-tnz4nhne5d4h','8704e290-4231-47e9-a00d-a1f0e7aa106f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(854,'1d8f0053-2f36-484c-8a00-0e90bd760bc8','41321f4f-c3cf-4566-b08a-73ec4c51ac1c','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerIpListMap-v2ttfhlnz5ti','41321f4f-c3cf-4566-b08a-73ec4c51ac1c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(855,'6223059d-16f8-469b-834c-0bd7e80eabb7','7c55ade7-f328-44ef-aa20-15a58e56988f','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-rkg7hplgaxxx-EnabledServicesValue-bfpemlf7z7ox','state changed','OS::Heat::Value',NULL,630),(856,'470c6f32-8cb9-40f7-8ff3-cc431c50c22a','7c55ade7-f328-44ef-aa20-15a58e56988f','2026-06-15 07:51:24',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-rkg7hplgaxxx-EnabledServicesValue-bfpemlf7z7ox','state changed','OS::Heat::Value',NULL,630),(857,'cc6710b7-f22e-408a-ba92-662f234db4b7','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-ContainersCommon-siirda4ospiq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(858,'45aa3242-6c7a-4db3-b293-5f1b2305436d','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','11','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp','state changed','OS::TripleO::Services::NovaLibvirt',NULL,631),(859,'1544cede-3d93-4c63-8f56-6f329a666b0c','a6d5db2e-a63d-4e7c-9065-6dd9521b3675','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-ContainersCommon-siirda4ospiq','a6d5db2e-a63d-4e7c-9065-6dd9521b3675','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(860,'eeea34c1-403b-422f-8545-647f6174fff3','a6d5db2e-a63d-4e7c-9065-6dd9521b3675','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-ContainersCommon-siirda4ospiq','a6d5db2e-a63d-4e7c-9065-6dd9521b3675','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(861,'004a4d88-06bd-469b-ae3a-51f037f32d33','41321f4f-c3cf-4566-b08a-73ec4c51ac1c','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-NetworkerIpListMap-v2ttfhlnz5ti-NetIpMapValue-zr5t5dtjlmyn','state changed','OS::Heat::Value',NULL,632),(862,'db5c7740-20c0-4bdb-8e50-6a46e4a137dc','41321f4f-c3cf-4566-b08a-73ec4c51ac1c','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-NetworkerIpListMap-v2ttfhlnz5ti-NetIpMapValue-zr5t5dtjlmyn','state changed','OS::Heat::Value',NULL,632),(863,'7197683d-b4dd-4af4-b146-0bae4cb240a0','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','6','ae7c5e37-452d-4fc1-86d8-f32a6f76d827','state changed','OS::TripleO::Services::Iscsid',NULL,494),(864,'96cb7c09-0b29-48d4-87f9-754364f785a2','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','3','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,633),(865,'669adaab-4a6a-4d60-9997-d509ce2107ea','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp','09d983c3-eca4-4458-bf39-52266de0fb3a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(866,'e46331fb-ba8a-482c-83b3-7bd293931340','a674c8c6-026c-4198-af85-7749ee9705d1','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji','a674c8c6-026c-4198-af85-7749ee9705d1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(867,'759d727c-7d0d-424d-8ddf-11d9fab0d143','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNames','overcloud-CellControllerServiceNames-ltmx3vkubldy','state changed','OS::Heat::Value',NULL,634),(868,'a8441358-9f14-4384-a9c9-867bf3c966fb','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','BlockStorageIpListMap','712f389b-f053-48c9-9e42-a35cf11963f3','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,516),(869,'00b12baf-5b1a-4cf0-948e-5fda5bd71b9c','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','CellControllerServiceNames','overcloud-CellControllerServiceNames-ltmx3vkubldy','state changed','OS::Heat::Value',NULL,634),(870,'1ab97839-c557-427f-84b2-262936035518','a674c8c6-026c-4198-af85-7749ee9705d1','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji-RoleParametersValue-li2kx5be4ebk','state changed','OS::Heat::Value',NULL,639),(871,'5cb30f19-c5b6-4efb-960f-402e0eb3174f','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','17','b00be456-1f12-4aa2-9f39-dcabba14e91c','state changed','OS::TripleO::Services::Snmp',NULL,591),(872,'40ec2609-e97b-479e-8d1a-60b05b40a308','a674c8c6-026c-4198-af85-7749ee9705d1','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji-RoleParametersValue-li2kx5be4ebk','state changed','OS::Heat::Value',NULL,639),(873,'80bef2c7-c31d-4d15-bd1b-33b4a73674ae','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaBase-aygfxg5umezz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,640),(874,'bfcefc46-70f3-4458-9453-92089d34b46a','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','10','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc','state changed','OS::TripleO::Services::NovaCompute',NULL,641),(875,'4fff6c92-d744-4825-a074-e60359064431','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','CephStorage','ef5546ee-cc88-4a34-8955-79224e310b43','state changed','OS::Heat::ResourceGroup',NULL,586),(876,'4d3674c0-daf1-4abe-9a29-b717fae4f60f','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','CellController','overcloud-CellController-5nnkubaj5fja','state changed','OS::Heat::ResourceGroup',NULL,643),(877,'386e469b-3297-4440-8cac-c1454944f84b','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','ContainersCommon','5a719a5a-c2ce-4286-9156-c98ef2ad40a0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(878,'8e559985-f5b4-4589-bde6-b277c64a9f12','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi-CeilometerServiceBase-cs4dx3mx43cu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,644),(879,'662358ba-fb60-4c94-ac3b-12d39111baf5','fee7798d-daab-4490-8834-5c168bfc8917','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaBase-aygfxg5umezz','fee7798d-daab-4490-8834-5c168bfc8917','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(880,'d81d6380-37c5-4f52-bcf8-46091299d1d8','754c417d-8b0d-4a6e-86de-3ed40cfe8ecc','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-CellController-5nnkubaj5fja','754c417d-8b0d-4a6e-86de-3ed40cfe8ecc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(881,'44ae9e0d-5856-4b11-bb32-8e9a8a1f77df','200ae4ef-4969-4a5a-963f-e54f7a39028a','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','ContainersCommon','3e8f85d5-e92d-4b06-9b8d-7ed5eb7d084d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(882,'c1cc9d29-4917-4a91-9fd1-6c87642abef1','200ae4ef-4969-4a5a-963f-e54f7a39028a','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu-CeilometerAgentCentralBase-5g7i2lezpmcm','200ae4ef-4969-4a5a-963f-e54f7a39028a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(883,'145b8503-3afe-499a-a16d-f638e354f102','754c417d-8b0d-4a6e-86de-3ed40cfe8ecc','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','overcloud-CellController-5nnkubaj5fja','754c417d-8b0d-4a6e-86de-3ed40cfe8ecc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(884,'80382441-c7f6-4035-abf0-2ca5a162b2cd','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','CephStorageServers','overcloud-CephStorageServers-6r64x4huv7xm','state changed','OS::Heat::Value',NULL,646),(885,'eb399b11-d111-4add-a68b-893940b7e43e','fee7798d-daab-4490-8834-5c168bfc8917','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaBase-aygfxg5umezz-RoleParametersValue-j36nbhnys6dc','state changed','OS::Heat::Value',NULL,647),(886,'5290ed04-0b44-4203-98f3-7678beb331af','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(887,'b3cece24-82fe-49ea-aafc-299e4bf73593','fee7798d-daab-4490-8834-5c168bfc8917','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaBase-aygfxg5umezz-RoleParametersValue-j36nbhnys6dc','state changed','OS::Heat::Value',NULL,647),(888,'6b7f16fc-6969-4883-8d15-d2fe847be5c2','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','CephStorageServers','overcloud-CephStorageServers-6r64x4huv7xm','state changed','OS::Heat::Value',NULL,646),(889,'91f53139-f949-46dc-ab02-ec0d266b6bcd','fee7798d-daab-4490-8834-5c168bfc8917','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaBase-aygfxg5umezz','fee7798d-daab-4490-8834-5c168bfc8917','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(890,'e079aef5-faa5-45ed-ab4f-032d6172af63','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','21','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-21-bzbaf5vutnlj','state changed','OS::TripleO::Services::TripleoFirewall',NULL,649),(891,'5d048acb-e944-463b-961a-6d35c0e64892','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','ObjectStorageIpListMap','8704e290-4231-47e9-a00d-a1f0e7aa106f','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,558),(892,'784065c5-4cef-48e6-b0bf-dc539dd0d485','042f5848-7832-4630-a057-434fd3f21d98','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi-CeilometerServiceBase-cs4dx3mx43cu','042f5848-7832-4630-a057-434fd3f21d98','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(893,'f376ad50-c9cb-4cec-bca7-61a935397e53','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-rds73pgunwge','state changed','OS::Heat::Value',NULL,651),(894,'ad49bcfc-33be-4d14-99e9-5a8dd0275dff','042f5848-7832-4630-a057-434fd3f21d98','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi-CeilometerServiceBase-cs4dx3mx43cu','042f5848-7832-4630-a057-434fd3f21d98','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(895,'0a3996c4-a20e-4816-a43e-60df53727aa4','66a1efe2-b928-4187-bede-fd9a277b0c40','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-21-bzbaf5vutnlj','66a1efe2-b928-4187-bede-fd9a277b0c40','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(896,'9ceba59f-1667-40d8-aa51-164ab9db0582','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-rds73pgunwge','state changed','OS::Heat::Value',NULL,651),(897,'93f3d683-240c-4c14-83e8-4953597f45e8','7c55ade7-f328-44ef-aa20-15a58e56988f','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerComputeIpListMap-rkg7hplgaxxx-NetIpMapValue-hbcqurq7kjpw','state changed','OS::Heat::Value',NULL,653),(898,'531e0398-fbd8-4f41-abfd-3085133f0280','7c55ade7-f328-44ef-aa20-15a58e56988f','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerComputeIpListMap-rkg7hplgaxxx-NetIpMapValue-hbcqurq7kjpw','state changed','OS::Heat::Value',NULL,653),(899,'0f075de7-9b07-40f0-998e-89bd7d6ae08b','7c55ade7-f328-44ef-aa20-15a58e56988f','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeIpListMap-rkg7hplgaxxx','7c55ade7-f328-44ef-aa20-15a58e56988f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(900,'a03272eb-3772-468c-a781-776659721d00','66a1efe2-b928-4187-bede-fd9a277b0c40','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-21-bzbaf5vutnlj-RoleParametersValue-ijws77izyyb7','state changed','OS::Heat::Value',NULL,654),(901,'ee0ed66f-3649-4094-b7fd-8fd7ece81ca7','66a1efe2-b928-4187-bede-fd9a277b0c40','2026-06-15 07:51:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-21-bzbaf5vutnlj-RoleParametersValue-ijws77izyyb7','state changed','OS::Heat::Value',NULL,654),(902,'7d5198ce-f50e-444f-94dd-e2de45a35e5a','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderCommon-zrhklgovhlbd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(903,'4e29db6a-11d2-401b-b59e-36d956c251d4','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-RoleParametersValue-7wnimyylwplx','state changed','OS::Heat::Value',NULL,655),(904,'6843d01c-ad92-4b1a-8fde-c1ef95c36825','66a1efe2-b928-4187-bede-fd9a277b0c40','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-21-bzbaf5vutnlj','66a1efe2-b928-4187-bede-fd9a277b0c40','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(905,'8b559923-0175-40bf-8247-4d0af18871f5','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-RoleParametersValue-7wnimyylwplx','state changed','OS::Heat::Value',NULL,655),(906,'fa80247e-cf9a-409f-9984-2e9788ac6c6b','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','ContainersCommon','a6d5db2e-a63d-4e7c-9065-6dd9521b3675','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(907,'6b50336b-9ec6-478e-b84d-588ca986c390','41321f4f-c3cf-4566-b08a-73ec4c51ac1c','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-NetworkerIpListMap-v2ttfhlnz5ti-EnabledServicesValue-kf7u65obp6zp','state changed','OS::Heat::Value',NULL,658),(908,'20c77ebc-1f10-4603-8a15-71626acc65ce','41321f4f-c3cf-4566-b08a-73ec4c51ac1c','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-NetworkerIpListMap-v2ttfhlnz5ti-EnabledServicesValue-kf7u65obp6zp','state changed','OS::Heat::Value',NULL,658),(909,'db7be78a-5fec-4ed3-8a9f-926f03359576','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaLogging-te4ynkk5bevb','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,659),(910,'23a3e4a9-e32f-4360-a01e-944187c29c58','4d9571b4-5fc0-4c97-911b-d0d76471027d','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderCommon-zrhklgovhlbd','4d9571b4-5fc0-4c97-911b-d0d76471027d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(911,'b1e9064d-c2ed-48b7-b261-5106257fbc93','41321f4f-c3cf-4566-b08a-73ec4c51ac1c','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','overcloud-NetworkerIpListMap-v2ttfhlnz5ti','41321f4f-c3cf-4566-b08a-73ec4c51ac1c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(912,'2fde277a-270c-4822-9860-13507f0fcbfe','4f86fd24-4fa8-4417-ae9c-f39ef1953f3a','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaLogging-te4ynkk5bevb','4f86fd24-4fa8-4417-ae9c-f39ef1953f3a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(913,'f5004962-6d41-46b2-b0e5-6d22f1e65b20','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','CephStorageIpListMap','overcloud-CephStorageIpListMap-pwxvs3m2e5zh','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,656),(914,'ed29a23e-37e2-4428-b15b-08da4283f0b3','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','1','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-1-uzbr6iffhge7','state changed','OS::TripleO::Services::CACerts',NULL,660),(915,'0bef10c7-55ac-4566-bb03-6ce031292609','4d9571b4-5fc0-4c97-911b-d0d76471027d','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderCommon-zrhklgovhlbd-ContainersCommon-6dfrksehjrcj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(916,'5181903a-0c5e-4fd3-a496-90c35ef367a4','b5e946e9-48f9-407e-8212-b24ea42bb480','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageIpListMap-pwxvs3m2e5zh','b5e946e9-48f9-407e-8212-b24ea42bb480','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(917,'413f1de1-b1cc-4484-9b3e-10b8aeda25c3','4f86fd24-4fa8-4417-ae9c-f39ef1953f3a','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaLogging-te4ynkk5bevb-InitLogContainerName-e46p3ebmrzrh','state changed','OS::Heat::Value',NULL,661),(918,'fe9511c2-e6f3-45ca-b9bd-036a13acedfa','39482e51-916b-4a27-8d1a-8424da158757','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-1-uzbr6iffhge7','39482e51-916b-4a27-8d1a-8424da158757','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(919,'c8e3c606-b78e-45f2-b396-c5d05eeaa920','4f86fd24-4fa8-4417-ae9c-f39ef1953f3a','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaLogging-te4ynkk5bevb-InitLogContainerName-e46p3ebmrzrh','state changed','OS::Heat::Value',NULL,661),(920,'a602c6d5-9b78-4610-9e85-93d4823b0b4a','39482e51-916b-4a27-8d1a-8424da158757','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-1-uzbr6iffhge7','39482e51-916b-4a27-8d1a-8424da158757','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(921,'63f325fe-2ea1-4e3c-a97f-948d5a63feee','861e6c31-410e-4c8e-b663-3bdd66093673','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderCommon-zrhklgovhlbd-ContainersCommon-6dfrksehjrcj','861e6c31-410e-4c8e-b663-3bdd66093673','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(922,'3a864bc8-df7e-49c0-8b32-c7675a3533f0','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','CeilometerAgentCentralBase','200ae4ef-4969-4a5a-963f-e54f7a39028a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,483),(923,'c6c08c3c-fb46-474d-909e-206995c596e4','b5e946e9-48f9-407e-8212-b24ea42bb480','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CephStorageIpListMap-pwxvs3m2e5zh-EnabledServicesValue-6tz25egevsyl','state changed','OS::Heat::Value',NULL,662),(924,'3e8f320d-f8f9-453b-83a2-41cae1c082eb','861e6c31-410e-4c8e-b663-3bdd66093673','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderCommon-zrhklgovhlbd-ContainersCommon-6dfrksehjrcj','861e6c31-410e-4c8e-b663-3bdd66093673','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(925,'a786dd18-425a-440d-8e88-a45293f82acc','b5e946e9-48f9-407e-8212-b24ea42bb480','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CephStorageIpListMap-pwxvs3m2e5zh-EnabledServicesValue-6tz25egevsyl','state changed','OS::Heat::Value',NULL,662),(926,'a349b5d6-f167-4bac-9e78-a68b356b81ac','a54cd05b-e3c4-4100-be06-26857f315e37','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-4-vrh6a53pjbhu','a54cd05b-e3c4-4100-be06-26857f315e37','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(927,'e8731ffa-5ac3-429e-9079-f40bc0c6cdf6','a674c8c6-026c-4198-af85-7749ee9705d1','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji-CeilometerServiceBase-ghmqitu6vwxo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,663),(928,'1e907619-6392-48fe-9640-626eaf58e2c8','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-ContainersCommon-vra6yrhs63is','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(929,'37cd0f5e-0b5d-4ada-9669-f6772ad1ad35','f6ad8639-00a9-45a0-94ce-1fc06f5f1184','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-ContainersCommon-vra6yrhs63is','f6ad8639-00a9-45a0-94ce-1fc06f5f1184','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(930,'1df932de-1db9-4d60-82b6-62497ae1fdf2','90f41bc3-053d-4ccd-aadd-97b468d6fbfb','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji-CeilometerServiceBase-ghmqitu6vwxo','90f41bc3-053d-4ccd-aadd-97b468d6fbfb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(931,'27b49ad9-4101-4413-b2fc-9916c89e3809','f6ad8639-00a9-45a0-94ce-1fc06f5f1184','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-ContainersCommon-vra6yrhs63is','f6ad8639-00a9-45a0-94ce-1fc06f5f1184','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(932,'51f98af5-61d5-4e23-b69d-4c418ea47503','90f41bc3-053d-4ccd-aadd-97b468d6fbfb','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji-CeilometerServiceBase-ghmqitu6vwxo','90f41bc3-053d-4ccd-aadd-97b468d6fbfb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(933,'f71a841d-fdda-4cfd-8232-422f0384b950','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi-RoleParametersValue-xttyertfhhjt','state changed','OS::Heat::Value',NULL,664),(934,'696fc284-4152-416d-ada7-3b75d4f2af07','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi-RoleParametersValue-xttyertfhhjt','state changed','OS::Heat::Value',NULL,664),(935,'2384b836-b584-410a-a0bc-f9ab15ebfa67','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','CellController','754c417d-8b0d-4a6e-86de-3ed40cfe8ecc','state changed','OS::Heat::ResourceGroup',NULL,643),(936,'c5ed832e-0fc8-4073-a45b-fd6a561d8afc','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','4','a54cd05b-e3c4-4100-be06-26857f315e37','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,281),(937,'bb8394c1-986f-44e5-8c86-36ba269b42f3','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','NovaBase','fee7798d-daab-4490-8834-5c168bfc8917','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,640),(938,'da1e9bcf-d201-41a1-930a-15caf6f75826','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','CellControllerComputeIpListMap','7c55ade7-f328-44ef-aa20-15a58e56988f','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,618),(939,'933bd3d7-7ff2-4cdf-8698-45b04470d6b9','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','CeilometerServiceBase','042f5848-7832-4630-a057-434fd3f21d98','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,644),(940,'4eef0b92-cb2f-44cc-86db-2f8e8bcba72b','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','21','66a1efe2-b928-4187-bede-fd9a277b0c40','state changed','OS::TripleO::Services::TripleoFirewall',NULL,649),(941,'34ccd414-6e35-4266-b8d2-2818fe807fd2','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','2026-06-15 07:51:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-2-3gqjn3qd7iyi','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(942,'fb4e7835-12ab-41f3-84fe-fa2fd489c86e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:26',NULL,'CREATE','IN_PROGRESS','CellControllerServers','overcloud-CellControllerServers-5n3kithjlsst','state changed','OS::Heat::Value',NULL,668),(943,'dfdfd091-5b41-4f3d-8306-c5f504861485','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','NovaComputeCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaComputeCommon-cxrpc3my4kt4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,669),(944,'4e31530c-3eb6-4761-94fe-8d30121fcc9d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','CellControllerServers','overcloud-CellControllerServers-5n3kithjlsst','state changed','OS::Heat::Value',NULL,668),(945,'892819fb-51ae-425c-a7ae-5e07a2e1d883','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','NetworkerIpListMap','41321f4f-c3cf-4566-b08a-73ec4c51ac1c','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,627),(946,'048aa7b2-f5f1-44a9-b9c0-c7fc97aa3a27','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderBase-7kwyazycj47w','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,670),(947,'16930083-17a1-4816-a84e-8b40f35ae22f','ce4df8f2-bad5-45a2-a134-5db9d43c8c36','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaComputeCommon-cxrpc3my4kt4','ce4df8f2-bad5-45a2-a134-5db9d43c8c36','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(948,'956817ca-8c47-4379-bd63-6886de8b9e79','ce4df8f2-bad5-45a2-a134-5db9d43c8c36','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaComputeCommon-cxrpc3my4kt4','ce4df8f2-bad5-45a2-a134-5db9d43c8c36','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(949,'73d3a2e9-fa1b-42ea-afa2-5d63bd06facc','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','25','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,671),(950,'ca78d635-3250-4537-af81-9c967b8d8666','7130228f-03f5-4e37-b2f1-bfc6c9fb8029','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderBase-7kwyazycj47w','7130228f-03f5-4e37-b2f1-bfc6c9fb8029','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(951,'5d46c89d-a02a-49b5-a2c5-3c70d8859b01','4d9571b4-5fc0-4c97-911b-d0d76471027d','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderCommon-zrhklgovhlbd-CinderNVMeOF-cgi3cbzj3zph','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(952,'a5c4cda1-0589-4282-a6a0-ef790379b476','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-tuoxb5mep5xe','state changed','OS::Heat::Value',NULL,673),(953,'72b2a6ef-5b1c-4439-aa05-f64108d36ffe','7130228f-03f5-4e37-b2f1-bfc6c9fb8029','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderBase-7kwyazycj47w','7130228f-03f5-4e37-b2f1-bfc6c9fb8029','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(954,'34ea6465-4356-40ae-b387-4d59dc547000','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw','3f690b39-5948-4d2e-bc5b-55f46fab90a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(955,'5778a269-d723-4a07-b382-a5d219a70e5a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-tuoxb5mep5xe','state changed','OS::Heat::Value',NULL,673),(956,'9b668691-ee0e-439a-9318-5cb871d7139c','4f86fd24-4fa8-4417-ae9c-f39ef1953f3a','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaLogging-te4ynkk5bevb-RoleParametersValue-3blxylvfjhpz','state changed','OS::Heat::Value',NULL,678),(957,'a9db5ed3-dea2-4efe-b95a-0866449e186b','82a2d5dd-e1b4-49d8-832c-c42125abd6af','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderCommon-zrhklgovhlbd-CinderNVMeOF-cgi3cbzj3zph','82a2d5dd-e1b4-49d8-832c-c42125abd6af','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(958,'a3c124a4-41b5-420b-9061-7b289fd38c61','4f86fd24-4fa8-4417-ae9c-f39ef1953f3a','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaLogging-te4ynkk5bevb-RoleParametersValue-3blxylvfjhpz','state changed','OS::Heat::Value',NULL,678),(959,'1f28e05e-f32f-4400-93c6-2ed894f08d7a','4f86fd24-4fa8-4417-ae9c-f39ef1953f3a','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaLogging-te4ynkk5bevb','4f86fd24-4fa8-4417-ae9c-f39ef1953f3a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(960,'a87c6832-e9fe-4670-bb1e-8dc05ccc7908','82a2d5dd-e1b4-49d8-832c-c42125abd6af','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderCommon-zrhklgovhlbd-CinderNVMeOF-cgi3cbzj3zph','82a2d5dd-e1b4-49d8-832c-c42125abd6af','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(961,'8bceb6b1-7401-460e-a43a-412975fd9952','4d9571b4-5fc0-4c97-911b-d0d76471027d','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','ContainersCommon','861e6c31-410e-4c8e-b663-3bdd66093673','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(962,'4d9d54af-ed6e-4764-8bed-1f104af9b236','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','1','39482e51-916b-4a27-8d1a-8424da158757','state changed','OS::TripleO::Services::CACerts',NULL,660),(963,'8a61dda7-bedb-4b1f-99fb-4dcb38c68195','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','2','e4403c68-1e0c-4c3c-849b-fbbb4e02a4e4','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,585),(964,'5bfee173-a806-4731-93f0-b930f60b7413','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','CellControllerIpListMap','overcloud-CellControllerIpListMap-qteckvqux7kk','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,682),(965,'7a1382d2-25fd-441b-8120-0fd8ab1ea458','a674c8c6-026c-4198-af85-7749ee9705d1','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji-ContainersCommon-vleh54exvulq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(966,'8eddf51b-8486-4a2f-9d5d-cb880c8dd3eb','6fe6382a-124f-40e8-8183-3e27200ded49','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji-ContainersCommon-vleh54exvulq','6fe6382a-124f-40e8-8183-3e27200ded49','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(967,'414aab2a-0e3d-423a-818f-4f473d17c2ef','b5e946e9-48f9-407e-8212-b24ea42bb480','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CephStorageIpListMap-pwxvs3m2e5zh-NetIpMapValue-xhhjkpmilmhh','state changed','OS::Heat::Value',NULL,683),(968,'495538e7-ab0a-4a3f-aa70-a6477eae13fb','6fe6382a-124f-40e8-8183-3e27200ded49','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji-ContainersCommon-vleh54exvulq','6fe6382a-124f-40e8-8183-3e27200ded49','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(969,'f9b08d0e-a09b-42b2-9746-67920237a959','b5e946e9-48f9-407e-8212-b24ea42bb480','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CephStorageIpListMap-pwxvs3m2e5zh-NetIpMapValue-xhhjkpmilmhh','state changed','OS::Heat::Value',NULL,683),(970,'982f5730-bb80-4b72-9166-856e27620d4e','ece607a8-5ae6-499e-9fcc-588de3c62418','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerIpListMap-qteckvqux7kk','ece607a8-5ae6-499e-9fcc-588de3c62418','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(971,'6b823667-33af-4cc7-b7e4-af82795ae788','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','8','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-8-xf4udorzotz2','state changed','OS::TripleO::Services::MetricsQdr',NULL,681),(972,'1d578573-130c-4606-89b7-cc71b9b3856b','b5e946e9-48f9-407e-8212-b24ea42bb480','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','overcloud-CephStorageIpListMap-pwxvs3m2e5zh','b5e946e9-48f9-407e-8212-b24ea42bb480','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(973,'5ad29a4d-0727-4ab9-941f-3f50f0babae6','a674c8c6-026c-4198-af85-7749ee9705d1','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','CeilometerServiceBase','90f41bc3-053d-4ccd-aadd-97b468d6fbfb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,663),(974,'321d014d-086a-4726-818c-3accc37d18bb','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','ContainersCommon','f6ad8639-00a9-45a0-94ce-1fc06f5f1184','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(975,'67d93bae-2df8-42ed-aa90-8aa7f0631586','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-RoleParametersValue-25k7qds3tymd','state changed','OS::Heat::Value',NULL,686),(976,'969a6f51-0c9e-41c0-bb96-7d901cbfae8c','ece607a8-5ae6-499e-9fcc-588de3c62418','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerIpListMap-qteckvqux7kk-EnabledServicesValue-i2bvgrbp6xvj','state changed','OS::Heat::Value',NULL,689),(977,'0011aef5-0323-4a45-b8cd-c33033a83da2','ece607a8-5ae6-499e-9fcc-588de3c62418','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerIpListMap-qteckvqux7kk-EnabledServicesValue-i2bvgrbp6xvj','state changed','OS::Heat::Value',NULL,689),(978,'ab4ae17c-774a-4fe1-b982-18b52b69d828','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-RoleParametersValue-25k7qds3tymd','state changed','OS::Heat::Value',NULL,686),(979,'dc69b448-cb21-4132-ac31-52bfb4255a3b','3cb7fbf5-0c38-4eb7-9557-ff0545bc1b27','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-8-xf4udorzotz2','3cb7fbf5-0c38-4eb7-9557-ff0545bc1b27','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(980,'54f86afb-af44-4afc-95d4-22bae55d2df1','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','5','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu','state changed','OS::TripleO::Services::CinderBackup',NULL,691),(981,'f04cb6eb-c1b4-4041-b3ca-a8154aa92151','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-ContainersCommon-45plsboahfg7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(982,'85629f7b-d52b-42a1-892c-bd3d0b19a326','51073b2e-e1be-4b26-92a0-0fb7c0220d8c','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-ContainersCommon-45plsboahfg7','51073b2e-e1be-4b26-92a0-0fb7c0220d8c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(983,'7f27f6cb-e34e-4f37-a507-e19429cfd218','3cb7fbf5-0c38-4eb7-9557-ff0545bc1b27','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-8-xf4udorzotz2-ContainersCommon-qtdcx3okmshz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(984,'de2e191c-6175-4a1a-9ca3-9cf163f0c692','51073b2e-e1be-4b26-92a0-0fb7c0220d8c','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-ContainersCommon-45plsboahfg7','51073b2e-e1be-4b26-92a0-0fb7c0220d8c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(985,'567ff535-3c4c-49f2-a286-dd93436c7c83','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','6','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe','state changed','OS::TripleO::Services::CinderScheduler',NULL,692),(986,'101c23ad-14f8-4880-9926-1d860c7d762e','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu','cc2a5e46-b213-4701-b668-8866c5b6a79c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(987,'b8762480-23ab-475b-a456-69dd7a908e14','11151e79-b6bc-4bcd-815c-8b1cbc5fe106','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-8-xf4udorzotz2-ContainersCommon-qtdcx3okmshz','11151e79-b6bc-4bcd-815c-8b1cbc5fe106','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(988,'97b73b7d-b152-47cc-99be-36db3c0979c6','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe','93c9336c-609a-4156-a6c6-57736adf9bc8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(989,'60a98fe3-34f3-4b34-8d90-83ec6a802d13','11151e79-b6bc-4bcd-815c-8b1cbc5fe106','2026-06-15 07:51:27',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-8-xf4udorzotz2-ContainersCommon-qtdcx3okmshz','11151e79-b6bc-4bcd-815c-8b1cbc5fe106','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(990,'d5ddb94a-31f1-4add-b046-f9381b44d3b6','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-ContainersCommon-szfa6homiwts','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(991,'9cc46b07-16b5-40f7-a630-050ae0f76a58','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-MySQLClient-ccoa6h7syvti','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(992,'375cf719-a70d-4c8a-8ae7-8240dba217e2','09edd534-44ea-49f6-81a2-f277e501370b','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-MySQLClient-ccoa6h7syvti','09edd534-44ea-49f6-81a2-f277e501370b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(993,'ea0c82bb-b8d7-46ca-8d11-cb9b56b491a0','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-RoleParametersValue-lxsf3iinwixy','state changed','OS::Heat::Value',NULL,693),(994,'1be94a4e-81c5-4c8a-ab70-885538c55337','09edd534-44ea-49f6-81a2-f277e501370b','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-MySQLClient-ccoa6h7syvti','09edd534-44ea-49f6-81a2-f277e501370b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(995,'7797c969-ae80-4458-bbab-5caac5e140d9','65284644-8740-4fa5-a69c-246dc7c77cf6','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-ContainersCommon-szfa6homiwts','65284644-8740-4fa5-a69c-246dc7c77cf6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(996,'aba69bcf-253a-4c9b-9dc4-f7d440667158','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-RoleParametersValue-lxsf3iinwixy','state changed','OS::Heat::Value',NULL,693),(997,'a2170f38-7257-42ee-a494-b0d9447c8229','65284644-8740-4fa5-a69c-246dc7c77cf6','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-ContainersCommon-szfa6homiwts','65284644-8740-4fa5-a69c-246dc7c77cf6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(998,'6bab17e3-3d82-47c2-bd44-1ffe6bc8e109','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','NovaComputeCommon','ce4df8f2-bad5-45a2-a134-5db9d43c8c36','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,669),(999,'e5d9aec7-d375-4020-9879-d264824d08c7','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderCommon-pjiakytyvbcz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1000,'07bfab1b-c320-4d1a-a9d5-5d1752d4cb7a','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','NovaLogging','4f86fd24-4fa8-4417-ae9c-f39ef1953f3a','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,659),(1001,'3ac25fa6-b67c-4ebc-b503-a59ff3b2cacb','30d09886-c7af-41a1-b886-6087b255ea19','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderCommon-pjiakytyvbcz','30d09886-c7af-41a1-b886-6087b255ea19','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1002,'c2995c91-1d56-4a0a-8428-f49b6657e801','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','CinderBase','7130228f-03f5-4e37-b2f1-bfc6c9fb8029','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,670),(1003,'5bcc3791-8f6f-4ee6-b94f-1a65b309d300','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','CephStorageIpListMap','b5e946e9-48f9-407e-8212-b24ea42bb480','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,656),(1004,'94dac6b8-3384-4b15-a3bb-65b2341ee513','30d09886-c7af-41a1-b886-6087b255ea19','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderCommon-pjiakytyvbcz-ContainersCommon-qgfctamed3wj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1005,'431daf29-cc2e-4335-8ca8-94718604c745','4d9571b4-5fc0-4c97-911b-d0d76471027d','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','CinderNVMeOF','82a2d5dd-e1b4-49d8-832c-c42125abd6af','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1006,'2459679d-6d6b-48ac-8186-6061565d14db','4d9571b4-5fc0-4c97-911b-d0d76471027d','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-CinderCommon-zrhklgovhlbd','4d9571b4-5fc0-4c97-911b-d0d76471027d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1007,'17b17448-c96b-4557-bedc-1462338f509f','dfd6c710-1dea-4476-a0df-9ad57baf15f3','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderCommon-pjiakytyvbcz-ContainersCommon-qgfctamed3wj','dfd6c710-1dea-4476-a0df-9ad57baf15f3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1008,'04525c0d-33ac-48d5-ad4b-1345e2f517bf','dfd6c710-1dea-4476-a0df-9ad57baf15f3','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderCommon-pjiakytyvbcz-ContainersCommon-qgfctamed3wj','dfd6c710-1dea-4476-a0df-9ad57baf15f3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1009,'6b49e069-8fda-4dc1-a393-7e058a29960b','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','NovaLibvirtCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaLibvirtCommon-ruk2ews6gurx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1010,'f2a7c129-2aa3-42ac-b569-45acf8f5a5fd','a674c8c6-026c-4198-af85-7749ee9705d1','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','ContainersCommon','6fe6382a-124f-40e8-8183-3e27200ded49','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1011,'cf96760c-89f0-48c6-b759-2153c109f635','a674c8c6-026c-4198-af85-7749ee9705d1','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-3-mqlq2s5hf7ji','a674c8c6-026c-4198-af85-7749ee9705d1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1012,'b521b080-ae8c-43d0-bc18-3c00eaefa7c5','8aa3ce34-6670-428d-8f94-512ecb51f116','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaLibvirtCommon-ruk2ews6gurx','8aa3ce34-6670-428d-8f94-512ecb51f116','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1013,'8851d279-cee4-48be-8f1a-aae842d569a5','ece607a8-5ae6-499e-9fcc-588de3c62418','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerIpListMap-qteckvqux7kk-NetIpMapValue-2hgcedn2ku65','state changed','OS::Heat::Value',NULL,694),(1014,'f6ef435c-fb02-4222-8d0e-ae2c74a78172','8aa3ce34-6670-428d-8f94-512ecb51f116','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaLibvirtCommon-ruk2ews6gurx-RoleParametersValue-xxkzeqyzn54s','state changed','OS::Heat::Value',NULL,695),(1015,'d9aecb99-85db-408d-86e0-25ab4ea3f7ca','ece607a8-5ae6-499e-9fcc-588de3c62418','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerIpListMap-qteckvqux7kk-NetIpMapValue-2hgcedn2ku65','state changed','OS::Heat::Value',NULL,694),(1016,'c9f0c347-68be-4821-aa0e-ac0b95e98efd','8aa3ce34-6670-428d-8f94-512ecb51f116','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaLibvirtCommon-ruk2ews6gurx-RoleParametersValue-xxkzeqyzn54s','state changed','OS::Heat::Value',NULL,695),(1017,'237a4b76-ab7b-41af-bb10-cf0e188cfda3','ece607a8-5ae6-499e-9fcc-588de3c62418','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','overcloud-CellControllerIpListMap-qteckvqux7kk','ece607a8-5ae6-499e-9fcc-588de3c62418','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1018,'2f91b6e2-6a5b-4fa3-a28b-8fc31cee840b','8aa3ce34-6670-428d-8f94-512ecb51f116','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaLibvirtCommon-ruk2ews6gurx','8aa3ce34-6670-428d-8f94-512ecb51f116','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1019,'8525d212-aebd-4c06-bf0a-4c93f8f141d2','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-NeutronBase-ckhywz6daier','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,696),(1020,'09ebbfb8-6e51-4f4b-ac32-cbe92f36d2c0','cc4c4112-2954-4f0a-8d58-6b45605c72e8','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-NeutronBase-ckhywz6daier','cc4c4112-2954-4f0a-8d58-6b45605c72e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1021,'95076d9d-9100-4890-827b-73d1006ffb0e','cc4c4112-2954-4f0a-8d58-6b45605c72e8','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-NeutronBase-ckhywz6daier','cc4c4112-2954-4f0a-8d58-6b45605c72e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1022,'11562815-4f9d-4ecc-b1fc-80182c38702b','3cb7fbf5-0c38-4eb7-9557-ff0545bc1b27','2026-06-15 07:51:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-8-xf4udorzotz2-RoleParametersValue-7yolklju5lkl','state changed','OS::Heat::Value',NULL,697),(1023,'6d0e44c5-f5c4-49f1-b370-eae54bf33371','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','ContainersCommon','51073b2e-e1be-4b26-92a0-0fb7c0220d8c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1024,'6bea0c95-c39d-4af3-819e-06b326943fb9','3cb7fbf5-0c38-4eb7-9557-ff0545bc1b27','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-8-xf4udorzotz2-RoleParametersValue-7yolklju5lkl','state changed','OS::Heat::Value',NULL,697),(1025,'53ca6c4e-9b99-47d4-bb7c-5b565ed73044','3cb7fbf5-0c38-4eb7-9557-ff0545bc1b27','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','ContainersCommon','11151e79-b6bc-4bcd-815c-8b1cbc5fe106','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1026,'5e064a8d-6045-4c61-9429-916d423b1383','3cb7fbf5-0c38-4eb7-9557-ff0545bc1b27','2026-06-15 07:51:28',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-8-xf4udorzotz2','3cb7fbf5-0c38-4eb7-9557-ff0545bc1b27','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1027,'365aabbc-74a3-485b-b2a2-914b6298f84e','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-CinderNVMeOF-uef3nmi33k6u','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1028,'e27d9d15-496d-405d-b3a8-c906edb908ce','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-RoleParametersValue-pqee3qa4kru3','state changed','OS::Heat::Value',NULL,698),(1029,'5ff7c406-f261-418c-9a7b-6716db155e01','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-RoleParametersValue-pqee3qa4kru3','state changed','OS::Heat::Value',NULL,698),(1030,'c996e202-39dc-46ee-9614-0584bc72e7c2','4b8d17b6-7dff-4e01-858a-3dc345e0db87','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-CinderNVMeOF-uef3nmi33k6u','4b8d17b6-7dff-4e01-858a-3dc345e0db87','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1031,'a4d76f58-1a14-4321-b2e3-315902e98f9f','4b8d17b6-7dff-4e01-858a-3dc345e0db87','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-CinderNVMeOF-uef3nmi33k6u','4b8d17b6-7dff-4e01-858a-3dc345e0db87','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1032,'5773bdfe-2690-4ca1-a2a6-f516dfa3e82f','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-ContainersCommon-bq3wakgg5l5n','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1033,'cb5c1a68-8b4d-444a-b06b-076f43618d84','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','MySQLClient','09edd534-44ea-49f6-81a2-f277e501370b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1034,'ad06328e-67ed-4e18-afc2-0f4c942e0216','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','CinderCommon','4d9571b4-5fc0-4c97-911b-d0d76471027d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1035,'149359a3-4fb4-4739-9239-04390c9ad851','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','ContainersCommon','65284644-8740-4fa5-a69c-246dc7c77cf6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1036,'6bb54b5c-3088-441e-86b6-79f351b79fc5','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-MySQLClient-jabmnautj3yu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1037,'054a5fd8-4777-4781-9587-6f26b207378e','4a4d1ac4-362b-42ec-9c09-1cd66299d5b0','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-ContainersCommon-bq3wakgg5l5n','4a4d1ac4-362b-42ec-9c09-1cd66299d5b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1038,'8f1c50ad-d93d-4a6e-9215-59ab5d8e3ba6','4a4d1ac4-362b-42ec-9c09-1cd66299d5b0','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-ContainersCommon-bq3wakgg5l5n','4a4d1ac4-362b-42ec-9c09-1cd66299d5b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1039,'ce28b237-d9d9-492b-939c-e2fcd5652dfc','e90ca6fc-33a0-4646-ad6a-41e0871007b2','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-MySQLClient-jabmnautj3yu','e90ca6fc-33a0-4646-ad6a-41e0871007b2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1040,'a55c3c96-3855-4853-a197-bb7826e330da','e90ca6fc-33a0-4646-ad6a-41e0871007b2','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-MySQLClient-jabmnautj3yu','e90ca6fc-33a0-4646-ad6a-41e0871007b2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1041,'7d5e4e8b-48cc-46e6-81ca-6c7f9f986f58','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','3','a674c8c6-026c-4198-af85-7749ee9705d1','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,633),(1042,'a6f0ad23-890d-4c58-adf1-fa2d3a3acb7e','30d09886-c7af-41a1-b886-6087b255ea19','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderCommon-pjiakytyvbcz-CinderNVMeOF-nqsmdsuu2qs7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1043,'9a506fa8-1fc8-4343-8429-137a0827bfdb','036c82e6-0f34-4062-be83-37b3472a696e','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderCommon-pjiakytyvbcz-CinderNVMeOF-nqsmdsuu2qs7','036c82e6-0f34-4062-be83-37b3472a696e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1044,'f9f1e735-c9ff-43c4-bfb3-68c5114c3fdb','30d09886-c7af-41a1-b886-6087b255ea19','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','ContainersCommon','dfd6c710-1dea-4476-a0df-9ad57baf15f3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1045,'64205b6f-f191-4864-b4a7-ab21492f3b5b','036c82e6-0f34-4062-be83-37b3472a696e','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderCommon-pjiakytyvbcz-CinderNVMeOF-nqsmdsuu2qs7','036c82e6-0f34-4062-be83-37b3472a696e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1046,'c35f31d3-c49e-42ea-9979-2e24db6d412b','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','NovaLibvirtLogging','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaLibvirtLogging-yzd5m55jhpng','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1047,'6952a718-5334-46da-8f6e-bd581754e4f6','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','CellControllerIpListMap','ece607a8-5ae6-499e-9fcc-588de3c62418','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,682),(1048,'6696b05b-99b2-4375-be64-30543a5cffaa','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','NovaLibvirtCommon','8aa3ce34-6670-428d-8f94-512ecb51f116','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1049,'6baa5950-3b92-490c-a259-f535539588c2','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','8','3cb7fbf5-0c38-4eb7-9557-ff0545bc1b27','state changed','OS::TripleO::Services::MetricsQdr',NULL,681),(1050,'b8e1ef62-f531-4ae6-95ee-861ec395c348','6574ea59-9f1b-480e-a771-6b6b7c24f310','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaLibvirtLogging-yzd5m55jhpng','6574ea59-9f1b-480e-a771-6b6b7c24f310','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1051,'654b4dc3-7996-4203-b724-9968f5e1cc32','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','7','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b','state changed','OS::TripleO::Services::CinderVolume',NULL,703),(1052,'27faec51-b7f4-4aff-a149-276b587a2331','6574ea59-9f1b-480e-a771-6b6b7c24f310','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp-NovaLibvirtLogging-yzd5m55jhpng','6574ea59-9f1b-480e-a771-6b6b7c24f310','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1053,'9481a7a9-3c80-4a70-88a2-fb0afd0040ec','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-NeutronLogging-atiyo6sb7dpz','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,704),(1054,'68d1a51d-f106-4803-ba98-0b3dabc86bb4','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b','5db58455-289a-400c-b099-4132d52e2911','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1055,'27954168-631b-4e6d-9d62-a383557d648a','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','NeutronBase','cc4c4112-2954-4f0a-8d58-6b45605c72e8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,696),(1056,'357be3fe-7881-4a90-b09e-c2ab1077464a','5f1551fa-8f9d-4856-a4d5-b64dba5fbd94','2026-06-15 07:51:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-NeutronLogging-atiyo6sb7dpz','5f1551fa-8f9d-4856-a4d5-b64dba5fbd94','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1057,'b8bd1050-e540-40b6-94f4-ba3861f937d2','5f1551fa-8f9d-4856-a4d5-b64dba5fbd94','2026-06-15 07:51:29',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-NeutronLogging-atiyo6sb7dpz','5f1551fa-8f9d-4856-a4d5-b64dba5fbd94','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1058,'ef8aef81-e6a4-490e-a0e3-15b875faaa1b','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-ApacheServiceBase-ng3fxb3v3nlc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,708),(1059,'b67b6628-f8ce-4c43-905a-ed6d4e409dd4','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaBase-cw4plqfem5gl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,709),(1060,'59924a92-c0d8-4418-b37d-ec6de7a8a1cc','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-RoleParametersValue-7nzhvxvnxh3z','state changed','OS::Heat::Value',NULL,710),(1061,'c286c724-c982-41cf-88ab-47e8ab4ca002','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','12','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-12-kzzhwzbgiw5e','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,711),(1062,'fe6394de-02a4-4b4c-864f-c8dd656e40a4','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-RoleParametersValue-7nzhvxvnxh3z','state changed','OS::Heat::Value',NULL,710),(1063,'da7cff60-3f73-4437-a89b-6a768c746f99','c7b6a180-6ba6-4d2a-b095-ff0884041ec6','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-ApacheServiceBase-ng3fxb3v3nlc','c7b6a180-6ba6-4d2a-b095-ff0884041ec6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1064,'d0b41db6-abd3-4ead-b817-5dfcff717f9a','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','CinderNVMeOF','4b8d17b6-7dff-4e01-858a-3dc345e0db87','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1065,'8f768c64-e457-41f2-a6ac-628749dcecdc','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderCommon-jcxp5s2ewkqp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1066,'596ba77d-6685-4625-a4bf-f1be2ec3e9b5','d79fea9a-da89-40a2-a6e9-792250bb0f3c','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaBase-cw4plqfem5gl','d79fea9a-da89-40a2-a6e9-792250bb0f3c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1067,'b83d1268-1546-43c8-b551-50489f027ce1','a617819b-4b53-4a7a-81fa-52a33a1c3cb0','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-12-kzzhwzbgiw5e','a617819b-4b53-4a7a-81fa-52a33a1c3cb0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1068,'480b0a02-b408-43aa-89a8-94c7a92f14e7','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','CinderBackupBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,712),(1069,'9c30eaf1-34a3-4064-94a8-a1e2977cfdfd','d79fea9a-da89-40a2-a6e9-792250bb0f3c','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaBase-cw4plqfem5gl-RoleParametersValue-aomtjpyzbuii','state changed','OS::Heat::Value',NULL,713),(1070,'d77ac7ad-2b65-4117-9cfd-9acfb286a02b','a617819b-4b53-4a7a-81fa-52a33a1c3cb0','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-12-kzzhwzbgiw5e-RoleParametersValue-6jk6uf57gghi','state changed','OS::Heat::Value',NULL,714),(1071,'d202851f-55e1-4347-870d-275db6c9cc9c','65ccb74f-36ce-4382-b439-87891988de3b','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderCommon-jcxp5s2ewkqp','65ccb74f-36ce-4382-b439-87891988de3b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1072,'8ccff3ea-00d6-4b9a-b219-7faa4c20f43a','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','ContainersCommon','4a4d1ac4-362b-42ec-9c09-1cd66299d5b0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1073,'82eaa823-ef46-4393-a3f9-61b0c1a8d23d','c7b6a180-6ba6-4d2a-b095-ff0884041ec6','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-ApacheServiceBase-ng3fxb3v3nlc-ApacheNetworks-lybbkhjv2wzo','state changed','OS::Heat::Value',NULL,715),(1074,'ae05dcd8-decc-403c-a4a9-0ce39f2b26de','d79fea9a-da89-40a2-a6e9-792250bb0f3c','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaBase-cw4plqfem5gl-RoleParametersValue-aomtjpyzbuii','state changed','OS::Heat::Value',NULL,713),(1075,'40e50159-651b-4172-b502-5ca52ea6453d','a617819b-4b53-4a7a-81fa-52a33a1c3cb0','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-12-kzzhwzbgiw5e-RoleParametersValue-6jk6uf57gghi','state changed','OS::Heat::Value',NULL,714),(1076,'614d6539-dae9-43b5-a4ae-69395cf6b929','c7b6a180-6ba6-4d2a-b095-ff0884041ec6','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-ApacheServiceBase-ng3fxb3v3nlc-ApacheNetworks-lybbkhjv2wzo','state changed','OS::Heat::Value',NULL,715),(1077,'c6aec45d-1847-488c-971c-a46f62cfa7ac','a617819b-4b53-4a7a-81fa-52a33a1c3cb0','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-12-kzzhwzbgiw5e','a617819b-4b53-4a7a-81fa-52a33a1c3cb0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1078,'f668ce9e-b302-44d2-862c-899e663c096f','c7b6a180-6ba6-4d2a-b095-ff0884041ec6','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb-ApacheServiceBase-ng3fxb3v3nlc','c7b6a180-6ba6-4d2a-b095-ff0884041ec6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1079,'19dfe22b-b31a-4a30-b10e-32ad895fd542','d79fea9a-da89-40a2-a6e9-792250bb0f3c','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc-NovaBase-cw4plqfem5gl','d79fea9a-da89-40a2-a6e9-792250bb0f3c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1080,'37ce28d8-6bd4-4fb8-a492-7acab2a9b834','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2','b162e745-5326-49e9-94ea-2ff666e079df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1081,'4f663b75-21a7-419a-87d7-d413fde8d645','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','MySQLClient','e90ca6fc-33a0-4646-ad6a-41e0871007b2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1082,'bb89738d-9601-4c2c-b0ec-733f8a832d24','65ccb74f-36ce-4382-b439-87891988de3b','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderCommon-jcxp5s2ewkqp-ContainersCommon-oc7ronoehhgf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1083,'602035e8-667d-4b73-b04b-b0a1931223a3','67515536-0a65-402b-a5cf-be61cb6e5241','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderCommon-jcxp5s2ewkqp-ContainersCommon-oc7ronoehhgf','67515536-0a65-402b-a5cf-be61cb6e5241','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1084,'55435921-012f-42eb-a55a-27af9fca7803','67515536-0a65-402b-a5cf-be61cb6e5241','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderCommon-jcxp5s2ewkqp-ContainersCommon-oc7ronoehhgf','67515536-0a65-402b-a5cf-be61cb6e5241','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1085,'4f9b842e-79ff-4001-80b5-371d58bd6445','30d09886-c7af-41a1-b886-6087b255ea19','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','CinderNVMeOF','036c82e6-0f34-4062-be83-37b3472a696e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1086,'737adae0-cc03-4e42-8de6-da8184ee0c2f','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-MySQLClient-d6serdm4yytb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1087,'0e6cb1ee-6f04-49d4-a5c0-7b398de80e7e','30d09886-c7af-41a1-b886-6087b255ea19','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderCommon-pjiakytyvbcz','30d09886-c7af-41a1-b886-6087b255ea19','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1088,'3445644e-6f2c-4c28-8a42-0073f8dcea31','58cf054c-63fb-481b-8f6d-6d34038e30c0','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-MySQLClient-d6serdm4yytb','58cf054c-63fb-481b-8f6d-6d34038e30c0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1089,'b2c1220a-7448-4495-881e-08232b9b90d6','58cf054c-63fb-481b-8f6d-6d34038e30c0','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-MySQLClient-d6serdm4yytb','58cf054c-63fb-481b-8f6d-6d34038e30c0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1090,'1782c271-4872-4317-9eea-0a7118215ead','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','NovaLibvirtLogging','6574ea59-9f1b-480e-a771-6b6b7c24f310','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1091,'e2c54244-5518-4688-ba97-c1b95a747eb4','09d983c3-eca4-4458-bf39-52266de0fb3a','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-11-4q6zzw5easjp','09d983c3-eca4-4458-bf39-52266de0fb3a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1092,'5d4380dc-f8b9-45fa-b0d4-96bc1f270684','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-RoleParametersValue-rkw73u46bcxn','state changed','OS::Heat::Value',NULL,716),(1093,'7785b893-9d1f-43a1-a59d-719dc72f5dfd','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw-RoleParametersValue-rkw73u46bcxn','state changed','OS::Heat::Value',NULL,716),(1094,'8d30d65d-51be-4d3b-9a9a-c67f33afb50b','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','NeutronLogging','5f1551fa-8f9d-4856-a4d5-b64dba5fbd94','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,704),(1095,'95b59728-9205-445f-89f5-151975b8ca85','3f690b39-5948-4d2e-bc5b-55f46fab90a2','2026-06-15 07:51:30',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-25-m5soebdpqekw','3f690b39-5948-4d2e-bc5b-55f46fab90a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1096,'326b0b1a-9709-4c18-99c0-6ec22741f8ba','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-MySQLClient-xd2uzy6d2hd3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1097,'dcc84c46-4045-413c-959b-b0a947a4cc2b','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-MySQLClient-qlfhwuuyhotw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1098,'c5a7670f-f263-486b-aac6-507647477178','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','ApacheServiceBase','c7b6a180-6ba6-4d2a-b095-ff0884041ec6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,708),(1099,'8833fe8c-fc1a-466a-bf8f-cafdcfbf8903','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','12','a617819b-4b53-4a7a-81fa-52a33a1c3cb0','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,711),(1100,'0da494ea-13d6-4b2c-a0b6-de19239ad752','56ed73a5-59f2-4656-8bc8-fd9d70212203','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-MySQLClient-xd2uzy6d2hd3','56ed73a5-59f2-4656-8bc8-fd9d70212203','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1101,'f3de1f5e-be6f-42fa-95cf-c70ff9ab7cc7','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','NovaBase','d79fea9a-da89-40a2-a6e9-792250bb0f3c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,709),(1102,'1f3bd2f4-d5de-447d-9417-df0df5ee8919','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-4-udlx3giu2cfb','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1103,'031ebaff-b3e1-4316-9bf3-4719520b6f28','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-RoleParametersValue-k6yontcfe7lb','state changed','OS::Heat::Value',NULL,717),(1104,'771fafe1-c323-45ee-a3a0-3b959960891f','56ed73a5-59f2-4656-8bc8-fd9d70212203','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-MySQLClient-xd2uzy6d2hd3','56ed73a5-59f2-4656-8bc8-fd9d70212203','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1105,'3e9d6991-9568-489c-87ac-84d353452e50','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-RoleParametersValue-k6yontcfe7lb','state changed','OS::Heat::Value',NULL,717),(1106,'fdb547cf-eaeb-4682-b131-71ccacd2e47a','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-10-lndyqbxnaegc','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1107,'592bf44e-b2a5-41d1-b7ab-cb570b8fe19f','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','MySQLClient','56ed73a5-59f2-4656-8bc8-fd9d70212203','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1108,'d8db863f-d7b6-4f0d-92a6-afb8f58a950e','73cdd861-748e-4a08-8f76-11ea34c427ca','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-MySQLClient-qlfhwuuyhotw','73cdd861-748e-4a08-8f76-11ea34c427ca','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1109,'694d6d5a-ee80-4962-b3bb-f31bd4be07df','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','CinderCommon','30d09886-c7af-41a1-b886-6087b255ea19','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1110,'f8f59601-6601-4b09-b70e-fc7cd0a8326f','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','25','3f690b39-5948-4d2e-bc5b-55f46fab90a2','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,671),(1111,'03fd1c23-f882-4b30-b2df-e12d6b05762f','73cdd861-748e-4a08-8f76-11ea34c427ca','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-MySQLClient-qlfhwuuyhotw','73cdd861-748e-4a08-8f76-11ea34c427ca','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1112,'7a2fdc4a-f1a0-40f6-af30-2a9d28192b45','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','11','09d983c3-eca4-4458-bf39-52266de0fb3a','state changed','OS::TripleO::Services::NovaLibvirt',NULL,631),(1113,'d11ffba6-a980-4000-9938-531ea2d35e24','65ccb74f-36ce-4382-b439-87891988de3b','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderCommon-jcxp5s2ewkqp-CinderNVMeOF-xra2tmoyarpo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1114,'f11210a3-0e18-45b5-917e-a22dd333e293','29ea976f-a72a-4957-8c68-fd8d1c948bef','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderCommon-jcxp5s2ewkqp-CinderNVMeOF-xra2tmoyarpo','29ea976f-a72a-4957-8c68-fd8d1c948bef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1115,'e1df0f29-b869-45a4-8ded-36afb6713c95','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','16','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-16-7jhnpeppudzn','state changed','OS::TripleO::Services::Rsyslog',NULL,721),(1116,'673f1d59-6c74-436f-95a7-8bf781560ac3','29ea976f-a72a-4957-8c68-fd8d1c948bef','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderCommon-jcxp5s2ewkqp-CinderNVMeOF-xra2tmoyarpo','29ea976f-a72a-4957-8c68-fd8d1c948bef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1117,'ab689b1c-6e61-4c11-b97f-928921383167','65ccb74f-36ce-4382-b439-87891988de3b','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','ContainersCommon','67515536-0a65-402b-a5cf-be61cb6e5241','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1118,'4d7d9c91-86ee-4505-81be-371c2b837158','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-ContainersCommon-bfp42hpaksiw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1119,'9fe9b8ec-b9c4-4571-8973-85aeaeadea5a','35803aaa-ca0f-4bcc-963f-b5c677f0dcd8','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-16-7jhnpeppudzn','35803aaa-ca0f-4bcc-963f-b5c677f0dcd8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1120,'7ccd15d2-03f5-4c97-a95e-021ff4270045','28ab2450-b18d-420b-8135-f863614da873','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-ContainersCommon-bfp42hpaksiw','28ab2450-b18d-420b-8135-f863614da873','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1121,'8b5138a8-db11-4576-809d-1950f8a7493b','28ab2450-b18d-420b-8135-f863614da873','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-ContainersCommon-bfp42hpaksiw','28ab2450-b18d-420b-8135-f863614da873','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1122,'d69d3ff8-3868-4383-b3b0-97c69dcf9b6c','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','MySQLClient','58cf054c-63fb-481b-8f6d-6d34038e30c0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1123,'e572d695-960d-4602-a762-0765385833b0','35803aaa-ca0f-4bcc-963f-b5c677f0dcd8','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-16-7jhnpeppudzn-ContainersCommon-fvja7zmnvotk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1124,'ae2e1f2c-6e79-4e6b-bc49-b9033e4a3b45','da6fb455-528c-442e-8bc3-7e6733d79599','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-16-7jhnpeppudzn-ContainersCommon-fvja7zmnvotk','da6fb455-528c-442e-8bc3-7e6733d79599','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1125,'14b8d893-caa5-4b02-8d53-fa26b325c261','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','15','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-15-iz5wozbvis46','state changed','OS::TripleO::Services::Podman',NULL,729),(1126,'a469cd68-6eda-4f58-a5ea-a64341c367fb','da6fb455-528c-442e-8bc3-7e6733d79599','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-16-7jhnpeppudzn-ContainersCommon-fvja7zmnvotk','da6fb455-528c-442e-8bc3-7e6733d79599','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1127,'c4382bf8-bfb3-478a-a190-7a01260db899','ee7a8f94-aaf3-47d8-944a-b6c0b33e4215','2026-06-15 07:51:31',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-15-iz5wozbvis46','ee7a8f94-aaf3-47d8-944a-b6c0b33e4215','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1128,'c5930771-0526-4a90-a8e9-5f9c9b5f6dd4','ee7a8f94-aaf3-47d8-944a-b6c0b33e4215','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-15-iz5wozbvis46','ee7a8f94-aaf3-47d8-944a-b6c0b33e4215','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1129,'ccf67e19-4d9a-491a-84f0-ae9d75e59ff7','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','10','cd39c2c5-5e0c-46c3-a60f-7eb39cc551df','state changed','OS::TripleO::Services::NovaCompute',NULL,641),(1130,'a58aeaa3-0160-41ba-83ed-d31b6f4e920a','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:31',NULL,'CREATE','COMPLETE','4','1a4ac5d8-cfe6-47eb-b183-2b18ce72e464','state changed','OS::TripleO::Services::CinderApi',NULL,617),(1131,'0cc9070a-6981-4ebf-b283-024a041fc754','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-ContainersCommon-bly3menjepyp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1132,'31c641a6-5778-45ee-829c-fa4f70a97781','fbe26fe0-a377-442f-be65-ad714d411fd7','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-ContainersCommon-bly3menjepyp','fbe26fe0-a377-442f-be65-ad714d411fd7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1133,'c1be4a3a-98f2-4518-919e-b73489b648be','fbe26fe0-a377-442f-be65-ad714d411fd7','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-ContainersCommon-bly3menjepyp','fbe26fe0-a377-442f-be65-ad714d411fd7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1134,'fa3acadb-9b84-4a2c-9d99-f3e348e43868','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderBase-o5gw5xlvffz4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,733),(1135,'7e270d8a-bb6c-45bf-b43c-7ec86d8fb0ed','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-ContainersCommon-pojwawq3eypr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1136,'69abb5c5-d5b7-4564-a9f7-bfb1285a48f9','7888c0bf-ce18-40b7-a7d3-a02b23210bc6','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-ContainersCommon-pojwawq3eypr','7888c0bf-ce18-40b7-a7d3-a02b23210bc6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1137,'53e4db8b-5e91-4c00-8ad3-574ccdd679a1','7888c0bf-ce18-40b7-a7d3-a02b23210bc6','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-ContainersCommon-pojwawq3eypr','7888c0bf-ce18-40b7-a7d3-a02b23210bc6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1138,'1f0f53b4-7ba1-4bb6-adac-9203bab85eab','3fb1bcf4-a4c6-42ee-bea9-442c19517231','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderBase-o5gw5xlvffz4','3fb1bcf4-a4c6-42ee-bea9-442c19517231','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1139,'1129384d-711d-4659-a6c7-3a8d0a6b85ec','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','MySQLClient','73cdd861-748e-4a08-8f76-11ea34c427ca','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1140,'b6f371b4-18b1-4382-b57d-ab82603db421','3fb1bcf4-a4c6-42ee-bea9-442c19517231','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderBase-o5gw5xlvffz4','3fb1bcf4-a4c6-42ee-bea9-442c19517231','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1141,'a17f986f-1b4e-4869-b4f0-b085f5a55387','65ccb74f-36ce-4382-b439-87891988de3b','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','CinderNVMeOF','29ea976f-a72a-4957-8c68-fd8d1c948bef','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1142,'02a75415-6298-499e-b71e-7a990e4ea8d3','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','8','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo','state changed','OS::TripleO::Services::Clustercheck',NULL,747),(1143,'6eed6762-dea8-46c9-aaf0-635c9f53d57a','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-RoleParametersValue-kdapqyh6zyf3','state changed','OS::Heat::Value',NULL,748),(1144,'76782cc3-650a-4604-b520-e52c140e8147','65ccb74f-36ce-4382-b439-87891988de3b','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe-CinderCommon-jcxp5s2ewkqp','65ccb74f-36ce-4382-b439-87891988de3b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1145,'694364ff-f721-4fc6-92b9-7304d8e5c184','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-RoleParametersValue-kdapqyh6zyf3','state changed','OS::Heat::Value',NULL,748),(1146,'9b14fee9-7cb6-4ef8-8cc4-eb7078675bfc','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','ContainersCommon','28ab2450-b18d-420b-8135-f863614da873','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1147,'82306bbb-b1d2-4046-b69f-72a3e4166deb','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','14','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-14-u4mdifrs44hy','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,750),(1148,'c454ad11-adf4-48d8-a43a-696a17156eb9','5096a856-b601-49ca-8096-18e0e4a1f594','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo','5096a856-b601-49ca-8096-18e0e4a1f594','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1149,'6fc1b4dc-de14-486e-80ee-a613b1319a8d','35803aaa-ca0f-4bcc-963f-b5c677f0dcd8','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-16-7jhnpeppudzn-RoleParametersValue-2w6mr3eaeyod','state changed','OS::Heat::Value',NULL,751),(1150,'b2ce3c0c-3fa6-423b-89b4-bb3444be112f','35803aaa-ca0f-4bcc-963f-b5c677f0dcd8','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-16-7jhnpeppudzn-RoleParametersValue-2w6mr3eaeyod','state changed','OS::Heat::Value',NULL,751),(1151,'b9903d79-eec7-44b4-ab3c-44630bf4dd44','db82c802-15e7-45d8-8a0d-78c14e56794a','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-14-u4mdifrs44hy','db82c802-15e7-45d8-8a0d-78c14e56794a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1152,'0adcc26e-a8a6-4e45-ac32-7da5110a8b5f','5096a856-b601-49ca-8096-18e0e4a1f594','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-ContainersCommon-ml4olqhor5y6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1153,'a9e3ef78-34e1-4602-8d6c-d65f94741f9a','35803aaa-ca0f-4bcc-963f-b5c677f0dcd8','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','ContainersCommon','da6fb455-528c-442e-8bc3-7e6733d79599','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1154,'860b958c-45d7-4327-b90d-b0f0f8a0db99','ba877af2-43e2-4f2f-845d-37b536acf030','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-ContainersCommon-ml4olqhor5y6','ba877af2-43e2-4f2f-845d-37b536acf030','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1155,'b6a2da0f-4f1c-46d0-b61d-f845add68a3c','db82c802-15e7-45d8-8a0d-78c14e56794a','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-14-u4mdifrs44hy-ContainersCommon-gyidcqmegh7e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1156,'2e75c1b7-35c6-46cb-9675-8548b3bd3ea0','35803aaa-ca0f-4bcc-963f-b5c677f0dcd8','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-16-7jhnpeppudzn','35803aaa-ca0f-4bcc-963f-b5c677f0dcd8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1157,'5c8a2903-00b5-41a5-afcd-18da6b9437f1','ba877af2-43e2-4f2f-845d-37b536acf030','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-ContainersCommon-ml4olqhor5y6','ba877af2-43e2-4f2f-845d-37b536acf030','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1158,'4c15364f-7f80-424c-90a0-06895bdd69bd','fce29fce-0c88-470e-8aa4-91072e492909','2026-06-15 07:51:32',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-14-u4mdifrs44hy-ContainersCommon-gyidcqmegh7e','fce29fce-0c88-470e-8aa4-91072e492909','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1159,'220c820f-8fc3-4457-b5b1-3e79a9ddf5bb','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','15','ee7a8f94-aaf3-47d8-944a-b6c0b33e4215','state changed','OS::TripleO::Services::Podman',NULL,729),(1160,'ae3885b1-3cb0-4cfa-ae43-25d4ad6da675','fce29fce-0c88-470e-8aa4-91072e492909','2026-06-15 07:51:32',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-14-u4mdifrs44hy-ContainersCommon-gyidcqmegh7e','fce29fce-0c88-470e-8aa4-91072e492909','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1161,'57f97393-14e3-436e-b33b-8305d3f227b4','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','19','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-19-y6np6k55wtrz','state changed','OS::TripleO::Services::Timesync',NULL,753),(1162,'c23328b3-7251-4f80-8dac-5d823475b5d9','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderCommon-dweqnov2qsxn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1163,'85e885a8-9e22-4894-b7d4-0470ffaa3f40','105dff92-be3c-4c3b-ad23-2dcacbaca4b1','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderCommon-dweqnov2qsxn','105dff92-be3c-4c3b-ad23-2dcacbaca4b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1164,'f0715658-5499-4a25-bcee-e0c854d76d8b','69e953bb-1a6b-4e69-b559-139309436f67','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-19-y6np6k55wtrz','69e953bb-1a6b-4e69-b559-139309436f67','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1165,'da452392-7f65-4604-9d30-2038e9f39ea3','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','ContainersCommon','fbe26fe0-a377-442f-be65-ad714d411fd7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1166,'4537be26-d01a-4435-a91b-92e9cc0ea1d8','69e953bb-1a6b-4e69-b559-139309436f67','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-19-y6np6k55wtrz','69e953bb-1a6b-4e69-b559-139309436f67','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1167,'5da74ec3-40e5-4f75-ad0a-363d9bd0f054','105dff92-be3c-4c3b-ad23-2dcacbaca4b1','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderCommon-dweqnov2qsxn-ContainersCommon-l3ibgwzknszc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1168,'9ef82d5d-ffcb-4dfc-b061-303580ba26a5','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','ContainersCommon','7888c0bf-ce18-40b7-a7d3-a02b23210bc6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1169,'92b798cb-eb97-4b3e-a043-3f56797bf439','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','CinderCommon','65ccb74f-36ce-4382-b439-87891988de3b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1170,'08effc68-746c-44d7-a8f8-f13a80e696b5','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','CinderBase','3fb1bcf4-a4c6-42ee-bea9-442c19517231','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,733),(1171,'e6e4404b-2cd3-4d27-b80d-b01b2822c84b','2bd433b5-1498-4da1-bf36-62c9b986e7ec','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderCommon-dweqnov2qsxn-ContainersCommon-l3ibgwzknszc','2bd433b5-1498-4da1-bf36-62c9b986e7ec','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1172,'e06d8b97-8d08-4783-b15c-5a316f8e7f74','93c9336c-609a-4156-a6c6-57736adf9bc8','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-6-rnh3nwszxxqe','93c9336c-609a-4156-a6c6-57736adf9bc8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1173,'3f1d0bbf-ed9a-4ce8-9847-162d7ba748d7','2bd433b5-1498-4da1-bf36-62c9b986e7ec','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderCommon-dweqnov2qsxn-ContainersCommon-l3ibgwzknszc','2bd433b5-1498-4da1-bf36-62c9b986e7ec','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1174,'c217e032-e0b4-4564-8e8c-9c5b7d2ee838','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderBase-eilm6nmrrkpe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,754),(1175,'09ce476e-ff73-4884-aa2a-f1d1619c72b5','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','16','35803aaa-ca0f-4bcc-963f-b5c677f0dcd8','state changed','OS::TripleO::Services::Rsyslog',NULL,721),(1176,'f11d96cd-e8b6-4c73-b16c-acd8175b366b','1b77c250-e303-49cc-a9a6-dee8031531bf','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderBase-eilm6nmrrkpe','1b77c250-e303-49cc-a9a6-dee8031531bf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1177,'87a8e04c-de72-4109-8dbd-8c3f7e0e6ff5','1b77c250-e303-49cc-a9a6-dee8031531bf','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderBase-eilm6nmrrkpe','1b77c250-e303-49cc-a9a6-dee8031531bf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1178,'cb702862-602a-48c2-9a6d-69adc6b4367c','5096a856-b601-49ca-8096-18e0e4a1f594','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-RoleParametersValue-wq2mno25rczm','state changed','OS::Heat::Value',NULL,758),(1179,'21a88343-dd07-4759-a3a4-68254acb0e6f','5096a856-b601-49ca-8096-18e0e4a1f594','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-RoleParametersValue-wq2mno25rczm','state changed','OS::Heat::Value',NULL,758),(1180,'63c19cc8-7e5c-4348-8ae9-de99d412119a','db82c802-15e7-45d8-8a0d-78c14e56794a','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-14-u4mdifrs44hy-RoleParametersValue-teqxuq5wf433','state changed','OS::Heat::Value',NULL,759),(1181,'cc17a286-28cf-479f-ad46-61b5051fb77b','db82c802-15e7-45d8-8a0d-78c14e56794a','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-14-u4mdifrs44hy-RoleParametersValue-teqxuq5wf433','state changed','OS::Heat::Value',NULL,759),(1182,'6d734c69-a256-401e-b347-1f55542f475c','5096a856-b601-49ca-8096-18e0e4a1f594','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','ContainersCommon','ba877af2-43e2-4f2f-845d-37b536acf030','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1183,'860243c8-929e-4b2b-9ba0-44f625f5d9ae','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','20','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-20-rkxqtasvp4q2','state changed','OS::TripleO::Services::Timezone',NULL,760),(1184,'6d4ab588-753e-4996-901f-61eda36d1d3e','916dc4b1-ec1e-49fd-b79d-73b1ef627a97','2026-06-15 07:51:33',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-20-rkxqtasvp4q2','916dc4b1-ec1e-49fd-b79d-73b1ef627a97','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1185,'a6cb28af-3707-4075-8403-6301c9d8218e','db82c802-15e7-45d8-8a0d-78c14e56794a','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','ContainersCommon','fce29fce-0c88-470e-8aa4-91072e492909','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1186,'85176c91-e5bc-4466-9a23-b716d9c71755','916dc4b1-ec1e-49fd-b79d-73b1ef627a97','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-20-rkxqtasvp4q2','916dc4b1-ec1e-49fd-b79d-73b1ef627a97','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1187,'133872f1-6f02-40da-aebb-96111dd96eb3','db82c802-15e7-45d8-8a0d-78c14e56794a','2026-06-15 07:51:33',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-14-u4mdifrs44hy','db82c802-15e7-45d8-8a0d-78c14e56794a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1188,'d27fde01-5cb5-40bf-9804-20754e4d7d5d','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','6','93c9336c-609a-4156-a6c6-57736adf9bc8','state changed','OS::TripleO::Services::CinderScheduler',NULL,692),(1189,'c5f9383c-d597-477a-9750-56b5aca1656c','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,761),(1190,'2defca5d-1e05-4ce4-b4d3-4714c09a8d3a','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','19','69e953bb-1a6b-4e69-b559-139309436f67','state changed','OS::TripleO::Services::Timesync',NULL,753),(1191,'0cb2a546-7ae9-4ba3-bb9d-37cad6766ee0','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1192,'c740615d-5b5d-4fd3-8dbc-aaf0ad3ffc4b','105dff92-be3c-4c3b-ad23-2dcacbaca4b1','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderCommon-dweqnov2qsxn-CinderNVMeOF-7queb5hkxsez','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1193,'83c013fa-fb70-45c3-bd94-fce28c696ef4','105dff92-be3c-4c3b-ad23-2dcacbaca4b1','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','ContainersCommon','2bd433b5-1498-4da1-bf36-62c9b986e7ec','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1194,'0ba3c6d7-62fa-4a87-aa40-e8fb1f257c8d','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderCommon-viovaskm2eqb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1195,'930cc987-f00d-4f21-85e1-6574b753addc','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','23','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-23-2g5ohnwfejre','state changed','OS::TripleO::Services::Tuned',NULL,764),(1196,'062b3c86-dad9-42cd-8f4d-428ef5224851','df35a92a-c96c-4cd1-962d-47c06aa18039','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderCommon-dweqnov2qsxn-CinderNVMeOF-7queb5hkxsez','df35a92a-c96c-4cd1-962d-47c06aa18039','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1197,'f91343ab-d169-4ab2-997e-136440a8cc62','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderCommon-pov6oywmkh3w','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1198,'78fb5528-401c-4c82-8b8a-ee7381a5096d','df35a92a-c96c-4cd1-962d-47c06aa18039','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderCommon-dweqnov2qsxn-CinderNVMeOF-7queb5hkxsez','df35a92a-c96c-4cd1-962d-47c06aa18039','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1199,'6951a7d1-707f-49ae-bc77-d02591cedae2','1c463f6a-7870-46fe-91e2-0e00819940b6','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderCommon-viovaskm2eqb','1c463f6a-7870-46fe-91e2-0e00819940b6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1200,'2609d369-ee8c-4eb7-b826-a0369201e125','5cd3522c-fc36-4a32-95d6-b583b5cee24c','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-23-2g5ohnwfejre','5cd3522c-fc36-4a32-95d6-b583b5cee24c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1201,'72f171c6-a1b0-4ce7-bc07-54ddef967cec','dabad9ee-89b2-4d66-b417-fa6b733811d1','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderCommon-pov6oywmkh3w','dabad9ee-89b2-4d66-b417-fa6b733811d1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1202,'640cf5f3-85a2-4742-86b9-056939c9804a','5cd3522c-fc36-4a32-95d6-b583b5cee24c','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-23-2g5ohnwfejre-RoleParametersValue-ajmaaesvrdiv','state changed','OS::Heat::Value',NULL,770),(1203,'1b9b1448-632b-45bb-9bc5-deef331e2255','1c463f6a-7870-46fe-91e2-0e00819940b6','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderCommon-viovaskm2eqb-CinderNVMeOF-p4myvswx5xlw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1204,'342dc0e2-5eec-4780-ba87-791d87670ed7','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','CinderBase','1b77c250-e303-49cc-a9a6-dee8031531bf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,754),(1205,'416ae2cb-5976-474c-8c47-27d0eea8d6c6','5cd3522c-fc36-4a32-95d6-b583b5cee24c','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-23-2g5ohnwfejre-RoleParametersValue-ajmaaesvrdiv','state changed','OS::Heat::Value',NULL,770),(1206,'3ee5d215-a4e3-4de4-85a5-ce72f1951f5c','5cd3522c-fc36-4a32-95d6-b583b5cee24c','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-23-2g5ohnwfejre','5cd3522c-fc36-4a32-95d6-b583b5cee24c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1207,'1424a7c7-573f-4941-908b-141eb9262480','dabad9ee-89b2-4d66-b417-fa6b733811d1','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderCommon-pov6oywmkh3w-ContainersCommon-sq6nal2zdsua','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1208,'184b0cf9-5bb9-4176-8de6-006629d9e9c2','915a1dbf-7f9e-480d-8fb7-139409f039c2','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderCommon-viovaskm2eqb-CinderNVMeOF-p4myvswx5xlw','915a1dbf-7f9e-480d-8fb7-139409f039c2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1209,'3736f941-9f95-485c-800f-c2405aeb7047','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','14','db82c802-15e7-45d8-8a0d-78c14e56794a','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,750),(1210,'2111f540-2b4b-43a3-9550-37c799babb20','915a1dbf-7f9e-480d-8fb7-139409f039c2','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderCommon-viovaskm2eqb-CinderNVMeOF-p4myvswx5xlw','915a1dbf-7f9e-480d-8fb7-139409f039c2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1211,'404fead6-b10a-45a9-9ec5-ad401197086d','5096a856-b601-49ca-8096-18e0e4a1f594','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','MysqlPuppetBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,773),(1212,'b049dfe8-3884-4012-9790-81f1c7a6bbde','298ba484-417c-4a91-93e8-7009e6798f01','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderCommon-pov6oywmkh3w-ContainersCommon-sq6nal2zdsua','298ba484-417c-4a91-93e8-7009e6798f01','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1213,'8bbd22a3-1d2b-49cf-8ebe-331075c4c032','298ba484-417c-4a91-93e8-7009e6798f01','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderCommon-pov6oywmkh3w-ContainersCommon-sq6nal2zdsua','298ba484-417c-4a91-93e8-7009e6798f01','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1214,'277142b2-2a9d-46e2-acee-533735bfa403','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','10','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-10-hljtxjrs6sqb','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,775),(1215,'ece73ecb-d796-400b-bc95-00e8c4a00478','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1216,'2cf60b3c-a900-409e-a95f-d6c7075800ef','71cfa86e-d350-48ce-aa2e-d9415c586dcb','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-10-hljtxjrs6sqb','71cfa86e-d350-48ce-aa2e-d9415c586dcb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1217,'56216710-56a3-479a-bef9-2a117675df28','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','20','916dc4b1-ec1e-49fd-b79d-73b1ef627a97','state changed','OS::TripleO::Services::Timezone',NULL,760),(1218,'d804504d-940b-476c-83be-d9f164fe8081','71cfa86e-d350-48ce-aa2e-d9415c586dcb','2026-06-15 07:51:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-10-hljtxjrs6sqb','71cfa86e-d350-48ce-aa2e-d9415c586dcb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1219,'09f16a76-cb54-4387-84c6-7be93802c0f6','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','18','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-18-agsogyr5op37','state changed','OS::TripleO::Services::Sshd',NULL,778),(1220,'23671fe8-fbc0-4a78-b619-c59f39165d4a','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','2026-06-15 07:51:34',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl-MysqlBase-fzihrr6lhfsk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,779),(1221,'6d46f7d9-9077-43b3-8ce0-3355a015e40f','8d4e235f-b05c-4763-822b-e93f6d14910f','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-18-agsogyr5op37','8d4e235f-b05c-4763-822b-e93f6d14910f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1222,'dcded405-3730-4a5d-8a74-e943ef0a2f5b','8d4e235f-b05c-4763-822b-e93f6d14910f','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-18-agsogyr5op37','8d4e235f-b05c-4763-822b-e93f6d14910f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1223,'3d2d8a0f-a3c8-43b9-b3b0-cde2ee54fa95','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','18','8d4e235f-b05c-4763-822b-e93f6d14910f','state changed','OS::TripleO::Services::Sshd',NULL,778),(1224,'e5fc9778-69e9-4aaf-96c7-3a53a94b899f','ea40a9ee-fd14-4f20-a4cc-682fcaa9ffbc','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl-MysqlBase-fzihrr6lhfsk','ea40a9ee-fd14-4f20-a4cc-682fcaa9ffbc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1225,'6d32a517-c3eb-4b00-bcdb-60c4a4b5f2e5','ea40a9ee-fd14-4f20-a4cc-682fcaa9ffbc','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl-MysqlBase-fzihrr6lhfsk','ea40a9ee-fd14-4f20-a4cc-682fcaa9ffbc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1226,'10e3759c-7fdf-4961-be0f-1b58b6b2a057','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','24','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4','state changed','OS::TripleO::Services::OVNController',NULL,781),(1227,'1fa469f3-e096-42d6-ab25-c6897a2a9d0e','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1228,'e6969448-6965-4705-9d81-7872b8db771c','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','22','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-22-4kjqrtmhuije','state changed','OS::TripleO::Services::TripleoPackages',NULL,783),(1229,'95ea901a-e0a9-42eb-b5b6-e17269d5e23c','9c265253-6553-49de-a4d0-ea12a248551c','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-22-4kjqrtmhuije','9c265253-6553-49de-a4d0-ea12a248551c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1230,'6d86ac3a-6a2f-4055-9e18-17230b06f2c5','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4-OVNBridgeMappingsValue-ijtobuhv74bg','state changed','OS::Heat::Value',NULL,784),(1231,'26218740-1051-49a1-b098-7c883f203580','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4-OVNBridgeMappingsValue-ijtobuhv74bg','state changed','OS::Heat::Value',NULL,784),(1232,'f1e51037-e9cf-4966-a9d6-729a78e050c6','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-RoleParametersValue-key446o4ukad','state changed','OS::Heat::Value',NULL,785),(1233,'25f009cf-39ce-41b0-bbef-854e59f2dec4','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-RoleParametersValue-key446o4ukad','state changed','OS::Heat::Value',NULL,785),(1234,'dbbdfb80-4a73-438e-8c92-d87e958dee4b','9c265253-6553-49de-a4d0-ea12a248551c','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-22-4kjqrtmhuije-Podman-vogmjljlew7b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,786),(1235,'397fbc00-2121-41c0-85f9-67550488bf0d','105dff92-be3c-4c3b-ad23-2dcacbaca4b1','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','CinderNVMeOF','df35a92a-c96c-4cd1-962d-47c06aa18039','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1236,'4c464370-6edb-45e5-a1a3-5a97a0f73457','105dff92-be3c-4c3b-ad23-2dcacbaca4b1','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderCommon-dweqnov2qsxn','105dff92-be3c-4c3b-ad23-2dcacbaca4b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1237,'54c51d97-d149-4ee0-b22b-ccd6749fa3cc','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','23','5cd3522c-fc36-4a32-95d6-b583b5cee24c','state changed','OS::TripleO::Services::Tuned',NULL,764),(1238,'542e45e6-aadd-406d-86fd-5cf0b7bd1c27','4c5c8123-105d-480f-9e98-d11a98e34c8d','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-22-4kjqrtmhuije-Podman-vogmjljlew7b','4c5c8123-105d-480f-9e98-d11a98e34c8d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1239,'bd7a367a-b32f-4547-b462-b812ba35df8c','4c5c8123-105d-480f-9e98-d11a98e34c8d','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-22-4kjqrtmhuije-Podman-vogmjljlew7b','4c5c8123-105d-480f-9e98-d11a98e34c8d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1240,'50abebf3-0cf6-480c-aa83-3bd0ff2d0fd4','1c463f6a-7870-46fe-91e2-0e00819940b6','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderCommon-viovaskm2eqb-ContainersCommon-kndihg7o27si','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1241,'4734e32b-2670-45b7-9f09-dca06c088a10','dabad9ee-89b2-4d66-b417-fa6b733811d1','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderCommon-pov6oywmkh3w-CinderNVMeOF-sbdbi23qiw66','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1242,'00b3f8bb-f123-4d90-8217-b1dcbf92ec15','d31f64aa-ca27-46c2-b9ad-82989950e089','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderCommon-viovaskm2eqb-ContainersCommon-kndihg7o27si','d31f64aa-ca27-46c2-b9ad-82989950e089','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1243,'a4736606-ff6b-4fd3-ae42-5fff9ed85838','1c463f6a-7870-46fe-91e2-0e00819940b6','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','CinderNVMeOF','915a1dbf-7f9e-480d-8fb7-139409f039c2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1244,'03302f6d-3504-41d0-a9ee-55884e7f12f2','d31f64aa-ca27-46c2-b9ad-82989950e089','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderCommon-viovaskm2eqb-ContainersCommon-kndihg7o27si','d31f64aa-ca27-46c2-b9ad-82989950e089','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1245,'e1dbd56d-0588-470d-8d8c-881b27119346','b09b1a45-7d07-4bb8-8a5f-32bd96e4fcef','2026-06-15 07:51:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderCommon-pov6oywmkh3w-CinderNVMeOF-sbdbi23qiw66','b09b1a45-7d07-4bb8-8a5f-32bd96e4fcef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1246,'9c5aba0c-2537-4a55-b867-4416d6f6673d','b09b1a45-7d07-4bb8-8a5f-32bd96e4fcef','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderCommon-pov6oywmkh3w-CinderNVMeOF-sbdbi23qiw66','b09b1a45-7d07-4bb8-8a5f-32bd96e4fcef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1247,'54460252-4421-4fd3-aac5-19d8a2bed5e4','dabad9ee-89b2-4d66-b417-fa6b733811d1','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','ContainersCommon','298ba484-417c-4a91-93e8-7009e6798f01','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1248,'42fd8dc5-cc39-410d-9803-044cbbf3f0e5','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:35',NULL,'CREATE','COMPLETE','10','71cfa86e-d350-48ce-aa2e-d9415c586dcb','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,775),(1249,'0e1800c2-9db5-4dd5-a55b-481fff869834','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl-ContainersCommon-eytjona5kkhj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1250,'37085cdc-1529-46b2-beb5-2d7df67991c9','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','MysqlBase','ea40a9ee-fd14-4f20-a4cc-682fcaa9ffbc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,779),(1251,'0d253e8f-7f9f-4b7b-8e78-e51d69a0154a','55ca051e-05d9-466d-a2e9-4b83219404fb','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl-ContainersCommon-eytjona5kkhj','55ca051e-05d9-466d-a2e9-4b83219404fb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1252,'62c39155-ffce-4221-9d47-24651bc263ea','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','CinderCommon','105dff92-be3c-4c3b-ad23-2dcacbaca4b1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1253,'06f3b821-21c2-4572-9b4e-dc2a5b702a58','55ca051e-05d9-466d-a2e9-4b83219404fb','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl-ContainersCommon-eytjona5kkhj','55ca051e-05d9-466d-a2e9-4b83219404fb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1254,'02252602-fbdb-4726-bf0c-723ea12a58bc','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','14','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3','state changed','OS::TripleO::Services::HeatApi',NULL,788),(1255,'d80f4a14-3542-4edd-9cbf-8062e909c3e5','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4-ContainersCommon-6b6paypja6tp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1256,'c05491d8-1b2e-4afa-8705-33d9ecb43a8f','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1257,'9489d195-df7f-4389-a778-84a70c671f4e','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-MySQLClient-swnxh6dbov4x','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1258,'e207a756-dc52-4821-af38-6208de6c153e','3682f194-cc23-4dec-9c4e-2b4cbc14a4fe','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4-ContainersCommon-6b6paypja6tp','3682f194-cc23-4dec-9c4e-2b4cbc14a4fe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1259,'f0d7e585-b95d-4832-802c-1a88fa201166','9c265253-6553-49de-a4d0-ea12a248551c','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-22-4kjqrtmhuije-RoleParametersValue-y3ghgnpngm5u','state changed','OS::Heat::Value',NULL,789),(1260,'d7054d88-8c60-4702-bc4d-56e81e556f9f','9c265253-6553-49de-a4d0-ea12a248551c','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-22-4kjqrtmhuije-RoleParametersValue-y3ghgnpngm5u','state changed','OS::Heat::Value',NULL,789),(1261,'4ab62298-924a-436f-a1f9-32ae937cadac','403fbbf3-5fd3-4870-ade4-db87b45a283e','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-MySQLClient-swnxh6dbov4x','403fbbf3-5fd3-4870-ade4-db87b45a283e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1262,'e4b13e38-c2ab-45e1-9cd5-cdb1d8086e2e','3682f194-cc23-4dec-9c4e-2b4cbc14a4fe','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4-ContainersCommon-6b6paypja6tp','3682f194-cc23-4dec-9c4e-2b4cbc14a4fe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1263,'407d9791-31d2-4433-81bd-e315b63ab94b','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','HeatApiLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-HeatApiLogging-j2e3yuvjjm34','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1264,'61b149c4-f040-49c9-b25c-fe9f2cba9429','403fbbf3-5fd3-4870-ade4-db87b45a283e','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-MySQLClient-swnxh6dbov4x','403fbbf3-5fd3-4870-ade4-db87b45a283e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1265,'1ed66bdc-72ae-4a7f-bb32-832c6d57ef78','0043fe0b-f8a6-4adf-a3e7-1ed38764042d','2026-06-15 07:51:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-HeatApiLogging-j2e3yuvjjm34','0043fe0b-f8a6-4adf-a3e7-1ed38764042d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1266,'99c05cc3-70e7-44c8-a51b-979f0306d7de','0043fe0b-f8a6-4adf-a3e7-1ed38764042d','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-HeatApiLogging-j2e3yuvjjm34','0043fe0b-f8a6-4adf-a3e7-1ed38764042d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1267,'b9a65f63-476d-4171-a23f-7678402c3a7d','9c265253-6553-49de-a4d0-ea12a248551c','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','Podman','4c5c8123-105d-480f-9e98-d11a98e34c8d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,786),(1268,'1b6bf26a-1d4a-4b53-8ef1-1e145c62f888','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','HeatApiLogging','0043fe0b-f8a6-4adf-a3e7-1ed38764042d','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1269,'082a1dce-701c-4b99-93c5-72d8a871776d','9c265253-6553-49de-a4d0-ea12a248551c','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-22-4kjqrtmhuije','9c265253-6553-49de-a4d0-ea12a248551c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1270,'d138052a-a7a8-45a7-82d6-c15c797be51b','1c463f6a-7870-46fe-91e2-0e00819940b6','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','ContainersCommon','d31f64aa-ca27-46c2-b9ad-82989950e089','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1271,'4cdd6c6b-d677-4b46-91ea-3545653aec23','1c463f6a-7870-46fe-91e2-0e00819940b6','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderCommon-viovaskm2eqb','1c463f6a-7870-46fe-91e2-0e00819940b6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1272,'37278848-9fb5-4b8c-b673-70834ad1853a','dabad9ee-89b2-4d66-b417-fa6b733811d1','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','CinderNVMeOF','b09b1a45-7d07-4bb8-8a5f-32bd96e4fcef','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1273,'71660d9a-76d3-4ea1-b316-94c2db0ba41e','dabad9ee-89b2-4d66-b417-fa6b733811d1','2026-06-15 07:51:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2-CinderCommon-pov6oywmkh3w','dabad9ee-89b2-4d66-b417-fa6b733811d1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1274,'3d0b266e-e584-40b8-9e77-1c33b37c96bb','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','2026-06-15 07:51:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl-RoleParametersValue-666ckr72sku4','state changed','OS::Heat::Value',NULL,790),(1275,'56ca26d9-e723-4850-8d6c-40851f25c98c','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl-RoleParametersValue-666ckr72sku4','state changed','OS::Heat::Value',NULL,790),(1276,'edd8ccc5-1bfc-4124-9375-4575685a7007','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','ContainersCommon','55ca051e-05d9-466d-a2e9-4b83219404fb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1277,'bf7d3070-bc6d-4b9e-8381-a4797e3134cb','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo-MysqlPuppetBase-mjjzy6xwftsl','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1278,'3041d43a-60c8-43f5-8370-736fe5bc2022','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','2026-06-15 07:51:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4-RoleParametersValue-u7jqf4lkco7o','state changed','OS::Heat::Value',NULL,791),(1279,'3d4001aa-4ed5-4b29-9ab2-6f32958467e9','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','22','9c265253-6553-49de-a4d0-ea12a248551c','state changed','OS::TripleO::Services::TripleoPackages',NULL,783),(1280,'ce9f2d88-9a6b-40a2-abc8-67f9c6679788','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4-RoleParametersValue-u7jqf4lkco7o','state changed','OS::Heat::Value',NULL,791),(1281,'0a4c7510-bd6b-4d62-ae22-2781a68d1aa9','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:37',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-ContainersCommon-l35sdteiem7f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1282,'356ba5ff-7506-4078-ba76-cf8a37ddc73a','a71b0d9b-cb92-4548-a6ee-0827f206c578','2026-06-15 07:51:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-ContainersCommon-l35sdteiem7f','a71b0d9b-cb92-4548-a6ee-0827f206c578','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1283,'88c7eb02-e635-460d-992b-10d9774ada61','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','ContainersCommon','3682f194-cc23-4dec-9c4e-2b4cbc14a4fe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1284,'48c05ef6-985a-411b-8104-576a52e19658','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp-24-dmr643qwmfy4','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1285,'560ca7ff-6e97-4e19-bd24-4ed649317904','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','MySQLClient','403fbbf3-5fd3-4870-ade4-db87b45a283e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1286,'e4932e77-6ca4-47ac-9e0d-675498a2a17d','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','CinderCommon','1c463f6a-7870-46fe-91e2-0e00819940b6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1287,'d83f6c85-55a8-4c8c-a021-9146f00f1456','a71b0d9b-cb92-4548-a6ee-0827f206c578','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-ContainersCommon-l35sdteiem7f','a71b0d9b-cb92-4548-a6ee-0827f206c578','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1288,'4ee4726c-312b-4963-9b49-ca9752b5902c','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','CinderCommon','dabad9ee-89b2-4d66-b417-fa6b733811d1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1289,'72a72802-7c6b-4f91-a95c-1b9066413b24','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-RoleParametersValue-ohnclbbrrfcf','state changed','OS::Heat::Value',NULL,792),(1290,'a7fec6bb-ab2c-4884-9791-8b8957a6e45f','b162e745-5326-49e9-94ea-2ff666e079df','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu-CinderBackupBase-65qg34wzgwu2','b162e745-5326-49e9-94ea-2ff666e079df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1291,'382a4e32-165a-4a92-8d0a-2f486ad7f8f8','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-RoleParametersValue-ohnclbbrrfcf','state changed','OS::Heat::Value',NULL,792),(1292,'6adf4fae-842f-4fbe-a09a-9603e1a3add5','5096a856-b601-49ca-8096-18e0e4a1f594','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','MysqlPuppetBase','b7ccab2b-bc58-4dd4-92db-ac94abd2812c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,773),(1293,'954de75d-eff4-4a6b-b484-c61dd7ca7684','5096a856-b601-49ca-8096-18e0e4a1f594','2026-06-15 07:51:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-8-cwm3szfwhcmo','5096a856-b601-49ca-8096-18e0e4a1f594','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1294,'ba7a8bf2-2841-468d-8c0f-e016d1dd0292','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','CinderBackupBase','b162e745-5326-49e9-94ea-2ff666e079df','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,712),(1295,'85e482f2-f745-4a53-b86d-690b56adca30','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','24','e1855787-b7c4-4ddf-abe6-266d8bb42aa2','state changed','OS::TripleO::Services::OVNController',NULL,781),(1296,'5a533d25-527f-4f31-94a0-6e64d55b55f8','cc2a5e46-b213-4701-b668-8866c5b6a79c','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-5-3wavbejxumuu','cc2a5e46-b213-4701-b668-8866c5b6a79c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1297,'d7fc5510-2e35-4aab-b5a4-3bddf7b2c668','71a179de-ee93-4230-b66f-816668a8b4d7','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceChain-mrdweyolkltp','71a179de-ee93-4230-b66f-816668a8b4d7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1298,'f71dc699-925c-4db2-af64-69b3c7bd44bf','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:38',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderBase-4n2ayrhopqwm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,793),(1299,'22e7c7d3-d723-4859-9b40-6eadf6e2a815','d38561e9-8e99-4e00-9ff9-42c0ba1e8ff0','2026-06-15 07:51:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderBase-4n2ayrhopqwm','d38561e9-8e99-4e00-9ff9-42c0ba1e8ff0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1300,'c5c7d2da-f9a6-4f10-ad64-31e034f18ff8','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','ContainersCommon','a71b0d9b-cb92-4548-a6ee-0827f206c578','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1301,'d48f7b0c-392f-4c92-80ec-97960ba1aaa0','d38561e9-8e99-4e00-9ff9-42c0ba1e8ff0','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib-CinderBase-4n2ayrhopqwm','d38561e9-8e99-4e00-9ff9-42c0ba1e8ff0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1302,'b4788e01-809c-435a-ba9c-8b55112c4b25','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:38',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-ContainersCommon-q22cpywefzwi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1303,'e57a3a6a-4de1-4c3f-afe6-1996a2d29dc3','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','8','5096a856-b601-49ca-8096-18e0e4a1f594','state changed','OS::TripleO::Services::Clustercheck',NULL,747),(1304,'7e113c19-b7b0-487f-a908-4707ce6c0481','32a07311-a6aa-455b-bcd7-e701023bb7c1','2026-06-15 07:51:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-ContainersCommon-q22cpywefzwi','32a07311-a6aa-455b-bcd7-e701023bb7c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1305,'06b47a36-76dc-41bb-8f54-cd8c20f898c8','32a07311-a6aa-455b-bcd7-e701023bb7c1','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-ContainersCommon-q22cpywefzwi','32a07311-a6aa-455b-bcd7-e701023bb7c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1306,'0ae83578-63f5-4e26-9099-fa975f722386','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','ServiceChain','71a179de-ee93-4230-b66f-816668a8b4d7','state changed','OS::Heat::ResourceChain',NULL,89),(1307,'331d7352-566d-4fb8-8798-b5be3473e5ad','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:38',NULL,'CREATE','COMPLETE','5','cc2a5e46-b213-4701-b668-8866c5b6a79c','state changed','OS::TripleO::Services::CinderBackup',NULL,691),(1308,'b0934925-4c36-4dc4-816e-fd7ea0bd4fa2','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:39',NULL,'CREATE','IN_PROGRESS','12','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,805),(1309,'2077b54e-10eb-4721-994e-787aa03b8cb8','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v','9888bb6e-8436-4978-8ef0-21919b985cfc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1310,'c844d2b9-5b39-4f20-ac9a-dfdf9ec007db','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:39',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-HeatBase-go4s64kylhcp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,814),(1311,'870129c5-1293-47c2-ac70-0564512a962d','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:39',NULL,'CREATE','COMPLETE','CinderBase','d38561e9-8e99-4e00-9ff9-42c0ba1e8ff0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,793),(1312,'99397cb2-b33d-4320-acea-13357f1aaf4b','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','2026-06-15 07:51:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b-CinderBase-melgokexbjib','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1313,'a1b95173-89f2-4c3e-89c7-f6d8b9e28d89','83230141-6d4a-444a-8763-f64b92657ce0','2026-06-15 07:51:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-HeatBase-go4s64kylhcp','83230141-6d4a-444a-8763-f64b92657ce0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1314,'1bcd4308-2fc9-407a-bc4a-e1691f590422','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:39',NULL,'CREATE','COMPLETE','ContainersCommon','32a07311-a6aa-455b-bcd7-e701023bb7c1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1315,'dc4bd355-0186-4956-a644-1cccb013b79e','83230141-6d4a-444a-8763-f64b92657ce0','2026-06-15 07:51:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-HeatBase-go4s64kylhcp','83230141-6d4a-444a-8763-f64b92657ce0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1316,'f672dd1e-88c9-4e0b-8362-217884d33cf9','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-RoleParametersValue-ep2bdei7dbcf','state changed','OS::Heat::Value',NULL,822),(1317,'a9fc1171-2d45-4424-a11d-3cef12cd5950','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-RoleParametersValue-ep2bdei7dbcf','state changed','OS::Heat::Value',NULL,822),(1318,'19a12af1-7626-424d-9376-a5ef7f778f5d','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:39',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceNames-z6fucoqhhfvb','state changed','OS::Heat::Value',NULL,832),(1319,'3da5e661-466c-42e9-bca1-f2d51ecfb23a','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceNames-z6fucoqhhfvb','state changed','OS::Heat::Value',NULL,832),(1320,'3e71f4a4-a1c4-4ca8-afb3-0052c8fddcf4','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','9','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-9-ox2boqr6myo2','state changed','OS::TripleO::Services::Collectd',NULL,835),(1321,'0cc927c5-f0d9-48d6-ad62-77cd84424ae6','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-HostFirewallTasks-s7semd5lk4r5','state changed','OS::Heat::Value',NULL,834),(1322,'e40621ec-a28d-4b86-82a5-c1d852f8ef08','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ExternalDeployTasks-5zkw7dxvrdaq','state changed','OS::Heat::Value',NULL,836),(1323,'389e2e29-18b1-4a14-ae6f-844253636f62','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ExternalDeployTasks-5zkw7dxvrdaq','state changed','OS::Heat::Value',NULL,836),(1324,'6d22d73a-b465-4b78-9cf3-43c5b1a80818','7ac6a40f-f7b1-4575-9ac1-48956271ee52','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-9-ox2boqr6myo2','7ac6a40f-f7b1-4575-9ac1-48956271ee52','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1325,'3099fa43-be55-4568-bfa5-fe05cb5c9561','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-HostFirewallTasks-s7semd5lk4r5','state changed','OS::Heat::Value',NULL,834),(1326,'0c6bd4a9-1979-46f3-bfdd-5c4dd537e0dc','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-KollaConfig-qn5gkucxzzav','state changed','OS::Heat::Value',NULL,837),(1327,'c4028fa7-daff-460b-a365-939e7d30e155','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','CinderBase','5179b57c-8afe-4d8c-b702-1a5608ca3ccc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,761),(1328,'b45c74c5-d061-46a8-828e-ea7f33eef924','5db58455-289a-400c-b099-4132d52e2911','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-7-ys5dnycab45b','5db58455-289a-400c-b099-4132d52e2911','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1329,'916f2738-ea48-43ff-831b-77854d735f8e','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-KollaConfig-qn5gkucxzzav','state changed','OS::Heat::Value',NULL,837),(1330,'74ac3472-e55c-49d8-9bc0-5dfb0a2c0605','7ac6a40f-f7b1-4575-9ac1-48956271ee52','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-9-ox2boqr6myo2-ContainersCommon-p46jv2vaf7fv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1331,'9abd6163-01c8-4536-9238-cf4e908c8c7d','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ExternalUpdateTasks-cc33jetypcov','state changed','OS::Heat::Value',NULL,838),(1332,'599228ac-9867-4162-b08d-e6a66f3655fc','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ExternalUpdateTasks-cc33jetypcov','state changed','OS::Heat::Value',NULL,838),(1333,'1642cf41-afe2-43f5-9259-e14c3b091061','69a69900-0a1b-4629-909f-3f7e7b0fec8d','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-9-ox2boqr6myo2-ContainersCommon-p46jv2vaf7fv','69a69900-0a1b-4629-909f-3f7e7b0fec8d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1334,'0fd3f0fc-d311-4417-af75-09580e2c814a','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ContainerPuppetTasks-lmzfkkptqbut','state changed','OS::Heat::Value',NULL,839),(1335,'465ad5d6-6a86-41df-9407-19681583f9de','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-ApacheServiceBase-z5ix43mkrudb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,840),(1336,'3d99658d-e664-46e4-b908-aeb02e6c676d','69a69900-0a1b-4629-909f-3f7e7b0fec8d','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-9-ox2boqr6myo2-ContainersCommon-p46jv2vaf7fv','69a69900-0a1b-4629-909f-3f7e7b0fec8d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1337,'62a72b0a-a88d-4360-9cac-81d840ed8928','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-DockerPuppetTasks-fmigah6birkv','state changed','OS::Heat::Value',NULL,841),(1338,'088862b3-b63c-400e-a610-08790cc2f436','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-DockerPuppetTasks-fmigah6birkv','state changed','OS::Heat::Value',NULL,841),(1339,'bd697a82-9221-4ea4-bfb8-0470874ff35f','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ContainerPuppetTasks-lmzfkkptqbut','state changed','OS::Heat::Value',NULL,839),(1340,'2c55977c-4aff-4ac3-8c94-c69995e1017d','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','HeatBase','83230141-6d4a-444a-8763-f64b92657ce0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,814),(1341,'898a658d-e752-48e4-a9b5-e78e75acf178','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceLogging-733muzj3ds7p','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1342,'4daf799f-fa4d-40ab-8b81-939ca4ca84f7','57daa34a-9206-4a7c-9592-3af81039314a','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceLogging-733muzj3ds7p','57daa34a-9206-4a7c-9592-3af81039314a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1343,'3bf0d13d-996f-4c9a-b1b4-36a7ac4f32cb','2f578f6e-53ff-4f33-b853-d0c7c1272d11','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-ApacheServiceBase-z5ix43mkrudb','2f578f6e-53ff-4f33-b853-d0c7c1272d11','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1344,'da33a5bd-8e2b-4444-8d5d-e46e820430ac','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-PuppetConfig-mv7cgizayhxy','state changed','OS::Heat::Value',NULL,842),(1345,'d0445d9b-3352-431c-9d9f-0789c6f3847d','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ComputeServiceChain-ksxcyuw5eues-DockerConfigScripts-knsxk5xxhanb','state changed','OS::Heat::Value',NULL,843),(1346,'e69d1ba6-2958-420a-953c-be57198c02e1','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-PuppetConfig-mv7cgizayhxy','state changed','OS::Heat::Value',NULL,842),(1347,'57cf2dfd-7a9d-4b52-b017-21136838e98b','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ComputeServiceChain-ksxcyuw5eues-DockerConfigScripts-knsxk5xxhanb','state changed','OS::Heat::Value',NULL,843),(1348,'5f54a487-bb04-4876-959a-aeb796df2304','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-UpdateTasks-neirxbd3if6h','state changed','OS::Heat::Value',NULL,845),(1349,'162d7fa6-8141-4854-8ce0-77f33155b302','57daa34a-9206-4a7c-9592-3af81039314a','2026-06-15 07:51:40',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceLogging-733muzj3ds7p-RoleParametersValue-d6skbwglj6ll','state changed','OS::Heat::Value',NULL,844),(1350,'5fd48b24-b841-4d40-96e7-734d0c6d3baf','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:40',NULL,'CREATE','COMPLETE','7','5db58455-289a-400c-b099-4132d52e2911','state changed','OS::TripleO::Services::CinderVolume',NULL,703),(1351,'f7837813-ea33-483f-860b-62561541304b','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-UpdateTasks-neirxbd3if6h','state changed','OS::Heat::Value',NULL,845),(1352,'4b0324b6-f020-4fdc-9ddd-bc68b6188ecd','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceServerMetadataHook-ogbujyjfdz5e','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,846),(1353,'c8d6745f-df85-4d50-abda-40265f1b21c8','57daa34a-9206-4a7c-9592-3af81039314a','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceLogging-733muzj3ds7p-RoleParametersValue-d6skbwglj6ll','state changed','OS::Heat::Value',NULL,844),(1354,'1325ccb4-052d-483f-be3e-8f54f98b6a21','2f578f6e-53ff-4f33-b853-d0c7c1272d11','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-ApacheServiceBase-z5ix43mkrudb-ApacheNetworks-2rms5eb7rxij','state changed','OS::Heat::Value',NULL,847),(1355,'3a03f1c8-d615-4e8d-8aaa-486945595cd1','2f578f6e-53ff-4f33-b853-d0c7c1272d11','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-ApacheServiceBase-z5ix43mkrudb-ApacheNetworks-2rms5eb7rxij','state changed','OS::Heat::Value',NULL,847),(1356,'6cf6a182-3756-49e1-b3ad-0b1c588ce4de','2f578f6e-53ff-4f33-b853-d0c7c1272d11','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3-ApacheServiceBase-z5ix43mkrudb','2f578f6e-53ff-4f33-b853-d0c7c1272d11','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1357,'4efe6f6f-2118-4466-9cfd-4a76cb6ac578','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-DockerConfig-n5i26vrwzzsv','state changed','OS::Heat::Value',NULL,848),(1358,'fb11c933-91f5-4cbb-bd82-bc0b4e148cf4','57daa34a-9206-4a7c-9592-3af81039314a','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceLogging-733muzj3ds7p','57daa34a-9206-4a7c-9592-3af81039314a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1359,'a3b6cbfb-f7d7-4f6a-a82b-a82c423616e7','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-DockerConfig-n5i26vrwzzsv','state changed','OS::Heat::Value',NULL,848),(1360,'bd90acb9-e5f7-4749-900a-c7b61570188d','d02dbed6-884a-4886-b097-7342abf593c4','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceServerMetadataHook-ogbujyjfdz5e','d02dbed6-884a-4886-b097-7342abf593c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1361,'48669f22-2346-4734-a5fe-a93a90f95c75','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ScaleTasks-uodwqxhru33j','state changed','OS::Heat::Value',NULL,850),(1362,'69f203b7-1c48-433d-b8d3-706a7cfb2f11','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-UpgradeTasks-3yekdpoz6lls','state changed','OS::Heat::Value',NULL,851),(1363,'772b6f09-480f-4671-8856-b6299c451fe5','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-UpgradeBatchTasks-ipmco2opumsv','state changed','OS::Heat::Value',NULL,852),(1364,'83941055-2670-46fe-9968-737a32108b0c','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-UpgradeTasks-3yekdpoz6lls','state changed','OS::Heat::Value',NULL,851),(1365,'7fa05c09-f713-42f0-a7cf-aa2ffbadb0fd','d02dbed6-884a-4886-b097-7342abf593c4','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceServerMetadataHook-ogbujyjfdz5e-IncomingMetadataSettings-vhnfjhbbjd5r','state changed','OS::Heat::Value',NULL,853),(1366,'c69d4c21-8422-402d-8744-2e94fd389742','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ScaleTasks-uodwqxhru33j','state changed','OS::Heat::Value',NULL,850),(1367,'1d5779f2-033e-48c5-84ba-c9fa8c6d5b23','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-UpgradeBatchTasks-ipmco2opumsv','state changed','OS::Heat::Value',NULL,852),(1368,'1cccd913-ef54-41cf-a3d5-46d739a6e7e5','d02dbed6-884a-4886-b097-7342abf593c4','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceServerMetadataHook-ogbujyjfdz5e-IncomingMetadataSettings-vhnfjhbbjd5r','state changed','OS::Heat::Value',NULL,853),(1369,'b3512510-b4aa-48b9-91ca-a2cd224084d7','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ExternalPostDeployTasks-zgc3wxoqlife','state changed','OS::Heat::Value',NULL,856),(1370,'ee2c33e8-03c3-4a1d-8d88-0b10e0a0173f','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ExternalPostDeployTasks-zgc3wxoqlife','state changed','OS::Heat::Value',NULL,856),(1371,'155df5bc-ca6c-4270-b361-0b142bb9455e','7ac6a40f-f7b1-4575-9ac1-48956271ee52','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-9-ox2boqr6myo2-RoleParametersValue-h6ksqirdpnln','state changed','OS::Heat::Value',NULL,855),(1372,'b079dfd0-fdb8-46d5-98f2-7a5078d038a5','d02dbed6-884a-4886-b097-7342abf593c4','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceServerMetadataHook-ogbujyjfdz5e-IndividualServices-qfddh3h2mi5p','state changed','OS::Heat::Value',NULL,858),(1373,'52490630-918e-482f-8a30-dbcea6f5e627','7ac6a40f-f7b1-4575-9ac1-48956271ee52','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','ContainersCommon','69a69900-0a1b-4629-909f-3f7e7b0fec8d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1374,'f70a0cba-816e-46a8-aac5-e1adb63cce3c','d02dbed6-884a-4886-b097-7342abf593c4','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceServerMetadataHook-ogbujyjfdz5e-IndividualServices-qfddh3h2mi5p','state changed','OS::Heat::Value',NULL,858),(1375,'971b7a10-f39f-4143-bede-fb3b27915d96','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-DeployStepsTasks-hcd5cs6peudl','state changed','OS::Heat::Value',NULL,861),(1376,'ed48b87d-c3b7-4d73-8e99-4170a33452e1','d02dbed6-884a-4886-b097-7342abf593c4','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceServerMetadataHook-ogbujyjfdz5e-CompactServices-okixcg6bvms2','state changed','OS::Heat::Value',NULL,860),(1377,'07d5c02a-26dc-4fb9-9575-578026493cb4','7ac6a40f-f7b1-4575-9ac1-48956271ee52','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-9-ox2boqr6myo2-RoleParametersValue-h6ksqirdpnln','state changed','OS::Heat::Value',NULL,855),(1378,'d5544d4c-4683-4ae1-a745-8e31e4061196','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-DeployStepsTasks-hcd5cs6peudl','state changed','OS::Heat::Value',NULL,861),(1379,'682fab90-6869-4c67-b617-8f1a5860f8b9','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-PostUpgradeTasks-tqrdnfmi3vcc','state changed','OS::Heat::Value',NULL,863),(1380,'d497e02b-f59c-4cc8-9fbe-67fa30ff61ea','d02dbed6-884a-4886-b097-7342abf593c4','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceServerMetadataHook-ogbujyjfdz5e-CompactServices-okixcg6bvms2','state changed','OS::Heat::Value',NULL,860),(1381,'a278d878-c478-401b-9231-e92e95c787a8','7ac6a40f-f7b1-4575-9ac1-48956271ee52','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-9-ox2boqr6myo2','7ac6a40f-f7b1-4575-9ac1-48956271ee52','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1382,'f5812619-7c32-4fde-a15d-e0487c2ed8bc','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-PostUpgradeTasks-tqrdnfmi3vcc','state changed','OS::Heat::Value',NULL,863),(1383,'db771dc0-f0c6-46d3-99af-e79bc0f43647','d02dbed6-884a-4886-b097-7342abf593c4','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceServerMetadataHook-ogbujyjfdz5e','d02dbed6-884a-4886-b097-7342abf593c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1384,'f6a9f9d6-ff07-4603-813d-43e167201b56','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','GlanceApi','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,864),(1385,'30607aec-46e0-46b3-a525-699c8f77dbaf','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceConfigSettings-yoylxtdor2hb','state changed','OS::Heat::Value',NULL,865),(1386,'29f4d801-556a-41af-b78c-f4a5824a7d10','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1387,'2a35d0a8-52bb-4ad1-a5eb-bce5636829a9','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ComputeServiceChain-ksxcyuw5eues-ServiceConfigSettings-yoylxtdor2hb','state changed','OS::Heat::Value',NULL,865),(1388,'1637b2b1-1d58-432e-b149-f549238e2248','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','GlanceLogging','57daa34a-9206-4a7c-9592-3af81039314a','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1389,'13c9b742-33aa-46f6-a2a0-c852b61d1df0','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','ApacheServiceBase','2f578f6e-53ff-4f33-b853-d0c7c1272d11','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,840),(1390,'467c9f5f-9413-4907-b744-7792626fb1b2','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','2026-06-15 07:51:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-14-cz2cjxqhcdm3','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1391,'624601dc-64f0-44d3-8134-c4e311ba378d','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:41',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ComputeServiceChain-ksxcyuw5eues-AnsibleGroupVars-y5iu72hlh3c7','state changed','OS::Heat::Value',NULL,866),(1392,'5a380d69-7e2f-42b8-9c7a-703e66189c57','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ComputeServiceChain-ksxcyuw5eues-GlobalConfigSettings-f7olxhu4awmd','state changed','OS::Heat::Value',NULL,868),(1393,'652c2e78-3d8e-4da5-900e-a0a743443cdd','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ComputeServiceChain-ksxcyuw5eues-AnsibleGroupVars-y5iu72hlh3c7','state changed','OS::Heat::Value',NULL,866),(1394,'220a5465-8124-4c26-b7f4-22904d57575a','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-PreDeployStepTasks-cpo7pnau3mua','state changed','OS::Heat::Value',NULL,871),(1395,'57ef0526-83db-484f-bcdf-11076943e024','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ComputeServiceChain-ksxcyuw5eues-GlobalConfigSettings-f7olxhu4awmd','state changed','OS::Heat::Value',NULL,868),(1396,'bf3fde7d-0e84-4f01-adf5-721513dcceef','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-PreDeployStepTasks-cpo7pnau3mua','state changed','OS::Heat::Value',NULL,871),(1397,'320b3e1a-53b7-4c18-abe3-ab8b73578195','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-IpaRegistrationTasks-dzn73g7qz4vp','state changed','OS::Heat::Value',NULL,873),(1398,'d47c0c70-1484-41ef-97a5-3fc7a8d399e9','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-IpaRegistrationTasks-dzn73g7qz4vp','state changed','OS::Heat::Value',NULL,873),(1399,'db072bd8-5079-4a12-a12c-78aafe489b9a','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-RoleParametersValue-5azvsyhu6o3o','state changed','OS::Heat::Value',NULL,877),(1400,'565110b2-0920-409f-ae09-ef7f48f2dac1','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','d02dbed6-884a-4886-b097-7342abf593c4','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,846),(1401,'3aa3eb85-2616-4f38-99e9-29708c7063ca','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-RoleParametersValue-5azvsyhu6o3o','state changed','OS::Heat::Value',NULL,877),(1402,'c1c59546-b12e-4bc5-a4c0-247eb3b27252','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','9','7ac6a40f-f7b1-4575-9ac1-48956271ee52','state changed','OS::TripleO::Services::Collectd',NULL,835),(1403,'de9466ec-eea1-4301-be6a-579424a3930f','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ExternalUpgradeTasks-ntik74g6biyn','state changed','OS::Heat::Value',NULL,879),(1404,'f092ee98-a080-4c3b-b086-e9cb17081683','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-PostUpdateTasks-xz7f57qpveb6','state changed','OS::Heat::Value',NULL,882),(1405,'1db1f9ef-49e5-406c-93f8-3848588fa47a','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-PostUpdateTasks-xz7f57qpveb6','state changed','OS::Heat::Value',NULL,882),(1406,'c3ff7a4e-c1d4-4db1-90be-7796e021c007','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-ExternalUpgradeTasks-ntik74g6biyn','state changed','OS::Heat::Value',NULL,879),(1407,'34315434-3622-4e62-8e9d-fa22b0ac3ef4','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','11','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc','state changed','OS::TripleO::Services::GlanceApi',NULL,886),(1408,'d3497de8-20d9-4d57-bae2-d089dbe87e93','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-ksxcyuw5eues-KeystoneResourcesConfigs-m5azknuwa7k2','state changed','OS::Heat::Value',NULL,885),(1409,'fdd0731b-dbe0-4b14-94b6-b6b6b34f848b','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','14','ee86a5df-6932-4ff9-8a26-eadc2dcd0cc7','state changed','OS::TripleO::Services::HeatApi',NULL,788),(1410,'353c7c91-3e08-4d0f-9bee-8fee7e772248','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-MonitoringSubscriptionsConfig-7efp6aodgn5s','state changed','OS::Heat::Value',NULL,888),(1411,'8242d46a-68da-4a2a-996c-3471cb76099e','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-MonitoringSubscriptionsConfig-7efp6aodgn5s','state changed','OS::Heat::Value',NULL,888),(1412,'ef5c5d03-2ad0-4c73-a3cf-260122f0147d','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-HostPrepTasks-3b47ihg2rz7m','state changed','OS::Heat::Value',NULL,889),(1413,'c5cf6357-2729-429b-af16-d03d4cbfe691','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-MySQLClient-pbflnryx6hge','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1414,'ce4ba870-9f51-4cac-84ce-7694db367249','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc','87597487-6d76-4aec-b0d0-e4cc722a6a26','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1415,'9c24ea87-2cd0-4f1e-adfc-f79598735cc3','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-HostPrepTasks-3b47ihg2rz7m','state changed','OS::Heat::Value',NULL,889),(1416,'4f0b44bb-9c6b-45ee-a2e0-5d47c04792c7','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-ksxcyuw5eues-KeystoneResourcesConfigs-m5azknuwa7k2','state changed','OS::Heat::Value',NULL,885),(1417,'74dff88b-3764-4f2f-9f91-e2ef76577ecc','0ba7eb7e-bd0d-48af-9827-2256473c3bee','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-MySQLClient-pbflnryx6hge','0ba7eb7e-bd0d-48af-9827-2256473c3bee','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1418,'1b36c218-aa06-4957-aec1-73f17508dd5b','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-PuppetStepConfig-irplnvbihwsx','state changed','OS::Heat::Value',NULL,891),(1419,'9721c075-b3fc-48e1-aac9-3bb97142d088','0ba7eb7e-bd0d-48af-9827-2256473c3bee','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-MySQLClient-pbflnryx6hge','0ba7eb7e-bd0d-48af-9827-2256473c3bee','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1420,'2c62205e-28b1-4822-8e04-5775df6610fe','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:42',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ComputeServiceChain-ksxcyuw5eues-PuppetStepConfig-irplnvbihwsx','state changed','OS::Heat::Value',NULL,891),(1421,'db5a873a-8361-4a8a-9a34-11b08845b4fc','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','13','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv','state changed','OS::TripleO::Services::HAproxy',NULL,893),(1422,'eb27d530-2bc1-422a-af51-82e49d422d78','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ComputeServiceChain-ksxcyuw5eues-FirewallFrontendRules-ep7xz3knox6d','state changed','OS::Heat::Value',NULL,894),(1423,'163035e9-b616-4a31-80c3-b22c320bf1a7','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ComputeServiceChain-ksxcyuw5eues-FirewallRules-mfkf4exewwd3','state changed','OS::Heat::Value',NULL,895),(1424,'46379ea8-7027-43a3-8c71-dc58d715de5f','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ComputeServiceChain-ksxcyuw5eues-FirewallRules-mfkf4exewwd3','state changed','OS::Heat::Value',NULL,895),(1425,'8efeea6f-45f2-4089-bca7-a0d243bbe8ef','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ComputeServiceChain-ksxcyuw5eues-FirewallFrontendRules-ep7xz3knox6d','state changed','OS::Heat::Value',NULL,894),(1426,'0f8db1d8-27e4-452e-bede-ec7cc61a1892','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-PreUpgradeRollingTasks-zhcdtuxkpd3t','state changed','OS::Heat::Value',NULL,901),(1427,'ee7f0b91-704a-48db-ad6d-cf73f031ef8b','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv','930ab81d-5bad-4a60-a139-0a715cd0e9bd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1428,'68bddc8b-9993-48ac-907c-10a9e33f8031','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-ksxcyuw5eues-PreUpgradeRollingTasks-zhcdtuxkpd3t','state changed','OS::Heat::Value',NULL,901),(1429,'7df536f6-af2d-4938-966b-5fdc76efdb17','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-MySQLClient-5ioxbdutip34','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1430,'437cc7b9-39ae-4730-b66b-e835e69555bf','a81298ba-a349-4da1-81a9-2679f5c46619','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-ksxcyuw5eues','a81298ba-a349-4da1-81a9-2679f5c46619','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1431,'1a30295e-6a91-43f3-927c-9b9dfe6cfa0e','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-TLSProxyBase-gxvft3wldmna','state changed','OS::TripleO::Services::TLSProxyBase',NULL,904),(1432,'4e488f0c-de45-4a59-88f3-cf04a01fe749','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyPublicTLS-ktylupdwdo2n','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,906),(1433,'7ca5096c-1f31-4d00-8180-c7033d5dff2e','54663735-eb89-48e4-ac87-187b6ce0f5c4','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-TLSProxyBase-gxvft3wldmna','54663735-eb89-48e4-ac87-187b6ce0f5c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1434,'e3498752-48c3-460a-9ba6-736794ad2db3','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','18','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-18-yi6trekcantm','state changed','OS::TripleO::Services::Horizon',NULL,905),(1435,'46a9e556-4f5e-4c00-8266-34ab3faddf42','ab709c15-7581-41ea-8d64-0670630c2a5c','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-MySQLClient-5ioxbdutip34','ab709c15-7581-41ea-8d64-0670630c2a5c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1436,'c2c49145-92ea-4a96-ab31-8b25a9bdcec3','ab709c15-7581-41ea-8d64-0670630c2a5c','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-MySQLClient-5ioxbdutip34','ab709c15-7581-41ea-8d64-0670630c2a5c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1437,'baf20e23-3ae8-474f-a548-12c07bfe2b37','54663735-eb89-48e4-ac87-187b6ce0f5c4','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-TLSProxyBase-gxvft3wldmna-ApacheNetworks-paresxiecqty','state changed','OS::Heat::Value',NULL,907),(1438,'ae457400-2832-4d77-a517-b2400c7b74a7','2cc78a5b-3eea-4f83-8c1b-1903e8bf5bc3','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyPublicTLS-ktylupdwdo2n','2cc78a5b-3eea-4f83-8c1b-1903e8bf5bc3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1439,'50523fa1-1a33-421e-a2d0-5d77cc09c019','54663735-eb89-48e4-ac87-187b6ce0f5c4','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-TLSProxyBase-gxvft3wldmna-ApacheNetworks-paresxiecqty','state changed','OS::Heat::Value',NULL,907),(1440,'906247ac-7361-488c-a9f0-9e368f2e3fcb','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','MySQLClient','ab709c15-7581-41ea-8d64-0670630c2a5c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1441,'9e184b6d-6336-4287-ae3f-39f608bd2575','2cc78a5b-3eea-4f83-8c1b-1903e8bf5bc3','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyPublicTLS-ktylupdwdo2n','2cc78a5b-3eea-4f83-8c1b-1903e8bf5bc3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1442,'03015259-4bf2-4832-baa3-54ff0a4503bc','54663735-eb89-48e4-ac87-187b6ce0f5c4','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-TLSProxyBase-gxvft3wldmna','54663735-eb89-48e4-ac87-187b6ce0f5c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1443,'3ef80c77-449a-4a37-abcd-2547edc7fe2c','81cfb08d-4f50-4419-8cde-7db79bbe3dab','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-18-yi6trekcantm','81cfb08d-4f50-4419-8cde-7db79bbe3dab','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1444,'9ad97358-ad6c-4b73-a8cb-66060200775c','81cfb08d-4f50-4419-8cde-7db79bbe3dab','2026-06-15 07:51:43',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-18-yi6trekcantm-RoleParametersValue-dgfu2dffxjdh','state changed','OS::Heat::Value',NULL,908),(1445,'524d7622-11eb-4561-bb16-86c33f1adcae','81cfb08d-4f50-4419-8cde-7db79bbe3dab','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-18-yi6trekcantm-RoleParametersValue-dgfu2dffxjdh','state changed','OS::Heat::Value',NULL,908),(1446,'9ea3b168-b0b8-49e0-93e9-4092b64b2e19','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','ComputeServiceChain','a81298ba-a349-4da1-81a9-2679f5c46619','state changed','OS::TripleO::ComputeServices',NULL,85),(1447,'025244a0-6149-4a0d-bb55-34bf45cf9916','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:43',NULL,'CREATE','COMPLETE','MySQLClient','0ba7eb7e-bd0d-48af-9827-2256473c3bee','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1448,'46e4b6ba-a85b-400f-9198-8c43c840ea10','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:44',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-CinderNVMeOF-ehoekqgjk3ko','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1449,'958af095-a1e7-4f63-853d-1ed1acb39905','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:44',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-CinderNVMeOF-cyefbaxgvueg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1450,'96728833-802f-4bc8-bd57-dce6d1c8de42','049e6c36-5153-4ac4-9d95-61dbd8de2536','2026-06-15 07:51:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-CinderNVMeOF-ehoekqgjk3ko','049e6c36-5153-4ac4-9d95-61dbd8de2536','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1451,'006a00c5-0460-492b-a477-4f03bf51e3ba','049e6c36-5153-4ac4-9d95-61dbd8de2536','2026-06-15 07:51:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-CinderNVMeOF-ehoekqgjk3ko','049e6c36-5153-4ac4-9d95-61dbd8de2536','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1452,'671e6e09-d9cf-4ba5-9c8d-16b7d9d49b09','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:44',NULL,'CREATE','IN_PROGRESS','HAProxyBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,943),(1453,'fe97fb16-79f1-4c55-b00f-f01d7d8271f4','203bd436-f777-433d-9adf-2c62cac305b1','2026-06-15 07:51:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-CinderNVMeOF-cyefbaxgvueg','203bd436-f777-433d-9adf-2c62cac305b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1454,'816c9546-ff8a-4a03-a54a-ab14ae393bf6','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:44',NULL,'CREATE','COMPLETE','TLSProxyBase','54663735-eb89-48e4-ac87-187b6ce0f5c4','state changed','OS::TripleO::Services::TLSProxyBase',NULL,904),(1455,'4dbda791-bc3a-4f42-9181-e0a52296c913','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','2cc78a5b-3eea-4f83-8c1b-1903e8bf5bc3','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,906),(1456,'455daa92-eaff-47ef-b57b-53f41a0c4309','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo','9982b5db-6073-46ee-adcb-8e16583b4458','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1457,'7992ef4c-1750-4a58-8676-8916079d5914','81cfb08d-4f50-4419-8cde-7db79bbe3dab','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-18-yi6trekcantm-ContainersCommon-kxzzo5ypqvgs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1458,'f687138d-a229-420b-be0d-f22ff4882d7f','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-ContainersCommon-khclrxxcmkqi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1459,'7783ab0e-84f8-47cb-afdd-dec68056d7d0','203bd436-f777-433d-9adf-2c62cac305b1','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-CinderNVMeOF-cyefbaxgvueg','203bd436-f777-433d-9adf-2c62cac305b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1460,'477d36dc-b017-4d28-a27e-86263ce4dd2f','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-RoleParametersValue-c2qrupmobbsq','state changed','OS::Heat::Value',NULL,946),(1461,'6d8e63c9-932d-43ed-a852-07383896a052','8177b482-9b95-4d79-b405-bd6f7e1f2070','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-18-yi6trekcantm-ContainersCommon-kxzzo5ypqvgs','8177b482-9b95-4d79-b405-bd6f7e1f2070','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1462,'186f6e54-928f-4594-9385-43ffb85eb880','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-a47rto3c5dqi','state changed','OS::Heat::Value',NULL,945),(1463,'6749d652-6e2e-4b27-a0cd-fddb00393453','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-RoleParametersValue-c2qrupmobbsq','state changed','OS::Heat::Value',NULL,946),(1464,'f66dc086-dff5-4924-b786-2d2144ecf599','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-a47rto3c5dqi','state changed','OS::Heat::Value',NULL,945),(1465,'6db0da5d-b961-496a-be0a-f72e2df51355','8177b482-9b95-4d79-b405-bd6f7e1f2070','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-18-yi6trekcantm-ContainersCommon-kxzzo5ypqvgs','8177b482-9b95-4d79-b405-bd6f7e1f2070','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1466,'d5d797b3-59df-4d0a-a783-6fecb19f0da1','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','CinderNVMeOF','049e6c36-5153-4ac4-9d95-61dbd8de2536','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1467,'d2f5e704-8d29-4c66-ad98-e9c678939dd8','375124d9-1794-4908-a3ab-fb9eb18b7219','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-ContainersCommon-khclrxxcmkqi','375124d9-1794-4908-a3ab-fb9eb18b7219','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1468,'558ec693-3fd4-4a33-afcc-582c32907fec','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-RoleParametersValue-qmhymfca3gin','state changed','OS::Heat::Value',NULL,947),(1469,'0274f99a-351f-41f6-b353-d06cbdbc91a7','375124d9-1794-4908-a3ab-fb9eb18b7219','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-ContainersCommon-khclrxxcmkqi','375124d9-1794-4908-a3ab-fb9eb18b7219','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1470,'4fdfb4a1-212c-455b-87fc-ecdde72ef466','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyInternalTLS-cbjznidnoyj7','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,948),(1471,'cf02c7a7-65d5-4124-8ddb-e2162ff9ecc9','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-RoleParametersValue-qmhymfca3gin','state changed','OS::Heat::Value',NULL,947),(1472,'6edd4796-a692-4957-8fec-e46e77b491f0','6f520498-5077-4ceb-b5db-6a23a9185e4d','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyInternalTLS-cbjznidnoyj7','6f520498-5077-4ceb-b5db-6a23a9185e4d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1473,'f75e77f6-2c43-4c29-aed0-962f566b88d9','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','ComputeServiceNames','overcloud-ComputeServiceNames-7w5vcpho4efj','state changed','OS::Heat::Value',NULL,949),(1474,'6d6e8db8-48f1-42dd-8a1b-214f7a8cffe2','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','ComputeServiceNames','overcloud-ComputeServiceNames-7w5vcpho4efj','state changed','OS::Heat::Value',NULL,949),(1475,'b5f6f094-e221-4351-b6dd-0c3c91de49de','6f520498-5077-4ceb-b5db-6a23a9185e4d','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','HAProxyNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyInternalTLS-cbjznidnoyj7-HAProxyNetworks-e54ccw7v3veu','state changed','OS::Heat::Value',NULL,950),(1476,'8cc5c70a-c60d-4edb-b37e-35810c820ae0','6f520498-5077-4ceb-b5db-6a23a9185e4d','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','HAProxyNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyInternalTLS-cbjznidnoyj7-HAProxyNetworks-e54ccw7v3veu','state changed','OS::Heat::Value',NULL,950),(1477,'ecbe1c1c-e46e-4eb8-8a22-238232e55578','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:45',NULL,'CREATE','IN_PROGRESS','Compute','overcloud-Compute-jgegfs3bargx','state changed','OS::Heat::ResourceGroup',NULL,952),(1478,'4bd329cd-4772-4818-b6bd-8a19eec594f7','6f520498-5077-4ceb-b5db-6a23a9185e4d','2026-06-15 07:51:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyInternalTLS-cbjznidnoyj7','6f520498-5077-4ceb-b5db-6a23a9185e4d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1479,'de6a1d53-78af-4f0a-ae0a-62d6f21da44b','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx','139a0855-1993-4453-8c33-eba60023b4d1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1480,'6ed3d24a-990c-4509-bc0f-bf1711280cc2','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx','139a0855-1993-4453-8c33-eba60023b4d1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1481,'749dfd37-00c5-45fb-920f-37a73df961b0','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','CinderNVMeOF','203bd436-f777-433d-9adf-2c62cac305b1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1482,'ae90281f-8f3f-4ca7-9221-d3b4191a233d','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:46',NULL,'UPDATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx','139a0855-1993-4453-8c33-eba60023b4d1','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(1483,'c7ec7431-0e3d-4ec1-a8e1-5fea0a1d1bbf','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-GlanceLogging-apepaj7liqdx','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1484,'3a4f5cb5-0f56-4f33-9627-536b6f542bc5','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-ContainersCommon-baqgtjijftzh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1485,'eb3f4dac-9a81-4945-8586-50397069ffa5','81cfb08d-4f50-4419-8cde-7db79bbe3dab','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','ContainersCommon','8177b482-9b95-4d79-b405-bd6f7e1f2070','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1486,'2cee820d-1d49-49da-bb7d-bb0a49168da3','05e12f1d-6c71-41b3-9b70-a2e2a6746c53','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-GlanceLogging-apepaj7liqdx','05e12f1d-6c71-41b3-9b70-a2e2a6746c53','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1487,'69063077-2bdf-491f-9c53-f8527ec38df9','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyInternalTLS-mi5ub7dxzb22','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,954),(1488,'230b3e7e-9bd0-4abb-a603-dc0a456f2544','0c7df817-a43f-49d3-86be-b2dc349d9119','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-ContainersCommon-baqgtjijftzh','0c7df817-a43f-49d3-86be-b2dc349d9119','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1489,'fd182f6e-6538-4537-a25e-94832ee73ffd','81cfb08d-4f50-4419-8cde-7db79bbe3dab','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-18-yi6trekcantm','81cfb08d-4f50-4419-8cde-7db79bbe3dab','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1490,'c69a95f1-dfe3-4400-b236-6865182fdef3','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','ContainersCommon','375124d9-1794-4908-a3ab-fb9eb18b7219','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1491,'1fcb9463-a3ac-471a-84fb-b1a02d618107','0c7df817-a43f-49d3-86be-b2dc349d9119','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-ContainersCommon-baqgtjijftzh','0c7df817-a43f-49d3-86be-b2dc349d9119','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1492,'afcf6b3b-e37b-4a7d-9773-253807ea7187','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-ContainersCommon-hlqqjr3suvy7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1493,'ac984e75-749d-4b48-8405-e703831948b4','05e12f1d-6c71-41b3-9b70-a2e2a6746c53','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-GlanceLogging-apepaj7liqdx-RoleParametersValue-6dv7rzjrlt24','state changed','OS::Heat::Value',NULL,955),(1494,'68691e4b-e964-4f9d-a4c2-72c9f746f7fc','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','ContainersCommon','0c7df817-a43f-49d3-86be-b2dc349d9119','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1495,'5b211efb-61a8-41cd-9ab2-617c87eef2c3','05e12f1d-6c71-41b3-9b70-a2e2a6746c53','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-GlanceLogging-apepaj7liqdx-RoleParametersValue-6dv7rzjrlt24','state changed','OS::Heat::Value',NULL,955),(1496,'093b8d56-f6df-4148-af56-c509792a0719','a5e02f93-db15-4e20-891c-cc24b77f2cbf','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-ContainersCommon-hlqqjr3suvy7','a5e02f93-db15-4e20-891c-cc24b77f2cbf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1497,'fd5b8a30-a4fe-41c0-ae97-02bcc2059cd1','05e12f1d-6c71-41b3-9b70-a2e2a6746c53','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-GlanceLogging-apepaj7liqdx','05e12f1d-6c71-41b3-9b70-a2e2a6746c53','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1498,'d921e717-b704-469e-95b8-be3a652aa7fc','2a95fd4b-f803-4d83-930d-e07eebfc0f58','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyInternalTLS-mi5ub7dxzb22','2a95fd4b-f803-4d83-930d-e07eebfc0f58','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1499,'f2edcb73-af4e-414c-aeb5-54b98bcb94e3','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','2','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3','state changed','OS::TripleO::Compute',NULL,956),(1500,'4d4563df-a6fa-415a-9dcb-a1a63a9b3426','a5e02f93-db15-4e20-891c-cc24b77f2cbf','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-ContainersCommon-hlqqjr3suvy7','a5e02f93-db15-4e20-891c-cc24b77f2cbf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1501,'4e0b0713-d369-46fa-b696-cd6bc2bdff57','2a95fd4b-f803-4d83-930d-e07eebfc0f58','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','HAProxyNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyInternalTLS-mi5ub7dxzb22-HAProxyNetworks-ylvo62ps3tag','state changed','OS::Heat::Value',NULL,957),(1502,'6ff6454e-8c1b-419d-8bbc-e32ae494f6e6','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3','2dfbb7f8-f236-4995-81c7-b5df4af90caa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1503,'2314beaf-b2c0-4a66-a045-de3d4610a4c8','2a95fd4b-f803-4d83-930d-e07eebfc0f58','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','HAProxyNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyInternalTLS-mi5ub7dxzb22-HAProxyNetworks-ylvo62ps3tag','state changed','OS::Heat::Value',NULL,957),(1504,'b1b86cb4-d619-4ca7-b51d-b3cef02c815d','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','6f520498-5077-4ceb-b5db-6a23a9185e4d','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,948),(1505,'fb46593e-7b7b-48f9-b795-4df4a42825e3','2a95fd4b-f803-4d83-930d-e07eebfc0f58','2026-06-15 07:51:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyInternalTLS-mi5ub7dxzb22','2a95fd4b-f803-4d83-930d-e07eebfc0f58','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1506,'e46725e0-06b6-4799-8509-b5edcc34031c','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:46',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NovaCompute-jifqesqlg3y4','state changed','OS::TripleO::ComputeServer',NULL,958),(1507,'0e52465a-cb2d-42b1-aa72-b0f56f4cf223','d7af03ac-0ed9-4213-b27d-8abda4102a53','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NovaCompute-jifqesqlg3y4','d7af03ac-0ed9-4213-b27d-8abda4102a53','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1508,'32bffb56-e52c-4ed8-83b1-ec5ac86637d3','d7af03ac-0ed9-4213-b27d-8abda4102a53','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-jifqesqlg3y4-deployed-server-chv7a4kofh6t','state changed','OS::Heat::DeployedServer',NULL,959),(1509,'ffab882c-042e-4d10-a4ee-1b0870298fea','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','18','81cfb08d-4f50-4419-8cde-7db79bbe3dab','state changed','OS::TripleO::Services::Horizon',NULL,905),(1510,'64a72a08-80a0-4412-ada0-5bcdba04b7de','d7af03ac-0ed9-4213-b27d-8abda4102a53','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','deployed-server','14e29fd3-bf07-411e-b409-6b5db200dcb3','state changed','OS::Heat::DeployedServer',NULL,959),(1511,'f6419ffe-6454-4433-907c-8a158f7ea734','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-TLSProxyBase-svojasgbkbq2','state changed','OS::TripleO::Services::TLSProxyBase',NULL,960),(1512,'8349e81d-6fde-4e94-9bd6-28d386b86b54','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-MySQLClient-qggaywvaktjc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1513,'ab197c17-b373-4911-b60e-d7f7dd5ea0c9','58728073-c40a-4481-9fde-8b8a50b80494','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-MySQLClient-qggaywvaktjc','58728073-c40a-4481-9fde-8b8a50b80494','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1514,'25b6341a-0796-45c2-837b-658b9ddb1c3c','2551abe0-4f6b-456e-a900-bcb8656be93c','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-TLSProxyBase-svojasgbkbq2','2551abe0-4f6b-456e-a900-bcb8656be93c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1515,'79a615a4-ca2f-4492-87eb-6923e2182d7b','58728073-c40a-4481-9fde-8b8a50b80494','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf-MySQLClient-qggaywvaktjc','58728073-c40a-4481-9fde-8b8a50b80494','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1516,'a5023d9e-21ba-4b47-b4d0-cdbcede37032','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-ContainersCommon-xp5fozbq65ym','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1517,'fd8ec881-2e61-44aa-ac27-cb5bc6517b38','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','HAProxyLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyLogging-dmft6zl7avvm','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1518,'f52185a6-649c-47f6-9a2e-d0731476b846','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','GlanceLogging','05e12f1d-6c71-41b3-9b70-a2e2a6746c53','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1519,'ef96ef3a-294d-4133-9ba0-ec352f2d86b5','2551abe0-4f6b-456e-a900-bcb8656be93c','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-TLSProxyBase-svojasgbkbq2-ApacheNetworks-ktg4jktx3mgf','state changed','OS::Heat::Value',NULL,964),(1520,'e99ce757-76a7-40b8-90a1-a9792ccbd1a8','8bee9c1f-36f9-4fbb-bd06-c7a706da3f6e','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyLogging-dmft6zl7avvm','8bee9c1f-36f9-4fbb-bd06-c7a706da3f6e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1521,'11d5516a-a550-4aa2-9ff6-8d8b1d89bafc','2551abe0-4f6b-456e-a900-bcb8656be93c','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-TLSProxyBase-svojasgbkbq2-ApacheNetworks-ktg4jktx3mgf','state changed','OS::Heat::Value',NULL,964),(1522,'6612a612-5c5e-404b-b941-3cb34be7b71a','8bee9c1f-36f9-4fbb-bd06-c7a706da3f6e','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyLogging-dmft6zl7avvm','8bee9c1f-36f9-4fbb-bd06-c7a706da3f6e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1523,'c01d14df-50d5-4488-9361-6ed74834ab39','2551abe0-4f6b-456e-a900-bcb8656be93c','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-TLSProxyBase-svojasgbkbq2','2551abe0-4f6b-456e-a900-bcb8656be93c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1524,'172ddc22-fc16-48d7-874f-93296ebd27de','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','ContainersCommon','a5e02f93-db15-4e20-891c-cc24b77f2cbf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1525,'e433aa16-16a1-4f64-a08f-ee1e50745520','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','1','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6','state changed','OS::TripleO::Compute',NULL,965),(1526,'ae7925b4-7bd8-4f24-be2f-5772dba81d0c','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','2a95fd4b-f803-4d83-930d-e07eebfc0f58','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,954),(1527,'8a7df58c-cd21-4c53-b86e-4ab499a032ab','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','22','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55','state changed','OS::TripleO::Services::Keystone',NULL,966),(1528,'748986ba-fedc-4726-b865-1637f5028dc5','40e44daf-54bf-43b8-aac0-a1373ca021b7','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-ContainersCommon-xp5fozbq65ym','40e44daf-54bf-43b8-aac0-a1373ca021b7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1529,'94e244e0-ada0-4296-9dfe-4fd42ffc22a9','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6','768234c8-8b26-4c4c-acdb-511db3a5be03','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1530,'20ab003b-b72a-42b2-8bb1-90d80b28c663','40e44daf-54bf-43b8-aac0-a1373ca021b7','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-ContainersCommon-xp5fozbq65ym','40e44daf-54bf-43b8-aac0-a1373ca021b7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1531,'6d008276-fab9-49ea-87dd-09e9c0c34958','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1532,'2bcf5d0a-4b0a-47fc-8c1e-7d60954dd9d2','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-MySQLClient-waidyjsggspf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1533,'8db0649c-d58b-4824-878e-8afdd1c6c7c0','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-DeploymentActions-5mhcumctvh7x','state changed','OS::Heat::Value',NULL,967),(1534,'793e1d4b-47ad-44ea-a0f7-52e0e89f421f','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:47',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NovaCompute-iih2a5nkebyy','state changed','OS::TripleO::ComputeServer',NULL,968),(1535,'3a797a53-a9f5-4eb4-ab16-d418137c3dea','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:47',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-DeploymentActions-5mhcumctvh7x','state changed','OS::Heat::Value',NULL,967),(1536,'ffc24726-92ca-4888-a464-35df0703b3b7','512ae6fe-2465-4d77-b841-db704d72dd8d','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-MySQLClient-waidyjsggspf','512ae6fe-2465-4d77-b841-db704d72dd8d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1537,'825a1924-1fe1-4968-a556-2f040e5e9e76','3220570c-d474-4c2d-9c3c-1afe7afd5f8c','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NovaCompute-iih2a5nkebyy','3220570c-d474-4c2d-9c3c-1afe7afd5f8c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1538,'a66d0926-903b-461e-bd79-c27ef8dd7fc1','512ae6fe-2465-4d77-b841-db704d72dd8d','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-MySQLClient-waidyjsggspf','512ae6fe-2465-4d77-b841-db704d72dd8d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1539,'edc672c1-b6e6-4cba-8124-5292a5990e22','d7af03ac-0ed9-4213-b27d-8abda4102a53','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NovaCompute-jifqesqlg3y4-ControlPlanePort-4bmxast7h2xt','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,971),(1540,'404cd1be-e93b-413d-9248-8fbabe257da1','3220570c-d474-4c2d-9c3c-1afe7afd5f8c','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NovaCompute-iih2a5nkebyy-ControlPlanePort-z54ersvokc6x','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,970),(1541,'e4bf0e25-1414-4cfc-a231-150427a08c50','96c1cd44-46ae-47cd-afe9-6148aef93411','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NovaCompute-jifqesqlg3y4-ControlPlanePort-4bmxast7h2xt','96c1cd44-46ae-47cd-afe9-6148aef93411','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1542,'5f078487-7be8-4e43-9a93-dfd514a183d3','5e79e02a-b26d-40d0-bee4-d37b58778545','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NovaCompute-iih2a5nkebyy-ControlPlanePort-z54ersvokc6x','5e79e02a-b26d-40d0-bee4-d37b58778545','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1543,'ca37bae8-0a03-48d2-89c3-1eeb64ebdbfe','5e79e02a-b26d-40d0-bee4-d37b58778545','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NovaCompute-iih2a5nkebyy-ControlPlanePort-z54ersvokc6x','5e79e02a-b26d-40d0-bee4-d37b58778545','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1544,'912fa661-2103-4b35-90bb-5875ca2a6aa3','96c1cd44-46ae-47cd-afe9-6148aef93411','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NovaCompute-jifqesqlg3y4-ControlPlanePort-4bmxast7h2xt','96c1cd44-46ae-47cd-afe9-6148aef93411','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1545,'8b6acb58-3056-4514-9a9b-fe16823c7f91','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-GlanceLogging-53vqcim2s3ar','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1546,'5a969feb-7bd9-4e18-afa6-9c1b26400da7','4e7ca558-56fa-45b5-bbc3-70e9ecc52346','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-GlanceLogging-53vqcim2s3ar','4e7ca558-56fa-45b5-bbc3-70e9ecc52346','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1547,'6bd8dc96-48ed-40f1-b185-a27090a639c3','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','MySQLClient','58728073-c40a-4481-9fde-8b8a50b80494','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1548,'43e14d82-3765-4d33-9e15-168ae58fd162','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','TLSProxyBase','2551abe0-4f6b-456e-a900-bcb8656be93c','state changed','OS::TripleO::Services::TLSProxyBase',NULL,960),(1549,'d19f2d93-f335-408d-bbc2-672a8c324a26','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v-GlanceApi-b5b2vorub6cf','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1550,'0b113a7b-8f4b-4513-917f-a2c536d9e4b3','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyPublicTLS-tuh26taksaw2','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,972),(1551,'ffd7197b-f1e9-47d8-8ba7-d9798bf261ff','4e7ca558-56fa-45b5-bbc3-70e9ecc52346','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-GlanceLogging-53vqcim2s3ar-RoleParametersValue-zsy4kcnrz67h','state changed','OS::Heat::Value',NULL,973),(1552,'1a6aef50-cb54-4b47-962c-6af8c0457a5b','4e7ca558-56fa-45b5-bbc3-70e9ecc52346','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-GlanceLogging-53vqcim2s3ar-RoleParametersValue-zsy4kcnrz67h','state changed','OS::Heat::Value',NULL,973),(1553,'c96bebb2-7fe2-4092-b76e-520dce59f500','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','0','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i','state changed','OS::TripleO::Compute',NULL,974),(1554,'34aa795e-9a13-4029-9631-2cbfcc999d27','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','HAProxyLogging','8bee9c1f-36f9-4fbb-bd06-c7a706da3f6e','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1555,'c136d63c-f01e-4e5d-ae1c-1b7cfcf755df','4e7ca558-56fa-45b5-bbc3-70e9ecc52346','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc-GlanceLogging-53vqcim2s3ar','4e7ca558-56fa-45b5-bbc3-70e9ecc52346','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1556,'ed607f41-3290-4759-996f-14698f05e980','b7864274-9084-4688-afb6-054822a2785e','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyPublicTLS-tuh26taksaw2','b7864274-9084-4688-afb6-054822a2785e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1557,'e736f7c1-2bb8-4acd-b0b3-52ce534a0c9b','b7864274-9084-4688-afb6-054822a2785e','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-HAProxyPublicTLS-tuh26taksaw2','b7864274-9084-4688-afb6-054822a2785e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1558,'1d8dde7b-e1a6-4dfc-b6c8-c551cf3af7d4','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i','ddc81659-94de-44c4-b881-7a3c01d59bfd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1559,'d99412ba-3ca2-43d3-ad22-eccd45a39d8a','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:48',NULL,'CREATE','COMPLETE','ContainersCommon','40e44daf-54bf-43b8-aac0-a1373ca021b7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1560,'bb957a41-ecda-4fed-9ac4-a4d05636f393','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-ContainersCommon-wzycktscubf6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1561,'4bc10b77-1cba-4a01-b225-e8499abd66c5','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-DeploymentActions-e7qd4woohlgy','state changed','OS::Heat::Value',NULL,975),(1562,'72070335-8561-4e9e-a064-49928ec46f3d','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:48',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-DeploymentActions-jk7mkt6csg2j','state changed','OS::Heat::Value',NULL,976),(1563,'a4c25eec-8808-4cb2-8069-963a23f4b077','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-DeploymentActions-jk7mkt6csg2j','state changed','OS::Heat::Value',NULL,976),(1564,'081b30b1-4c36-4e49-9892-d51f808bb7a0','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-DeploymentActions-e7qd4woohlgy','state changed','OS::Heat::Value',NULL,975),(1565,'51377ef4-8351-4a30-9a70-251c6edeee60','29840935-dbd2-4e5b-ba2e-72872181a5e7','2026-06-15 07:51:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-ContainersCommon-wzycktscubf6','29840935-dbd2-4e5b-ba2e-72872181a5e7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1566,'0371d5e6-501f-4adf-bce1-acd50640767b','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','MySQLClient','512ae6fe-2465-4d77-b841-db704d72dd8d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1567,'7f5570ee-4d94-4b2a-aa3e-c8af66392cbe','29840935-dbd2-4e5b-ba2e-72872181a5e7','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-ContainersCommon-wzycktscubf6','29840935-dbd2-4e5b-ba2e-72872181a5e7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1568,'991f8856-7143-4f13-9bbe-1ff2a8ea3b1f','3220570c-d474-4c2d-9c3c-1afe7afd5f8c','2026-06-15 07:51:49',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-iih2a5nkebyy-deployed-server-5bmrqmnndhvx','state changed','OS::Heat::DeployedServer',NULL,979),(1569,'333476ec-8230-476a-93d4-ee066248fa2a','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','GlanceApi','aeb0ab48-ce3f-4012-9a24-38ea2bc5429a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,864),(1570,'00f512fa-e21e-49cd-b07e-6f29c7ba1156','3220570c-d474-4c2d-9c3c-1afe7afd5f8c','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','deployed-server','1ad19eb7-9183-4e85-8aa4-8a8bc5ddc243','state changed','OS::Heat::DeployedServer',NULL,979),(1571,'5d13dd92-c6e2-4737-a38e-06485d9663ea','9888bb6e-8436-4978-8ef0-21919b985cfc','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-12-2lhv6y6dl34v','9888bb6e-8436-4978-8ef0-21919b985cfc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1572,'dc28cce9-b828-4f92-a739-d4e5b0d19ea9','d7af03ac-0ed9-4213-b27d-8abda4102a53','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','ControlPlanePort','96c1cd44-46ae-47cd-afe9-6148aef93411','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,971),(1573,'725e7b50-5195-4ca9-af22-c7fff479b904','3220570c-d474-4c2d-9c3c-1afe7afd5f8c','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','ControlPlanePort','5e79e02a-b26d-40d0-bee4-d37b58778545','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,970),(1574,'d8e2bb49-c812-43dc-8183-48d5e93f997a','d7af03ac-0ed9-4213-b27d-8abda4102a53','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NovaCompute-jifqesqlg3y4','d7af03ac-0ed9-4213-b27d-8abda4102a53','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1575,'1ddbc3a3-1f7d-4023-a475-88b228856fe7','3220570c-d474-4c2d-9c3c-1afe7afd5f8c','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NovaCompute-iih2a5nkebyy','3220570c-d474-4c2d-9c3c-1afe7afd5f8c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1576,'b92d7acc-7f97-4d8b-80f2-7f5c07af570c','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','GlanceLogging','4e7ca558-56fa-45b5-bbc3-70e9ecc52346','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1577,'80a71d3b-c9ba-4374-a629-0817e214464c','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:49',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-RoleParametersValue-ucr3mwjejqw3','state changed','OS::Heat::Value',NULL,980),(1578,'0339ca22-ef25-4b44-aaa3-28b17e005aa8','87597487-6d76-4aec-b0d0-e4cc722a6a26','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-11-3gou5beldgtc','87597487-6d76-4aec-b0d0-e4cc722a6a26','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1579,'270f9b11-52b1-49f5-a381-8e09115d8279','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo-RoleParametersValue-ucr3mwjejqw3','state changed','OS::Heat::Value',NULL,980),(1580,'b4da5046-5ecd-4eff-85e7-71654238e86b','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','b7864274-9084-4688-afb6-054822a2785e','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,972),(1581,'b5f2514c-dd1f-41ed-9b2c-5581880d8835','9982b5db-6073-46ee-adcb-8e16583b4458','2026-06-15 07:51:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv-HAProxyBase-kqtkmwwuoqoo','9982b5db-6073-46ee-adcb-8e16583b4458','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1582,'12f5af4b-3bbe-4b12-92e9-414af158a465','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:49',NULL,'CREATE','IN_PROGRESS','KeystoneLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-KeystoneLogging-i5lnmzlbzpt2','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1583,'15036a40-3abb-4fb9-b21d-1cc4b6f58f9b','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NovaCompute-hpfjljmwngr3','state changed','OS::TripleO::ComputeServer',NULL,981),(1584,'c36ae481-ffc9-4881-ae08-5fe56788d6d4','f455fcc5-b831-4ba3-9b6e-6d1a3423b215','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-KeystoneLogging-i5lnmzlbzpt2','f455fcc5-b831-4ba3-9b6e-6d1a3423b215','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1585,'acd61821-a5c1-4191-ad38-0ff38c53d585','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','NovaCompute','d7af03ac-0ed9-4213-b27d-8abda4102a53','state changed','OS::TripleO::ComputeServer',NULL,958),(1586,'ce5b133b-c8c6-472a-9d18-0e48b0ed8556','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','NovaCompute','3220570c-d474-4c2d-9c3c-1afe7afd5f8c','state changed','OS::TripleO::ComputeServer',NULL,968),(1587,'6ad1a09e-af2a-446d-9080-87a2fae42831','f693a37a-43f3-4968-a850-be7ceae6fdb6','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NovaCompute-hpfjljmwngr3','f693a37a-43f3-4968-a850-be7ceae6fdb6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1588,'08902aae-55d0-4302-a6a7-27e15a54534a','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','ContainersCommon','29840935-dbd2-4e5b-ba2e-72872181a5e7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1589,'0d089404-ba1b-4b62-9612-f5ebff1cb05a','f693a37a-43f3-4968-a850-be7ceae6fdb6','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-hpfjljmwngr3-deployed-server-rjzgjdynif6t','state changed','OS::Heat::DeployedServer',NULL,984),(1590,'d7ccc1fa-1c11-46d9-b303-1a0495e00ac1','f455fcc5-b831-4ba3-9b6e-6d1a3423b215','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-KeystoneLogging-i5lnmzlbzpt2-RoleParametersValue-xwxha33bw5ej','state changed','OS::Heat::Value',NULL,983),(1591,'99051306-3004-49b7-8c14-22b98ee077cc','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-ComputeExtraConfigPre-pwb2ccqovs7a','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,985),(1592,'8257b71c-1be0-4bda-a089-951d37786d3d','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-TenantPort-2k4wsfvk4njm','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,987),(1593,'ce6a8908-f961-4498-afd5-6d8c644130ae','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','12','9888bb6e-8436-4978-8ef0-21919b985cfc','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,805),(1594,'0d4e40a1-9ca2-4e17-9643-97822ed3b616','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','11','87597487-6d76-4aec-b0d0-e4cc722a6a26','state changed','OS::TripleO::Services::GlanceApi',NULL,886),(1595,'58b89645-bd2d-4122-b00d-99006a72728f','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NetHostMap-4xy4r4nn2ael','state changed','OS::Heat::Value',NULL,988),(1596,'ac603f27-51d4-4163-bd24-045fb537fb47','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NetHostMap-4xy4r4nn2ael','state changed','OS::Heat::Value',NULL,988),(1597,'c94196ad-38c8-475e-b3f7-d09d088ea6f7','005c0993-62ae-4991-bb61-0ad63e6e8b4d','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-ComputeExtraConfigPre-pwb2ccqovs7a','005c0993-62ae-4991-bb61-0ad63e6e8b4d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1598,'75fc2047-d679-4ca5-9f79-07ac9bbf8e07','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-StoragePort-kh64u73etxyy','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,990),(1599,'500acb5a-1dc5-4cd0-9506-66c12bc31590','005c0993-62ae-4991-bb61-0ad63e6e8b4d','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-ComputeExtraConfigPre-pwb2ccqovs7a','005c0993-62ae-4991-bb61-0ad63e6e8b4d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1600,'e9fd366f-fa74-4467-b2b2-e9ee9dfc20eb','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NodeTLSCAData-epmk3qaleid2','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1601,'a0c17777-6909-4b67-9d93-61d8487cdfc4','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','HAProxyBase','9982b5db-6073-46ee-adcb-8e16583b4458','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,943),(1602,'7c228f3f-2faf-4d29-92b3-506429681650','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-InternalApiPort-wrsje6mq7qai','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,992),(1603,'e2c4d4a4-64c5-493d-b119-207282fad97f','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-PreNetworkConfig-pq3ubnzasejc','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1604,'fc518f4f-c139-4610-b583-a16853d4b81c','f455fcc5-b831-4ba3-9b6e-6d1a3423b215','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-KeystoneLogging-i5lnmzlbzpt2-RoleParametersValue-xwxha33bw5ej','state changed','OS::Heat::Value',NULL,983),(1605,'f1a01db8-88eb-4d3c-adab-0b1afbbdb5dd','efce36d5-5a26-469c-b2dc-ed334d3d6238','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-TenantPort-2k4wsfvk4njm','efce36d5-5a26-469c-b2dc-ed334d3d6238','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1606,'fb144429-3d44-4db2-9b23-7f30ee858f81','0d8e187b-a36f-436f-8342-6387e50465e4','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-InternalApiPort-wrsje6mq7qai','0d8e187b-a36f-436f-8342-6387e50465e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1607,'dcc3a846-26f4-451f-9a5c-49952ceced01','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NovaComputeAnsibleHostVars-xjp6y6hryeci','state changed','OS::Heat::Value',NULL,994),(1608,'9a099d38-b3a0-48c7-91e9-c9e056c0a419','f693a37a-43f3-4968-a850-be7ceae6fdb6','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','deployed-server','f0d417d3-2648-48a7-9fbd-708f0a50f93a','state changed','OS::Heat::DeployedServer',NULL,984),(1609,'3438e502-469e-4e73-b6d1-a9e4009f9011','f455fcc5-b831-4ba3-9b6e-6d1a3423b215','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-KeystoneLogging-i5lnmzlbzpt2','f455fcc5-b831-4ba3-9b6e-6d1a3423b215','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1610,'750657d8-b9db-4273-bd6f-6983652d57b8','930ab81d-5bad-4a60-a139-0a715cd0e9bd','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-13-k6ktps37sgbv','930ab81d-5bad-4a60-a139-0a715cd0e9bd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1611,'7eaacc11-f16c-4f94-bc78-257534121ce5','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-PreNetworkConfig-kfs3alosjm4k','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1612,'c6fd74ae-df85-4829-bba8-ac1723ae1484','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-TenantPort-jhw46xjgv43v','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,995),(1613,'1afd5868-6533-4de5-a678-86c4cff16a6c','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','PreNetworkConfig','59ebed2f-61b2-40a8-a7c4-aeb497494be8','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1614,'b2446f47-ff6e-4d14-9403-26d6a8b5e2cc','a033deeb-4236-4333-bef5-481be3ca19a5','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-StoragePort-kh64u73etxyy','a033deeb-4236-4333-bef5-481be3ca19a5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1615,'408b6faa-0409-40ae-8315-84971fe30a2c','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NovaComputeAnsibleHostVars-xjp6y6hryeci','state changed','OS::Heat::Value',NULL,994),(1616,'04671f24-6236-4f9d-96b7-014ebf49c13d','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','NodeTLSCAData','92e3055d-63ff-4b9c-8a3c-de4706f6e2c5','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1617,'d915accf-0e2b-4681-90b5-27e5f170d756','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','PreNetworkConfig','540b5126-6146-433a-97e4-d79d02d681cc','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1618,'7ca716c7-cd25-4e7a-82e5-ab70e889a6a3','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-ComputeExtraConfigPre-emft6ri5um6l','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,998),(1619,'f9042b51-9a62-4e54-9445-d39fb06c935e','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NodeTLSCAData-6mb4jy3aoquw','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1620,'ec1f840f-49c4-40e9-924c-94c5e2b841af','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-StoragePort-37i34ef7dsm4','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1000),(1621,'85e073e7-5a7c-48fd-9853-0aaa2b9d0c4e','0d8e187b-a36f-436f-8342-6387e50465e4','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-InternalApiPort-wrsje6mq7qai-InternalApiDeployedPort-sjusu625f5fi','state changed','OS::Heat::Value',NULL,1003),(1622,'e375d76a-9f46-4a4b-9c2e-90bf4b018bbe','a033deeb-4236-4333-bef5-481be3ca19a5','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-StoragePort-kh64u73etxyy-StorageDeployedPort-nqo2nivjg5y7','state changed','OS::Heat::Value',NULL,1004),(1623,'52ade0f0-900b-4c00-bbc1-e88c12110319','aa178e0e-339c-4e11-8843-ef5c2937ea73','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-TenantPort-jhw46xjgv43v','aa178e0e-339c-4e11-8843-ef5c2937ea73','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1624,'1abff926-1ddb-4562-8186-93889cbd01d7','a033deeb-4236-4333-bef5-481be3ca19a5','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-StoragePort-kh64u73etxyy-StorageDeployedPort-nqo2nivjg5y7','state changed','OS::Heat::Value',NULL,1004),(1625,'b7467d43-3707-4b47-96bf-cf34e5bb3d98','a033deeb-4236-4333-bef5-481be3ca19a5','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-StoragePort-kh64u73etxyy','a033deeb-4236-4333-bef5-481be3ca19a5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1626,'dc0cb086-3d2c-4f87-9197-53654eda894c','0d8e187b-a36f-436f-8342-6387e50465e4','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-InternalApiPort-wrsje6mq7qai-InternalApiDeployedPort-sjusu625f5fi','state changed','OS::Heat::Value',NULL,1003),(1627,'5fe8acc4-9b2f-4b28-a7a4-0003ef253ffc','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-InternalApiPort-shnjkpm5f2z5','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1010),(1628,'8777eb6b-3f66-446c-84ca-7eb02af3e6d3','efce36d5-5a26-469c-b2dc-ed334d3d6238','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-TenantPort-2k4wsfvk4njm-TenantDeployedPort-e6eqq3iseyj2','state changed','OS::Heat::Value',NULL,1008),(1629,'71c0d5c4-93aa-4160-b9e8-953931a7114f','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NetHostMap-bcbo3rku6j4s','state changed','OS::Heat::Value',NULL,1009),(1630,'868621d9-9d3f-435a-a082-a71672cc9b41','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','NodeTLSCAData','06206a3f-9c51-415d-a129-d613d7935d3a','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1631,'c07e2253-6fad-46c0-aff3-6d0c5168fbf2','a130ca18-af2d-419c-883e-b3f9a5a30305','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-ComputeExtraConfigPre-emft6ri5um6l','a130ca18-af2d-419c-883e-b3f9a5a30305','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1632,'c02c7cdf-257a-45d0-aa3f-35e099cbce56','0d8e187b-a36f-436f-8342-6387e50465e4','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-InternalApiPort-wrsje6mq7qai','0d8e187b-a36f-436f-8342-6387e50465e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1633,'5e89d559-8052-4c9a-9b29-9998ccf46a41','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NetHostMap-bcbo3rku6j4s','state changed','OS::Heat::Value',NULL,1009),(1634,'9c606145-d144-49cf-8031-cf69abbbfa43','a130ca18-af2d-419c-883e-b3f9a5a30305','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-ComputeExtraConfigPre-emft6ri5um6l','a130ca18-af2d-419c-883e-b3f9a5a30305','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1635,'666592dc-2104-4b3d-ab09-14899cc71e47','27370e3e-14fa-47b8-9dad-c944f23503be','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-InternalApiPort-shnjkpm5f2z5','27370e3e-14fa-47b8-9dad-c944f23503be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1636,'41fc0fe9-5eee-45a3-b966-53390c4db967','efce36d5-5a26-469c-b2dc-ed334d3d6238','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-TenantPort-2k4wsfvk4njm-TenantDeployedPort-e6eqq3iseyj2','state changed','OS::Heat::Value',NULL,1008),(1637,'af5ebb32-a436-444b-b8a3-e8692bd53a4f','36d4c991-5460-4a03-9ba4-7b17334fe50d','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-StoragePort-37i34ef7dsm4','36d4c991-5460-4a03-9ba4-7b17334fe50d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1638,'a6368dbb-e51e-4bb3-8770-0fac4c2cc7ae','efce36d5-5a26-469c-b2dc-ed334d3d6238','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-TenantPort-2k4wsfvk4njm','efce36d5-5a26-469c-b2dc-ed334d3d6238','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1639,'0bf4351d-ee73-43a9-9d27-749185f3c4a2','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NovaComputeAnsibleHostVars-o6ljau2sjwhi','state changed','OS::Heat::Value',NULL,1016),(1640,'f6500fea-02ae-4857-b76e-7955b033cd39','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NovaComputeAnsibleHostVars-o6ljau2sjwhi','state changed','OS::Heat::Value',NULL,1016),(1641,'d5305b71-9cd5-4633-94d9-2c1933cda1d5','aa178e0e-339c-4e11-8843-ef5c2937ea73','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-TenantPort-jhw46xjgv43v-TenantDeployedPort-gsybywhszdio','state changed','OS::Heat::Value',NULL,1020),(1642,'213b9303-1619-4701-96bf-3e6760366bf5','aa178e0e-339c-4e11-8843-ef5c2937ea73','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-TenantPort-jhw46xjgv43v-TenantDeployedPort-gsybywhszdio','state changed','OS::Heat::Value',NULL,1020),(1643,'acff4932-9bfa-40d1-a43e-7a9acf1e0497','27370e3e-14fa-47b8-9dad-c944f23503be','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-InternalApiPort-shnjkpm5f2z5-InternalApiDeployedPort-vwesznmxb23z','state changed','OS::Heat::Value',NULL,1022),(1644,'36632c28-4d38-4274-bf1e-52f46d4ea177','aa178e0e-339c-4e11-8843-ef5c2937ea73','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-TenantPort-jhw46xjgv43v','aa178e0e-339c-4e11-8843-ef5c2937ea73','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1645,'78b221bb-e644-4374-8747-baa99f893e2f','27370e3e-14fa-47b8-9dad-c944f23503be','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-InternalApiPort-shnjkpm5f2z5-InternalApiDeployedPort-vwesznmxb23z','state changed','OS::Heat::Value',NULL,1022),(1646,'3c72c57e-05eb-4802-ad90-306605015b92','36d4c991-5460-4a03-9ba4-7b17334fe50d','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-StoragePort-37i34ef7dsm4-StorageDeployedPort-4ywjxalh3xbs','state changed','OS::Heat::Value',NULL,1025),(1647,'cb50efb7-60f5-465a-9ada-7ca4d07e92f5','36d4c991-5460-4a03-9ba4-7b17334fe50d','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-StoragePort-37i34ef7dsm4-StorageDeployedPort-4ywjxalh3xbs','state changed','OS::Heat::Value',NULL,1025),(1648,'f44c0e2e-5f44-4146-98e8-5342646c5a35','27370e3e-14fa-47b8-9dad-c944f23503be','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-InternalApiPort-shnjkpm5f2z5','27370e3e-14fa-47b8-9dad-c944f23503be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1649,'bdb255da-46c2-45f2-9b01-4ccd8da8ded9','36d4c991-5460-4a03-9ba4-7b17334fe50d','2026-06-15 07:51:50',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-StoragePort-37i34ef7dsm4','36d4c991-5460-4a03-9ba4-7b17334fe50d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1650,'231153c7-cc92-414c-a06b-e4432e333de7','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','15','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-15-zwx2xd7ykgj2','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,1031),(1651,'333e5157-d7a2-4432-b1c0-04f9e8960a39','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:50',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-RoleParametersValue-myg4mby7tbdb','state changed','OS::Heat::Value',NULL,1030),(1652,'fa1ca872-bca3-4e48-9641-ccd5a89f1bbf','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-RoleParametersValue-myg4mby7tbdb','state changed','OS::Heat::Value',NULL,1030),(1653,'21b9c165-16a7-4f52-87de-b43ae733a5e4','9275e0a8-5f35-4154-ae7a-8e170fbf0280','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-15-zwx2xd7ykgj2','9275e0a8-5f35-4154-ae7a-8e170fbf0280','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1654,'cf66ed49-b1bc-4821-afa7-05ddf9946637','9275e0a8-5f35-4154-ae7a-8e170fbf0280','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-15-zwx2xd7ykgj2','9275e0a8-5f35-4154-ae7a-8e170fbf0280','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1655,'44b8d477-4941-407e-86f9-59272249a289','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','KeystoneLogging','f455fcc5-b831-4ba3-9b6e-6d1a3423b215','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1656,'42686302-4c5d-4127-a5f6-76330328c5d1','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','16','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1033),(1657,'48687f11-d84e-4c1e-8080-7df9360f76dc','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af','1cf03de2-c9d7-47af-bac5-c6a223fcb833','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1658,'f47cb2a6-3bcd-448d-907d-cf693e37d844','f693a37a-43f3-4968-a850-be7ceae6fdb6','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NovaCompute-hpfjljmwngr3-ControlPlanePort-pwlrsvnd2l7f','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1034),(1659,'d9c74135-9f24-4363-b598-bb24e55e6cf1','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','005c0993-62ae-4991-bb61-0ad63e6e8b4d','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,985),(1660,'12bf5e9e-a7f2-49a9-be84-275be6d69fbd','e0c0aecf-542b-4f07-9c2a-eb25da6a72dc','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NovaCompute-hpfjljmwngr3-ControlPlanePort-pwlrsvnd2l7f','e0c0aecf-542b-4f07-9c2a-eb25da6a72dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1661,'11724344-68d0-48ea-b4ff-1e8b6daaac85','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-RoleParametersValue-4sgniuv22zxo','state changed','OS::Heat::Value',NULL,1036),(1662,'6acc1730-26d6-48c4-aacb-923768bf3a1a','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NodeExtraConfig-6uknvqlz53uw','state changed','OS::TripleO::NodeExtraConfig',NULL,1037),(1663,'dcd4762a-07fd-4d9b-92d8-ec6e5e62e944','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-RoleParametersValue-4sgniuv22zxo','state changed','OS::Heat::Value',NULL,1036),(1664,'45844d85-4035-47c3-b399-3422d86ce643','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','13','930ab81d-5bad-4a60-a139-0a715cd0e9bd','state changed','OS::TripleO::Services::HAproxy',NULL,893),(1665,'7e30fa41-d034-4d63-af8a-47ce9e847bbb','e0c0aecf-542b-4f07-9c2a-eb25da6a72dc','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NovaCompute-hpfjljmwngr3-ControlPlanePort-pwlrsvnd2l7f','e0c0aecf-542b-4f07-9c2a-eb25da6a72dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1666,'b11f7c0a-9498-4ec5-bb2c-ff576d919209','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','InternalApiPort','0d8e187b-a36f-436f-8342-6387e50465e4','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,992),(1667,'a14728e7-03e0-48e7-8efd-865e6ab154a7','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','TenantPort','efce36d5-5a26-469c-b2dc-ed334d3d6238','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,987),(1668,'c4588d35-48eb-49a5-bbbb-ad4de162f48a','bdafd3e9-9b97-4bf4-944e-f0bc90455792','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NodeExtraConfig-6uknvqlz53uw','bdafd3e9-9b97-4bf4-944e-f0bc90455792','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1669,'157f551f-5477-4ccf-9cde-5342f95bd73e','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','StoragePort','a033deeb-4236-4333-bef5-481be3ca19a5','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,990),(1670,'53b54a66-ec42-4aba-9ebc-7b81b216c0bc','bdafd3e9-9b97-4bf4-944e-f0bc90455792','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NodeExtraConfig-6uknvqlz53uw','bdafd3e9-9b97-4bf4-944e-f0bc90455792','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1671,'951daa04-54ce-41be-af95-d7a1c82f2f7d','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','NodeExtraConfig','bdafd3e9-9b97-4bf4-944e-f0bc90455792','state changed','OS::TripleO::NodeExtraConfig',NULL,1037),(1672,'285fa73c-f455-45e2-8be0-ae56cdeeeb98','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NetIpMap-zdutmcsq36xs','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1046),(1673,'81115a09-572f-4294-9d1c-506c72c1ca90','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','TenantPort','aa178e0e-339c-4e11-8843-ef5c2937ea73','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,995),(1674,'91b34763-e56a-4720-a5dc-f1858014239b','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','a130ca18-af2d-419c-883e-b3f9a5a30305','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,998),(1675,'292c5f57-fefd-45c2-b4be-1c0fc22154a6','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','InternalApiPort','27370e3e-14fa-47b8-9dad-c944f23503be','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1010),(1676,'31db9bf9-8269-4554-b8d3-f349f98d54a7','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','StoragePort','36d4c991-5460-4a03-9ba4-7b17334fe50d','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1000),(1677,'85df1d1f-d83d-4ff6-94ea-e1580d1b0c34','becaaadd-77c3-4dd1-9190-6d561a77d2cf','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NetIpMap-zdutmcsq36xs','becaaadd-77c3-4dd1-9190-6d561a77d2cf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1678,'62986bb5-c046-4b0a-8adb-71fa0ed4ab36','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NodeExtraConfig-wl2zvqhhc6qv','state changed','OS::TripleO::NodeExtraConfig',NULL,1051),(1679,'f36ea9c3-3d60-4749-b945-020c08cf0992','55bc4bb4-a381-490f-957f-cf0c290852a7','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NodeExtraConfig-wl2zvqhhc6qv','55bc4bb4-a381-490f-957f-cf0c290852a7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1680,'b90b06b7-31a3-4b3b-a218-d252d5a52301','55bc4bb4-a381-490f-957f-cf0c290852a7','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NodeExtraConfig-wl2zvqhhc6qv','55bc4bb4-a381-490f-957f-cf0c290852a7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1681,'77776bbc-fd6c-4b12-8ff4-352348de14f2','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:51',NULL,'CREATE','COMPLETE','NodeExtraConfig','55bc4bb4-a381-490f-957f-cf0c290852a7','state changed','OS::TripleO::NodeExtraConfig',NULL,1051),(1682,'d0d6168a-b2c2-4d1e-8dcf-c186d8dc767b','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NetIpMap-remsltygx6o3','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1062),(1683,'0d9447d9-f29e-4517-8b08-21ec305f8b82','becaaadd-77c3-4dd1-9190-6d561a77d2cf','2026-06-15 07:51:51',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NetIpMap-zdutmcsq36xs-NetIpMapValue-p3y7i2krrqen','state changed','OS::Heat::Value',NULL,1063),(1684,'7eb56bd3-d90d-4fbc-8cce-d1ff4c6c568b','becaaadd-77c3-4dd1-9190-6d561a77d2cf','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NetIpMap-zdutmcsq36xs-NetIpMapValue-p3y7i2krrqen','state changed','OS::Heat::Value',NULL,1063),(1685,'5a8db9fb-76d9-485a-b9b3-92c61893d774','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-ApacheServiceBase-mp6sv7gqszn5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1064),(1686,'c4ceb871-b078-4ff5-966d-619fffdc3916','becaaadd-77c3-4dd1-9190-6d561a77d2cf','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3-NetIpMap-zdutmcsq36xs','becaaadd-77c3-4dd1-9190-6d561a77d2cf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1687,'a2c302a8-92db-4d7b-b4f8-9cd7c47a864d','25849288-6e94-4fe5-a655-76d787b7ad91','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NetIpMap-remsltygx6o3','25849288-6e94-4fe5-a655-76d787b7ad91','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1688,'18f59b60-e8eb-4c6a-9cd0-07fcfb947fdc','ebb69558-2760-4a54-a35a-80c19317fb6e','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-ApacheServiceBase-mp6sv7gqszn5','ebb69558-2760-4a54-a35a-80c19317fb6e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1689,'ebadf398-c329-4a5a-b9d6-d89893eb6a8f','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','15','9275e0a8-5f35-4154-ae7a-8e170fbf0280','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,1031),(1690,'f0274d67-ffa6-48b3-8bf4-ca5f53ab971c','25849288-6e94-4fe5-a655-76d787b7ad91','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NetIpMap-remsltygx6o3-NetIpMapValue-du5rza3omlfq','state changed','OS::Heat::Value',NULL,1069),(1691,'3bd61b61-cfc6-414f-aa7e-7d47fd38bd77','25849288-6e94-4fe5-a655-76d787b7ad91','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NetIpMap-remsltygx6o3-NetIpMapValue-du5rza3omlfq','state changed','OS::Heat::Value',NULL,1069),(1692,'d6393220-c7ea-491f-8369-b3fda2946734','ebb69558-2760-4a54-a35a-80c19317fb6e','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-ApacheServiceBase-mp6sv7gqszn5-ApacheNetworks-lx4vx4ly3vmx','state changed','OS::Heat::Value',NULL,1070),(1693,'f6b88255-75dc-465d-999d-448bb7d9103b','25849288-6e94-4fe5-a655-76d787b7ad91','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6-NetIpMap-remsltygx6o3','25849288-6e94-4fe5-a655-76d787b7ad91','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1694,'bf9e456a-462a-424b-8855-6b03906d7539','ebb69558-2760-4a54-a35a-80c19317fb6e','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-ApacheServiceBase-mp6sv7gqszn5-ApacheNetworks-lx4vx4ly3vmx','state changed','OS::Heat::Value',NULL,1070),(1695,'eb14449c-78ea-46db-8ffb-30fc056de230','ebb69558-2760-4a54-a35a-80c19317fb6e','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55-ApacheServiceBase-mp6sv7gqszn5','ebb69558-2760-4a54-a35a-80c19317fb6e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1696,'b14d1e87-3090-4920-9584-f96b68fb4171','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','17','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml','state changed','OS::TripleO::Services::HeatEngine',NULL,1071),(1697,'3f414dee-11d2-4b06-9e30-531267bd8f9a','f693a37a-43f3-4968-a850-be7ceae6fdb6','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','ControlPlanePort','e0c0aecf-542b-4f07-9c2a-eb25da6a72dc','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1034),(1698,'00d016c0-17ad-4098-b73a-4e316293ddab','f693a37a-43f3-4968-a850-be7ceae6fdb6','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NovaCompute-hpfjljmwngr3','f693a37a-43f3-4968-a850-be7ceae6fdb6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1699,'4a8d36aa-b8ac-43c0-89e9-4d260f6f6d44','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','19','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-19-4fssho4grl2i','state changed','OS::TripleO::Services::IpaClient',NULL,1073),(1700,'97f53efc-6fad-4ae6-ac8c-bc7e3fd37d84','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','HeatApiCfnLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-HeatApiCfnLogging-hrxqkrb7cmcu','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1701,'0245fa2f-aedf-4407-b776-ead58cd34659','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1702,'99cc1505-6fba-49ab-9c11-354c3d18e5b6','7be222f3-1e0a-4fd0-9677-929a5a302a11','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-HeatApiCfnLogging-hrxqkrb7cmcu','7be222f3-1e0a-4fd0-9677-929a5a302a11','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1703,'6f69583f-fa2a-47e3-953e-7ef1d865d84a','7be222f3-1e0a-4fd0-9677-929a5a302a11','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-HeatApiCfnLogging-hrxqkrb7cmcu','7be222f3-1e0a-4fd0-9677-929a5a302a11','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1704,'d9b8b046-f041-48e4-b73a-095d53336242','ea919929-5104-43f9-8d27-379e6a5ca3d9','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-19-4fssho4grl2i','ea919929-5104-43f9-8d27-379e6a5ca3d9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1705,'ac21aca1-7d82-48c3-8968-4b435ced9b44','ea919929-5104-43f9-8d27-379e6a5ca3d9','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-19-4fssho4grl2i','ea919929-5104-43f9-8d27-379e6a5ca3d9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1706,'8ef6df47-2287-4bcf-817b-e07f74eaf05d','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','HeatEngineLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-HeatEngineLogging-mn7lttm7ef2k','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1707,'d877dc36-1d30-475d-881d-c252b5968edd','d5fc0351-253a-4a21-b548-ea9a9edfe94c','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-HeatEngineLogging-mn7lttm7ef2k','d5fc0351-253a-4a21-b548-ea9a9edfe94c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1708,'89e83d79-7f4c-46ab-b9c9-e959621a1841','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','NetIpMap','becaaadd-77c3-4dd1-9190-6d561a77d2cf','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1046),(1709,'b0f3505f-bed7-468b-ba86-955a14b5ccf0','2dfbb7f8-f236-4995-81c7-b5df4af90caa','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-2-ueibd3bjc5i3','2dfbb7f8-f236-4995-81c7-b5df4af90caa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1710,'74996f5d-0209-4585-89aa-655ef3ec3ac1','d5fc0351-253a-4a21-b548-ea9a9edfe94c','2026-06-15 07:51:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-HeatEngineLogging-mn7lttm7ef2k-RoleParametersValue-4vakpunqfneo','state changed','OS::Heat::Value',NULL,1074),(1711,'62c5c40e-801c-4545-bf64-8bbc33a12827','d5fc0351-253a-4a21-b548-ea9a9edfe94c','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-HeatEngineLogging-mn7lttm7ef2k-RoleParametersValue-4vakpunqfneo','state changed','OS::Heat::Value',NULL,1074),(1712,'f1066efc-2257-4880-8073-4ba52ec4a7ab','d5fc0351-253a-4a21-b548-ea9a9edfe94c','2026-06-15 07:51:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-HeatEngineLogging-mn7lttm7ef2k','d5fc0351-253a-4a21-b548-ea9a9edfe94c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1713,'21f4af06-8acf-4ff1-b19a-1196c62ee08c','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','ApacheServiceBase','ebb69558-2760-4a54-a35a-80c19317fb6e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1064),(1714,'7ac26cdd-bb84-4770-9e22-9d17072416e7','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','NovaCompute','f693a37a-43f3-4968-a850-be7ceae6fdb6','state changed','OS::TripleO::ComputeServer',NULL,981),(1715,'a1bc0cb5-acd4-4766-9c76-656f0ee5aa2b','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','NetIpMap','25849288-6e94-4fe5-a655-76d787b7ad91','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1062),(1716,'188c42b6-90ae-4bee-9a81-ba927557b177','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-22-jlgqptuska55','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1717,'79cb3abc-fe37-4453-ad46-7e8fe871f93a','768234c8-8b26-4c4c-acdb-511db3a5be03','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-1-a2s75jir4dv6','768234c8-8b26-4c4c-acdb-511db3a5be03','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1718,'6e8a8c75-3675-44e9-99e9-0fb34c7a1561','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-StoragePort-fhmpxy5yrfn5','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1076),(1719,'c42de1e1-d150-4ec3-85f1-be5a23a076d6','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-InternalApiPort-lnole4dluni3','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1077),(1720,'38b03d91-3ee2-4538-aae8-f945a7a9589a','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NodeTLSCAData-vi2ujcrvnuci','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1721,'cce90374-1107-4d8a-9cf8-92d69dabae32','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','NodeTLSCAData','ab31569a-934d-428a-9c16-e953780334f2','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1722,'013c1e59-2203-4598-b67b-c814869e6c20','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NetHostMap-n7gusp6flyzi','state changed','OS::Heat::Value',NULL,1078),(1723,'f5b095bb-7895-4156-a7d9-9f881fcba899','be2d6857-ba0e-4e0c-8dea-8a053d0db323','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-InternalApiPort-lnole4dluni3','be2d6857-ba0e-4e0c-8dea-8a053d0db323','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1724,'898e59aa-1db6-4ddb-b4db-ecf2250d0957','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-ComputeExtraConfigPre-tupcawyc6swi','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1079),(1725,'799eaf10-7459-4834-a3df-2dd2583067c6','652cf6ab-2a97-4dea-9a81-b832bc5310f6','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-StoragePort-fhmpxy5yrfn5','652cf6ab-2a97-4dea-9a81-b832bc5310f6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1726,'b3e339bd-62c1-4330-b226-6d28cd1479ca','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NetHostMap-n7gusp6flyzi','state changed','OS::Heat::Value',NULL,1078),(1727,'cfb8a481-4c84-47e0-8c57-d0befd2663fe','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-PreNetworkConfig-xsqjc25inwrl','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1728,'f706ddf7-2f82-463a-9dac-80d55279456d','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-TenantPort-ekidn34erslf','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1082),(1729,'6bc786f0-901a-468f-bff6-730c57a214cd','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NovaComputeAnsibleHostVars-uqfgljju3oh4','state changed','OS::Heat::Value',NULL,1083),(1730,'33f89461-903a-48e8-b3c4-24b69ec08d9e','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','PreNetworkConfig','5fd0d409-3dc5-4779-b29a-0245ddc32e42','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1731,'58701cc6-1368-4b53-bfc8-2f6460b9f493','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-ApacheServiceBase-eh6u3r7e45bz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1084),(1732,'0928d5a6-52da-4aaa-97a2-c325516fc3c2','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NovaComputeAnsibleHostVars-uqfgljju3oh4','state changed','OS::Heat::Value',NULL,1083),(1733,'2e23b386-9bd0-4bd2-9c43-b1180903833b','ba141505-29cd-4831-b074-e0853a13d678','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-ComputeExtraConfigPre-tupcawyc6swi','ba141505-29cd-4831-b074-e0853a13d678','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1734,'14553eef-2b8d-4d35-a300-9479f0505b4c','652cf6ab-2a97-4dea-9a81-b832bc5310f6','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-StoragePort-fhmpxy5yrfn5-StorageDeployedPort-il5br3bahl5a','state changed','OS::Heat::Value',NULL,1085),(1735,'68fe6ff2-15e5-42f5-9fd6-a0271459e019','4e108ae6-604c-4345-939b-3ea323fcb1fe','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-TenantPort-ekidn34erslf','4e108ae6-604c-4345-939b-3ea323fcb1fe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1736,'c2b24b83-3629-40ed-84b7-83caa8095f61','ba141505-29cd-4831-b074-e0853a13d678','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-ComputeExtraConfigPre-tupcawyc6swi','ba141505-29cd-4831-b074-e0853a13d678','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1737,'024092b8-b78c-4d41-a40a-37dd13f784f7','652cf6ab-2a97-4dea-9a81-b832bc5310f6','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-StoragePort-fhmpxy5yrfn5-StorageDeployedPort-il5br3bahl5a','state changed','OS::Heat::Value',NULL,1085),(1738,'eee4d996-9d54-40c8-bfd0-9793baadcb7a','be2d6857-ba0e-4e0c-8dea-8a053d0db323','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-InternalApiPort-lnole4dluni3-InternalApiDeployedPort-grd7s3uen224','state changed','OS::Heat::Value',NULL,1086),(1739,'5c15bb93-c6d8-43f8-872b-0154ab4cb10f','652cf6ab-2a97-4dea-9a81-b832bc5310f6','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-StoragePort-fhmpxy5yrfn5','652cf6ab-2a97-4dea-9a81-b832bc5310f6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1740,'189f0d7b-27df-4148-8136-7ef9f0eab014','49a0f14f-ccf0-45ea-974d-1ec57542e19a','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-ApacheServiceBase-eh6u3r7e45bz','49a0f14f-ccf0-45ea-974d-1ec57542e19a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1741,'724f04ae-6920-4808-80a5-151d91608e04','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','HeatApiCfnLogging','7be222f3-1e0a-4fd0-9677-929a5a302a11','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1742,'80ca0d90-8bfb-4532-ac75-819f261d8e25','be2d6857-ba0e-4e0c-8dea-8a053d0db323','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-InternalApiPort-lnole4dluni3-InternalApiDeployedPort-grd7s3uen224','state changed','OS::Heat::Value',NULL,1086),(1743,'f793e028-5b0c-46d1-b718-fac63bc016b0','4e108ae6-604c-4345-939b-3ea323fcb1fe','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-TenantPort-ekidn34erslf-TenantDeployedPort-z2aziaddknll','state changed','OS::Heat::Value',NULL,1087),(1744,'911b93e8-0a87-454c-9110-e5d3d98e0894','be2d6857-ba0e-4e0c-8dea-8a053d0db323','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-InternalApiPort-lnole4dluni3','be2d6857-ba0e-4e0c-8dea-8a053d0db323','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1745,'3104e7dc-c665-46a5-a099-166af387987e','4e108ae6-604c-4345-939b-3ea323fcb1fe','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-TenantPort-ekidn34erslf-TenantDeployedPort-z2aziaddknll','state changed','OS::Heat::Value',NULL,1087),(1746,'3de507e0-eba4-4bfb-8584-3b65e8f25a0c','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','19','ea919929-5104-43f9-8d27-379e6a5ca3d9','state changed','OS::TripleO::Services::IpaClient',NULL,1073),(1747,'f8c5f4dc-e60e-4430-be34-88f970c59ec2','4e108ae6-604c-4345-939b-3ea323fcb1fe','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-TenantPort-ekidn34erslf','4e108ae6-604c-4345-939b-3ea323fcb1fe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1748,'f983c7e3-1980-4297-a971-d7852c1adf66','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','2','2dfbb7f8-f236-4995-81c7-b5df4af90caa','state changed','OS::TripleO::Compute',NULL,956),(1749,'f528d6ff-d0b3-4c62-8992-6b97274e3363','49a0f14f-ccf0-45ea-974d-1ec57542e19a','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-ApacheServiceBase-eh6u3r7e45bz-ApacheNetworks-yfbwtv57yg27','state changed','OS::Heat::Value',NULL,1088),(1750,'18937da1-994b-46b0-af3c-7255cc121252','49a0f14f-ccf0-45ea-974d-1ec57542e19a','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-ApacheServiceBase-eh6u3r7e45bz-ApacheNetworks-yfbwtv57yg27','state changed','OS::Heat::Value',NULL,1088),(1751,'0f9b838f-2916-4881-a802-8a063939f62e','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','22','0050f24d-bf9c-4cc8-8613-1bda9050fd8d','state changed','OS::TripleO::Services::Keystone',NULL,966),(1752,'36ab0e43-a040-4288-bb52-845b787968d3','49a0f14f-ccf0-45ea-974d-1ec57542e19a','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-ApacheServiceBase-eh6u3r7e45bz','49a0f14f-ccf0-45ea-974d-1ec57542e19a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1753,'38e07a91-2268-4ba1-bcfb-b1455cbf0da7','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','1','768234c8-8b26-4c4c-acdb-511db3a5be03','state changed','OS::TripleO::Compute',NULL,965),(1754,'6ae06eb6-64df-49d8-bb14-f76776bb751a','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-MySQLClient-p3hezi6qmhy7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1755,'c428048f-a547-43ff-9f37-b6c8b5c24a91','4f91612c-3d43-415a-9305-6a9ff8f20e26','2026-06-15 07:51:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-MySQLClient-p3hezi6qmhy7','4f91612c-3d43-415a-9305-6a9ff8f20e26','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1756,'13099c5a-4ed0-4683-bdcf-8e58a49e694a','4f91612c-3d43-415a-9305-6a9ff8f20e26','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-MySQLClient-p3hezi6qmhy7','4f91612c-3d43-415a-9305-6a9ff8f20e26','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1757,'4a00622b-952b-4017-9027-0effd3256b9f','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:53',NULL,'CREATE','COMPLETE','HeatEngineLogging','d5fc0351-253a-4a21-b548-ea9a9edfe94c','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1758,'d51f9b3d-6e75-430f-a386-38bff2136eef','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','23','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy','state changed','OS::TripleO::Services::ManilaApi',NULL,1090),(1759,'a9038127-ff05-42cc-9d43-a5b1f9020030','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy','7a052d79-58a2-4d45-97d6-6b10e017f129','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1760,'f81d8ae6-ef6c-4792-8365-5477ceac5a1c','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-MySQLClient-tgaiei2q6fip','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1761,'9824d968-632d-4742-bc83-2fc106782501','948e7f17-776e-46df-b573-b36939da0550','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-MySQLClient-tgaiei2q6fip','948e7f17-776e-46df-b573-b36939da0550','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1762,'2a258306-ca63-42a8-8d5b-88a37b237a6c','948e7f17-776e-46df-b573-b36939da0550','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-MySQLClient-tgaiei2q6fip','948e7f17-776e-46df-b573-b36939da0550','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1763,'5920acae-6f63-47de-9431-ea46167ff713','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','InternalApiPort','be2d6857-ba0e-4e0c-8dea-8a053d0db323','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1077),(1764,'1d642b24-d40b-41ec-a8ac-3614b23d94e3','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','StoragePort','652cf6ab-2a97-4dea-9a81-b832bc5310f6','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1076),(1765,'2d976ca3-aac2-4a72-9d2e-c9a4d759129e','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','26','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj','state changed','OS::TripleO::Services::ManilaShare',NULL,1099),(1766,'df3934a6-1b6e-4bc2-943d-0b35dec05426','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-ContainersCommon-hwsegdzzx4nh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1767,'ceb41e36-29b6-45ba-908b-e6a4ade5a142','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','ba141505-29cd-4831-b074-e0853a13d678','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1079),(1768,'216ed7a5-8b4b-4665-ae21-4872e7473fc0','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj','37a5128e-08ed-40c2-b263-95b36d620ae9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1769,'85e63a01-1978-4bd8-ab14-a984d66569f1','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','TenantPort','4e108ae6-604c-4345-939b-3ea323fcb1fe','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1082),(1770,'6ed8d7f8-bef6-4476-a4d8-167750f9dc8c','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','ApacheServiceBase','49a0f14f-ccf0-45ea-974d-1ec57542e19a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1084),(1771,'d2a19503-7acf-41dc-a57c-205629e8c7f1','482b68c6-60d1-4835-9cd6-a9e28b82a4fd','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-ContainersCommon-hwsegdzzx4nh','482b68c6-60d1-4835-9cd6-a9e28b82a4fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1772,'f19e5016-d438-4a4f-a06f-f69cbce75905','482b68c6-60d1-4835-9cd6-a9e28b82a4fd','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-ContainersCommon-hwsegdzzx4nh','482b68c6-60d1-4835-9cd6-a9e28b82a4fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1773,'b9b444fc-7f4e-4638-8b6e-66d916722924','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NodeExtraConfig-vk4p3jib5qem','state changed','OS::TripleO::NodeExtraConfig',NULL,1105),(1774,'b596063e-2b1f-4f7b-b160-3ee0fb6ce8fb','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-HeatBase-vbs3rbxpfwjt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1107),(1775,'ea60a15d-3778-415f-b962-368cb68eb338','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NetIpMap-p72gnt7zhuzh','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1109),(1776,'0740c755-a0a3-4b98-b906-b16244b94a3d','2c6bbe8b-a1a5-4373-9919-263242bf52a4','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-HeatBase-vbs3rbxpfwjt','2c6bbe8b-a1a5-4373-9919-263242bf52a4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1777,'c379fbf9-b2ad-4a11-a335-c2ffeda33816','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','ManilaShareContainerBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1110),(1778,'eb724c82-beed-48f3-a7d2-db3f3376bdf7','2c6bbe8b-a1a5-4373-9919-263242bf52a4','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-HeatBase-vbs3rbxpfwjt','2c6bbe8b-a1a5-4373-9919-263242bf52a4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1779,'75d60023-e46b-4d13-ab3a-9914a2fa51cb','c47e97a7-bf64-4e88-a4dd-73f64b4e0b72','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NetIpMap-p72gnt7zhuzh','c47e97a7-bf64-4e88-a4dd-73f64b4e0b72','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1780,'0015d834-f770-4748-a408-6fc37471574f','8ef086e0-d20b-4678-a633-13792f3a0ddf','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NodeExtraConfig-vk4p3jib5qem','8ef086e0-d20b-4678-a633-13792f3a0ddf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1781,'55fb4699-ed5d-4709-9a0f-e6badbf9cb03','8ef086e0-d20b-4678-a633-13792f3a0ddf','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NodeExtraConfig-vk4p3jib5qem','8ef086e0-d20b-4678-a633-13792f3a0ddf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1782,'7171b0e1-1840-47c9-9345-cc0fa127e86a','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','MySQLClient','4f91612c-3d43-415a-9305-6a9ff8f20e26','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1783,'b2d3e2ac-0c86-4215-85c1-2c865e14a8a1','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:54',NULL,'CREATE','COMPLETE','NodeExtraConfig','8ef086e0-d20b-4678-a633-13792f3a0ddf','state changed','OS::TripleO::NodeExtraConfig',NULL,1105),(1784,'3633ac6d-58ee-4072-82a6-6fce6fd03fc6','c47e97a7-bf64-4e88-a4dd-73f64b4e0b72','2026-06-15 07:51:54',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NetIpMap-p72gnt7zhuzh-NetIpMapValue-ildjdv5shr7y','state changed','OS::Heat::Value',NULL,1111),(1785,'8309d8f0-c5ff-4dcd-979d-e64c3d11a29b','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:51:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu','13d18384-be40-4113-974d-3d1e8a069bdf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1786,'5dd24e16-adaa-4039-9770-26f4682be52e','c47e97a7-bf64-4e88-a4dd-73f64b4e0b72','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NetIpMap-p72gnt7zhuzh-NetIpMapValue-ildjdv5shr7y','state changed','OS::Heat::Value',NULL,1111),(1787,'d7b4a9f8-6946-4b42-a5f5-ff2ce668d83c','c47e97a7-bf64-4e88-a4dd-73f64b4e0b72','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i-NetIpMap-p72gnt7zhuzh','c47e97a7-bf64-4e88-a4dd-73f64b4e0b72','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1788,'f671bd2a-94fa-41ce-8c0b-0e6dd6732c17','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:51:55',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ManilaBase-hzahi72rxfah','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1112),(1789,'1bacd5cd-d485-4543-9529-4f60655366fe','bfa3698d-f582-4116-bbfd-a1cdd9a48488','2026-06-15 07:51:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ManilaBase-hzahi72rxfah','bfa3698d-f582-4116-bbfd-a1cdd9a48488','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1790,'c48c9f17-5bba-4fab-9710-40b504d4a718','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:55',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-RoleParametersValue-byliiqdgzufi','state changed','OS::Heat::Value',NULL,1113),(1791,'0766413b-158c-482a-bc4e-c411d9d82bbe','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-RoleParametersValue-byliiqdgzufi','state changed','OS::Heat::Value',NULL,1113),(1792,'393d5f98-3d35-46e0-ba12-0582f8aa932a','bfa3698d-f582-4116-bbfd-a1cdd9a48488','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ManilaBase-hzahi72rxfah','bfa3698d-f582-4116-bbfd-a1cdd9a48488','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1793,'c8ba5971-9264-467a-ba4d-a6fe034ea408','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','MySQLClient','948e7f17-776e-46df-b573-b36939da0550','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1794,'e4becc99-2962-4ce6-a89c-9a5444d0f561','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:55',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-HeatBase-qixgq7d5l2py','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1114),(1795,'bc8d26d8-7263-46fb-9476-f0e67540f1c4','d5f6b8df-27b1-44a1-866f-579f3fde3a9b','2026-06-15 07:51:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-HeatBase-qixgq7d5l2py','d5f6b8df-27b1-44a1-866f-579f3fde3a9b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1796,'a8af5f8d-1790-4170-8b3f-378255285ce7','d5f6b8df-27b1-44a1-866f-579f3fde3a9b','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af-HeatBase-qixgq7d5l2py','d5f6b8df-27b1-44a1-866f-579f3fde3a9b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1797,'1e580bae-f61f-4300-94cd-a6298676c35d','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','ContainersCommon','482b68c6-60d1-4835-9cd6-a9e28b82a4fd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1798,'a1f5be26-81d3-4b4f-8353-7c7d576ad7b4','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:55',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-RoleParametersValue-wusgl7qmpdnw','state changed','OS::Heat::Value',NULL,1115),(1799,'8a7abda8-7a95-458e-9820-98c4561a429c','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-RoleParametersValue-wusgl7qmpdnw','state changed','OS::Heat::Value',NULL,1115),(1800,'7ba205f0-d200-4891-824d-9b6120ee17e5','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:51:55',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-MySQLClient-oqjz4m2fe4wg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1801,'5aa97404-fc7f-4ab1-9fc7-a64ba31b7478','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','HeatBase','2c6bbe8b-a1a5-4373-9919-263242bf52a4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1107),(1802,'28f57f6e-9d46-41a9-8b4b-6f14bdc687c9','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','NetIpMap','c47e97a7-bf64-4e88-a4dd-73f64b4e0b72','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1109),(1803,'538304bc-9635-4335-a622-fcc9c3711b95','9228bf1f-e852-4462-9269-a745bf25c77a','2026-06-15 07:51:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-MySQLClient-oqjz4m2fe4wg','9228bf1f-e852-4462-9269-a745bf25c77a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1804,'84c5ab01-c981-4648-894b-ef885c5b1d83','ddc81659-94de-44c4-b881-7a3c01d59bfd','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','overcloud-Compute-jgegfs3bargx-0-uu5el5i3rj6i','ddc81659-94de-44c4-b881-7a3c01d59bfd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1805,'42a81eb2-4d6e-4e9d-b66e-afe73531c401','9228bf1f-e852-4462-9269-a745bf25c77a','2026-06-15 07:51:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-MySQLClient-oqjz4m2fe4wg','9228bf1f-e852-4462-9269-a745bf25c77a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1806,'f1642a6e-3103-4101-a448-d2c12ebe01b1','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:51:56',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-RoleParametersValue-5fiofptlrd63','state changed','OS::Heat::Value',NULL,1116),(1807,'5629c06b-55ec-4d3b-b5d4-816fa54467b0','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-RoleParametersValue-5fiofptlrd63','state changed','OS::Heat::Value',NULL,1116),(1808,'f41070bc-23b6-4997-9fa7-bc47696d1900','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:56',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ManilaBase-ofs3u5uqvhbt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1117),(1809,'79fc8548-550e-48cb-9e6e-58befd4fafbb','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','ManilaBase','bfa3698d-f582-4116-bbfd-a1cdd9a48488','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1112),(1810,'79618b2f-8a1d-4c14-a844-834d640435f7','1f36e572-97fb-4a57-a0dc-09d8f3e4c099','2026-06-15 07:51:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ManilaBase-ofs3u5uqvhbt','1f36e572-97fb-4a57-a0dc-09d8f3e4c099','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1811,'2a497dd6-9510-4dd5-b193-ae9863b6210f','1f36e572-97fb-4a57-a0dc-09d8f3e4c099','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ManilaBase-ofs3u5uqvhbt','1f36e572-97fb-4a57-a0dc-09d8f3e4c099','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1812,'a6c753df-6a41-40f7-a969-07bda3f8fc53','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','ManilaBase','1f36e572-97fb-4a57-a0dc-09d8f3e4c099','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1117),(1813,'e49566f7-0da1-432b-b084-bf82b1bd94b7','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','0','ddc81659-94de-44c4-b881-7a3c01d59bfd','state changed','OS::TripleO::Compute',NULL,974),(1814,'2c6c057c-9939-43e6-9349-f10c59a23c0f','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','HeatBase','d5f6b8df-27b1-44a1-866f-579f3fde3a9b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1114),(1815,'e05236ce-8b8e-495c-a7b0-24fbe526cb17','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-ContainersCommon-a6u22j6u4cdx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1816,'031e30c1-bbca-43b3-9744-bfbbeb9c039f','139a0855-1993-4453-8c33-eba60023b4d1','2026-06-15 07:51:56',NULL,'UPDATE','COMPLETE','overcloud-Compute-jgegfs3bargx','139a0855-1993-4453-8c33-eba60023b4d1','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(1817,'81024fbe-f52f-4c13-9db8-6aff3680f125','1cf03de2-c9d7-47af-bac5-c6a223fcb833','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-16-j227ucvdv3af','1cf03de2-c9d7-47af-bac5-c6a223fcb833','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1818,'3656d4f4-576a-40b6-8650-ebc385e3c136','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:51:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ContainersCommon-cwm5z32oon52','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1819,'ce6457ef-606c-40e4-93e5-c79a30f7b6a2','82d19b2b-3797-4261-a80a-a9f2f1f29435','2026-06-15 07:51:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-ContainersCommon-a6u22j6u4cdx','82d19b2b-3797-4261-a80a-a9f2f1f29435','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1820,'0a191a23-04cb-4c4d-830c-be72c0b0b963','82d19b2b-3797-4261-a80a-a9f2f1f29435','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml-ContainersCommon-a6u22j6u4cdx','82d19b2b-3797-4261-a80a-a9f2f1f29435','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1821,'5646382a-cbff-4b6b-a06b-d32def27011a','71cf2dc0-1843-4cb5-9505-aae2f76cc18d','2026-06-15 07:51:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ContainersCommon-cwm5z32oon52','71cf2dc0-1843-4cb5-9505-aae2f76cc18d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1822,'660ae347-84ad-4a24-9548-9b664da31f23','71cf2dc0-1843-4cb5-9505-aae2f76cc18d','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ContainersCommon-cwm5z32oon52','71cf2dc0-1843-4cb5-9505-aae2f76cc18d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1823,'00493a04-1543-413b-91b8-ca36c681cf0a','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:51:56',NULL,'CREATE','COMPLETE','MySQLClient','9228bf1f-e852-4462-9269-a745bf25c77a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1824,'1c7783cb-4741-42e9-836c-d4140b29d5c5','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:51:57',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-MySQLClient-f2pdc5fcc5im','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1825,'2df778bd-5206-449d-b255-1dc2d811b44f','4eafebe2-5bfc-434a-b9e9-755a14cd40dc','2026-06-15 07:51:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-MySQLClient-f2pdc5fcc5im','4eafebe2-5bfc-434a-b9e9-755a14cd40dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1826,'c979823d-c392-43c3-8dc1-37d551e32807','4eafebe2-5bfc-434a-b9e9-755a14cd40dc','2026-06-15 07:51:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-MySQLClient-f2pdc5fcc5im','4eafebe2-5bfc-434a-b9e9-755a14cd40dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1827,'f6676e8f-47c4-4c11-a4c1-72b9ed24442f','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:57',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ApacheServiceBase-3snpqdpc26aa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1118),(1828,'7aede6d5-4736-4be5-9f4c-6517e68aa5cc','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:57',NULL,'CREATE','COMPLETE','16','1cf03de2-c9d7-47af-bac5-c6a223fcb833','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1033),(1829,'52a955e0-2f8b-4974-9876-697dcc47f33d','c0d6e21a-7218-41bf-a929-8ce0d99a35b1','2026-06-15 07:51:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ApacheServiceBase-3snpqdpc26aa','c0d6e21a-7218-41bf-a929-8ce0d99a35b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1830,'4641132a-1c7a-46cc-8862-7e384ef81c2a','c0d6e21a-7218-41bf-a929-8ce0d99a35b1','2026-06-15 07:51:57',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ApacheServiceBase-3snpqdpc26aa-ApacheNetworks-rkzbvtjar7rd','state changed','OS::Heat::Value',NULL,1119),(1831,'2981bc4c-db86-4258-9574-79804f869860','c0d6e21a-7218-41bf-a929-8ce0d99a35b1','2026-06-15 07:51:57',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ApacheServiceBase-3snpqdpc26aa-ApacheNetworks-rkzbvtjar7rd','state changed','OS::Heat::Value',NULL,1119),(1832,'5a805b86-e3bb-4c11-8655-abedb6c9caee','c0d6e21a-7218-41bf-a929-8ce0d99a35b1','2026-06-15 07:51:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ApacheServiceBase-3snpqdpc26aa','c0d6e21a-7218-41bf-a929-8ce0d99a35b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1833,'6e06a5e1-f99c-4d1b-8c8a-0009f63fa0c2','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:57',NULL,'CREATE','COMPLETE','Compute','139a0855-1993-4453-8c33-eba60023b4d1','state changed','OS::Heat::ResourceGroup',NULL,952),(1834,'564e4307-d64a-4d9b-a40f-a7f848729027','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:51:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-RoleParametersValue-mhvpdmqnp5ih','state changed','OS::Heat::Value',NULL,1129),(1835,'7bee0618-b2ef-4736-a3be-036aaafc877f','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:51:57',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-RoleParametersValue-mhvpdmqnp5ih','state changed','OS::Heat::Value',NULL,1129),(1836,'06284056-a078-4fa6-9ea5-771f07275e33','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:57',NULL,'CREATE','IN_PROGRESS','20','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-20-qdcovqjpdinj','state changed','OS::TripleO::Services::Iscsid',NULL,1131),(1837,'69b2a8a2-d5cb-47a6-97f3-725c84ad2d04','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:57',NULL,'CREATE','COMPLETE','ContainersCommon','82d19b2b-3797-4261-a80a-a9f2f1f29435','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1838,'61ed8a63-4c04-466c-aec1-e5e7c9a93ff5','78aa30f5-2ece-4690-b03c-bf4c34137ea6','2026-06-15 07:51:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-20-qdcovqjpdinj','78aa30f5-2ece-4690-b03c-bf4c34137ea6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1839,'5f7af352-6253-4b01-aacc-90e7331aae0c','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:51:57',NULL,'CREATE','COMPLETE','ContainersCommon','71cf2dc0-1843-4cb5-9505-aae2f76cc18d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1840,'754c1618-ef71-48fb-975a-12f8b041207f','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','2026-06-15 07:51:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-17-drufeo54zjml','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1841,'9f5b97bc-e5c2-4cf0-9ae6-5a587da88c8d','78aa30f5-2ece-4690-b03c-bf4c34137ea6','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-20-qdcovqjpdinj-RoleParametersValue-d3762c5uqacd','state changed','OS::Heat::Value',NULL,1135),(1842,'1d1569b7-754e-4d9d-990a-0235de8f290b','78aa30f5-2ece-4690-b03c-bf4c34137ea6','2026-06-15 07:51:58',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-20-qdcovqjpdinj-RoleParametersValue-d3762c5uqacd','state changed','OS::Heat::Value',NULL,1135),(1843,'6d459673-d2e7-4131-96e2-44e733259b5b','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','ManilaShareCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ManilaShareCommon-z3hnitanfqla','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1844,'684d3a66-fbd7-4905-8899-eecf38ed272f','fa257b4f-0f3d-4dc7-ae80-d1ef4b962dff','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ManilaShareCommon-z3hnitanfqla','fa257b4f-0f3d-4dc7-ae80-d1ef4b962dff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1845,'41f9eff3-527d-4dc8-9352-b3c264ea0c0e','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ContainersCommon-6wddznjqlhjf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1846,'fc1ed036-f9f7-498c-9dd6-e3d586d1a065','fa257b4f-0f3d-4dc7-ae80-d1ef4b962dff','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ManilaShareCommon-z3hnitanfqla-ContainersCommon-4vc63ymkhyog','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1847,'fc6f14ff-75a5-45be-82be-6deabd870880','72ec963a-a685-447a-8126-bbad55ee5d8d','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ContainersCommon-6wddznjqlhjf','72ec963a-a685-447a-8126-bbad55ee5d8d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1848,'70ec0326-4c9c-487f-8d83-55c0ba148c38','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:51:58',NULL,'CREATE','COMPLETE','MySQLClient','4eafebe2-5bfc-434a-b9e9-755a14cd40dc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1849,'032dae72-59cd-42fc-8d7b-0db37dfa8eb4','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','ComputeServers','overcloud-ComputeServers-vdclz3woyvxw','state changed','OS::Heat::Value',NULL,1145),(1850,'439650d5-341c-4016-9478-4aaf734687ad','72ec963a-a685-447a-8126-bbad55ee5d8d','2026-06-15 07:51:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy-ContainersCommon-6wddznjqlhjf','72ec963a-a685-447a-8126-bbad55ee5d8d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1851,'63f91fb0-b0de-4bc4-8950-7b6521430e4c','acfee127-383f-4be8-89bd-c8798325ecb8','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ManilaShareCommon-z3hnitanfqla-ContainersCommon-4vc63ymkhyog','acfee127-383f-4be8-89bd-c8798325ecb8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1852,'c07bbfa3-e492-48d2-9da9-6fb81258f9bf','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:58',NULL,'CREATE','COMPLETE','ApacheServiceBase','c0d6e21a-7218-41bf-a929-8ce0d99a35b1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1118),(1853,'25eac623-7ce8-47d6-9d19-efecc537e2d9','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:58',NULL,'CREATE','COMPLETE','ComputeServers','overcloud-ComputeServers-vdclz3woyvxw','state changed','OS::Heat::Value',NULL,1145),(1854,'6ef3b68f-34e1-4142-9973-d0a33179a4dc','acfee127-383f-4be8-89bd-c8798325ecb8','2026-06-15 07:51:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ManilaShareCommon-z3hnitanfqla-ContainersCommon-4vc63ymkhyog','acfee127-383f-4be8-89bd-c8798325ecb8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1855,'bfa0a554-b794-4799-a9e0-a6a2ca641d9c','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-pk64dymr25cg','state changed','OS::Heat::Value',NULL,1148),(1856,'2034e8ef-5643-40db-9f92-f45aee482b9a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:58',NULL,'CREATE','COMPLETE','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-pk64dymr25cg','state changed','OS::Heat::Value',NULL,1148),(1857,'d0433a54-a4c7-4428-b557-9cee84e88dd7','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:58',NULL,'CREATE','COMPLETE','17','b9ed188b-2155-4b79-bf90-3cc9efdbf93e','state changed','OS::TripleO::Services::HeatEngine',NULL,1071),(1858,'80df8181-6fbd-4226-8ab7-15ca339a65bc','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','ComputeIpListMap','overcloud-ComputeIpListMap-ttgffbzr7vym','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1150),(1859,'8a9636bf-5be4-4ccf-869d-a05ad90192c5','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','ManilaCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaCommon-ayipe63o2fks','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1860,'7e61d8a9-f1d3-4148-a9d0-f0b8cdf7668e','bd1ef20a-0ab2-4945-9d56-662b15bcbf0b','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeIpListMap-ttgffbzr7vym','bd1ef20a-0ab2-4945-9d56-662b15bcbf0b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1861,'d33e73b8-e829-45e2-9184-7ef374912630','cf1b5aa1-99a2-49b2-91df-ed6683eba860','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaCommon-ayipe63o2fks','cf1b5aa1-99a2-49b2-91df-ed6683eba860','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1862,'5c90e27b-7ef1-4b24-9f97-49e6ab6dca58','bd1ef20a-0ab2-4945-9d56-662b15bcbf0b','2026-06-15 07:51:58',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeIpListMap-ttgffbzr7vym-NetIpMapValue-2pzgiq7udhz6','state changed','OS::Heat::Value',NULL,1157),(1863,'f5f69d66-f0a1-4cee-89f1-1cd46382afea','bd1ef20a-0ab2-4945-9d56-662b15bcbf0b','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeIpListMap-ttgffbzr7vym-NetIpMapValue-2pzgiq7udhz6','state changed','OS::Heat::Value',NULL,1157),(1864,'8ca54dd1-552f-4128-993a-acac53c2d203','78aa30f5-2ece-4690-b03c-bf4c34137ea6','2026-06-15 07:51:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-20-qdcovqjpdinj-ContainersCommon-6unb54f3tm55','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1865,'34c8613d-2826-4526-bded-703cdd6a031d','18cdcad5-4fdf-4cbf-a14c-6d12a725289a','2026-06-15 07:51:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-20-qdcovqjpdinj-ContainersCommon-6unb54f3tm55','18cdcad5-4fdf-4cbf-a14c-6d12a725289a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1866,'d89958b6-a031-4b84-8983-b6912a0e268b','18cdcad5-4fdf-4cbf-a14c-6d12a725289a','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-20-qdcovqjpdinj-ContainersCommon-6unb54f3tm55','18cdcad5-4fdf-4cbf-a14c-6d12a725289a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1867,'6a06c12f-db0d-45f7-873f-1e8989844629','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:51:59',NULL,'CREATE','IN_PROGRESS','21','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-21-uttkcujfgpiy','state changed','OS::TripleO::Services::Kernel',NULL,1159),(1868,'4502d124-69e9-4800-95c2-163c04d85ff2','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:51:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ContainersCommon-3k364pi36slr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1869,'2192ff7b-f7ba-4423-85df-85f90d87d4c5','cf1b5aa1-99a2-49b2-91df-ed6683eba860','2026-06-15 07:51:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaCommon-ayipe63o2fks-ContainersCommon-myf7sspmyuvt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1870,'7d226ee2-0f56-47d3-ab7f-f846c5527248','64b7d767-464a-44a4-b9ab-af89fc3ffa0c','2026-06-15 07:51:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ContainersCommon-3k364pi36slr','64b7d767-464a-44a4-b9ab-af89fc3ffa0c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1871,'34ecc56c-009e-4522-b220-c488a6d52e34','58f671a1-86ed-4deb-9c3c-4591dda46736','2026-06-15 07:51:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-21-uttkcujfgpiy','58f671a1-86ed-4deb-9c3c-4591dda46736','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1872,'d54ae057-a99d-4bf3-be28-8a277176ac23','64b7d767-464a-44a4-b9ab-af89fc3ffa0c','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ContainersCommon-3k364pi36slr','64b7d767-464a-44a4-b9ab-af89fc3ffa0c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1873,'88620bb5-7a6c-4fda-8c08-ebd412da272f','7392d046-ee41-4527-a604-16cdd087735f','2026-06-15 07:51:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaCommon-ayipe63o2fks-ContainersCommon-myf7sspmyuvt','7392d046-ee41-4527-a604-16cdd087735f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1874,'133d0dbf-a9f6-4ff5-9443-a024f526d294','7392d046-ee41-4527-a604-16cdd087735f','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaCommon-ayipe63o2fks-ContainersCommon-myf7sspmyuvt','7392d046-ee41-4527-a604-16cdd087735f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1875,'4132b940-edf9-4ad0-ba0b-20796771446d','58f671a1-86ed-4deb-9c3c-4591dda46736','2026-06-15 07:51:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-21-uttkcujfgpiy-RoleParametersValue-wkik7jcloqnz','state changed','OS::Heat::Value',NULL,1160),(1876,'9c4c173e-b536-4343-8a53-a6c19e6336d5','58f671a1-86ed-4deb-9c3c-4591dda46736','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-21-uttkcujfgpiy-RoleParametersValue-wkik7jcloqnz','state changed','OS::Heat::Value',NULL,1160),(1877,'e5a47444-287a-4270-9504-d30a9f45b541','58f671a1-86ed-4deb-9c3c-4591dda46736','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-21-uttkcujfgpiy','58f671a1-86ed-4deb-9c3c-4591dda46736','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1878,'41ee2373-b0d6-4c8d-a822-4c704233a315','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','ContainersCommon','72ec963a-a685-447a-8126-bbad55ee5d8d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1879,'c3d985fa-3433-4884-91b9-af61e295f0ad','7a052d79-58a2-4d45-97d6-6b10e017f129','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-23-rtkhcm452miy','7a052d79-58a2-4d45-97d6-6b10e017f129','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1880,'19ce34f2-5acd-43fd-ac6b-3d061d468a44','fa257b4f-0f3d-4dc7-ae80-d1ef4b962dff','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','ContainersCommon','acfee127-383f-4be8-89bd-c8798325ecb8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1881,'61975138-98cb-47a8-8492-d9128e6c9b8b','fa257b4f-0f3d-4dc7-ae80-d1ef4b962dff','2026-06-15 07:51:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu-ManilaShareCommon-z3hnitanfqla','fa257b4f-0f3d-4dc7-ae80-d1ef4b962dff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1882,'a51d3a92-195f-464f-8832-765ed2dfb20c','bd1ef20a-0ab2-4945-9d56-662b15bcbf0b','2026-06-15 07:52:00',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ComputeIpListMap-ttgffbzr7vym-EnabledServicesValue-cuscfwzvgqh5','state changed','OS::Heat::Value',NULL,1161),(1883,'d490169a-a82f-4542-8e4e-abe5e3e61bff','bd1ef20a-0ab2-4945-9d56-662b15bcbf0b','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ComputeIpListMap-ttgffbzr7vym-EnabledServicesValue-cuscfwzvgqh5','state changed','OS::Heat::Value',NULL,1161),(1884,'aa18d69d-41e8-4be9-8517-f1e4db7e74dc','bd1ef20a-0ab2-4945-9d56-662b15bcbf0b','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','overcloud-ComputeIpListMap-ttgffbzr7vym','bd1ef20a-0ab2-4945-9d56-662b15bcbf0b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1885,'87b8b1b5-022b-4dd8-8465-0436d94a58cd','78aa30f5-2ece-4690-b03c-bf4c34137ea6','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','ContainersCommon','18cdcad5-4fdf-4cbf-a14c-6d12a725289a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1886,'7f488c5c-7f09-426a-bacf-f335fcca5ea4','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','23','7a052d79-58a2-4d45-97d6-6b10e017f129','state changed','OS::TripleO::Services::ManilaApi',NULL,1090),(1887,'54819eec-b897-4527-9b49-af7af1a3f01a','78aa30f5-2ece-4690-b03c-bf4c34137ea6','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-20-qdcovqjpdinj','78aa30f5-2ece-4690-b03c-bf4c34137ea6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1888,'5b3b030f-c58e-4dc2-ad6d-604432ab72b7','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','ManilaShareCommon','fa257b4f-0f3d-4dc7-ae80-d1ef4b962dff','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1889,'75c2348b-f798-4aaf-aeb9-93985d8f2fda','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','21','58f671a1-86ed-4deb-9c3c-4591dda46736','state changed','OS::TripleO::Services::Kernel',NULL,1159),(1890,'1e3fa60b-6077-466f-a219-101f27aa16a9','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','ContainersCommon','64b7d767-464a-44a4-b9ab-af89fc3ffa0c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1891,'117bca99-9be0-45c2-ab07-d8ea767be1f1','cf1b5aa1-99a2-49b2-91df-ed6683eba860','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','ContainersCommon','7392d046-ee41-4527-a604-16cdd087735f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1892,'460b446b-0eb0-47de-b807-ba8949a6f966','cf1b5aa1-99a2-49b2-91df-ed6683eba860','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaCommon-ayipe63o2fks','cf1b5aa1-99a2-49b2-91df-ed6683eba860','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1893,'a842d6c9-3f6c-4f84-99fc-b149ea06daa0','13d18384-be40-4113-974d-3d1e8a069bdf','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj-ManilaShareContainerBase-6plcrcgggpfu','13d18384-be40-4113-974d-3d1e8a069bdf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1894,'ded28e22-8002-4715-bc17-19df95613136','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:00',NULL,'CREATE','IN_PROGRESS','25','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1168),(1895,'ec38467c-6835-473a-a60b-1245ff091de3','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6','d7434bc3-49b2-4b79-bce9-e0041172d64f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1896,'571c4cf9-7061-40e4-a0a2-ed4f838e0cf4','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-RoleParametersValue-7aol35pf4oex','state changed','OS::Heat::Value',NULL,1172),(1897,'5f51c8fa-bdf3-494e-8430-74201b9fe1b2','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-RoleParametersValue-7aol35pf4oex','state changed','OS::Heat::Value',NULL,1172),(1898,'cdcc19c6-7343-4b22-92ac-baa0eaacd9c7','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:00',NULL,'CREATE','IN_PROGRESS','27','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-27-to6qwcl3olfw','state changed','OS::TripleO::Services::Memcached',NULL,1173),(1899,'f864e09b-2730-4f80-b1ce-2b003d01a3d7','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:00',NULL,'CREATE','COMPLETE','ComputeIpListMap','bd1ef20a-0ab2-4945-9d56-662b15bcbf0b','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1150),(1900,'21bce740-de02-42d0-a154-b8870bdbf89e','99202e72-b97c-4d44-8061-76735786355e','2026-06-15 07:52:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-27-to6qwcl3olfw','99202e72-b97c-4d44-8061-76735786355e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1901,'57705a59-89c9-4d9d-be28-cbe36be00d7b','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:52:01',NULL,'CREATE','COMPLETE','ManilaCommon','cf1b5aa1-99a2-49b2-91df-ed6683eba860','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1902,'01f96e5d-b74b-4a2f-b3a6-6e1ed6c5e25c','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:01',NULL,'CREATE','COMPLETE','20','78aa30f5-2ece-4690-b03c-bf4c34137ea6','state changed','OS::TripleO::Services::Iscsid',NULL,1131),(1903,'b3dfd065-2c86-47b7-b52b-19e239e4edb9','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:52:01',NULL,'CREATE','COMPLETE','ManilaShareContainerBase','13d18384-be40-4113-974d-3d1e8a069bdf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1110),(1904,'acd99fc0-8288-413b-beec-5d6021e519c1','37a5128e-08ed-40c2-b263-95b36d620ae9','2026-06-15 07:52:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-26-4hzcf3ezhznj','37a5128e-08ed-40c2-b263-95b36d620ae9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1905,'eeb50a56-7ff0-44ab-82d0-a5cc37438040','99202e72-b97c-4d44-8061-76735786355e','2026-06-15 07:52:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-27-to6qwcl3olfw-ContainersCommon-ixsh7ao3xets','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1906,'e74c5175-a3dc-4dc0-8e4a-4fa83b5a4d13','7261edab-d551-4b66-bde4-ce89c208dffb','2026-06-15 07:52:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-27-to6qwcl3olfw-ContainersCommon-ixsh7ao3xets','7261edab-d551-4b66-bde4-ce89c208dffb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1907,'bceb9fac-7ff2-4aad-9d84-9b08d550921c','7261edab-d551-4b66-bde4-ce89c208dffb','2026-06-15 07:52:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-27-to6qwcl3olfw-ContainersCommon-ixsh7ao3xets','7261edab-d551-4b66-bde4-ce89c208dffb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1908,'839cb33a-e6b3-4ad7-b356-24205397a2b0','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:01',NULL,'CREATE','IN_PROGRESS','24','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-24-gei744vzulld','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1177),(1909,'a5b8dc52-900c-49eb-a1c8-8827c845228e','967da480-11fa-4852-a59a-94ba7a8aeeeb','2026-06-15 07:52:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-24-gei744vzulld','967da480-11fa-4852-a59a-94ba7a8aeeeb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1910,'a8ef8e1f-6602-4b6e-a44a-971edc65c241','967da480-11fa-4852-a59a-94ba7a8aeeeb','2026-06-15 07:52:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-24-gei744vzulld','967da480-11fa-4852-a59a-94ba7a8aeeeb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1911,'0ac277de-5872-491d-9f29-f40fd7b45cb9','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:01',NULL,'CREATE','COMPLETE','26','37a5128e-08ed-40c2-b263-95b36d620ae9','state changed','OS::TripleO::Services::ManilaShare',NULL,1099),(1912,'378d388e-3d30-4f04-b143-a6b252a10871','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:01',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-ManilaBase-sogw6h7ciey7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1178),(1913,'4f6ec334-510d-420d-a737-b88de47e828d','1f4a0652-0c5c-41cd-9196-2c6011caa3e7','2026-06-15 07:52:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-ManilaBase-sogw6h7ciey7','1f4a0652-0c5c-41cd-9196-2c6011caa3e7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1914,'dfee97a1-72a3-4d17-b341-4ead3f655e49','1f4a0652-0c5c-41cd-9196-2c6011caa3e7','2026-06-15 07:52:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-ManilaBase-sogw6h7ciey7','1f4a0652-0c5c-41cd-9196-2c6011caa3e7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1915,'38011280-e462-44c0-809e-1c9e4d2368bc','99202e72-b97c-4d44-8061-76735786355e','2026-06-15 07:52:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-27-to6qwcl3olfw-RoleParametersValue-iu7xh4zhiexf','state changed','OS::Heat::Value',NULL,1182),(1916,'21ce25a5-ac8a-4f42-a904-5bc31c4842f5','99202e72-b97c-4d44-8061-76735786355e','2026-06-15 07:52:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-27-to6qwcl3olfw-RoleParametersValue-iu7xh4zhiexf','state changed','OS::Heat::Value',NULL,1182),(1917,'b9571c09-d777-443c-b089-d577ca48cdac','99202e72-b97c-4d44-8061-76735786355e','2026-06-15 07:52:02',NULL,'CREATE','COMPLETE','ContainersCommon','7261edab-d551-4b66-bde4-ce89c208dffb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1918,'1c5e421d-2125-4ae3-a604-ff130114df48','99202e72-b97c-4d44-8061-76735786355e','2026-06-15 07:52:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-27-to6qwcl3olfw','99202e72-b97c-4d44-8061-76735786355e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1919,'8678ecb6-9c07-4031-90c0-ccc9338525de','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:02',NULL,'CREATE','IN_PROGRESS','30','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-30-go43qvx5fpnp','state changed','OS::TripleO::Services::MySQLClient',NULL,1193),(1920,'40fea49a-9472-40b7-9b9f-aa521b7288da','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:02',NULL,'CREATE','COMPLETE','24','967da480-11fa-4852-a59a-94ba7a8aeeeb','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1177),(1921,'d49d7bee-e55f-4cf2-8318-45ab6a7c3890','5fe7f539-b359-4ba7-9bc5-fae222f163c0','2026-06-15 07:52:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-30-go43qvx5fpnp','5fe7f539-b359-4ba7-9bc5-fae222f163c0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1922,'3c100088-ff5f-4e73-b1d1-abb23d16a9ab','5fe7f539-b359-4ba7-9bc5-fae222f163c0','2026-06-15 07:52:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-30-go43qvx5fpnp','5fe7f539-b359-4ba7-9bc5-fae222f163c0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1923,'85d2eb24-c963-40ad-8923-54e7b9f6d33a','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:02',NULL,'CREATE','IN_PROGRESS','28','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-28-dr6y7xlf5ghg','state changed','OS::TripleO::Services::MetricsQdr',NULL,1195),(1924,'74f9b1b6-e9cd-498f-b87d-d6059dfb4801','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:02',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-ContainersCommon-ecck5j6mnu73','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1925,'3d239455-e627-4190-908a-d50cc0f406dc','5c8fe793-62af-4832-98ab-cc722eabea14','2026-06-15 07:52:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-28-dr6y7xlf5ghg','5c8fe793-62af-4832-98ab-cc722eabea14','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1926,'b7ff7d27-1f7b-4791-b7db-a63d100118a9','776f61f5-7c4b-4b05-992e-eaaccced7798','2026-06-15 07:52:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-ContainersCommon-ecck5j6mnu73','776f61f5-7c4b-4b05-992e-eaaccced7798','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1927,'043570fd-41aa-49c1-92b3-5900fc3692b3','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:03',NULL,'CREATE','COMPLETE','27','99202e72-b97c-4d44-8061-76735786355e','state changed','OS::TripleO::Services::Memcached',NULL,1173),(1928,'28a193d7-78a4-4dd9-8531-2068b880b519','776f61f5-7c4b-4b05-992e-eaaccced7798','2026-06-15 07:52:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-ContainersCommon-ecck5j6mnu73','776f61f5-7c4b-4b05-992e-eaaccced7798','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1929,'d5ad2f52-e885-4724-b4bc-2029f930afde','5c8fe793-62af-4832-98ab-cc722eabea14','2026-06-15 07:52:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-28-dr6y7xlf5ghg-RoleParametersValue-7yxqgsxsq7bc','state changed','OS::Heat::Value',NULL,1196),(1930,'4c09ca4e-51b3-4f44-87f3-b8828cf1b1bb','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:03',NULL,'CREATE','COMPLETE','ManilaBase','1f4a0652-0c5c-41cd-9196-2c6011caa3e7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1178),(1931,'d0a6b5e4-ef43-4146-9d50-c7d8e2bd6f00','5c8fe793-62af-4832-98ab-cc722eabea14','2026-06-15 07:52:03',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-28-dr6y7xlf5ghg-RoleParametersValue-7yxqgsxsq7bc','state changed','OS::Heat::Value',NULL,1196),(1932,'e74f8e2e-2b51-4c8f-88d9-6817f68fcc13','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:03',NULL,'CREATE','IN_PROGRESS','31','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc','state changed','OS::TripleO::Services::NeutronApi',NULL,1200),(1933,'44fd7ea4-b6a3-4dfb-996b-70e1df9f5d26','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc','ca6c7986-aed4-44a4-b57b-560ca277e644','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1934,'76172eae-d180-4760-95b9-745a7088e83b','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:03',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-NeutronLogging-gpa73lkz3lgo','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1201),(1935,'12a8b484-cbfa-4fcb-a8f7-cb1b45cebc4c','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:03',NULL,'CREATE','COMPLETE','30','5fe7f539-b359-4ba7-9bc5-fae222f163c0','state changed','OS::TripleO::Services::MySQLClient',NULL,1193),(1936,'c20efc48-429e-4967-82fe-fb3b057b7dc2','b53aa016-5f79-436f-b637-baa3da8e4126','2026-06-15 07:52:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-NeutronLogging-gpa73lkz3lgo','b53aa016-5f79-436f-b637-baa3da8e4126','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1937,'458cc881-8d6b-4f65-a15f-ded4c6249fad','b53aa016-5f79-436f-b637-baa3da8e4126','2026-06-15 07:52:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-NeutronLogging-gpa73lkz3lgo-RoleParametersValue-thuz3ufhzxj7','state changed','OS::Heat::Value',NULL,1203),(1938,'034d4c27-7508-4304-a6d9-19241aca7742','b53aa016-5f79-436f-b637-baa3da8e4126','2026-06-15 07:52:03',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-NeutronLogging-gpa73lkz3lgo-RoleParametersValue-thuz3ufhzxj7','state changed','OS::Heat::Value',NULL,1203),(1939,'1e3f4d2b-4ce4-4cf5-b3c0-939f270d8f5a','b53aa016-5f79-436f-b637-baa3da8e4126','2026-06-15 07:52:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-NeutronLogging-gpa73lkz3lgo','b53aa016-5f79-436f-b637-baa3da8e4126','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1940,'761f0134-2d67-410f-aeaf-9c24227537ea','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:03',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-MySQLClient-hwfkg4uxkciv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1941,'80a3aeda-89e0-404c-ba7b-428a9343524e','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','34','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb','state changed','OS::TripleO::Services::NovaConductor',NULL,1204),(1942,'426b01a1-f9e3-475a-bea8-fd3afa7710f8','175e3a0b-380e-481e-8ae7-0f32f3d97b63','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-MySQLClient-hwfkg4uxkciv','175e3a0b-380e-481e-8ae7-0f32f3d97b63','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1943,'8f4255d0-9fb1-4bae-abd8-f29145a563a8','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:04',NULL,'CREATE','COMPLETE','ContainersCommon','776f61f5-7c4b-4b05-992e-eaaccced7798','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1944,'63caf94e-40ae-48ff-b01e-46a3edb7d653','175e3a0b-380e-481e-8ae7-0f32f3d97b63','2026-06-15 07:52:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6-MySQLClient-hwfkg4uxkciv','175e3a0b-380e-481e-8ae7-0f32f3d97b63','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1945,'7dd895ce-205c-4f72-91f4-6e446e3fda32','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb','0d4e89b4-3d64-445f-b469-edd22c1af7fc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1946,'1cdc1f7b-85f6-413f-ad06-c22a846d2c68','5c8fe793-62af-4832-98ab-cc722eabea14','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-28-dr6y7xlf5ghg-ContainersCommon-25y2325pkkny','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1947,'681f50ba-0670-4523-b24e-6b1a3b3eedd3','ca2b2c87-13f1-4313-a28b-3b3d5239ad14','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-28-dr6y7xlf5ghg-ContainersCommon-25y2325pkkny','ca2b2c87-13f1-4313-a28b-3b3d5239ad14','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1948,'b354dde1-1fff-46fa-8efb-71265ae48f8e','ca2b2c87-13f1-4313-a28b-3b3d5239ad14','2026-06-15 07:52:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-28-dr6y7xlf5ghg-ContainersCommon-25y2325pkkny','ca2b2c87-13f1-4313-a28b-3b3d5239ad14','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1949,'436279ea-7e77-4b1a-a9e1-3d3aacb44043','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-RoleParametersValue-kvv6l6dyhqls','state changed','OS::Heat::Value',NULL,1205),(1950,'9e8a8894-eb07-4b12-8408-5c501cc73095','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:04',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-RoleParametersValue-kvv6l6dyhqls','state changed','OS::Heat::Value',NULL,1205),(1951,'e1de6623-119b-4f0b-9c52-efb58f383cd1','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaLogging-hqar3x5nfoqx','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1207),(1952,'ea38abda-79d8-4593-a2ef-50d2b4d73c9e','dfe0ac71-488c-4e6c-b569-d0dc893bc95b','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaLogging-hqar3x5nfoqx','dfe0ac71-488c-4e6c-b569-d0dc893bc95b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1953,'21a9de13-a73d-4660-90c6-df29c74f2279','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-RoleParametersValue-mckzsqmv56y7','state changed','OS::Heat::Value',NULL,1208),(1954,'730e4a11-9e1d-468a-80d7-7f39cb8c1b10','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:04',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-RoleParametersValue-mckzsqmv56y7','state changed','OS::Heat::Value',NULL,1208),(1955,'b8dec1e2-f440-4be5-84ab-31ccbd2e3fa0','dfe0ac71-488c-4e6c-b569-d0dc893bc95b','2026-06-15 07:52:04',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaLogging-hqar3x5nfoqx-InitLogContainerName-6sijxinmhwqr','state changed','OS::Heat::Value',NULL,1209),(1956,'bd30b1e1-e37f-4bf4-87a8-5f8637b086a4','dfe0ac71-488c-4e6c-b569-d0dc893bc95b','2026-06-15 07:52:04',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaLogging-hqar3x5nfoqx-InitLogContainerName-6sijxinmhwqr','state changed','OS::Heat::Value',NULL,1209),(1957,'1074f5d6-efef-46cc-89c6-1bfea1c34cb6','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:04',NULL,'CREATE','COMPLETE','NeutronLogging','b53aa016-5f79-436f-b637-baa3da8e4126','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1201),(1958,'d07cb823-4f44-4b86-9f07-8dbf986134bc','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','MySQLClient','175e3a0b-380e-481e-8ae7-0f32f3d97b63','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1959,'2200a4b7-1cc7-4231-81ba-ec5daf362ced','d7434bc3-49b2-4b79-bce9-e0041172d64f','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-25-mv5l6tho6my6','d7434bc3-49b2-4b79-bce9-e0041172d64f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1960,'749e294a-e632-4662-9859-a6c2e1f7fe64','5c8fe793-62af-4832-98ab-cc722eabea14','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','ContainersCommon','ca2b2c87-13f1-4313-a28b-3b3d5239ad14','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1961,'8b8f5f38-efdb-4ac8-83b7-9b54a116d41b','5c8fe793-62af-4832-98ab-cc722eabea14','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-28-dr6y7xlf5ghg','5c8fe793-62af-4832-98ab-cc722eabea14','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1962,'a1a3587f-9b09-4db5-b284-66d6fc27edaa','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-ContainersCommon-l6qsb4f3ym3j','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1963,'f57049b8-3cbc-4634-95df-afa44ce113f4','caf047bf-07eb-48e1-ad49-4977772d2b03','2026-06-15 07:52:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-ContainersCommon-l6qsb4f3ym3j','caf047bf-07eb-48e1-ad49-4977772d2b03','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1964,'89d7a7c0-0941-42a1-aafa-ac51a3dc3e3a','caf047bf-07eb-48e1-ad49-4977772d2b03','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-ContainersCommon-l6qsb4f3ym3j','caf047bf-07eb-48e1-ad49-4977772d2b03','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1965,'4933c05f-169f-4225-80e2-3b377a8e95f8','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-ContainersCommon-3u7tdz5oxudk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1966,'a48a000e-bf64-4ee8-ae07-ec60d88b99ca','dfe0ac71-488c-4e6c-b569-d0dc893bc95b','2026-06-15 07:52:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaLogging-hqar3x5nfoqx-RoleParametersValue-oaqmzuelsova','state changed','OS::Heat::Value',NULL,1210),(1967,'c12d41a5-2cd5-40aa-8f4c-b392adead055','dfe0ac71-488c-4e6c-b569-d0dc893bc95b','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaLogging-hqar3x5nfoqx-RoleParametersValue-oaqmzuelsova','state changed','OS::Heat::Value',NULL,1210),(1968,'a58e9cdd-4442-4b4b-ae9e-79d5fcd22344','dfe0ac71-488c-4e6c-b569-d0dc893bc95b','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaLogging-hqar3x5nfoqx','dfe0ac71-488c-4e6c-b569-d0dc893bc95b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1969,'b0caa39e-11ba-4316-abcf-68e65a6c2bcb','1dbeb828-b928-4efc-ba49-204f5e604c8c','2026-06-15 07:52:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-ContainersCommon-3u7tdz5oxudk','1dbeb828-b928-4efc-ba49-204f5e604c8c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1970,'1b930c90-04f8-4b2e-b156-fbb5f623ca98','1dbeb828-b928-4efc-ba49-204f5e604c8c','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-ContainersCommon-3u7tdz5oxudk','1dbeb828-b928-4efc-ba49-204f5e604c8c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1971,'17cbe85e-6d70-495f-93d1-fecac3dc4c56','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','25','d7434bc3-49b2-4b79-bce9-e0041172d64f','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1168),(1972,'cb8289c5-3f1f-4354-b266-79736ecabe43','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:05',NULL,'CREATE','COMPLETE','28','5c8fe793-62af-4832-98ab-cc722eabea14','state changed','OS::TripleO::Services::MetricsQdr',NULL,1195),(1973,'00d00b71-92e6-4585-b67e-e27a67df5fab','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaApiDBClient-lskn525mmyf7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1218),(1974,'19a430d2-630f-4033-b156-9d4233749866','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','32','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1219),(1975,'4ca5b407-a07a-4fab-8314-a69c2520e669','f4712b63-6c97-43bc-a131-a0b789e742b3','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaApiDBClient-lskn525mmyf7','f4712b63-6c97-43bc-a131-a0b789e742b3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1976,'f1fd3452-2a8f-4e64-a3c0-c19634986fe0','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:06',NULL,'CREATE','COMPLETE','ContainersCommon','caf047bf-07eb-48e1-ad49-4977772d2b03','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1977,'03b238e6-b7ae-413d-b279-55fe567812c4','f4712b63-6c97-43bc-a131-a0b789e742b3','2026-06-15 07:52:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaApiDBClient-lskn525mmyf7','f4712b63-6c97-43bc-a131-a0b789e742b3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1978,'1f12b3f8-e907-4b03-908a-cb9cc7c9a45a','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:06',NULL,'CREATE','COMPLETE','NovaLogging','dfe0ac71-488c-4e6c-b569-d0dc893bc95b','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1207),(1979,'1fb983fe-e70e-42c0-a992-b5f248169554','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','29','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj','state changed','OS::TripleO::Services::MySQL',NULL,1221),(1980,'d8f773d6-7c16-4430-b14c-599180bc7d45','9f862eda-0ee5-446a-8a27-1987ed5dd999','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio','9f862eda-0ee5-446a-8a27-1987ed5dd999','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1981,'bfe15f4c-0379-43f5-b226-9154bb2c4f0f','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-MySQLClient-hs6lnekrzubg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1982,'24591da5-6131-4fb1-90f5-d3c4ea435bd5','0a16db92-41a9-4318-ad08-e28032c3e194','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj','0a16db92-41a9-4318-ad08-e28032c3e194','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1983,'b20c006b-0c65-4146-ae5e-21358881d18d','9f862eda-0ee5-446a-8a27-1987ed5dd999','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-NeutronBase-4iz76wscgkdl','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1222),(1984,'c346b56b-3d12-49c4-abe3-98c0c1f3460e','aaca0089-d498-491b-b3c7-0207bd8be2f8','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-MySQLClient-hs6lnekrzubg','aaca0089-d498-491b-b3c7-0207bd8be2f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1985,'7e08e9c7-fa3f-48b5-8a7d-ad8de400ab4f','aaca0089-d498-491b-b3c7-0207bd8be2f8','2026-06-15 07:52:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-MySQLClient-hs6lnekrzubg','aaca0089-d498-491b-b3c7-0207bd8be2f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1986,'8b94621d-79bb-4944-8724-ac096bad4969','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:06',NULL,'CREATE','COMPLETE','ContainersCommon','1dbeb828-b928-4efc-ba49-204f5e604c8c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1987,'5ca145d7-a15d-4a5e-a16e-16d96dc4f4b4','80ca7555-a7a6-4de6-86e1-02a0895a7b67','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-NeutronBase-4iz76wscgkdl','80ca7555-a7a6-4de6-86e1-02a0895a7b67','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1988,'b1ea8052-aa02-4e58-84c8-f9c2c07f22dd','0a16db92-41a9-4318-ad08-e28032c3e194','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj-ContainersCommon-idb7jo5yfduw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1989,'0f1d861c-87f8-4b83-a3b7-99311b5857c7','5bf31d51-d1a5-47a3-89d3-641b75fe469f','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj-ContainersCommon-idb7jo5yfduw','5bf31d51-d1a5-47a3-89d3-641b75fe469f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1990,'77f70745-5671-40e6-9aae-8b7429583dd8','80ca7555-a7a6-4de6-86e1-02a0895a7b67','2026-06-15 07:52:06',NULL,'CREATE','IN_PROGRESS','NeutronMl2Base','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-NeutronBase-4iz76wscgkdl-NeutronMl2Base-6jxbyps2jwiq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1223),(1991,'71e93498-6c5c-4fd3-a375-31596f5e6e14','5bf31d51-d1a5-47a3-89d3-641b75fe469f','2026-06-15 07:52:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj-ContainersCommon-idb7jo5yfduw','5bf31d51-d1a5-47a3-89d3-641b75fe469f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1992,'3059a019-5e25-4cf5-9798-40fec8a64382','16edde4d-ba3d-471d-a62b-774ed2e7e6b1','2026-06-15 07:52:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-NeutronBase-4iz76wscgkdl-NeutronMl2Base-6jxbyps2jwiq','16edde4d-ba3d-471d-a62b-774ed2e7e6b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1993,'bdbb89da-d209-4646-bf99-9396fd90012e','16edde4d-ba3d-471d-a62b-774ed2e7e6b1','2026-06-15 07:52:07',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-NeutronBase-4iz76wscgkdl-NeutronMl2Base-6jxbyps2jwiq-NeutronBase-hhwzqyu7ooc5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1224),(1994,'8486247f-8d38-4202-bfeb-f0b73f0e1acf','e36bdf93-3214-4859-a141-bea83683123a','2026-06-15 07:52:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-NeutronBase-4iz76wscgkdl-NeutronMl2Base-6jxbyps2jwiq-NeutronBase-hhwzqyu7ooc5','e36bdf93-3214-4859-a141-bea83683123a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1995,'a5036b45-17ae-4dae-8904-ea2b4e456607','e36bdf93-3214-4859-a141-bea83683123a','2026-06-15 07:52:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-NeutronBase-4iz76wscgkdl-NeutronMl2Base-6jxbyps2jwiq-NeutronBase-hhwzqyu7ooc5','e36bdf93-3214-4859-a141-bea83683123a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1996,'206bd84e-fb0b-4dc7-a003-58ca1c091ffb','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:07',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaDBClient-b352qrpsrvyr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1225),(1997,'771f942e-12c7-4f34-8417-550a62e0a9ba','108dcc36-3afd-42c8-97cd-6a24975f87bc','2026-06-15 07:52:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaDBClient-b352qrpsrvyr','108dcc36-3afd-42c8-97cd-6a24975f87bc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1998,'8f62f71d-b7bd-4701-bc0f-91310ef18ceb','108dcc36-3afd-42c8-97cd-6a24975f87bc','2026-06-15 07:52:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaDBClient-b352qrpsrvyr','108dcc36-3afd-42c8-97cd-6a24975f87bc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1999,'c07cfb83-490a-4656-a983-7bb4e21860cd','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:07',NULL,'CREATE','COMPLETE','NovaApiDBClient','f4712b63-6c97-43bc-a131-a0b789e742b3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1218),(2000,'de331aa0-e5a1-41ea-8572-5a2ee7f2b517','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:07',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-NeutronBase-bkqgtuubk4kb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1226),(2001,'5b60c58e-ba37-4223-854c-2052a4f1bdf7','9f862eda-0ee5-446a-8a27-1987ed5dd999','2026-06-15 07:52:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-RoleParametersValue-gttewjfrgm5h','state changed','OS::Heat::Value',NULL,1227),(2002,'24567926-bd48-46fe-b550-e37c11136591','9f862eda-0ee5-446a-8a27-1987ed5dd999','2026-06-15 07:52:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-RoleParametersValue-gttewjfrgm5h','state changed','OS::Heat::Value',NULL,1227),(2003,'1260bfcd-f097-4a3e-97f7-6858dba929d9','9d48199c-a31d-4bd1-9086-3cb73790f12f','2026-06-15 07:52:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-NeutronBase-bkqgtuubk4kb','9d48199c-a31d-4bd1-9086-3cb73790f12f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2004,'b2d99a47-5a5d-45cb-ab3f-bd222879b00a','9d48199c-a31d-4bd1-9086-3cb73790f12f','2026-06-15 07:52:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-NeutronBase-bkqgtuubk4kb','9d48199c-a31d-4bd1-9086-3cb73790f12f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2005,'4dfcaac3-2905-4b53-9514-3244ca944cc5','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:07',NULL,'CREATE','COMPLETE','MySQLClient','aaca0089-d498-491b-b3c7-0207bd8be2f8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2006,'4a2cec2f-547f-47f6-b04e-d52db22a1abc','0a16db92-41a9-4318-ad08-e28032c3e194','2026-06-15 07:52:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj-RoleParametersValue-we2tcpqhrz5x','state changed','OS::Heat::Value',NULL,1228),(2007,'fa79c4a3-3bfa-4bc1-8025-246b7fb66976','0a16db92-41a9-4318-ad08-e28032c3e194','2026-06-15 07:52:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj-RoleParametersValue-we2tcpqhrz5x','state changed','OS::Heat::Value',NULL,1228),(2008,'67406789-ccab-41a4-a20d-8b76c5e6b162','0a16db92-41a9-4318-ad08-e28032c3e194','2026-06-15 07:52:07',NULL,'CREATE','COMPLETE','ContainersCommon','5bf31d51-d1a5-47a3-89d3-641b75fe469f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2009,'269b00ca-270a-4425-a9ad-b4cfd49a75e0','16edde4d-ba3d-471d-a62b-774ed2e7e6b1','2026-06-15 07:52:08',NULL,'CREATE','COMPLETE','NeutronBase','e36bdf93-3214-4859-a141-bea83683123a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1224),(2010,'e8e0473f-6684-4494-ba74-6bce0243abe7','16edde4d-ba3d-471d-a62b-774ed2e7e6b1','2026-06-15 07:52:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-NeutronBase-4iz76wscgkdl-NeutronMl2Base-6jxbyps2jwiq','16edde4d-ba3d-471d-a62b-774ed2e7e6b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2011,'633c2c76-d2e9-476e-9e3f-b84be69bd0ef','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:08',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-MySQLClient-nsgtuxmdryq6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2012,'caabc7dc-87f9-444c-80b9-7c731138676c','5518f68f-7d6f-4919-86a2-c21b33cd0ba4','2026-06-15 07:52:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-MySQLClient-nsgtuxmdryq6','5518f68f-7d6f-4919-86a2-c21b33cd0ba4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2013,'762a9868-5276-4ef1-ad35-dcfc4fb4bd5a','5518f68f-7d6f-4919-86a2-c21b33cd0ba4','2026-06-15 07:52:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-MySQLClient-nsgtuxmdryq6','5518f68f-7d6f-4919-86a2-c21b33cd0ba4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2014,'3d22b7ca-6ff5-4548-af0b-189dafc0a371','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:08',NULL,'CREATE','COMPLETE','NovaDBClient','108dcc36-3afd-42c8-97cd-6a24975f87bc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1225),(2015,'8d29126e-117e-4e2c-b2d0-f9fff09d7e47','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:08',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-TLSProxyBase-uur3eoowcsza','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1229),(2016,'79a0ed98-577c-4d17-aab9-8a7189a9ef55','9e7be1f3-80ee-450e-b2d0-fa740f08d161','2026-06-15 07:52:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-TLSProxyBase-uur3eoowcsza','9e7be1f3-80ee-450e-b2d0-fa740f08d161','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2017,'4b67fa69-7449-4e7d-a5a0-4656836cc40a','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:08',NULL,'CREATE','COMPLETE','NeutronBase','9d48199c-a31d-4bd1-9086-3cb73790f12f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1226),(2018,'48a07923-b127-4e33-9829-f433b86e7027','0a16db92-41a9-4318-ad08-e28032c3e194','2026-06-15 07:52:08',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj-MysqlBase-jkbm7k6ijt3b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1230),(2019,'d72ebf43-0031-4377-9d12-bf3bf05438a3','9e7be1f3-80ee-450e-b2d0-fa740f08d161','2026-06-15 07:52:08',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-TLSProxyBase-uur3eoowcsza-ApacheNetworks-itbc6rszln42','state changed','OS::Heat::Value',NULL,1231),(2020,'8cd14645-3268-4068-9b65-4965ea72f51a','9e7be1f3-80ee-450e-b2d0-fa740f08d161','2026-06-15 07:52:08',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-TLSProxyBase-uur3eoowcsza-ApacheNetworks-itbc6rszln42','state changed','OS::Heat::Value',NULL,1231),(2021,'710afaad-7fb7-469e-a9af-b88bd25853c3','cf381968-3012-4d1e-ac20-a672a18e5b14','2026-06-15 07:52:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj-MysqlBase-jkbm7k6ijt3b','cf381968-3012-4d1e-ac20-a672a18e5b14','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2022,'05f3e39f-be35-45ce-a93e-aae6d5b088fd','9e7be1f3-80ee-450e-b2d0-fa740f08d161','2026-06-15 07:52:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc-TLSProxyBase-uur3eoowcsza','9e7be1f3-80ee-450e-b2d0-fa740f08d161','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2023,'f394a5e2-8bd8-4f6f-8374-6506e61f32c0','cf381968-3012-4d1e-ac20-a672a18e5b14','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj-MysqlBase-jkbm7k6ijt3b','cf381968-3012-4d1e-ac20-a672a18e5b14','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2024,'d5befb62-0897-4302-974a-2ba132bded4d','80ca7555-a7a6-4de6-86e1-02a0895a7b67','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','NeutronMl2Base','16edde4d-ba3d-471d-a62b-774ed2e7e6b1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1223),(2025,'a53a2b3e-e6b2-4173-8301-95037a9aed9b','80ca7555-a7a6-4de6-86e1-02a0895a7b67','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio-NeutronBase-4iz76wscgkdl','80ca7555-a7a6-4de6-86e1-02a0895a7b67','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2026,'4bfbe1fb-4e7b-44f0-a119-696120a53043','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:09',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaBase-rmxhvy2lmglv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1232),(2027,'c99b4bf4-3ed6-4f5d-a87b-ef44819ee038','f4186148-dc43-4dd8-9bcd-f6aa09442f4d','2026-06-15 07:52:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaBase-rmxhvy2lmglv','f4186148-dc43-4dd8-9bcd-f6aa09442f4d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2028,'663b3eca-88c0-4688-9cfa-c83417d0c1a1','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','MySQLClient','5518f68f-7d6f-4919-86a2-c21b33cd0ba4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2029,'cefd6db3-8d26-459b-8e28-72797044bad2','f4186148-dc43-4dd8-9bcd-f6aa09442f4d','2026-06-15 07:52:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaBase-rmxhvy2lmglv-RoleParametersValue-z35nxb42redo','state changed','OS::Heat::Value',NULL,1233),(2030,'6b580bd8-e098-4ea4-af84-6236028569ad','f4186148-dc43-4dd8-9bcd-f6aa09442f4d','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaBase-rmxhvy2lmglv-RoleParametersValue-z35nxb42redo','state changed','OS::Heat::Value',NULL,1233),(2031,'74dbb006-3ce0-497b-8cfb-682597ea6997','f4186148-dc43-4dd8-9bcd-f6aa09442f4d','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb-NovaBase-rmxhvy2lmglv','f4186148-dc43-4dd8-9bcd-f6aa09442f4d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2032,'dc147819-9c5f-4835-bc53-8e9a898e8128','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','TLSProxyBase','9e7be1f3-80ee-450e-b2d0-fa740f08d161','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1229),(2033,'462573fc-8b5f-48e4-bd25-dbc08d2034b0','ca6c7986-aed4-44a4-b57b-560ca277e644','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-31-naph3avrwiqc','ca6c7986-aed4-44a4-b57b-560ca277e644','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2034,'455e4586-5880-42da-a903-da6f3d5bb5b2','9f862eda-0ee5-446a-8a27-1987ed5dd999','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','NeutronBase','80ca7555-a7a6-4de6-86e1-02a0895a7b67','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1222),(2035,'43d8aa65-3241-467e-b14b-bbb1e2fe3bce','9f862eda-0ee5-446a-8a27-1987ed5dd999','2026-06-15 07:52:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-32-yzdd4ijujmio','9f862eda-0ee5-446a-8a27-1987ed5dd999','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2036,'cc8b035c-f22e-4e17-9ac7-f16046a7c5ce','0a16db92-41a9-4318-ad08-e28032c3e194','2026-06-15 07:52:10',NULL,'CREATE','COMPLETE','MysqlBase','cf381968-3012-4d1e-ac20-a672a18e5b14','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1230),(2037,'55384bd2-4f9f-4180-8c17-c137a7305c27','0a16db92-41a9-4318-ad08-e28032c3e194','2026-06-15 07:52:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-29-shy57vlgumrj','0a16db92-41a9-4318-ad08-e28032c3e194','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2038,'218f0e49-c46e-4376-a608-0b5b24a15a96','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:10',NULL,'CREATE','COMPLETE','NovaBase','f4186148-dc43-4dd8-9bcd-f6aa09442f4d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1232),(2039,'eb7f2726-d48e-406d-923e-899717ec93f7','0d4e89b4-3d64-445f-b469-edd22c1af7fc','2026-06-15 07:52:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-34-lh5yda7zwzyb','0d4e89b4-3d64-445f-b469-edd22c1af7fc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2040,'4a07f702-9e80-4914-b159-5e6468f948ca','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:10',NULL,'CREATE','COMPLETE','31','ca6c7986-aed4-44a4-b57b-560ca277e644','state changed','OS::TripleO::Services::NeutronApi',NULL,1200),(2041,'1e419a84-7834-432c-8f78-79e2167dfb89','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:10',NULL,'CREATE','COMPLETE','32','9f862eda-0ee5-446a-8a27-1987ed5dd999','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1219),(2042,'778d8f0f-7775-4f6c-a3b8-c0eaa15f7150','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:10',NULL,'CREATE','COMPLETE','29','0a16db92-41a9-4318-ad08-e28032c3e194','state changed','OS::TripleO::Services::MySQL',NULL,1221),(2043,'c7ad07d6-7675-49e1-a9b7-5d571c1f4645','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','36','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m','state changed','OS::TripleO::Services::NovaScheduler',NULL,1251),(2044,'51b9f745-15e5-4a0d-8881-1f6e35e76846','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:11',NULL,'CREATE','COMPLETE','34','0d4e89b4-3d64-445f-b469-edd22c1af7fc','state changed','OS::TripleO::Services::NovaConductor',NULL,1204),(2045,'60273ccc-dd80-4693-905e-b89b2f00b438','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','33','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz','state changed','OS::TripleO::Services::NovaApi',NULL,1253),(2046,'b9aadd8e-0c4e-4899-b70e-29160dfff21b','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','35','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3','state changed','OS::TripleO::Services::NovaMetadata',NULL,1254),(2047,'d00c1b3a-38c8-4ec5-b5d8-df3bc6ba4878','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m','24489618-212c-43a0-bd02-a10805821b0b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2048,'15c90569-0310-4ebe-be9f-d57ad6d43857','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3','83616a1b-fbd8-4ed4-9819-8c7f81161458','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2049,'98e92a46-d5d6-45a5-b141-2e911547a4e4','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz','c5304150-612b-4f3f-873f-ebb40eeac0a1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2050,'5d51d7ad-2f3b-4964-bd29-b226dcb8bfe8','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-RoleParametersValue-4kjmdlvu4sna','state changed','OS::Heat::Value',NULL,1261),(2051,'d3460338-6e9e-46fd-8ab0-95ea6ae4b4c2','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-RoleParametersValue-4kjmdlvu4sna','state changed','OS::Heat::Value',NULL,1261),(2052,'c96b030e-6e21-46c9-86ea-77f2d16a47d1','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-ContainersCommon-nv7vlllckxni','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2053,'6b8b59d4-4743-4fe3-a59a-a375a30ae121','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaLogging-jduzagesjtav','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1266),(2054,'6edba40d-6e03-455b-a696-34fbad052ed5','e039b9b2-b27a-4635-b97f-936491b3db4e','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-ContainersCommon-nv7vlllckxni','e039b9b2-b27a-4635-b97f-936491b3db4e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2055,'6daa9ec6-242c-4f38-b404-dcc6c6c67553','ece57bf3-dce4-4d86-9589-0c3a514fe9b5','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaLogging-jduzagesjtav','ece57bf3-dce4-4d86-9589-0c3a514fe9b5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2056,'47d5774d-8757-4740-ba56-17b89ebb87c9','e039b9b2-b27a-4635-b97f-936491b3db4e','2026-06-15 07:52:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-ContainersCommon-nv7vlllckxni','e039b9b2-b27a-4635-b97f-936491b3db4e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2057,'4e958875-7e90-4abd-875d-259b18f6fc98','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-RoleParametersValue-eggobuprsygt','state changed','OS::Heat::Value',NULL,1268),(2058,'3f1ebf74-9085-4896-a67c-f4bcb9afd75f','ece57bf3-dce4-4d86-9589-0c3a514fe9b5','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaLogging-jduzagesjtav-RoleParametersValue-das2o3cgknds','state changed','OS::Heat::Value',NULL,1269),(2059,'f8687275-86e8-4af3-aabc-da317f133d6c','ece57bf3-dce4-4d86-9589-0c3a514fe9b5','2026-06-15 07:52:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaLogging-jduzagesjtav-RoleParametersValue-das2o3cgknds','state changed','OS::Heat::Value',NULL,1269),(2060,'9f6adaac-392c-40a6-9b27-dda03eff73e0','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','38','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-38-vsrbui3p7pfk','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1270),(2061,'2a508c6a-8bb1-4951-bf1b-7b93c79d824d','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-RoleParametersValue-eggobuprsygt','state changed','OS::Heat::Value',NULL,1268),(2062,'c05afd12-bc6e-4a69-a44f-16b6025a5012','2bbbcfbe-a5d4-4a61-9160-912570c777d6','2026-06-15 07:52:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-38-vsrbui3p7pfk','2bbbcfbe-a5d4-4a61-9160-912570c777d6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2063,'50bff79a-3288-47a5-8df5-21e26c33484e','2bbbcfbe-a5d4-4a61-9160-912570c777d6','2026-06-15 07:52:12',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-38-vsrbui3p7pfk-RoleParametersValue-7vyeouc5c25e','state changed','OS::Heat::Value',NULL,1271),(2064,'e63ea201-6afe-4c3e-afb6-0e4562787c0a','2bbbcfbe-a5d4-4a61-9160-912570c777d6','2026-06-15 07:52:12',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-38-vsrbui3p7pfk-RoleParametersValue-7vyeouc5c25e','state changed','OS::Heat::Value',NULL,1271),(2065,'49f52f2d-f6c6-43d9-ad12-530ba8006241','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:12',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaDBClient-rkfdeg5mwkln','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1272),(2066,'c9d47df6-9879-4a98-b55d-099ae0abc3e6','e7b2fc6f-a86c-41ee-869e-a1e082f9fa00','2026-06-15 07:52:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaDBClient-rkfdeg5mwkln','e7b2fc6f-a86c-41ee-869e-a1e082f9fa00','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2067,'0007bc23-2e3c-4478-9e67-a874f6236070','e7b2fc6f-a86c-41ee-869e-a1e082f9fa00','2026-06-15 07:52:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaDBClient-rkfdeg5mwkln','e7b2fc6f-a86c-41ee-869e-a1e082f9fa00','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2068,'8c2269f6-27b0-48e9-9173-eba38aeccf20','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:12',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-MySQLClient-bdmjgvkxihvk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2069,'490c0c2b-611c-4284-a31e-3faa7f6d2400','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:12',NULL,'CREATE','COMPLETE','ContainersCommon','e039b9b2-b27a-4635-b97f-936491b3db4e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2070,'52925d97-f35c-4ac0-b5ba-b9f131d3c290','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:12',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-ContainersCommon-ulc7ky6i42zl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2071,'fa225f57-6f90-4bca-9108-db65ef75eec7','2048f441-19a7-467b-b853-a8657d513a0b','2026-06-15 07:52:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-MySQLClient-bdmjgvkxihvk','2048f441-19a7-467b-b853-a8657d513a0b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2072,'1d1d60c5-2272-4013-b9ab-7b47660b9fb4','2048f441-19a7-467b-b853-a8657d513a0b','2026-06-15 07:52:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-MySQLClient-bdmjgvkxihvk','2048f441-19a7-467b-b853-a8657d513a0b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2073,'5d6bc110-b076-4dad-8edd-37d62a441b01','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:12',NULL,'CREATE','COMPLETE','MySQLClient','2048f441-19a7-467b-b853-a8657d513a0b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2074,'12977c59-8d3c-4ebb-978a-67aa39fdaa06','ece57bf3-dce4-4d86-9589-0c3a514fe9b5','2026-06-15 07:52:12',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaLogging-jduzagesjtav-InitLogContainerName-sp3fazq3o66g','state changed','OS::Heat::Value',NULL,1273),(2075,'d1c48ce7-c15b-44ae-b310-46625c98a1ca','bdc22bb9-a2d6-46ae-8832-ca1c724100bf','2026-06-15 07:52:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-ContainersCommon-ulc7ky6i42zl','bdc22bb9-a2d6-46ae-8832-ca1c724100bf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2076,'f7d6b693-b26a-43dc-8643-0a5a5e0dd1e9','ece57bf3-dce4-4d86-9589-0c3a514fe9b5','2026-06-15 07:52:12',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaLogging-jduzagesjtav-InitLogContainerName-sp3fazq3o66g','state changed','OS::Heat::Value',NULL,1273),(2077,'a9a797c1-b295-40be-8542-48085a33f22a','bdc22bb9-a2d6-46ae-8832-ca1c724100bf','2026-06-15 07:52:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-ContainersCommon-ulc7ky6i42zl','bdc22bb9-a2d6-46ae-8832-ca1c724100bf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2078,'c52f147d-522d-46aa-8fe1-c8bff5b77d5e','ece57bf3-dce4-4d86-9589-0c3a514fe9b5','2026-06-15 07:52:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaLogging-jduzagesjtav','ece57bf3-dce4-4d86-9589-0c3a514fe9b5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2079,'237798c2-5478-4011-9929-c3fab1d0e4d3','2bbbcfbe-a5d4-4a61-9160-912570c777d6','2026-06-15 07:52:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-38-vsrbui3p7pfk-ContainersCommon-3lxyxhkpulau','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2080,'d32be046-60d0-4943-b803-952bd9840125','951cb698-b6fc-43bc-a941-5c0a108d173a','2026-06-15 07:52:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-38-vsrbui3p7pfk-ContainersCommon-3lxyxhkpulau','951cb698-b6fc-43bc-a941-5c0a108d173a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2081,'0e7ff3d4-0950-44aa-b59c-9612d9a9791e','951cb698-b6fc-43bc-a941-5c0a108d173a','2026-06-15 07:52:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-38-vsrbui3p7pfk-ContainersCommon-3lxyxhkpulau','951cb698-b6fc-43bc-a941-5c0a108d173a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2082,'8cceb663-ff04-46c0-a477-9cba255b9916','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-ContainersCommon-ojrvcjk4wfyd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2083,'61db4076-d92e-49dc-804f-41cf682aa5ca','f389b89f-b343-42d0-a50f-852c6dc8dd07','2026-06-15 07:52:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-ContainersCommon-ojrvcjk4wfyd','f389b89f-b343-42d0-a50f-852c6dc8dd07','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2084,'5d423d37-76bc-441b-9a4c-72d96997d0a6','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:13',NULL,'CREATE','COMPLETE','NovaDBClient','e7b2fc6f-a86c-41ee-869e-a1e082f9fa00','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1272),(2085,'43c408e0-10ce-49a7-ab73-a9c96fa0ea45','f389b89f-b343-42d0-a50f-852c6dc8dd07','2026-06-15 07:52:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-ContainersCommon-ojrvcjk4wfyd','f389b89f-b343-42d0-a50f-852c6dc8dd07','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2086,'607769b5-433b-4a58-916b-2dbf6ff43bfb','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:13',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaDBClient-yhj3jc7icwxn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1274),(2087,'1e00e573-3013-414d-893c-154c58462090','09a93bea-84ad-4471-b1d8-f0df4198c2b1','2026-06-15 07:52:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaDBClient-yhj3jc7icwxn','09a93bea-84ad-4471-b1d8-f0df4198c2b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2088,'ee35660d-82e9-4e84-a3a1-ec2bd65338cd','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:13',NULL,'CREATE','COMPLETE','NovaLogging','ece57bf3-dce4-4d86-9589-0c3a514fe9b5','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1266),(2089,'1a2e8753-0569-44ee-a2d1-a3404254f092','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:13',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaDBClient-kz2g62ckwomj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1275),(2090,'36676286-55ed-49e1-8dda-6d7d57cd5bc6','09a93bea-84ad-4471-b1d8-f0df4198c2b1','2026-06-15 07:52:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaDBClient-yhj3jc7icwxn','09a93bea-84ad-4471-b1d8-f0df4198c2b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2091,'91f80463-5437-4559-9053-d7a99f142d58','c2abb41c-d40b-45a7-addc-9b2af264a99a','2026-06-15 07:52:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaDBClient-kz2g62ckwomj','c2abb41c-d40b-45a7-addc-9b2af264a99a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2092,'dd2bf1e5-ead6-489a-b8cb-b6521fb143ca','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:13',NULL,'CREATE','COMPLETE','ContainersCommon','bdc22bb9-a2d6-46ae-8832-ca1c724100bf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2093,'0bab16f7-2716-4362-9163-40fa42fc9873','c2abb41c-d40b-45a7-addc-9b2af264a99a','2026-06-15 07:52:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaDBClient-kz2g62ckwomj','c2abb41c-d40b-45a7-addc-9b2af264a99a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2094,'6339e385-1962-4ddd-bc53-8e175ac407c7','2bbbcfbe-a5d4-4a61-9160-912570c777d6','2026-06-15 07:52:14',NULL,'CREATE','COMPLETE','ContainersCommon','951cb698-b6fc-43bc-a941-5c0a108d173a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2095,'ac1ae2b5-4d52-4a08-b947-41b2624a22a4','2bbbcfbe-a5d4-4a61-9160-912570c777d6','2026-06-15 07:52:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-38-vsrbui3p7pfk','2bbbcfbe-a5d4-4a61-9160-912570c777d6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2096,'cb8fc379-b6eb-4d69-b873-c78a514a2031','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:14',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaApiDBClient-w6pay4gwgbe3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1276),(2097,'9f30c359-7859-4901-8e68-feee1a0572e8','e6562215-c471-4004-87c7-02de66ca2a36','2026-06-15 07:52:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaApiDBClient-w6pay4gwgbe3','e6562215-c471-4004-87c7-02de66ca2a36','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2098,'40c7eb32-1d6d-4c5e-8653-97844d3cd49e','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:14',NULL,'CREATE','COMPLETE','ContainersCommon','f389b89f-b343-42d0-a50f-852c6dc8dd07','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2099,'dcd92fd9-12e4-42ee-afc2-37dcec1f0308','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:14',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaApiDBClient-fqfurisam757','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1277),(2100,'fd814be1-3e29-4f25-86d3-0227187f838e','e6562215-c471-4004-87c7-02de66ca2a36','2026-06-15 07:52:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaApiDBClient-w6pay4gwgbe3','e6562215-c471-4004-87c7-02de66ca2a36','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2101,'ccf9049c-c0cd-4782-a6cf-4ce45a10fd0d','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:14',NULL,'CREATE','IN_PROGRESS','NovaMetadataLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaMetadataLogging-lz5qajap66oo','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2102,'65324876-7a3a-4231-b276-211308e7b301','b0d9ce38-1315-49bd-8f12-2dbf4b6cf4f9','2026-06-15 07:52:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaApiDBClient-fqfurisam757','b0d9ce38-1315-49bd-8f12-2dbf4b6cf4f9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2103,'f9498c74-8a46-449f-bb2b-ba9b3143966f','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:14',NULL,'CREATE','COMPLETE','NovaDBClient','09a93bea-84ad-4471-b1d8-f0df4198c2b1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1274),(2104,'4785c054-a8d6-4107-8d41-8453e1a7f5cd','b0d9ce38-1315-49bd-8f12-2dbf4b6cf4f9','2026-06-15 07:52:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaApiDBClient-fqfurisam757','b0d9ce38-1315-49bd-8f12-2dbf4b6cf4f9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2105,'f9788176-f871-4b3b-baa9-e894be6314ea','0236d88c-1024-4202-bf6f-c57225f66c07','2026-06-15 07:52:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaMetadataLogging-lz5qajap66oo','0236d88c-1024-4202-bf6f-c57225f66c07','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2106,'d6718f91-a51b-4bb1-b495-67c907849993','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:14',NULL,'CREATE','COMPLETE','NovaDBClient','c2abb41c-d40b-45a7-addc-9b2af264a99a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1275),(2107,'d0a1c5ed-3712-4a1a-933c-5cbad1b4dd4a','0236d88c-1024-4202-bf6f-c57225f66c07','2026-06-15 07:52:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaMetadataLogging-lz5qajap66oo-RoleParametersValue-gzzl5byfiw6l','state changed','OS::Heat::Value',NULL,1278),(2108,'f171fa98-d439-4628-83bf-60506db1704e','0236d88c-1024-4202-bf6f-c57225f66c07','2026-06-15 07:52:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaMetadataLogging-lz5qajap66oo-RoleParametersValue-gzzl5byfiw6l','state changed','OS::Heat::Value',NULL,1278),(2109,'573633a8-f39c-479f-9e9e-b08efdb030d0','0236d88c-1024-4202-bf6f-c57225f66c07','2026-06-15 07:52:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaMetadataLogging-lz5qajap66oo','0236d88c-1024-4202-bf6f-c57225f66c07','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2110,'51daae34-e17d-4d54-aa53-2ed1771178af','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:15',NULL,'CREATE','COMPLETE','38','2bbbcfbe-a5d4-4a61-9160-912570c777d6','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1270),(2111,'d588ceee-cf9b-47fe-ba37-58d700d1ce0c','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:15',NULL,'CREATE','IN_PROGRESS','42','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6','state changed','OS::TripleO::Services::PlacementApi',NULL,1282),(2112,'431dcdfb-7ff4-4c54-8f25-7cc9e66d6d80','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6','900a6ea3-4d2c-44e2-8583-58c38e5b168b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2113,'e030514d-af4e-47e7-b892-8fe27bc08713','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:15',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-MySQLClient-aastwzdipijb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2114,'4db63b9a-0fcc-4bc6-96dd-2816c62a378c','ee2d8818-5b11-4ea3-92b9-65f1e3952872','2026-06-15 07:52:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-MySQLClient-aastwzdipijb','ee2d8818-5b11-4ea3-92b9-65f1e3952872','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2115,'0d5eeaa7-0516-41e7-8f47-afd32823eda0','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:15',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-RoleParametersValue-ze6coahpf4vs','state changed','OS::Heat::Value',NULL,1283),(2116,'921f9239-9950-48e9-ad00-30803c6b57b2','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:15',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-RoleParametersValue-ze6coahpf4vs','state changed','OS::Heat::Value',NULL,1283),(2117,'3c23773a-5d46-4a06-9e9a-e132c742ddee','ee2d8818-5b11-4ea3-92b9-65f1e3952872','2026-06-15 07:52:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-MySQLClient-aastwzdipijb','ee2d8818-5b11-4ea3-92b9-65f1e3952872','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2118,'4a609790-58e1-4259-a5e1-0d399162a13c','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:15',NULL,'CREATE','COMPLETE','NovaApiDBClient','e6562215-c471-4004-87c7-02de66ca2a36','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1276),(2119,'271fc75b-e743-448b-a57f-019b640eb436','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:15',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-RoleParametersValue-6gaixvesacw5','state changed','OS::Heat::Value',NULL,1284),(2120,'ba5099a7-c244-490f-84db-4c5b93cc8604','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:15',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-ApacheServiceBase-ftbdm2tghops','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1285),(2121,'1a268b23-be0d-4ad1-8ac2-6b55b3545e1a','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:15',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-RoleParametersValue-6gaixvesacw5','state changed','OS::Heat::Value',NULL,1284),(2122,'8db1fe7f-f1e0-42e8-b2b0-4dfe07be43d6','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:15',NULL,'CREATE','COMPLETE','NovaApiDBClient','b0d9ce38-1315-49bd-8f12-2dbf4b6cf4f9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1277),(2123,'6b696428-98e7-4811-8ef7-ede8aefb16d5','9b6d0b40-7795-4f87-b5d7-9bd5077c95dc','2026-06-15 07:52:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-ApacheServiceBase-ftbdm2tghops','9b6d0b40-7795-4f87-b5d7-9bd5077c95dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2124,'ee93f334-205e-46f8-b749-f6557b5eb3d9','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:15',NULL,'CREATE','COMPLETE','NovaMetadataLogging','0236d88c-1024-4202-bf6f-c57225f66c07','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2125,'1c719bcb-f608-43f7-8631-9a24aa5c2cd7','9b6d0b40-7795-4f87-b5d7-9bd5077c95dc','2026-06-15 07:52:15',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-ApacheServiceBase-ftbdm2tghops-ApacheNetworks-bregjiragz46','state changed','OS::Heat::Value',NULL,1286),(2126,'a8782c48-138f-48a6-b10d-9dddeae0cc21','9b6d0b40-7795-4f87-b5d7-9bd5077c95dc','2026-06-15 07:52:15',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-ApacheServiceBase-ftbdm2tghops-ApacheNetworks-bregjiragz46','state changed','OS::Heat::Value',NULL,1286),(2127,'5b1e979e-8424-4954-9874-0c9082af7b9e','9b6d0b40-7795-4f87-b5d7-9bd5077c95dc','2026-06-15 07:52:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-ApacheServiceBase-ftbdm2tghops','9b6d0b40-7795-4f87-b5d7-9bd5077c95dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2128,'a267237d-82c9-4d2b-855f-07436e8a038f','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaBase-hbksyzr3r6w4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1287),(2129,'c3061a1a-703c-416f-aea5-498341808087','27c74679-457a-4d28-9ee5-513d8362f3c6','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaBase-hbksyzr3r6w4','27c74679-457a-4d28-9ee5-513d8362f3c6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2130,'9a4b083c-8d7a-4169-b46c-354317e9d1a2','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','NovaApiLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaApiLogging-fpim5xg3apsr','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(2131,'1e45032d-c71f-4af0-bab2-ef1631b344c7','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:16',NULL,'CREATE','COMPLETE','MySQLClient','ee2d8818-5b11-4ea3-92b9-65f1e3952872','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2132,'a9e37291-7b22-43ce-b5f3-eacf6cb7d20b','6b1c690f-18c5-4169-a530-5d08eac3f904','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaApiLogging-fpim5xg3apsr','6b1c690f-18c5-4169-a530-5d08eac3f904','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2133,'304851bc-231f-4bd5-b262-f9a168c247ef','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-ApacheServiceBase-7k3zdhurrejd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1288),(2134,'350d970e-d014-479b-8cbe-bef4081582a9','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaApiDBClient-dubnxmtw3jcr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1289),(2135,'5b3e1db3-3504-4e57-b0a0-507e76fd07cd','6b1c690f-18c5-4169-a530-5d08eac3f904','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaApiLogging-fpim5xg3apsr-RoleParametersValue-53e5iipd7wwf','state changed','OS::Heat::Value',NULL,1291),(2136,'0882d714-6cfe-4be1-ac23-1d540abb8b53','c0178638-1119-4095-bca3-ad8419c48e33','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaApiDBClient-dubnxmtw3jcr','c0178638-1119-4095-bca3-ad8419c48e33','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2137,'85759e91-d019-4c91-bc2d-0bc760639d55','27c74679-457a-4d28-9ee5-513d8362f3c6','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaBase-hbksyzr3r6w4-RoleParametersValue-2d4wifjzbk25','state changed','OS::Heat::Value',NULL,1290),(2138,'8d39757e-c4ce-49a7-a0d2-536600cd1809','6b1c690f-18c5-4169-a530-5d08eac3f904','2026-06-15 07:52:16',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaApiLogging-fpim5xg3apsr-RoleParametersValue-53e5iipd7wwf','state changed','OS::Heat::Value',NULL,1291),(2139,'e6545fb4-b321-4d88-bf43-87f9f73a7255','6b1c690f-18c5-4169-a530-5d08eac3f904','2026-06-15 07:52:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaApiLogging-fpim5xg3apsr','6b1c690f-18c5-4169-a530-5d08eac3f904','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2140,'6d9f2ee1-d1bd-4ca1-812a-380cf7c9547d','84be6ed3-a722-4e81-affd-6a01ea359569','2026-06-15 07:52:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-ApacheServiceBase-7k3zdhurrejd','84be6ed3-a722-4e81-affd-6a01ea359569','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2141,'b616d8b5-0789-4394-b0ce-a63a2fa6bed1','27c74679-457a-4d28-9ee5-513d8362f3c6','2026-06-15 07:52:16',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaBase-hbksyzr3r6w4-RoleParametersValue-2d4wifjzbk25','state changed','OS::Heat::Value',NULL,1290),(2142,'7e6e786f-c047-41eb-a0a4-195551a37ce5','c0178638-1119-4095-bca3-ad8419c48e33','2026-06-15 07:52:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaApiDBClient-dubnxmtw3jcr','c0178638-1119-4095-bca3-ad8419c48e33','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2143,'bf15e90e-bd36-4486-8bfd-ad2dccac13b0','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:16',NULL,'CREATE','COMPLETE','ApacheServiceBase','9b6d0b40-7795-4f87-b5d7-9bd5077c95dc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1285),(2144,'e9878bc5-d3de-4cd3-8619-b3b89f4dbbfb','27c74679-457a-4d28-9ee5-513d8362f3c6','2026-06-15 07:52:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m-NovaBase-hbksyzr3r6w4','27c74679-457a-4d28-9ee5-513d8362f3c6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2145,'88ee88fc-7f61-402c-b27d-9d6ea89934bf','84be6ed3-a722-4e81-affd-6a01ea359569','2026-06-15 07:52:17',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-ApacheServiceBase-7k3zdhurrejd-ApacheNetworks-toim5blcyyht','state changed','OS::Heat::Value',NULL,1292),(2146,'1bd53595-e558-4055-a1ac-eef5b82eab56','84be6ed3-a722-4e81-affd-6a01ea359569','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-ApacheServiceBase-7k3zdhurrejd-ApacheNetworks-toim5blcyyht','state changed','OS::Heat::Value',NULL,1292),(2147,'b7640736-a626-439f-b1cb-75b506390ea5','84be6ed3-a722-4e81-affd-6a01ea359569','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-ApacheServiceBase-7k3zdhurrejd','84be6ed3-a722-4e81-affd-6a01ea359569','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2148,'a5f515ff-9e8b-4fc0-a353-61fa0423b034','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:17',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-ApacheServiceBase-2iljixb5zse3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1293),(2149,'4fa43c36-21c7-4bcb-86d8-2e4a2cda09b7','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','NovaBase','27c74679-457a-4d28-9ee5-513d8362f3c6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1287),(2150,'6d088ab6-f779-4f6a-aa10-b8a560c60d6a','24489618-212c-43a0-bd02-a10805821b0b','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-36-w4ntfxeqcx2m','24489618-212c-43a0-bd02-a10805821b0b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2151,'a890ea10-ef91-4cd6-971b-c8f9c4ab340f','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:17',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-ContainersCommon-3figtpssghku','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2152,'3235bfae-d17f-4959-90dc-93ad42296576','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','NovaApiLogging','6b1c690f-18c5-4169-a530-5d08eac3f904','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(2153,'b37df3be-3342-4103-9d8a-5d9c844b8db2','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:17',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaBase-pmo5kveqk4o5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1294),(2154,'fb4af01a-ff32-46d5-9732-32ae24ebb94a','da399283-108c-42af-a0b4-0900549710cd','2026-06-15 07:52:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-ContainersCommon-3figtpssghku','da399283-108c-42af-a0b4-0900549710cd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2155,'0a317ce3-e531-4095-b7f1-d2acc8f2a18f','439267fe-4b23-45cc-ac30-8a2ea6875050','2026-06-15 07:52:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-ApacheServiceBase-2iljixb5zse3','439267fe-4b23-45cc-ac30-8a2ea6875050','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2156,'a42c70e4-d2da-4931-87f3-6053c403b248','da399283-108c-42af-a0b4-0900549710cd','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-ContainersCommon-3figtpssghku','da399283-108c-42af-a0b4-0900549710cd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2157,'eb9a42ef-7ffc-419f-aaa8-133c080a7cff','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','NovaApiDBClient','c0178638-1119-4095-bca3-ad8419c48e33','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1289),(2158,'5eb9db3d-f595-461a-ac18-75dc1a91a08c','8e9243f7-1959-4be8-b9a6-61529f25f0b0','2026-06-15 07:52:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaBase-pmo5kveqk4o5','8e9243f7-1959-4be8-b9a6-61529f25f0b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2159,'69d9a668-268e-4ffb-b9da-1be4a88b013b','439267fe-4b23-45cc-ac30-8a2ea6875050','2026-06-15 07:52:17',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-ApacheServiceBase-2iljixb5zse3-ApacheNetworks-vpd4u4eupy5u','state changed','OS::Heat::Value',NULL,1295),(2160,'af040421-5a53-4dfd-888d-cfba26d164ed','439267fe-4b23-45cc-ac30-8a2ea6875050','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-ApacheServiceBase-2iljixb5zse3-ApacheNetworks-vpd4u4eupy5u','state changed','OS::Heat::Value',NULL,1295),(2161,'5fa23f0d-5221-4fe5-b42f-5bcb55737564','439267fe-4b23-45cc-ac30-8a2ea6875050','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-ApacheServiceBase-2iljixb5zse3','439267fe-4b23-45cc-ac30-8a2ea6875050','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2162,'7c34e8bd-83bd-467b-b98f-0a2494a121e6','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:17',NULL,'CREATE','COMPLETE','ApacheServiceBase','84be6ed3-a722-4e81-affd-6a01ea359569','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1288),(2163,'b38abd0a-2a40-4209-aacd-c7d345e5c604','8e9243f7-1959-4be8-b9a6-61529f25f0b0','2026-06-15 07:52:18',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaBase-pmo5kveqk4o5-RoleParametersValue-l2z5zuub46c5','state changed','OS::Heat::Value',NULL,1296),(2164,'c93edd5b-5740-48e3-b16f-e56c82b23a62','8e9243f7-1959-4be8-b9a6-61529f25f0b0','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaBase-pmo5kveqk4o5-RoleParametersValue-l2z5zuub46c5','state changed','OS::Heat::Value',NULL,1296),(2165,'80c7463c-55fc-4365-aadf-115531f16fe8','8e9243f7-1959-4be8-b9a6-61529f25f0b0','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-NovaBase-pmo5kveqk4o5','8e9243f7-1959-4be8-b9a6-61529f25f0b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2166,'64a83c8c-573b-43cd-9233-7d84cb68893c','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','36','24489618-212c-43a0-bd02-a10805821b0b','state changed','OS::TripleO::Services::NovaScheduler',NULL,1251),(2167,'d46c6a66-fa4f-424d-96c5-7fa15896022d','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:18',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaBase-os6hk5ikc5tg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1297),(2168,'e36fda30-2dbf-4e9e-a0a3-574f097da3a0','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:18',NULL,'CREATE','IN_PROGRESS','PlacementLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-PlacementLogging-shji5rijfpz3','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2169,'360a1584-cdb5-4fb5-a343-5b5c48a42173','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:18',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-MySQLClient-fxvqftyzf3l3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2170,'1106c2c7-49e9-4cdc-98a1-53552dec7888','98028dd3-73f7-488f-b45e-c7aa31faf5c3','2026-06-15 07:52:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaBase-os6hk5ikc5tg','98028dd3-73f7-488f-b45e-c7aa31faf5c3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2171,'7aec0a99-618e-4a60-95ed-1b83b4a441ce','8095c6b5-37ff-4e69-a630-16532c194ff9','2026-06-15 07:52:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-PlacementLogging-shji5rijfpz3','8095c6b5-37ff-4e69-a630-16532c194ff9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2172,'d166b09e-3112-4611-bfdf-d387b2c7e6a9','7d5dd7c7-f96e-4389-ac2c-3637b8486513','2026-06-15 07:52:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-MySQLClient-fxvqftyzf3l3','7d5dd7c7-f96e-4389-ac2c-3637b8486513','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2173,'4cbd0e29-985f-47a2-b9bd-ad853c0754a0','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','ContainersCommon','da399283-108c-42af-a0b4-0900549710cd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2174,'b097c4ca-7fe2-4f7c-8b81-57eef3eed8be','98028dd3-73f7-488f-b45e-c7aa31faf5c3','2026-06-15 07:52:18',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaBase-os6hk5ikc5tg-RoleParametersValue-verdxfebndbz','state changed','OS::Heat::Value',NULL,1304),(2175,'df463ac0-d102-4d5f-be33-1dc135dc2e2c','7d5dd7c7-f96e-4389-ac2c-3637b8486513','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3-MySQLClient-fxvqftyzf3l3','7d5dd7c7-f96e-4389-ac2c-3637b8486513','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2176,'868eeca2-b947-4714-b1da-b6d1d3164318','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','ApacheServiceBase','439267fe-4b23-45cc-ac30-8a2ea6875050','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1293),(2177,'31e36880-2bb9-4961-b29b-aaee7c9bc8c7','8095c6b5-37ff-4e69-a630-16532c194ff9','2026-06-15 07:52:18',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-PlacementLogging-shji5rijfpz3-RoleParametersValue-7cw5ouvnnpwb','state changed','OS::Heat::Value',NULL,1305),(2178,'074da8c8-3b49-467b-96be-ef199be28516','98028dd3-73f7-488f-b45e-c7aa31faf5c3','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaBase-os6hk5ikc5tg-RoleParametersValue-verdxfebndbz','state changed','OS::Heat::Value',NULL,1304),(2179,'900f52e1-b60d-4b3a-9119-86de5f4bf50b','98028dd3-73f7-488f-b45e-c7aa31faf5c3','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz-NovaBase-os6hk5ikc5tg','98028dd3-73f7-488f-b45e-c7aa31faf5c3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2180,'564155d1-eb84-43f8-8e21-ea281125b1a1','8095c6b5-37ff-4e69-a630-16532c194ff9','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-PlacementLogging-shji5rijfpz3-RoleParametersValue-7cw5ouvnnpwb','state changed','OS::Heat::Value',NULL,1305),(2181,'0519fea4-c3a4-4237-bf0c-faedce42e3e2','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:18',NULL,'CREATE','COMPLETE','NovaBase','8e9243f7-1959-4be8-b9a6-61529f25f0b0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1294),(2182,'647d82c4-d37f-4bbb-8a8c-dcc13a376814','8095c6b5-37ff-4e69-a630-16532c194ff9','2026-06-15 07:52:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-PlacementLogging-shji5rijfpz3','8095c6b5-37ff-4e69-a630-16532c194ff9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2183,'2b7248e3-2d73-4ab6-9ddd-f6777a6c6e1e','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:19',NULL,'CREATE','IN_PROGRESS','40','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6','state changed','OS::TripleO::Services::OVNController',NULL,1310),(2184,'a45c3c7f-d7f3-46da-b62a-b044db429a80','574f2967-9aeb-426d-b96e-ba0a89de5690','2026-06-15 07:52:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6','574f2967-9aeb-426d-b96e-ba0a89de5690','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2185,'b7c3093e-f8c3-40a9-81f0-878e9210393f','574f2967-9aeb-426d-b96e-ba0a89de5690','2026-06-15 07:52:19',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6-ContainersCommon-lbmuds5fb3he','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2186,'caddb3bd-786e-4bda-8693-5f3115bb8cdf','8bd9a6d7-4794-4c32-b347-9720ce16e42d','2026-06-15 07:52:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6-ContainersCommon-lbmuds5fb3he','8bd9a6d7-4794-4c32-b347-9720ce16e42d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2187,'c89cd814-fb08-4408-9206-235a05ad9f74','8bd9a6d7-4794-4c32-b347-9720ce16e42d','2026-06-15 07:52:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6-ContainersCommon-lbmuds5fb3he','8bd9a6d7-4794-4c32-b347-9720ce16e42d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2188,'ab33d345-8816-4831-a00b-75ffe8c39071','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:19',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-MySQLClient-akgjby4lxtrg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2189,'f894b3d7-0d53-478d-b664-06777cb98b0e','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:19',NULL,'CREATE','COMPLETE','NovaBase','98028dd3-73f7-488f-b45e-c7aa31faf5c3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1297),(2190,'d45655cc-3b21-42b7-be03-307e8dfa89dc','6d4afa61-6223-49c3-b396-a5f769bebea3','2026-06-15 07:52:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-MySQLClient-akgjby4lxtrg','6d4afa61-6223-49c3-b396-a5f769bebea3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2191,'77ba37dc-b16e-48cd-a732-dd26824e81f2','c5304150-612b-4f3f-873f-ebb40eeac0a1','2026-06-15 07:52:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-33-f2d33brzn7hz','c5304150-612b-4f3f-873f-ebb40eeac0a1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2192,'13d6e880-7abb-4a99-a7ca-053aa6e49fef','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:19',NULL,'CREATE','COMPLETE','PlacementLogging','8095c6b5-37ff-4e69-a630-16532c194ff9','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2193,'8afb4906-33d2-40fb-a70a-e7f27e0cfee3','6d4afa61-6223-49c3-b396-a5f769bebea3','2026-06-15 07:52:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6-MySQLClient-akgjby4lxtrg','6d4afa61-6223-49c3-b396-a5f769bebea3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2194,'2e79cde6-7a05-4659-a2cc-67c7ad96c023','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:19',NULL,'CREATE','COMPLETE','MySQLClient','7d5dd7c7-f96e-4389-ac2c-3637b8486513','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2195,'40819740-27ed-45ca-aa11-6226aa1c24f0','83616a1b-fbd8-4ed4-9819-8c7f81161458','2026-06-15 07:52:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-35-ugbbwlw7lgi3','83616a1b-fbd8-4ed4-9819-8c7f81161458','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2196,'87ecf913-d48c-4554-870a-cb4eea214208','574f2967-9aeb-426d-b96e-ba0a89de5690','2026-06-15 07:52:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6-RoleParametersValue-cty5jkjndm42','state changed','OS::Heat::Value',NULL,1311),(2197,'1358e350-1e9a-4964-a099-077d56087fd1','574f2967-9aeb-426d-b96e-ba0a89de5690','2026-06-15 07:52:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6-RoleParametersValue-cty5jkjndm42','state changed','OS::Heat::Value',NULL,1311),(2198,'cc20d023-d51d-4df2-8f64-4b38cd02da00','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:20',NULL,'CREATE','COMPLETE','33','c5304150-612b-4f3f-873f-ebb40eeac0a1','state changed','OS::TripleO::Services::NovaApi',NULL,1253),(2199,'d3e408eb-b055-4fe1-a828-ca08e6e339df','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:20',NULL,'CREATE','COMPLETE','35','83616a1b-fbd8-4ed4-9819-8c7f81161458','state changed','OS::TripleO::Services::NovaMetadata',NULL,1254),(2200,'8b1b3b04-0c5d-4b40-aff8-0a045cd03ac0','574f2967-9aeb-426d-b96e-ba0a89de5690','2026-06-15 07:52:20',NULL,'CREATE','COMPLETE','ContainersCommon','8bd9a6d7-4794-4c32-b347-9720ce16e42d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2201,'48a323f4-bcfb-40e0-b5ca-c68a5dcf2d11','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:20',NULL,'CREATE','COMPLETE','MySQLClient','6d4afa61-6223-49c3-b396-a5f769bebea3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2202,'ef71e6d1-b051-4389-a16c-cec2505ff1e3','900a6ea3-4d2c-44e2-8583-58c38e5b168b','2026-06-15 07:52:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-42-yzypkshfeso6','900a6ea3-4d2c-44e2-8583-58c38e5b168b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2203,'e386b3b7-d2ec-42f5-91b5-d0f409325afd','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:21',NULL,'CREATE','IN_PROGRESS','37','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1336),(2204,'6868aadf-9eb1-47fd-b934-1a87424e6087','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:21',NULL,'CREATE','IN_PROGRESS','39','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-39-qhlhs76bqlfe','state changed','OS::TripleO::Services::OVNDBs',NULL,1337),(2205,'26f04e1d-3ff3-4583-bcf6-a3ecedd8069f','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w','5dfa22ba-18de-4c66-8520-dde542b58f6f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2206,'dc18889c-5d6f-41c1-99b4-c6d2567d7dfa','4a3c4135-5adf-4b59-8cd3-c23da57e7b94','2026-06-15 07:52:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-39-qhlhs76bqlfe','4a3c4135-5adf-4b59-8cd3-c23da57e7b94','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2207,'a217c6c7-bb8d-4fd4-93d8-3ff1fd2ee0cc','574f2967-9aeb-426d-b96e-ba0a89de5690','2026-06-15 07:52:21',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6-OVNBridgeMappingsValue-5npye3ltopdx','state changed','OS::Heat::Value',NULL,1338),(2208,'1de39700-bac8-4b58-84f0-fd2df68b8ad1','574f2967-9aeb-426d-b96e-ba0a89de5690','2026-06-15 07:52:21',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6-OVNBridgeMappingsValue-5npye3ltopdx','state changed','OS::Heat::Value',NULL,1338),(2209,'e81c2cc5-5844-4385-850f-7c1eca30da3b','574f2967-9aeb-426d-b96e-ba0a89de5690','2026-06-15 07:52:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-40-6vde7kf2iwi6','574f2967-9aeb-426d-b96e-ba0a89de5690','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2210,'81ccc754-24e4-4870-b9ba-d90e30372206','4a3c4135-5adf-4b59-8cd3-c23da57e7b94','2026-06-15 07:52:21',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-39-qhlhs76bqlfe-ContainersCommon-3vhthnyxpdvf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2211,'b31e15a2-670a-4058-873c-4df0fad0f576','acfa098a-e550-4bc5-af43-d4237c78706b','2026-06-15 07:52:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-39-qhlhs76bqlfe-ContainersCommon-3vhthnyxpdvf','acfa098a-e550-4bc5-af43-d4237c78706b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2212,'8af8b810-10f8-48f4-ae15-fda940e9a09e','acfa098a-e550-4bc5-af43-d4237c78706b','2026-06-15 07:52:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-39-qhlhs76bqlfe-ContainersCommon-3vhthnyxpdvf','acfa098a-e550-4bc5-af43-d4237c78706b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2213,'cee86d70-e9ef-40a6-9646-c3b0319aa283','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:21',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaDBClient-7zme4datjchb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1339),(2214,'00abcf1d-7cdd-4d4b-83c2-20949420714d','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:21',NULL,'CREATE','COMPLETE','42','900a6ea3-4d2c-44e2-8583-58c38e5b168b','state changed','OS::TripleO::Services::PlacementApi',NULL,1282),(2215,'47544448-03bc-4bfd-8ee7-0cf89951c39d','e3e5a934-a6e9-4562-8202-e50f359b4f73','2026-06-15 07:52:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaDBClient-7zme4datjchb','e3e5a934-a6e9-4562-8202-e50f359b4f73','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2216,'476bd952-fa9b-40ac-860d-f01c1eafeb01','e3e5a934-a6e9-4562-8202-e50f359b4f73','2026-06-15 07:52:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaDBClient-7zme4datjchb','e3e5a934-a6e9-4562-8202-e50f359b4f73','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2217,'b68d12f8-5912-4508-9d43-4c7ca376764c','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','46','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo','state changed','OS::TripleO::Services::Redis',NULL,1348),(2218,'0a39fe33-dd3e-4c0d-a862-0c28cf4dd4b2','615212be-12fc-4d7a-a5a2-53da91b6ab7e','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo','615212be-12fc-4d7a-a5a2-53da91b6ab7e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2219,'d4810d97-d112-479f-a077-5477d5abcfeb','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:22',NULL,'CREATE','COMPLETE','40','574f2967-9aeb-426d-b96e-ba0a89de5690','state changed','OS::TripleO::Services::OVNController',NULL,1310),(2220,'04ee795f-e63f-4e7a-8b69-be0fd13e845f','615212be-12fc-4d7a-a5a2-53da91b6ab7e','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1349),(2221,'202f5f33-489d-4341-9507-83e6782dd588','cdcd959d-fa19-4fef-98b7-167312d93931','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa','cdcd959d-fa19-4fef-98b7-167312d93931','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2222,'164f63ea-d830-44b2-bb53-2cf4b676379b','4a3c4135-5adf-4b59-8cd3-c23da57e7b94','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-39-qhlhs76bqlfe-RoleParametersValue-2pljtjsp6jvg','state changed','OS::Heat::Value',NULL,1352),(2223,'e46fcdd7-98ab-4be7-96f9-b114a60c35b7','4a3c4135-5adf-4b59-8cd3-c23da57e7b94','2026-06-15 07:52:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-39-qhlhs76bqlfe-RoleParametersValue-2pljtjsp6jvg','state changed','OS::Heat::Value',NULL,1352),(2224,'bbebf911-2f5b-41a9-bf87-529856df5c90','cdcd959d-fa19-4fef-98b7-167312d93931','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa-RedisBase-owoqe3n33wdc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1355),(2225,'f5ce1fb3-e5e9-4255-926a-b98af8291a5e','4a3c4135-5adf-4b59-8cd3-c23da57e7b94','2026-06-15 07:52:22',NULL,'CREATE','COMPLETE','ContainersCommon','acfa098a-e550-4bc5-af43-d4237c78706b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2226,'fb278b62-c0e5-4cbe-9123-2ca4268b2fe0','4a3c4135-5adf-4b59-8cd3-c23da57e7b94','2026-06-15 07:52:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-39-qhlhs76bqlfe','4a3c4135-5adf-4b59-8cd3-c23da57e7b94','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2227,'e13b4181-9c1c-4baf-a393-32026a83443c','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-RoleParametersValue-p2rf4bfgjjoa','state changed','OS::Heat::Value',NULL,1356),(2228,'e005a7b3-5c46-4154-a1c7-1e59732fc120','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-RoleParametersValue-p2rf4bfgjjoa','state changed','OS::Heat::Value',NULL,1356),(2229,'9fbe98d1-785a-4b2c-a087-9935d479d0e6','95513db7-edd4-4998-a633-a65d39faab7b','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa-RedisBase-owoqe3n33wdc','95513db7-edd4-4998-a633-a65d39faab7b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2230,'8edf4e1b-21b0-43c2-b961-99f7720dcec8','95513db7-edd4-4998-a633-a65d39faab7b','2026-06-15 07:52:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa-RedisBase-owoqe3n33wdc','95513db7-edd4-4998-a633-a65d39faab7b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2231,'45985e77-9720-492f-b41a-576dba067986','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaLogging-ntdwlhk35vel','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1358),(2232,'e1469923-a0f3-4f5e-83ac-9f4c185c1586','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','44','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-44-tnhhd5w5lyy3','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1359),(2233,'a4e465b5-c13d-4f62-bb2f-e098e4a2d5fd','312ab3bc-2ade-4de3-9f15-9b1ce6449153','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaLogging-ntdwlhk35vel','312ab3bc-2ade-4de3-9f15-9b1ce6449153','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2234,'798fc6e6-ee17-47f3-9f49-d3922df59045','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:22',NULL,'CREATE','COMPLETE','NovaDBClient','e3e5a934-a6e9-4562-8202-e50f359b4f73','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1339),(2235,'1ce0eb6f-d51d-49f9-911b-c3c3a220718a','0a42fc6c-3dca-4690-8ae8-61be1376a77b','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-44-tnhhd5w5lyy3','0a42fc6c-3dca-4690-8ae8-61be1376a77b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2236,'dbab6955-67ac-4306-8c99-c08e917141e0','312ab3bc-2ade-4de3-9f15-9b1ce6449153','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaLogging-ntdwlhk35vel-RoleParametersValue-4sakus7krmuj','state changed','OS::Heat::Value',NULL,1360),(2237,'eda3867b-433d-4573-8d6c-62f891aefb2f','312ab3bc-2ade-4de3-9f15-9b1ce6449153','2026-06-15 07:52:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaLogging-ntdwlhk35vel-RoleParametersValue-4sakus7krmuj','state changed','OS::Heat::Value',NULL,1360),(2238,'810dbb15-0e35-4672-9ce0-471f2eb1ff4e','0a42fc6c-3dca-4690-8ae8-61be1376a77b','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-44-tnhhd5w5lyy3-ContainersCommon-zzm7x6xh5us4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2239,'b475cc50-c989-41cf-80d5-41a4fd620bc7','cdaabeba-8fdf-4d65-8532-fd3793efe2de','2026-06-15 07:52:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-44-tnhhd5w5lyy3-ContainersCommon-zzm7x6xh5us4','cdaabeba-8fdf-4d65-8532-fd3793efe2de','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2240,'82a6c722-936f-44b2-8fc3-7f9ca6957dd6','cdaabeba-8fdf-4d65-8532-fd3793efe2de','2026-06-15 07:52:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-44-tnhhd5w5lyy3-ContainersCommon-zzm7x6xh5us4','cdaabeba-8fdf-4d65-8532-fd3793efe2de','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2241,'b4118f35-eff4-4e8a-ad1d-11b35329858b','615212be-12fc-4d7a-a5a2-53da91b6ab7e','2026-06-15 07:52:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RoleParametersValue-i2u6zrtydh6s','state changed','OS::Heat::Value',NULL,1361),(2242,'3808048a-6759-4ce5-bc60-c8e709e55c40','615212be-12fc-4d7a-a5a2-53da91b6ab7e','2026-06-15 07:52:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RoleParametersValue-i2u6zrtydh6s','state changed','OS::Heat::Value',NULL,1361),(2243,'6e97e4c7-09f3-48b4-954a-5ae82228a62a','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:23',NULL,'CREATE','COMPLETE','39','4a3c4135-5adf-4b59-8cd3-c23da57e7b94','state changed','OS::TripleO::Services::OVNDBs',NULL,1337),(2244,'a853953b-6120-44a9-a29b-644cd1ec5b3b','cdcd959d-fa19-4fef-98b7-167312d93931','2026-06-15 07:52:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa-RoleParametersValue-d2opxnz7zcn5','state changed','OS::Heat::Value',NULL,1363),(2245,'d56b21ee-48df-4cea-a00b-6538313ecb63','cdcd959d-fa19-4fef-98b7-167312d93931','2026-06-15 07:52:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa-RoleParametersValue-d2opxnz7zcn5','state changed','OS::Heat::Value',NULL,1363),(2246,'527cd6e2-f815-4253-844c-8016256d3df7','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:23',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaBase-gsovwsz7fowt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1365),(2247,'6b019b17-5c8e-4f9f-836b-4433b1cb5bcd','cdcd959d-fa19-4fef-98b7-167312d93931','2026-06-15 07:52:23',NULL,'CREATE','COMPLETE','RedisBase','95513db7-edd4-4998-a633-a65d39faab7b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1355),(2248,'c61369e0-94b8-44ac-9513-bf3c84ec3631','4cb61d72-27f5-441e-ab0a-e1048cb72bfa','2026-06-15 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaBase-gsovwsz7fowt','4cb61d72-27f5-441e-ab0a-e1048cb72bfa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2249,'dac1a486-3afb-4f7a-97ee-d99aebf6694a','4cb61d72-27f5-441e-ab0a-e1048cb72bfa','2026-06-15 07:52:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaBase-gsovwsz7fowt-RoleParametersValue-abehk3ly7icx','state changed','OS::Heat::Value',NULL,1367),(2250,'b866a2ca-1b89-4a6c-81ab-0f78470fecb7','4cb61d72-27f5-441e-ab0a-e1048cb72bfa','2026-06-15 07:52:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaBase-gsovwsz7fowt-RoleParametersValue-abehk3ly7icx','state changed','OS::Heat::Value',NULL,1367),(2251,'9d9b2080-8c4a-4e10-8ee8-0651b0aef961','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:23',NULL,'CREATE','IN_PROGRESS','43','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1368),(2252,'fc1b4956-317a-4009-90f3-fbdcc38b5ac3','4cb61d72-27f5-441e-ab0a-e1048cb72bfa','2026-06-15 07:52:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaBase-gsovwsz7fowt','4cb61d72-27f5-441e-ab0a-e1048cb72bfa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2253,'35546f29-d117-46fc-b5ff-5cac9f046701','312ab3bc-2ade-4de3-9f15-9b1ce6449153','2026-06-15 07:52:23',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaLogging-ntdwlhk35vel-InitLogContainerName-ctsmk63mriqj','state changed','OS::Heat::Value',NULL,1369),(2254,'19546cb5-0cd6-4db6-99d2-4dc104539980','312ab3bc-2ade-4de3-9f15-9b1ce6449153','2026-06-15 07:52:23',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaLogging-ntdwlhk35vel-InitLogContainerName-ctsmk63mriqj','state changed','OS::Heat::Value',NULL,1369),(2255,'ca03fb01-cf0c-400f-9627-863d5b305135','dc5df47e-5630-40a5-9b7b-b4042f71626c','2026-06-15 07:52:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f','dc5df47e-5630-40a5-9b7b-b4042f71626c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2256,'cea4a249-c90c-445f-9c9f-e3cbceff828c','312ab3bc-2ade-4de3-9f15-9b1ce6449153','2026-06-15 07:52:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-NovaLogging-ntdwlhk35vel','312ab3bc-2ade-4de3-9f15-9b1ce6449153','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2257,'00b79a69-a127-40ad-9fe9-66fa0ef2c2e6','0a42fc6c-3dca-4690-8ae8-61be1376a77b','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','ContainersCommon','cdaabeba-8fdf-4d65-8532-fd3793efe2de','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2258,'97d6784e-07ff-41db-9249-837ea17337fa','0a42fc6c-3dca-4690-8ae8-61be1376a77b','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-44-tnhhd5w5lyy3','0a42fc6c-3dca-4690-8ae8-61be1376a77b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2259,'ace4b880-0886-48d8-843a-4b870d95abaa','dc5df47e-5630-40a5-9b7b-b4042f71626c','2026-06-15 07:52:24',NULL,'CREATE','IN_PROGRESS','RabbitmqBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1370),(2260,'fb55ad06-cd72-4b1e-a3ea-797c2de9eab6','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','2026-06-15 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2261,'43645fc3-57a1-4ced-a0c3-a4cd1ca80aeb','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','2026-06-15 07:52:24',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RoleParametersValue-yz6lq3fyujsf','state changed','OS::Heat::Value',NULL,1371),(2262,'b1fa6a2d-9589-4200-8762-20b9db260e1d','615212be-12fc-4d7a-a5a2-53da91b6ab7e','2026-06-15 07:52:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-ContainersCommon-kwcd3w5xzcv2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2263,'b0702181-efa1-4f31-b81e-9e69839f2ea2','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RoleParametersValue-yz6lq3fyujsf','state changed','OS::Heat::Value',NULL,1371),(2264,'3e2ce9dc-4aa4-4c6a-8b2a-8c748b92472b','ef006fe8-7289-4207-8c93-e6116e5e3633','2026-06-15 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-ContainersCommon-kwcd3w5xzcv2','ef006fe8-7289-4207-8c93-e6116e5e3633','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2265,'5d61a8d5-a8c9-46d1-a1d1-3d09a533144a','ef006fe8-7289-4207-8c93-e6116e5e3633','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-ContainersCommon-kwcd3w5xzcv2','ef006fe8-7289-4207-8c93-e6116e5e3633','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2266,'6b7c56b1-548f-4f09-87b2-08c79c4403eb','cdcd959d-fa19-4fef-98b7-167312d93931','2026-06-15 07:52:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa-ContainersCommon-jz5bexzhe6bz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2267,'4afd87ac-ab7e-4345-8e67-c971ce6f0f7f','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-ContainersCommon-7tfwx6dnzh2x','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2268,'7b6cd020-20d0-4469-9627-bcd3f7fdbdee','22449ce7-d99c-4e00-95da-3dd844400f89','2026-06-15 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa-ContainersCommon-jz5bexzhe6bz','22449ce7-d99c-4e00-95da-3dd844400f89','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2269,'f21f7724-21cb-45e5-b62b-53511ea0d36d','22449ce7-d99c-4e00-95da-3dd844400f89','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa-ContainersCommon-jz5bexzhe6bz','22449ce7-d99c-4e00-95da-3dd844400f89','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2270,'fdee7ca9-0fcd-41e3-bf8d-5c392e710dfc','a6847fa5-2254-4184-9bdd-bcce95df297f','2026-06-15 07:52:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-ContainersCommon-7tfwx6dnzh2x','a6847fa5-2254-4184-9bdd-bcce95df297f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2271,'ae6cca54-a239-400c-ae12-91529718d405','cdcd959d-fa19-4fef-98b7-167312d93931','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','ContainersCommon','22449ce7-d99c-4e00-95da-3dd844400f89','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2272,'d3e6f143-fd39-4c6f-a88c-ce3afe6652b4','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','NovaBase','4cb61d72-27f5-441e-ab0a-e1048cb72bfa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1365),(2273,'a151394e-b70c-4a7e-881c-2ee0fc82344d','cdcd959d-fa19-4fef-98b7-167312d93931','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo-RedisBase-xml55uvgnkfa','cdcd959d-fa19-4fef-98b7-167312d93931','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2274,'dca4979a-595b-4e1f-9514-7675dbe60620','a6847fa5-2254-4184-9bdd-bcce95df297f','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-ContainersCommon-7tfwx6dnzh2x','a6847fa5-2254-4184-9bdd-bcce95df297f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2275,'046cfc2f-bd05-4a49-8abe-2a4226cf2f13','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','NovaLogging','312ab3bc-2ade-4de3-9f15-9b1ce6449153','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1358),(2276,'e7da0bd1-c7b5-453e-a6ad-e1ae83c8b9e1','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:24',NULL,'CREATE','COMPLETE','44','0a42fc6c-3dca-4690-8ae8-61be1376a77b','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1359),(2277,'943c44c7-131e-4073-b061-02b45ccd5997','dc5df47e-5630-40a5-9b7b-b4042f71626c','2026-06-15 07:52:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RoleParametersValue-6he2ul26bx43','state changed','OS::Heat::Value',NULL,1374),(2278,'aea9cbeb-80ee-4421-b351-32659bf9b941','dc5df47e-5630-40a5-9b7b-b4042f71626c','2026-06-15 07:52:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RoleParametersValue-6he2ul26bx43','state changed','OS::Heat::Value',NULL,1374),(2279,'9d29f9e9-a2c2-4514-bde4-4e1e6c7184b7','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:25',NULL,'CREATE','IN_PROGRESS','48','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-48-a5licozofsp5','state changed','OS::TripleO::Services::Snmp',NULL,1375),(2280,'39f85a18-31f6-433b-9c5e-8ac4f4c598e7','eb5527e7-85f8-4b48-8807-d64e9733bd58','2026-06-15 07:52:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-48-a5licozofsp5','eb5527e7-85f8-4b48-8807-d64e9733bd58','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2281,'7fd3582a-253b-40fb-a10c-9d98b912415a','eb5527e7-85f8-4b48-8807-d64e9733bd58','2026-06-15 07:52:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-48-a5licozofsp5','eb5527e7-85f8-4b48-8807-d64e9733bd58','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2282,'38d9d808-3cfc-4da8-9925-74c179050401','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','2026-06-15 07:52:25',NULL,'CREATE','IN_PROGRESS','RabbitMQServiceBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RabbitMQServiceBase-opilaa5ancae','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1376),(2283,'16702d07-a1f6-4164-8765-3d00e5e3abf5','615212be-12fc-4d7a-a5a2-53da91b6ab7e','2026-06-15 07:52:25',NULL,'CREATE','COMPLETE','ContainersCommon','ef006fe8-7289-4207-8c93-e6116e5e3633','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2284,'2d1ad392-e3df-4272-86cd-cf035b8e227b','2ee252e7-a0ef-4a75-b299-856ffeec7db4','2026-06-15 07:52:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RabbitMQServiceBase-opilaa5ancae','2ee252e7-a0ef-4a75-b299-856ffeec7db4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2285,'59710de2-d6cb-429d-8e52-e96c51300f73','615212be-12fc-4d7a-a5a2-53da91b6ab7e','2026-06-15 07:52:25',NULL,'CREATE','COMPLETE','RedisBase','cdcd959d-fa19-4fef-98b7-167312d93931','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1349),(2286,'3e959911-eb07-47f1-91ea-40847f174512','615212be-12fc-4d7a-a5a2-53da91b6ab7e','2026-06-15 07:52:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-46-7xfaslhvrofo','615212be-12fc-4d7a-a5a2-53da91b6ab7e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2287,'514ef114-e7aa-4acc-b2b1-eb9d5f5fd4bd','2ee252e7-a0ef-4a75-b299-856ffeec7db4','2026-06-15 07:52:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RabbitMQServiceBase-opilaa5ancae-RoleParametersValue-rjbvxxnyblo6','state changed','OS::Heat::Value',NULL,1377),(2288,'369f5227-ad0d-407e-89d3-ac49856b11ce','2ee252e7-a0ef-4a75-b299-856ffeec7db4','2026-06-15 07:52:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RabbitMQServiceBase-opilaa5ancae-RoleParametersValue-rjbvxxnyblo6','state changed','OS::Heat::Value',NULL,1377),(2289,'801f1c27-b7a6-48bd-b92f-7771d49b6fdb','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:25',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-MySQLClient-a566w7iunulv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2290,'3dbc80a0-cf40-4cfc-a31d-3d05c8980317','ae874a37-0262-4b39-ba1f-ec3949190d1e','2026-06-15 07:52:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-MySQLClient-a566w7iunulv','ae874a37-0262-4b39-ba1f-ec3949190d1e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2291,'64030243-f1d3-482a-9f13-d9b0fb6dd270','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:25',NULL,'CREATE','COMPLETE','ContainersCommon','a6847fa5-2254-4184-9bdd-bcce95df297f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2292,'a2e7b7c6-b8f2-4a21-9f15-614325727a68','ae874a37-0262-4b39-ba1f-ec3949190d1e','2026-06-15 07:52:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w-MySQLClient-a566w7iunulv','ae874a37-0262-4b39-ba1f-ec3949190d1e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2293,'fea6a6e6-4d32-4d63-922d-648242a9a394','dc5df47e-5630-40a5-9b7b-b4042f71626c','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-ContainersCommon-yvxciufjvqgf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2294,'f8c9f245-61ec-4b6c-aaa1-14f6bdca2352','9ad148bf-4235-496b-ad4a-761a0744c5b0','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-ContainersCommon-yvxciufjvqgf','9ad148bf-4235-496b-ad4a-761a0744c5b0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2295,'b08270e2-7bda-4255-bd3b-de8988892671','9ad148bf-4235-496b-ad4a-761a0744c5b0','2026-06-15 07:52:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-ContainersCommon-yvxciufjvqgf','9ad148bf-4235-496b-ad4a-761a0744c5b0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2296,'6b58a245-8356-49bc-89e1-d251bb4cf8c7','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:26',NULL,'CREATE','COMPLETE','48','eb5527e7-85f8-4b48-8807-d64e9733bd58','state changed','OS::TripleO::Services::Snmp',NULL,1375),(2297,'e3b9875b-f092-4486-ab9a-14ae270f0772','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:26',NULL,'CREATE','COMPLETE','46','615212be-12fc-4d7a-a5a2-53da91b6ab7e','state changed','OS::TripleO::Services::Redis',NULL,1348),(2298,'8e491135-afc2-4afd-89c2-19593954f261','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-ContainersCommon-wvuws6x57ayq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2299,'89587a06-66dc-45f6-8bac-8fd9ea59106d','488bef5a-2d21-4a19-a1fd-fd4b91befbd8','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-ContainersCommon-wvuws6x57ayq','488bef5a-2d21-4a19-a1fd-fd4b91befbd8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2300,'79f8dad3-e8b9-4d51-97b8-549a4cc74499','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','52','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba','state changed','OS::TripleO::Services::SwiftStorage',NULL,1382),(2301,'cdea73a1-0696-4139-9511-7ca244c339c9','2ee252e7-a0ef-4a75-b299-856ffeec7db4','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RabbitMQServiceBase-opilaa5ancae-ContainersCommon-ipkmpaqedk6m','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2302,'d8621b88-0d29-4b2f-bb7d-a0ba69dd0a6f','488bef5a-2d21-4a19-a1fd-fd4b91befbd8','2026-06-15 07:52:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-ContainersCommon-wvuws6x57ayq','488bef5a-2d21-4a19-a1fd-fd4b91befbd8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2303,'833e5d88-6559-4207-9660-06823deedf8d','2885c300-4c17-4955-be9a-a45c695b8f4f','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RabbitMQServiceBase-opilaa5ancae-ContainersCommon-ipkmpaqedk6m','2885c300-4c17-4955-be9a-a45c695b8f4f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2304,'46cb1dc4-df74-42a7-8409-cd40155f23db','8eb82519-d6ab-4b12-9ad2-5082500d9f73','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba','8eb82519-d6ab-4b12-9ad2-5082500d9f73','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2305,'a65c4a43-00e2-49f0-8cbb-1c7842074c3b','2885c300-4c17-4955-be9a-a45c695b8f4f','2026-06-15 07:52:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RabbitMQServiceBase-opilaa5ancae-ContainersCommon-ipkmpaqedk6m','2885c300-4c17-4955-be9a-a45c695b8f4f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2306,'54f2ff10-afd5-4b66-8a6f-755f7d5eb128','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:26',NULL,'CREATE','COMPLETE','MySQLClient','ae874a37-0262-4b39-ba1f-ec3949190d1e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2307,'e6c19909-b96c-4e8a-b0a1-98e3556769a6','5dfa22ba-18de-4c66-8520-dde542b58f6f','2026-06-15 07:52:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-37-55rpmcanlr2w','5dfa22ba-18de-4c66-8520-dde542b58f6f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2308,'7ff5aa51-405d-4f8d-8643-b0ae2c40f736','8eb82519-d6ab-4b12-9ad2-5082500d9f73','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba-RoleParametersValue-7mbehq2q5i2s','state changed','OS::Heat::Value',NULL,1387),(2309,'4c44c424-445a-488b-9053-9de730e789e9','8eb82519-d6ab-4b12-9ad2-5082500d9f73','2026-06-15 07:52:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba-RoleParametersValue-7mbehq2q5i2s','state changed','OS::Heat::Value',NULL,1387),(2310,'a2d0f773-fc66-4180-a464-89f7fc62c1be','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','50','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf','state changed','OS::TripleO::Services::SwiftProxy',NULL,1388),(2311,'3b3fa953-db5e-4477-92d0-c8310787df5e','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2312,'3c0ec188-48d6-4cd7-8221-18d85d1ffc12','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-RoleParametersValue-avthxzptisrp','state changed','OS::Heat::Value',NULL,1389),(2313,'5734f792-0228-4fc2-8b2a-dfe4aa366b25','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-RoleParametersValue-avthxzptisrp','state changed','OS::Heat::Value',NULL,1389),(2314,'70a9c8c3-7089-4032-9530-2105b8236f24','dc5df47e-5630-40a5-9b7b-b4042f71626c','2026-06-15 07:52:27',NULL,'CREATE','COMPLETE','ContainersCommon','9ad148bf-4235-496b-ad4a-761a0744c5b0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2315,'ba5d7133-6dd9-4256-b4b3-d76dccb88501','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:27',NULL,'CREATE','COMPLETE','37','5dfa22ba-18de-4c66-8520-dde542b58f6f','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1336),(2316,'bc7cdd95-c823-42ca-836c-adff1440dff6','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','2026-06-15 07:52:27',NULL,'CREATE','COMPLETE','ContainersCommon','488bef5a-2d21-4a19-a1fd-fd4b91befbd8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2317,'2de89951-da7d-4da8-a050-468eb5eb8dc8','2ee252e7-a0ef-4a75-b299-856ffeec7db4','2026-06-15 07:52:27',NULL,'CREATE','COMPLETE','ContainersCommon','2885c300-4c17-4955-be9a-a45c695b8f4f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2318,'f261fb5b-f751-4338-a337-04eed6425970','2ee252e7-a0ef-4a75-b299-856ffeec7db4','2026-06-15 07:52:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph-RabbitMQServiceBase-opilaa5ancae','2ee252e7-a0ef-4a75-b299-856ffeec7db4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2319,'e2d25c85-f1fb-4f62-97c2-bf06a61ead67','8eb82519-d6ab-4b12-9ad2-5082500d9f73','2026-06-15 07:52:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba-ContainersCommon-t23x46ensxfz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2320,'9d7c35a3-c9af-4892-8e2e-96e24b2ed6df','c0237340-8d88-4bb6-bf3f-f66098368c6c','2026-06-15 07:52:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba-ContainersCommon-t23x46ensxfz','c0237340-8d88-4bb6-bf3f-f66098368c6c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2321,'63d378d9-724b-4c68-a439-8cb0cea5b0af','c0237340-8d88-4bb6-bf3f-f66098368c6c','2026-06-15 07:52:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba-ContainersCommon-t23x46ensxfz','c0237340-8d88-4bb6-bf3f-f66098368c6c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2322,'7a9fc1f2-a6df-4922-a395-0acab1039980','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:28',NULL,'CREATE','IN_PROGRESS','41','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-41-tgmmn2ky24yn','state changed','OS::TripleO::Services::Pacemaker',NULL,1399),(2323,'87549153-8ce6-413a-8687-10a018be6c6f','af784f11-c9d9-4620-b771-8ca967d088da','2026-06-15 07:52:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-41-tgmmn2ky24yn','af784f11-c9d9-4620-b771-8ca967d088da','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2324,'a073347c-5b4d-4a57-9fd5-77dda8af06f2','af784f11-c9d9-4620-b771-8ca967d088da','2026-06-15 07:52:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-41-tgmmn2ky24yn','af784f11-c9d9-4620-b771-8ca967d088da','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2325,'08085b50-225f-4be5-a4c5-9950072afa93','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:28',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-SwiftBase-wcmlal7cpwmu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1400),(2326,'f6fc5209-301d-4de9-8704-f0bd4b07e665','ee8b16f9-ac6b-40a7-8dfe-4f4d1d6a4a78','2026-06-15 07:52:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-SwiftBase-wcmlal7cpwmu','ee8b16f9-ac6b-40a7-8dfe-4f4d1d6a4a78','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2327,'dd03d5df-3105-4021-b5c3-6b1fbcad4392','ee8b16f9-ac6b-40a7-8dfe-4f4d1d6a4a78','2026-06-15 07:52:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-SwiftBase-wcmlal7cpwmu','ee8b16f9-ac6b-40a7-8dfe-4f4d1d6a4a78','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2328,'d5716c74-836e-40b6-83d2-27553e921569','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','2026-06-15 07:52:28',NULL,'CREATE','COMPLETE','RabbitMQServiceBase','2ee252e7-a0ef-4a75-b299-856ffeec7db4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1376),(2329,'b2d6a727-1e98-44f3-93e6-567297ec8fdc','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','2026-06-15 07:52:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f-RabbitmqBase-eascmyhcewph','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2330,'06187e6d-c355-4e49-a536-de82d0306a51','8eb82519-d6ab-4b12-9ad2-5082500d9f73','2026-06-15 07:52:28',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba-SwiftBase-45krmmzekue7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1401),(2331,'4d3c1a49-1d9f-471e-a67c-15a292522d22','57a8d6cf-2901-4fe7-8b17-296e93a0bddc','2026-06-15 07:52:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba-SwiftBase-45krmmzekue7','57a8d6cf-2901-4fe7-8b17-296e93a0bddc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2332,'314093f4-314a-493f-9225-f3a1a10ea547','8eb82519-d6ab-4b12-9ad2-5082500d9f73','2026-06-15 07:52:28',NULL,'CREATE','COMPLETE','ContainersCommon','c0237340-8d88-4bb6-bf3f-f66098368c6c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2333,'49029195-8697-4802-9d47-778088976fc9','57a8d6cf-2901-4fe7-8b17-296e93a0bddc','2026-06-15 07:52:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba-SwiftBase-45krmmzekue7','57a8d6cf-2901-4fe7-8b17-296e93a0bddc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2334,'e336c6fa-8cad-401c-851c-653d22856cca','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:29',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-TLSProxyBase-r7e3ckucptrn','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1402),(2335,'9f4b56a7-e05a-4c45-a29d-8b5d80b323ba','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:29',NULL,'CREATE','COMPLETE','41','af784f11-c9d9-4620-b771-8ca967d088da','state changed','OS::TripleO::Services::Pacemaker',NULL,1399),(2336,'b797f786-111d-4f5e-a34a-9f25b5555430','dc5df47e-5630-40a5-9b7b-b4042f71626c','2026-06-15 07:52:29',NULL,'CREATE','COMPLETE','RabbitmqBase','312b3fdb-e6bd-4fa7-a4f2-58db4469b625','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1370),(2337,'7a6b6ac5-c3d8-4e4d-b80d-fbb4828ba8d0','dc5df47e-5630-40a5-9b7b-b4042f71626c','2026-06-15 07:52:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-43-qlhw25s4k27f','dc5df47e-5630-40a5-9b7b-b4042f71626c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2338,'6a5f3d95-83db-44b6-8cc3-314dc6b23151','4edd248c-f305-4442-9a42-e36753dbb6fa','2026-06-15 07:52:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-TLSProxyBase-r7e3ckucptrn','4edd248c-f305-4442-9a42-e36753dbb6fa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2339,'c4c35924-244a-4782-8b9b-4c1b82d932f6','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:29',NULL,'CREATE','COMPLETE','SwiftBase','ee8b16f9-ac6b-40a7-8dfe-4f4d1d6a4a78','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1400),(2340,'ddac418e-f41a-45c4-a64b-042c7e78faee','4edd248c-f305-4442-9a42-e36753dbb6fa','2026-06-15 07:52:29',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-TLSProxyBase-r7e3ckucptrn-ApacheNetworks-vl7qkfgwngn2','state changed','OS::Heat::Value',NULL,1404),(2341,'bd45058a-45e8-4ef0-937f-b22ccd8643de','4edd248c-f305-4442-9a42-e36753dbb6fa','2026-06-15 07:52:29',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-TLSProxyBase-r7e3ckucptrn-ApacheNetworks-vl7qkfgwngn2','state changed','OS::Heat::Value',NULL,1404),(2342,'06468509-6661-4f83-ae63-65819e6f5506','4edd248c-f305-4442-9a42-e36753dbb6fa','2026-06-15 07:52:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-TLSProxyBase-r7e3ckucptrn','4edd248c-f305-4442-9a42-e36753dbb6fa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2343,'fefff8d2-ee92-45de-abb2-4622bdcf3862','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:29',NULL,'CREATE','IN_PROGRESS','45','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-45-w7ja57pmtlhb','state changed','OS::TripleO::Services::Podman',NULL,1405),(2344,'9b797ddd-3fe6-44b1-b93b-89fdde988e9d','7682a26d-64c7-4d44-8036-97823fc91a9d','2026-06-15 07:52:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-45-w7ja57pmtlhb','7682a26d-64c7-4d44-8036-97823fc91a9d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2345,'dbc7c323-2df1-4ae0-9679-e5d75b5b8db0','7682a26d-64c7-4d44-8036-97823fc91a9d','2026-06-15 07:52:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-45-w7ja57pmtlhb','7682a26d-64c7-4d44-8036-97823fc91a9d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2346,'2dde9499-d446-49c0-aed2-4d7daa6f1cea','8eb82519-d6ab-4b12-9ad2-5082500d9f73','2026-06-15 07:52:29',NULL,'CREATE','COMPLETE','SwiftBase','57a8d6cf-2901-4fe7-8b17-296e93a0bddc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1401),(2347,'10f6880e-7ab6-4f96-ab26-122db1b913d6','8eb82519-d6ab-4b12-9ad2-5082500d9f73','2026-06-15 07:52:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-52-gwiwjgqhi5ba','8eb82519-d6ab-4b12-9ad2-5082500d9f73','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2348,'8f8bb207-964f-4e1d-ac9f-042db2aaab68','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:30',NULL,'CREATE','COMPLETE','43','dc5df47e-5630-40a5-9b7b-b4042f71626c','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1368),(2349,'548b31c4-6909-41f8-a9e6-a6ed1af8d01b','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:30',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-ContainersCommon-ukpcmsjg5byz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2350,'e4380e63-60c8-49c6-8665-381b5d3601b4','f0075546-061d-48ce-9e38-6a8ff0da08b9','2026-06-15 07:52:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-ContainersCommon-ukpcmsjg5byz','f0075546-061d-48ce-9e38-6a8ff0da08b9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2351,'28857848-fc5a-46f2-b53f-fce27c64d9a6','f0075546-061d-48ce-9e38-6a8ff0da08b9','2026-06-15 07:52:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf-ContainersCommon-ukpcmsjg5byz','f0075546-061d-48ce-9e38-6a8ff0da08b9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2352,'7e879c8c-764c-4abe-bf54-78a27ec41843','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:30',NULL,'CREATE','COMPLETE','TLSProxyBase','4edd248c-f305-4442-9a42-e36753dbb6fa','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1402),(2353,'6be18414-089b-4f7d-b0cd-02950eb3198d','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:30',NULL,'CREATE','IN_PROGRESS','47','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-47-pedaohoishoc','state changed','OS::TripleO::Services::Rsyslog',NULL,1415),(2354,'b21a7eaa-c035-473a-ae9f-532841699ccc','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:30',NULL,'CREATE','COMPLETE','45','7682a26d-64c7-4d44-8036-97823fc91a9d','state changed','OS::TripleO::Services::Podman',NULL,1405),(2355,'77cf0e0f-562c-446a-aaac-83ce935b2495','8f70905f-69d5-469c-9179-f5c1dc0f09b8','2026-06-15 07:52:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-47-pedaohoishoc','8f70905f-69d5-469c-9179-f5c1dc0f09b8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2356,'59b6d1f3-bc25-4796-8810-228a2cb55cda','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:30',NULL,'CREATE','COMPLETE','52','8eb82519-d6ab-4b12-9ad2-5082500d9f73','state changed','OS::TripleO::Services::SwiftStorage',NULL,1382),(2357,'58aed85e-4398-4983-a432-3189e8af09f7','8f70905f-69d5-469c-9179-f5c1dc0f09b8','2026-06-15 07:52:30',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-47-pedaohoishoc-ContainersCommon-yd5dts32w6aj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2358,'a8279ec0-c15c-49af-998c-ccf38ea2118e','ff392ffc-513f-4de2-a564-a1d78c6760aa','2026-06-15 07:52:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-47-pedaohoishoc-ContainersCommon-yd5dts32w6aj','ff392ffc-513f-4de2-a564-a1d78c6760aa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2359,'79bc43f4-7f73-45cf-a792-dbd9988f3d2a','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:31',NULL,'CREATE','IN_PROGRESS','49','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-49-wgd4ahetjm6f','state changed','OS::TripleO::Services::Sshd',NULL,1421),(2360,'06cde6db-834a-4741-9348-3983118b7356','ff392ffc-513f-4de2-a564-a1d78c6760aa','2026-06-15 07:52:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-47-pedaohoishoc-ContainersCommon-yd5dts32w6aj','ff392ffc-513f-4de2-a564-a1d78c6760aa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2361,'40593d8a-3a7a-4220-91a0-a9bcce65c81c','f9520401-d2dd-4d46-9e16-95656e86fd63','2026-06-15 07:52:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-49-wgd4ahetjm6f','f9520401-d2dd-4d46-9e16-95656e86fd63','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2362,'17624c90-90cd-455b-a5cb-29197a140290','f9520401-d2dd-4d46-9e16-95656e86fd63','2026-06-15 07:52:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-49-wgd4ahetjm6f','f9520401-d2dd-4d46-9e16-95656e86fd63','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2363,'363a537d-9d04-4c74-b3be-c2e2dfb35500','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:31',NULL,'CREATE','IN_PROGRESS','56','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-56-ukr54rkm5now','state changed','OS::TripleO::Services::TripleoPackages',NULL,1422),(2364,'69acb528-d8bc-490d-806a-162956117326','db2b718c-4735-4d83-ad32-58f10fa29e1e','2026-06-15 07:52:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-56-ukr54rkm5now','db2b718c-4735-4d83-ad32-58f10fa29e1e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2365,'fcb921e0-6316-4c5d-a66a-4fd3e794630b','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:31',NULL,'CREATE','COMPLETE','ContainersCommon','f0075546-061d-48ce-9e38-6a8ff0da08b9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2366,'6c1eba04-499f-4ec5-9c48-ebd7ffcaac15','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','2026-06-15 07:52:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-50-mg6dsztyufwf','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2367,'7ca0b0e1-98e3-419f-8213-0e2097022e66','db2b718c-4735-4d83-ad32-58f10fa29e1e','2026-06-15 07:52:31',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-56-ukr54rkm5now-RoleParametersValue-c27qc5scxuxb','state changed','OS::Heat::Value',NULL,1423),(2368,'074c67ad-8cd4-4167-84dc-84fb8c452c2f','db2b718c-4735-4d83-ad32-58f10fa29e1e','2026-06-15 07:52:31',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-56-ukr54rkm5now-RoleParametersValue-c27qc5scxuxb','state changed','OS::Heat::Value',NULL,1423),(2369,'fdf295d8-e5e4-4b60-bbfb-00bf50b6f73b','8f70905f-69d5-469c-9179-f5c1dc0f09b8','2026-06-15 07:52:31',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-47-pedaohoishoc-RoleParametersValue-vggyikrdqo54','state changed','OS::Heat::Value',NULL,1424),(2370,'d5413345-a0a3-4bf6-b615-6d8a8f40f28b','8f70905f-69d5-469c-9179-f5c1dc0f09b8','2026-06-15 07:52:31',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-47-pedaohoishoc-RoleParametersValue-vggyikrdqo54','state changed','OS::Heat::Value',NULL,1424),(2371,'61f29fcd-b73e-490a-ac14-7fc1bf4cd7bf','8f70905f-69d5-469c-9179-f5c1dc0f09b8','2026-06-15 07:52:32',NULL,'CREATE','COMPLETE','ContainersCommon','ff392ffc-513f-4de2-a564-a1d78c6760aa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2372,'d4ffb6d4-b12b-45ce-92a0-18d988b0aa47','8f70905f-69d5-469c-9179-f5c1dc0f09b8','2026-06-15 07:52:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-47-pedaohoishoc','8f70905f-69d5-469c-9179-f5c1dc0f09b8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2373,'d3d249d7-581f-45c3-8613-6248b8887f83','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:32',NULL,'CREATE','COMPLETE','50','f7cba350-8e00-4216-b88a-8d4d4cd13a3d','state changed','OS::TripleO::Services::SwiftProxy',NULL,1388),(2374,'f56f39cf-f638-47cc-aaf7-8b28f731f845','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:32',NULL,'CREATE','COMPLETE','49','f9520401-d2dd-4d46-9e16-95656e86fd63','state changed','OS::TripleO::Services::Sshd',NULL,1421),(2375,'69fd8596-bf05-4b7d-82f0-dfe23e5fd2e2','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:32',NULL,'CREATE','IN_PROGRESS','53','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-53-lm23xdygdybg','state changed','OS::TripleO::Services::Timesync',NULL,1431),(2376,'fe42a1f3-139d-4f54-8b2f-b19ba482b33d','db2b718c-4735-4d83-ad32-58f10fa29e1e','2026-06-15 07:52:32',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-56-ukr54rkm5now-Podman-7pywqg2uhxq4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1432),(2377,'a1e27e41-5a7f-4c53-9e44-48c60f7a969d','890e494b-bf32-41d0-bc3c-29c9956b940b','2026-06-15 07:52:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-53-lm23xdygdybg','890e494b-bf32-41d0-bc3c-29c9956b940b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2378,'72779870-d9f8-47e3-b707-bb0af95bb8e6','117c7043-ef95-4a2c-b3f2-08f7eb175052','2026-06-15 07:52:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-56-ukr54rkm5now-Podman-7pywqg2uhxq4','117c7043-ef95-4a2c-b3f2-08f7eb175052','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2379,'e6ef789e-22cb-4231-b138-c4151d362aee','890e494b-bf32-41d0-bc3c-29c9956b940b','2026-06-15 07:52:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-53-lm23xdygdybg','890e494b-bf32-41d0-bc3c-29c9956b940b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2380,'14204640-9bb8-4463-9bdb-23f67f9626c5','117c7043-ef95-4a2c-b3f2-08f7eb175052','2026-06-15 07:52:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-56-ukr54rkm5now-Podman-7pywqg2uhxq4','117c7043-ef95-4a2c-b3f2-08f7eb175052','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2381,'22f8b4eb-6530-442a-839f-9140694e725a','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:32',NULL,'CREATE','IN_PROGRESS','54','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-54-l42hkovqliuu','state changed','OS::TripleO::Services::Timezone',NULL,1434),(2382,'b10fb526-e873-4852-8f7b-5a3388a7d538','08ae5680-778d-41ed-bacf-cb437ff57163','2026-06-15 07:52:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-54-l42hkovqliuu','08ae5680-778d-41ed-bacf-cb437ff57163','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2383,'3e5db3e8-f43d-44b1-82a9-5750c58e782e','08ae5680-778d-41ed-bacf-cb437ff57163','2026-06-15 07:52:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-54-l42hkovqliuu','08ae5680-778d-41ed-bacf-cb437ff57163','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2384,'02c4eeb3-61eb-4b59-9e5d-b3ed10bf755a','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:32',NULL,'CREATE','COMPLETE','47','8f70905f-69d5-469c-9179-f5c1dc0f09b8','state changed','OS::TripleO::Services::Rsyslog',NULL,1415),(2385,'9ba3dec6-96e5-4873-a7d6-296e79cebd54','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:33',NULL,'CREATE','IN_PROGRESS','51','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-51-4goe3j5jo6p7','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1438),(2386,'f04920b8-d37e-4815-ba73-62b6388a8cc5','8a1ae196-3409-4eb6-8a58-38214f4dd420','2026-06-15 07:52:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-51-4goe3j5jo6p7','8a1ae196-3409-4eb6-8a58-38214f4dd420','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2387,'b43fdc1f-f0f6-4cf2-a7c8-cadfbf116812','8a1ae196-3409-4eb6-8a58-38214f4dd420','2026-06-15 07:52:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-51-4goe3j5jo6p7-RoleParametersValue-lvwsi2ko5nwf','state changed','OS::Heat::Value',NULL,1439),(2388,'80f2e398-8302-4c63-83d6-dc6991e7b3eb','8a1ae196-3409-4eb6-8a58-38214f4dd420','2026-06-15 07:52:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-51-4goe3j5jo6p7-RoleParametersValue-lvwsi2ko5nwf','state changed','OS::Heat::Value',NULL,1439),(2389,'5093c26b-aa39-4374-b183-dfe2e80afc5a','8a1ae196-3409-4eb6-8a58-38214f4dd420','2026-06-15 07:52:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-51-4goe3j5jo6p7','8a1ae196-3409-4eb6-8a58-38214f4dd420','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2390,'74aa1174-2bef-4031-a54a-5e1e4dd26579','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:33',NULL,'CREATE','COMPLETE','53','890e494b-bf32-41d0-bc3c-29c9956b940b','state changed','OS::TripleO::Services::Timesync',NULL,1431),(2391,'c025e52d-ac07-4e0f-945b-fce2da5cd65a','db2b718c-4735-4d83-ad32-58f10fa29e1e','2026-06-15 07:52:33',NULL,'CREATE','COMPLETE','Podman','117c7043-ef95-4a2c-b3f2-08f7eb175052','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1432),(2392,'ebba6126-7c9d-4d17-b224-d57071c3c91f','db2b718c-4735-4d83-ad32-58f10fa29e1e','2026-06-15 07:52:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-56-ukr54rkm5now','db2b718c-4735-4d83-ad32-58f10fa29e1e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2393,'f96cb97f-be31-4a53-8bab-3f8c4765e266','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:33',NULL,'CREATE','COMPLETE','54','08ae5680-778d-41ed-bacf-cb437ff57163','state changed','OS::TripleO::Services::Timezone',NULL,1434),(2394,'035f2b3c-fa63-41fe-b1c7-9cc3e326031d','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:33',NULL,'CREATE','IN_PROGRESS','57','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-57-y6ecg6nvidqe','state changed','OS::TripleO::Services::Tuned',NULL,1441),(2395,'87563ca5-36b0-468a-98b4-a28e336adfa4','d18d9974-ced8-4c73-ae92-22a062fe40c0','2026-06-15 07:52:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-57-y6ecg6nvidqe','d18d9974-ced8-4c73-ae92-22a062fe40c0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2396,'fd4d49f2-a0fb-48fd-9791-d156e4a3fd09','d18d9974-ced8-4c73-ae92-22a062fe40c0','2026-06-15 07:52:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-57-y6ecg6nvidqe-RoleParametersValue-io4ldamwbsxt','state changed','OS::Heat::Value',NULL,1442),(2397,'e32a9f64-3a9b-43a2-b743-ad971cf073f9','d18d9974-ced8-4c73-ae92-22a062fe40c0','2026-06-15 07:52:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-57-y6ecg6nvidqe-RoleParametersValue-io4ldamwbsxt','state changed','OS::Heat::Value',NULL,1442),(2398,'8aacefba-a8cb-4fae-a4be-f7a6a39af74c','d18d9974-ced8-4c73-ae92-22a062fe40c0','2026-06-15 07:52:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-57-y6ecg6nvidqe','d18d9974-ced8-4c73-ae92-22a062fe40c0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2399,'0371cce2-206a-4d89-bc4b-a8ba436417fd','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:34',NULL,'CREATE','COMPLETE','51','8a1ae196-3409-4eb6-8a58-38214f4dd420','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1438),(2400,'01d3515b-044c-4843-9471-386e4e59f23a','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:34',NULL,'CREATE','COMPLETE','56','db2b718c-4735-4d83-ad32-58f10fa29e1e','state changed','OS::TripleO::Services::TripleoPackages',NULL,1422),(2401,'093d0bf3-9c2f-413a-8975-4d5d51bc5ee7','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:34',NULL,'CREATE','IN_PROGRESS','55','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-55-jvgsmxjguv5n','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1445),(2402,'42791aac-35f4-4ff6-83fe-e92c72eb0de8','01bd7baa-5b27-4821-a3fb-6493160ae371','2026-06-15 07:52:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-55-jvgsmxjguv5n','01bd7baa-5b27-4821-a3fb-6493160ae371','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2403,'9d694ca4-5f63-4da2-9ed4-9352fa62ceef','01bd7baa-5b27-4821-a3fb-6493160ae371','2026-06-15 07:52:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-55-jvgsmxjguv5n-RoleParametersValue-47mzwzp4ymnd','state changed','OS::Heat::Value',NULL,1446),(2404,'0a4c4187-0ebf-4e88-95fd-63edc171e4a1','01bd7baa-5b27-4821-a3fb-6493160ae371','2026-06-15 07:52:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-55-jvgsmxjguv5n-RoleParametersValue-47mzwzp4ymnd','state changed','OS::Heat::Value',NULL,1446),(2405,'aea2389c-18b9-480e-8fa4-e80d34bac2b4','01bd7baa-5b27-4821-a3fb-6493160ae371','2026-06-15 07:52:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn-55-jvgsmxjguv5n','01bd7baa-5b27-4821-a3fb-6493160ae371','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2406,'3c131913-d1c5-4c50-adf2-9ebc7a699c54','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:34',NULL,'CREATE','COMPLETE','57','d18d9974-ced8-4c73-ae92-22a062fe40c0','state changed','OS::TripleO::Services::Tuned',NULL,1441),(2407,'b0a17ada-ae1c-4a19-93df-ab50be8538c8','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:35',NULL,'CREATE','COMPLETE','55','01bd7baa-5b27-4821-a3fb-6493160ae371','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1445),(2408,'0e27eee3-1262-4986-a6ef-a6e52547a28a','dca2769f-7b59-42dc-a901-0e9fad841673','2026-06-15 07:52:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceChain-4yi5tkplwmnn','dca2769f-7b59-42dc-a901-0e9fad841673','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2409,'f7a40e72-427d-471c-884d-2de4f4276e4f','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:35',NULL,'CREATE','COMPLETE','ServiceChain','dca2769f-7b59-42dc-a901-0e9fad841673','state changed','OS::Heat::ResourceChain',NULL,88),(2410,'a503901a-7231-47cd-8031-5559cb4045fd','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:37',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-UpgradeTasks-paqg7vejteru','state changed','OS::Heat::Value',NULL,1455),(2411,'e80f08ca-04da-48a2-8fc5-e14c986f922e','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:37',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-PreDeployStepTasks-nnsk67ohyran','state changed','OS::Heat::Value',NULL,1456),(2412,'78ae75d1-8a0e-4cf5-9199-81712bb7a0c9','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:37',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-UpgradeTasks-paqg7vejteru','state changed','OS::Heat::Value',NULL,1455),(2413,'11b747f1-6276-44b7-8c09-3daf913c652a','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:37',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-PreDeployStepTasks-nnsk67ohyran','state changed','OS::Heat::Value',NULL,1456),(2414,'1f63d72b-be1d-4acd-8028-f6b2e074c24a','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:37',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceServerMetadataHook-x57f3psjak4c','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,1457),(2415,'b96cdf3f-f3fd-4ce5-b5b2-9755125901d0','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:37',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ControllerServiceChain-3mxwxvzexbje-FirewallRules-4vg5uinwgbb5','state changed','OS::Heat::Value',NULL,1458),(2416,'8e7985d1-11e2-4f7b-8d56-298db250d542','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:38',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ControllerServiceChain-3mxwxvzexbje-DockerConfigScripts-sermhfy7v6kj','state changed','OS::Heat::Value',NULL,1459),(2417,'6a0e2c21-52a6-4234-8218-e7e3b69ce841','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:38',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ControllerServiceChain-3mxwxvzexbje-DockerConfigScripts-sermhfy7v6kj','state changed','OS::Heat::Value',NULL,1459),(2418,'fd1f7fb3-ebbb-41eb-b6ed-4d0990f3aac9','7fcea028-5296-434d-bb3b-51286a222c39','2026-06-15 07:52:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceServerMetadataHook-x57f3psjak4c','7fcea028-5296-434d-bb3b-51286a222c39','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2419,'1bcaa959-e0cd-443e-a9f7-7803b37cb7be','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:38',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ControllerServiceChain-3mxwxvzexbje-FirewallRules-4vg5uinwgbb5','state changed','OS::Heat::Value',NULL,1458),(2420,'ea08a937-aa0f-4882-89f4-fe3f7c46858b','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:38',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-IpaRegistrationTasks-hruoe2mraurl','state changed','OS::Heat::Value',NULL,1460),(2421,'2730b89a-65ef-4dc9-ab76-6373144bd6f6','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:38',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-IpaRegistrationTasks-hruoe2mraurl','state changed','OS::Heat::Value',NULL,1460),(2422,'1fd5e86a-f830-4fd1-a3c1-8f918fb48590','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:38',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-PostUpgradeTasks-vewng33ye2vj','state changed','OS::Heat::Value',NULL,1461),(2423,'1dc9e085-2138-43f3-a283-d0d9ff52a67d','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:38',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-PostUpgradeTasks-vewng33ye2vj','state changed','OS::Heat::Value',NULL,1461),(2424,'56a7733b-6e01-4c04-9736-2e9b18c81863','7fcea028-5296-434d-bb3b-51286a222c39','2026-06-15 07:52:38',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceServerMetadataHook-x57f3psjak4c-IncomingMetadataSettings-2rxb65xtgzp5','state changed','OS::Heat::Value',NULL,1462),(2425,'23114a74-0c6c-4456-969a-19eb3ff24e1a','7fcea028-5296-434d-bb3b-51286a222c39','2026-06-15 07:52:38',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceServerMetadataHook-x57f3psjak4c-IncomingMetadataSettings-2rxb65xtgzp5','state changed','OS::Heat::Value',NULL,1462),(2426,'64952c4a-25cb-40f6-abb0-2f7b099ff722','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:38',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ControllerServiceChain-3mxwxvzexbje-GlobalConfigSettings-gfqbuz3336l7','state changed','OS::Heat::Value',NULL,1463),(2427,'c1a8a543-c073-419a-aa5b-30be641f47ad','7fcea028-5296-434d-bb3b-51286a222c39','2026-06-15 07:52:38',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceServerMetadataHook-x57f3psjak4c-IndividualServices-qmbleyzg7ti4','state changed','OS::Heat::Value',NULL,1465),(2428,'36331108-bd9a-4345-ae6a-244324d374ef','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:38',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-PuppetConfig-gbxmwzfgca3r','state changed','OS::Heat::Value',NULL,1466),(2429,'124ecf24-2ee0-4aa0-ac93-419cdbb3defb','7fcea028-5296-434d-bb3b-51286a222c39','2026-06-15 07:52:38',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceServerMetadataHook-x57f3psjak4c-IndividualServices-qmbleyzg7ti4','state changed','OS::Heat::Value',NULL,1465),(2430,'3e1c0689-3386-4038-9778-5d172cdff466','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-PuppetConfig-gbxmwzfgca3r','state changed','OS::Heat::Value',NULL,1466),(2431,'c4019355-fbb2-4f1e-a086-966aff50eac0','7fcea028-5296-434d-bb3b-51286a222c39','2026-06-15 07:52:39',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceServerMetadataHook-x57f3psjak4c-CompactServices-zdmkffrjxeag','state changed','OS::Heat::Value',NULL,1467),(2432,'98be8691-d303-440a-8e5b-e2ea91689b20','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ControllerServiceChain-3mxwxvzexbje-GlobalConfigSettings-gfqbuz3336l7','state changed','OS::Heat::Value',NULL,1463),(2433,'2314fa5a-a9cc-4d06-bef6-e75134c71565','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-UpdateTasks-vy6t7zyeccyn','state changed','OS::Heat::Value',NULL,1468),(2434,'a81a909e-4250-4107-b2f4-f54c2c86d113','7fcea028-5296-434d-bb3b-51286a222c39','2026-06-15 07:52:39',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceServerMetadataHook-x57f3psjak4c-CompactServices-zdmkffrjxeag','state changed','OS::Heat::Value',NULL,1467),(2435,'349815db-0e98-4fa6-a18e-464316a48985','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-UpdateTasks-vy6t7zyeccyn','state changed','OS::Heat::Value',NULL,1468),(2436,'7a9f68f9-24ee-4642-b5d5-ee382fc650d3','7fcea028-5296-434d-bb3b-51286a222c39','2026-06-15 07:52:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceServerMetadataHook-x57f3psjak4c','7fcea028-5296-434d-bb3b-51286a222c39','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2437,'757fad95-344e-4bc8-b5b9-ec61f4531096','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','7fcea028-5296-434d-bb3b-51286a222c39','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,1457),(2438,'e062cfbf-0a24-4791-9b8e-b09c3e8bca0c','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-DeployStepsTasks-kulxmb42svre','state changed','OS::Heat::Value',NULL,1469),(2439,'c45e2652-557b-449d-b4e6-e8c722b292de','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-DeployStepsTasks-kulxmb42svre','state changed','OS::Heat::Value',NULL,1469),(2440,'3848804d-b6e2-4b64-9563-11ed4baf1385','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-PuppetStepConfig-kffb6lbkuoug','state changed','OS::Heat::Value',NULL,1470),(2441,'c0c7a02f-ff2d-4ec3-80e9-c69ce0f35ffb','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-PuppetStepConfig-kffb6lbkuoug','state changed','OS::Heat::Value',NULL,1470),(2442,'5b580c0f-9de4-405a-9a70-2a131ba0694a','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:39',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-UpgradeBatchTasks-y65izkgydcpf','state changed','OS::Heat::Value',NULL,1471),(2443,'84ef7333-0c0a-4aa5-a913-fb695836d0e6','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:40',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-DockerPuppetTasks-ds7qbfd3tjt2','state changed','OS::Heat::Value',NULL,1472),(2444,'7ca706bf-aed9-43cc-819e-0b1713208121','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:40',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-DockerPuppetTasks-ds7qbfd3tjt2','state changed','OS::Heat::Value',NULL,1472),(2445,'5f53f3d9-53bc-4e05-94c5-bd2f85b18933','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:40',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-UpgradeBatchTasks-y65izkgydcpf','state changed','OS::Heat::Value',NULL,1471),(2446,'20f5cb2a-cf7d-4045-a8f4-a4611d29e49e','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:40',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ExternalUpdateTasks-5rsmcdd3qvfc','state changed','OS::Heat::Value',NULL,1473),(2447,'225c7f43-d1ff-435a-b528-c9d8df76ece0','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:40',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ExternalUpdateTasks-5rsmcdd3qvfc','state changed','OS::Heat::Value',NULL,1473),(2448,'e08a0ab5-8ba2-4c03-b35c-7b637fe83905','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:40',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ContainerPuppetTasks-kpoytyn5g6ra','state changed','OS::Heat::Value',NULL,1474),(2449,'e9ed4ed3-54ff-4f7e-ada9-27dc9c63eae1','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:40',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ContainerPuppetTasks-kpoytyn5g6ra','state changed','OS::Heat::Value',NULL,1474),(2450,'1b5c945e-b77f-40ae-b6b2-da59fbe078cf','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:40',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-HostPrepTasks-d2v4er2uowdd','state changed','OS::Heat::Value',NULL,1475),(2451,'cf274904-f109-4e8a-a3d8-1ae3eff7d86f','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-PreUpgradeRollingTasks-clteukppi5qg','state changed','OS::Heat::Value',NULL,1476),(2452,'43bf639f-3c67-47e3-b206-ca2c857edc15','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-PreUpgradeRollingTasks-clteukppi5qg','state changed','OS::Heat::Value',NULL,1476),(2453,'3141defc-9bdd-457d-a787-f5157be39834','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-HostPrepTasks-d2v4er2uowdd','state changed','OS::Heat::Value',NULL,1475),(2454,'05cc9684-d601-43b0-93d8-8a99b8cfbaaf','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-PostUpdateTasks-a5vzx2ox5l6g','state changed','OS::Heat::Value',NULL,1477),(2455,'3d9e2253-9a4b-4a6d-88f6-92af1a5d499c','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-PostUpdateTasks-a5vzx2ox5l6g','state changed','OS::Heat::Value',NULL,1477),(2456,'d5469cdd-1eb5-4255-a9f7-3c7b5f160961','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-DockerConfig-rdvztfl6qkko','state changed','OS::Heat::Value',NULL,1478),(2457,'27370482-62eb-461b-868e-c7faa72536f2','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-DockerConfig-rdvztfl6qkko','state changed','OS::Heat::Value',NULL,1478),(2458,'4ecaabaa-8c08-42db-9708-3e0467a713b9','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-HostFirewallTasks-twd6e5hzdpud','state changed','OS::Heat::Value',NULL,1479),(2459,'cd53f1a1-9c4c-402f-a897-a873c8bb8feb','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-HostFirewallTasks-twd6e5hzdpud','state changed','OS::Heat::Value',NULL,1479),(2460,'4836400d-9021-45ea-a761-e8998da25d64','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceNames-bsnoae2nky7z','state changed','OS::Heat::Value',NULL,1480),(2461,'46edd67f-1d9c-488d-96f4-6a5c76a2bf5d','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:41',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceNames-bsnoae2nky7z','state changed','OS::Heat::Value',NULL,1480),(2462,'907fe8f3-d6ea-4cfe-8866-93119eca5d88','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:42',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-KollaConfig-5mwhllzqws7x','state changed','OS::Heat::Value',NULL,1481),(2463,'f6eefc4b-2612-4f45-901d-4267b79ef7bb','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:42',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-KollaConfig-5mwhllzqws7x','state changed','OS::Heat::Value',NULL,1481),(2464,'4ac58db2-890d-4441-abd9-4e1a54773caf','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:42',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ControllerServiceChain-3mxwxvzexbje-FirewallFrontendRules-miyp74px5fuq','state changed','OS::Heat::Value',NULL,1482),(2465,'973fd239-192f-4338-a6e2-5f235e5dfc42','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:42',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ExternalDeployTasks-o32kih5ps4fi','state changed','OS::Heat::Value',NULL,1483),(2466,'c9667598-bc95-4256-8023-c68e20dac375','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:42',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ControllerServiceChain-3mxwxvzexbje-FirewallFrontendRules-miyp74px5fuq','state changed','OS::Heat::Value',NULL,1482),(2467,'6f9b0069-3447-4d78-82ed-5ea8e13d3e2c','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:42',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ScaleTasks-sd36mzdogzl5','state changed','OS::Heat::Value',NULL,1484),(2468,'dbc78b1b-9cbb-4d90-b9ed-c3f2f7bd8dea','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:42',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ScaleTasks-sd36mzdogzl5','state changed','OS::Heat::Value',NULL,1484),(2469,'407be17e-535c-4df4-89eb-21aad85c3c70','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:42',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ExternalDeployTasks-o32kih5ps4fi','state changed','OS::Heat::Value',NULL,1483),(2470,'04da381b-05c2-4d35-b7a0-7d0bf1509550','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:43',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-3mxwxvzexbje-KeystoneResourcesConfigs-dbpbr2xjgxyn','state changed','OS::Heat::Value',NULL,1485),(2471,'d9088efd-c3f4-4813-89a9-783a865963b2','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:43',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-3mxwxvzexbje-KeystoneResourcesConfigs-dbpbr2xjgxyn','state changed','OS::Heat::Value',NULL,1485),(2472,'e64026a6-55f1-4d50-bbf7-d1ef45bef896','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:43',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-MonitoringSubscriptionsConfig-vfc2bvuwmgec','state changed','OS::Heat::Value',NULL,1486),(2473,'61c50dac-3fd5-46b0-9b72-1ac768e07442','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:43',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-3mxwxvzexbje-MonitoringSubscriptionsConfig-vfc2bvuwmgec','state changed','OS::Heat::Value',NULL,1486),(2474,'c33aaac9-8e54-4c8c-b26f-af76a005657c','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:43',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceConfigSettings-yzs7danebyxh','state changed','OS::Heat::Value',NULL,1487),(2475,'5516501d-8b1c-458c-9ac9-d80338ddf9f2','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:43',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ExternalUpgradeTasks-3lgx7uey3o3w','state changed','OS::Heat::Value',NULL,1488),(2476,'a73138ba-2580-4df1-a7e5-5088dada43b0','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:43',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ExternalUpgradeTasks-3lgx7uey3o3w','state changed','OS::Heat::Value',NULL,1488),(2477,'e03c6a48-b38f-4645-b9a2-3f19d97622c1','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:43',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ControllerServiceChain-3mxwxvzexbje-ServiceConfigSettings-yzs7danebyxh','state changed','OS::Heat::Value',NULL,1487),(2478,'e8fd515c-b32b-47f3-b2be-8a512d18e424','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:43',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ExternalPostDeployTasks-dnq2evtiod62','state changed','OS::Heat::Value',NULL,1489),(2479,'33e46c32-9bca-49a2-8d73-58b11eb5add6','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:44',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ControllerServiceChain-3mxwxvzexbje-ExternalPostDeployTasks-dnq2evtiod62','state changed','OS::Heat::Value',NULL,1489),(2480,'8d53ce81-4f4b-4cc7-9656-9005cd267567','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:44',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ControllerServiceChain-3mxwxvzexbje-AnsibleGroupVars-dpn5xzfgbgwe','state changed','OS::Heat::Value',NULL,1491),(2481,'b726ef7f-1956-4704-a464-86571003b150','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:44',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ControllerServiceChain-3mxwxvzexbje-AnsibleGroupVars-dpn5xzfgbgwe','state changed','OS::Heat::Value',NULL,1491),(2482,'568906ca-92c8-4cc4-a62b-cc1b06fa6001','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','2026-06-15 07:52:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-3mxwxvzexbje','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2483,'9f8ed50c-cbb9-44a9-9606-81402199f3b5','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:44',NULL,'CREATE','COMPLETE','ControllerServiceChain','e88aadae-5b3e-42d2-9d2d-d730fc44f2d6','state changed','OS::TripleO::ControllerServices',NULL,80),(2484,'8e32cac0-da74-4f9b-bd3b-678496d3133e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:46',NULL,'CREATE','IN_PROGRESS','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-dysdtpplyrlr','state changed','OS::Heat::Value',NULL,1527),(2485,'a3f1e0fe-6e6f-4b94-8864-4488e0a711e2','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:46',NULL,'CREATE','COMPLETE','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-dysdtpplyrlr','state changed','OS::Heat::Value',NULL,1527),(2486,'5b0020f7-5766-4c4c-a4fa-1edf50af1211','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:46',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-r6dceak2zkmb','state changed','OS::Heat::Value',NULL,1528),(2487,'a41f9560-3cb5-4a08-9870-bd05fa466348','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:46',NULL,'CREATE','COMPLETE','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-r6dceak2zkmb','state changed','OS::Heat::Value',NULL,1528),(2488,'9b4b835c-cbb6-489d-93e6-d4158f64a06d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:46',NULL,'CREATE','IN_PROGRESS','GlobalConfig','overcloud-GlobalConfig-xncruqy7y3hx','state changed','OS::Heat::Value',NULL,1529),(2489,'cd937450-e34f-4922-b610-386b80cefe0f','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:46',NULL,'CREATE','COMPLETE','GlobalConfig','overcloud-GlobalConfig-xncruqy7y3hx','state changed','OS::Heat::Value',NULL,1529),(2490,'b4b786e7-aeac-4fe5-aba3-9cebeb5e9918','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:46',NULL,'CREATE','IN_PROGRESS','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-nlfojjzpa6hh','state changed','OS::Heat::Value',NULL,1532),(2491,'77cfb4e3-1769-418c-a59f-2cdfdeac4ead','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-tzqdhilzyxqj','state changed','OS::Heat::Value',NULL,1531),(2492,'435ee353-b15e-4273-9af4-86bc53f826d8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-nlfojjzpa6hh','state changed','OS::Heat::Value',NULL,1532),(2493,'d828c820-9695-46f0-ab70-5ce832e29520','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-tzqdhilzyxqj','state changed','OS::Heat::Value',NULL,1531),(2494,'7cca5bf3-46b8-4ab6-a8bf-3960a4292a1d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','CellControllerConfigData','overcloud-CellControllerConfigData-xh73jpzsat4q','state changed','OS::Heat::Value',NULL,1534),(2495,'5d94b433-c6ce-4865-86df-e8b1f93a48cb','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','CellControllerConfigData','overcloud-CellControllerConfigData-xh73jpzsat4q','state changed','OS::Heat::Value',NULL,1534),(2496,'3dc553b6-4fef-45a4-a0b2-6efbd5cf7797','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-FirewallFrontendRules-tfuh3a6lkpmo','state changed','OS::Heat::Value',NULL,1535),(2497,'5887c045-7edf-408e-a54a-f10bd0409841','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-FirewallFrontendRules-tfuh3a6lkpmo','state changed','OS::Heat::Value',NULL,1535),(2498,'efbea5cc-7b3e-4177-bc74-6290115dfac3','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-xuabfdhn5nqf','state changed','OS::Heat::Value',NULL,1536),(2499,'97ea6722-e522-4b42-8650-afa1b6d3e439','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-l25sshouswv3','state changed','OS::Heat::Value',NULL,1538),(2500,'35446bf7-556a-4f0e-aac0-383487391de7','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-xuabfdhn5nqf','state changed','OS::Heat::Value',NULL,1536),(2501,'c068c636-8fb6-425b-b0a2-933173cb6841','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','CellControllerGroupVars','overcloud-CellControllerGroupVars-xylvu7x2kxcv','state changed','OS::Heat::Value',NULL,1537),(2502,'f6c57923-287f-47a5-8b5c-73452fdd2f62','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-l25sshouswv3','state changed','OS::Heat::Value',NULL,1538),(2503,'7e5b4506-3143-42fe-91ef-a9b9f8ccb73f','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','CellControllerGroupVars','overcloud-CellControllerGroupVars-xylvu7x2kxcv','state changed','OS::Heat::Value',NULL,1537),(2504,'c73cbeb8-d6ac-48c0-8bff-4829f3c1dec4','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-h3ldxp2yuhew','state changed','OS::Heat::Value',NULL,1541),(2505,'4972651d-a298-4d37-a467-38d6186cd36d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-qejls57anp4p','state changed','OS::Heat::Value',NULL,1542),(2506,'22a1f7e3-a4d7-45aa-926a-bbd499626c34','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-qejls57anp4p','state changed','OS::Heat::Value',NULL,1542),(2507,'2d529ee3-cbb1-427e-856d-63b8de8c0f78','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','NetworkerGroupVars','overcloud-NetworkerGroupVars-fpycs5x555br','state changed','OS::Heat::Value',NULL,1539),(2508,'7672e3f5-f608-4ad9-a1ed-3c6261c50b4b','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','ComputeGroupVars','overcloud-ComputeGroupVars-32fvmtrqc2si','state changed','OS::Heat::Value',NULL,1544),(2509,'a018cab6-f5aa-4be4-b1e1-2537b3b7cefe','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-h3ldxp2yuhew','state changed','OS::Heat::Value',NULL,1541),(2510,'9296f52c-2b12-4c31-bd6d-2ab5e7f3fc06','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','ComputeGroupVars','overcloud-ComputeGroupVars-32fvmtrqc2si','state changed','OS::Heat::Value',NULL,1544),(2511,'10567ac0-7336-4554-ac58-4504b7dffeb3','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','IN_PROGRESS','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-3jn6fnlrsaxv','state changed','OS::Heat::Value',NULL,1545),(2512,'e24be3dd-2ee2-436d-a4c1-cc6b78b59cb6','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:47',NULL,'CREATE','COMPLETE','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-3jn6fnlrsaxv','state changed','OS::Heat::Value',NULL,1545),(2513,'25bbccf2-535f-4267-bd66-294871db0967','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','IN_PROGRESS','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-p6ss6wvivm5f','state changed','OS::Heat::Value',NULL,1547),(2514,'ff45ffb5-261d-4bac-8809-4dc34786be22','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','COMPLETE','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-p6ss6wvivm5f','state changed','OS::Heat::Value',NULL,1547),(2515,'6b2b06d0-158a-48fd-adc3-93c4ad616e10','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','IN_PROGRESS','ComputeConfigData','overcloud-ComputeConfigData-arwr7t3dulig','state changed','OS::Heat::Value',NULL,1549),(2516,'73e2658b-5938-4792-8e6e-714b38d1b64e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','IN_PROGRESS','ControllerGroupVars','overcloud-ControllerGroupVars-uixnnw3zcp5t','state changed','OS::Heat::Value',NULL,1543),(2517,'488baca7-e2be-45e8-ad67-0ff5b29260f8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','COMPLETE','ComputeConfigData','overcloud-ComputeConfigData-arwr7t3dulig','state changed','OS::Heat::Value',NULL,1549),(2518,'61f67bd8-0198-4a18-882e-4a9f2d6f4895','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','COMPLETE','NetworkerGroupVars','overcloud-NetworkerGroupVars-fpycs5x555br','state changed','OS::Heat::Value',NULL,1539),(2519,'4a29e79c-5f85-4d12-b7ae-bc9cf621cfcc','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','IN_PROGRESS','CephStorageGroupVars','overcloud-CephStorageGroupVars-xzkq6be3nd2j','state changed','OS::Heat::Value',NULL,1550),(2520,'a7ff0502-283c-456a-925a-a8e054c458a0','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','IN_PROGRESS','ControllerServiceNames','overcloud-ControllerServiceNames-35w4pwxygj27','state changed','OS::Heat::Value',NULL,1551),(2521,'2f5d8ace-1f3e-42fb-8c44-bcc4aefbd184','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','COMPLETE','ControllerServiceNames','overcloud-ControllerServiceNames-35w4pwxygj27','state changed','OS::Heat::Value',NULL,1551),(2522,'6e6ceb17-72ef-4d37-9609-1c08336e130e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','COMPLETE','ControllerGroupVars','overcloud-ControllerGroupVars-uixnnw3zcp5t','state changed','OS::Heat::Value',NULL,1543),(2523,'4c27b0d2-53e2-4baa-9bb4-9998bad3f123','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','COMPLETE','CephStorageGroupVars','overcloud-CephStorageGroupVars-xzkq6be3nd2j','state changed','OS::Heat::Value',NULL,1550),(2524,'228c6c16-f410-423f-8c6b-ff3713355057','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','IN_PROGRESS','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-ifceepq2tqyw','state changed','OS::Heat::Value',NULL,1552),(2525,'c5c53fcc-2868-4dc4-83bd-b4d7ba1bbfea','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','COMPLETE','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-ifceepq2tqyw','state changed','OS::Heat::Value',NULL,1552),(2526,'972e46b4-b0ec-419f-bb5f-9f19602d0b78','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','IN_PROGRESS','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-ristzr33eesp','state changed','OS::Heat::Value',NULL,1553),(2527,'bc9075f5-a092-4812-abc0-a558b20e6831','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','COMPLETE','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-ristzr33eesp','state changed','OS::Heat::Value',NULL,1553),(2528,'2e599c3f-bd13-4a09-8bc4-c2eaee6e6f30','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','IN_PROGRESS','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-e4zpvbmaeyhj','state changed','OS::Heat::Value',NULL,1555),(2529,'78a04721-84c6-4ba6-91e1-f39886309285','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','COMPLETE','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-e4zpvbmaeyhj','state changed','OS::Heat::Value',NULL,1555),(2530,'84406abc-53d4-4140-9e6c-c4cf4d7e417a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:48',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-n72un4v4v7ig','state changed','OS::Heat::ResourceGroup',NULL,1558),(2531,'03a0ae9a-a280-45a7-ac56-245794627ab7','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','IN_PROGRESS','NetworkerConfigData','overcloud-NetworkerConfigData-z7lvbsvalbkb','state changed','OS::Heat::Value',NULL,1560),(2532,'aa5f1383-8278-46a8-bb9a-2692097b0978','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-lpekwx5znsrs','state changed','OS::Heat::Value',NULL,1562),(2533,'2ae706eb-c4a5-41ad-92a4-d0af5ae89778','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','COMPLETE','NetworkerConfigData','overcloud-NetworkerConfigData-z7lvbsvalbkb','state changed','OS::Heat::Value',NULL,1560),(2534,'862ac08f-cffc-490f-9f6b-a27dbdf128d0','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:49',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig','4d78b488-1049-4329-bf32-1e85126915c2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2535,'e309aa40-6357-4b4e-b23b-e4d85a8c89a6','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','COMPLETE','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-lpekwx5znsrs','state changed','OS::Heat::Value',NULL,1562),(2536,'77b9ead3-6ccc-489d-9703-a56e1fdcaf2d','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:49',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig','4d78b488-1049-4329-bf32-1e85126915c2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2537,'c386fcd5-36ba-4959-958c-25f2f9636d90','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','IN_PROGRESS','CephStorageConfigData','overcloud-CephStorageConfigData-j35qwlzmegmc','state changed','OS::Heat::Value',NULL,1561),(2538,'4d6dd44f-ad6a-4389-8d09-2aba13ff684f','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','COMPLETE','CephStorageConfigData','overcloud-CephStorageConfigData-j35qwlzmegmc','state changed','OS::Heat::Value',NULL,1561),(2539,'4ce5ad8c-5d89-4e60-95e2-39be9a761462','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','IN_PROGRESS','BlockStorageConfigData','overcloud-BlockStorageConfigData-h6ma2e56xlz2','state changed','OS::Heat::Value',NULL,1564),(2540,'ec8972f9-8b3b-4c19-b85e-5c79672cc439','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','COMPLETE','BlockStorageConfigData','overcloud-BlockStorageConfigData-h6ma2e56xlz2','state changed','OS::Heat::Value',NULL,1564),(2541,'93aa9c3f-c71b-4d06-a9a6-d859eaa966a6','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','IN_PROGRESS','ControllerConfigData','overcloud-ControllerConfigData-t2joroabwkve','state changed','OS::Heat::Value',NULL,1566),(2542,'9a04a785-57ef-44d1-af7d-23933b2f6281','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:52:49',NULL,'CREATE','COMPLETE','ControllerConfigData','overcloud-ControllerConfigData-t2joroabwkve','state changed','OS::Heat::Value',NULL,1566),(2543,'3abd472b-dce2-483c-beaf-04f3ae6a9ec6','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:50',NULL,'UPDATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig','4d78b488-1049-4329-bf32-1e85126915c2','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(2544,'03bc37c0-f608-4f16-b199-082ee282fa39','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:50',NULL,'CREATE','IN_PROGRESS','0','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh','state changed','OS::TripleO::Controller',NULL,1567),(2545,'1a83b773-f25e-4439-b4dd-858f6a30f4b9','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:50',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh','e2a48c69-f617-49cb-b89a-efd3e2294e65','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2546,'b63ce15c-a22e-4790-8121-20943c5dca4c','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:50',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-DeploymentActions-xrjh2gz6qx65','state changed','OS::Heat::Value',NULL,1568),(2547,'505f2a5c-5b01-4a24-b825-251a11298c1b','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:50',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-DeploymentActions-xrjh2gz6qx65','state changed','OS::Heat::Value',NULL,1568),(2548,'3b42020c-d7fb-4ab5-aab8-f5411dc950af','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:51',NULL,'CREATE','IN_PROGRESS','1','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz','state changed','OS::TripleO::Controller',NULL,1570),(2549,'82f1a164-5773-40c8-8fb1-26ff8c10b6cf','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:51',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz','59aa56db-6284-4022-b695-77e8c210b187','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2550,'1246e754-2019-4298-9493-221c91a714e8','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:51',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-Controller-6i4t3oi5ul2q','state changed','OS::TripleO::ControllerServer',NULL,1571),(2551,'ec043201-6742-495d-9612-534c98555e3a','fb2591a4-50c3-4e8e-8d96-53b0c8be5e4c','2026-06-15 07:52:51',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-Controller-6i4t3oi5ul2q','fb2591a4-50c3-4e8e-8d96-53b0c8be5e4c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2552,'e157cdbe-ca6b-4926-af5e-8199109f7b14','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:51',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-DeploymentActions-7q4f76fwnos4','state changed','OS::Heat::Value',NULL,1572),(2553,'8c94154d-4403-4bcb-a394-8ba751d0cd22','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:51',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-DeploymentActions-7q4f76fwnos4','state changed','OS::Heat::Value',NULL,1572),(2554,'5f01c88b-010c-4c40-aa1b-d73a860fc301','fb2591a4-50c3-4e8e-8d96-53b0c8be5e4c','2026-06-15 07:52:52',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-6i4t3oi5ul2q-deployed-server-fprjmlyty3pe','state changed','OS::Heat::DeployedServer',NULL,1574),(2555,'2c8320cc-1bc2-4328-a6e9-8714352d4df3','fb2591a4-50c3-4e8e-8d96-53b0c8be5e4c','2026-06-15 07:52:52',NULL,'CREATE','COMPLETE','deployed-server','f13c6de4-2962-42be-84f9-11b867bead5c','state changed','OS::Heat::DeployedServer',NULL,1574),(2556,'4cad67d0-5596-4f59-ae7a-0903ee01d3f8','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:52',NULL,'CREATE','IN_PROGRESS','2','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m','state changed','OS::TripleO::Controller',NULL,1575),(2557,'59f99a89-8b6d-484b-9ea1-08537b529a3e','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:52',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2558,'91b08a80-c197-46b6-8027-c36e482fa814','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:52',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-DeploymentActions-clvl4bqj4t4o','state changed','OS::Heat::Value',NULL,1576),(2559,'2885ba77-a5c8-49f7-98f0-e4d8a08e7e26','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:52',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-DeploymentActions-clvl4bqj4t4o','state changed','OS::Heat::Value',NULL,1576),(2560,'cb9cfab5-6eea-4319-a59f-efca022c3ebf','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:52',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-Controller-tpt3pihchxbc','state changed','OS::TripleO::ControllerServer',NULL,1578),(2561,'aed93ce5-1d49-4480-80e3-267b4bd0db45','cbdc2426-f366-4587-8746-964c2c083238','2026-06-15 07:52:53',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-Controller-tpt3pihchxbc','cbdc2426-f366-4587-8746-964c2c083238','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2562,'6949c8b6-d31f-4ad5-8a79-813cc106c245','fb2591a4-50c3-4e8e-8d96-53b0c8be5e4c','2026-06-15 07:52:53',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-Controller-6i4t3oi5ul2q-ControlPlanePort-bvdypdtyf7jb','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1579),(2563,'c92043a1-9d5f-4a23-aaaf-ddc2e9590937','cbdc2426-f366-4587-8746-964c2c083238','2026-06-15 07:52:53',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-tpt3pihchxbc-deployed-server-h7hn4de7tsbh','state changed','OS::Heat::DeployedServer',NULL,1580),(2564,'7746813e-70fa-4243-a866-636a4566973d','fbcc8791-4b0e-4f50-8a51-edfba7ddd461','2026-06-15 07:52:53',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-Controller-6i4t3oi5ul2q-ControlPlanePort-bvdypdtyf7jb','fbcc8791-4b0e-4f50-8a51-edfba7ddd461','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2565,'6f1cfe93-c7c8-49e6-9198-040a04035804','fbcc8791-4b0e-4f50-8a51-edfba7ddd461','2026-06-15 07:52:53',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-Controller-6i4t3oi5ul2q-ControlPlanePort-bvdypdtyf7jb','fbcc8791-4b0e-4f50-8a51-edfba7ddd461','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2566,'87463045-dee9-4d34-8921-0871c49037cc','cbdc2426-f366-4587-8746-964c2c083238','2026-06-15 07:52:53',NULL,'CREATE','COMPLETE','deployed-server','c9f9c827-ede0-43fc-805a-c973222c74b4','state changed','OS::Heat::DeployedServer',NULL,1580),(2567,'f174c942-6682-4780-82ab-8fbd4dd38698','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:53',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-Controller-2jbousrkdt2m','state changed','OS::TripleO::ControllerServer',NULL,1581),(2568,'8493889e-30d3-489f-bdbb-dcfe4b0aaf00','7f221c4c-e0f2-4771-8b8f-6e5961e29667','2026-06-15 07:52:54',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-Controller-2jbousrkdt2m','7f221c4c-e0f2-4771-8b8f-6e5961e29667','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2569,'935b5233-3fbf-4621-8dab-a38d62956900','cbdc2426-f366-4587-8746-964c2c083238','2026-06-15 07:52:54',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-Controller-tpt3pihchxbc-ControlPlanePort-yu7zxhrwvay7','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1582),(2570,'c613b9ec-7311-453d-a318-2999b7605629','7f221c4c-e0f2-4771-8b8f-6e5961e29667','2026-06-15 07:52:54',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-Controller-2jbousrkdt2m-ControlPlanePort-ehoadtzjuyhb','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1583),(2571,'697a83f2-cfe4-43a3-b1bb-2c2b8f2fa461','fb2591a4-50c3-4e8e-8d96-53b0c8be5e4c','2026-06-15 07:52:54',NULL,'CREATE','COMPLETE','ControlPlanePort','fbcc8791-4b0e-4f50-8a51-edfba7ddd461','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1579),(2572,'6ccdcd3d-80a3-45cf-8542-0be36d57dc23','079f69d6-032c-48ec-be4e-0b7280883883','2026-06-15 07:52:54',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-Controller-tpt3pihchxbc-ControlPlanePort-yu7zxhrwvay7','079f69d6-032c-48ec-be4e-0b7280883883','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2573,'b608af48-cd68-4b63-b173-e513bc1f2009','fb2591a4-50c3-4e8e-8d96-53b0c8be5e4c','2026-06-15 07:52:54',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-Controller-6i4t3oi5ul2q','fb2591a4-50c3-4e8e-8d96-53b0c8be5e4c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2574,'5d618513-6ded-40dc-a8fa-463df9714cb5','6a247c09-edd7-4c90-af13-6c4bf7aa134e','2026-06-15 07:52:54',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-Controller-2jbousrkdt2m-ControlPlanePort-ehoadtzjuyhb','6a247c09-edd7-4c90-af13-6c4bf7aa134e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2575,'e38a2b65-3372-43c7-8fe9-be730fa8b387','079f69d6-032c-48ec-be4e-0b7280883883','2026-06-15 07:52:54',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-Controller-tpt3pihchxbc-ControlPlanePort-yu7zxhrwvay7','079f69d6-032c-48ec-be4e-0b7280883883','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2576,'efd28c64-2f53-42b0-aefb-9a7798035dc1','6a247c09-edd7-4c90-af13-6c4bf7aa134e','2026-06-15 07:52:54',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-Controller-2jbousrkdt2m-ControlPlanePort-ehoadtzjuyhb','6a247c09-edd7-4c90-af13-6c4bf7aa134e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2577,'bffc838b-f89c-4ddc-b9ae-67976da3a530','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:54',NULL,'CREATE','COMPLETE','Controller','fb2591a4-50c3-4e8e-8d96-53b0c8be5e4c','state changed','OS::TripleO::ControllerServer',NULL,1571),(2578,'cbaa51cb-6c04-47c6-9e10-133eea3b832e','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NodeTLSCAData-gs3ipxgatefh','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2579,'848af49d-82cf-44c0-8c5b-2c6b0105a170','7f221c4c-e0f2-4771-8b8f-6e5961e29667','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-2jbousrkdt2m-deployed-server-t32ziabbrfj5','state changed','OS::Heat::DeployedServer',NULL,1585),(2580,'37acb260-aa86-4e01-a77d-665498c75fd8','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StoragePort-e7nfn76chdwf','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1586),(2581,'05f25406-7483-4054-8980-319ef13e00de','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StorageMgmtPort-jgx2t4zvfzxk','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1587),(2582,'1d2bc854-887a-49c6-b47d-3cceddc36f34','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','NodeTLSCAData','7971320b-0cd9-4fdd-a78c-aab2bad665ab','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2583,'254186f9-9fed-4b7d-97e1-12cc28f9b731','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-InternalApiPort-zwuvbkwgbar6','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1589),(2584,'3f0b3ab9-ae8f-4dad-800f-045b5f26ec39','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ControllerExtraConfigPre-fhpgtiwgxiqi','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1588),(2585,'e19a6341-6ae4-432e-aa78-8347766d8b0b','cbdc2426-f366-4587-8746-964c2c083238','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','ControlPlanePort','079f69d6-032c-48ec-be4e-0b7280883883','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1582),(2586,'07f699ad-3027-41bc-ae8a-4b79376f9621','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ExternalPort-q2zauj73qxi4','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1591),(2587,'64280702-ee6d-4e9f-8712-255c2e36d9ae','94f796fe-4051-4319-b1a4-3483a9c1332c','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ControllerExtraConfigPre-fhpgtiwgxiqi','94f796fe-4051-4319-b1a4-3483a9c1332c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2588,'5f19166a-cfa5-42b6-87c3-ac1a522d2d76','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NetHostMap-msawzuqymtbk','state changed','OS::Heat::Value',NULL,1590),(2589,'acb75bad-69a1-4ecf-8ba2-428491511d09','63c9e225-f84c-433f-a522-86fcd5af4653','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StoragePort-e7nfn76chdwf','63c9e225-f84c-433f-a522-86fcd5af4653','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2590,'c049a6a9-6087-4a6b-a0c0-ee1237e9f387','7f221c4c-e0f2-4771-8b8f-6e5961e29667','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','ControlPlanePort','6a247c09-edd7-4c90-af13-6c4bf7aa134e','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1583),(2591,'aeb956db-e2a2-4cd4-921e-cd4970144835','cbdc2426-f366-4587-8746-964c2c083238','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-Controller-tpt3pihchxbc','cbdc2426-f366-4587-8746-964c2c083238','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2592,'705ecd6e-0175-438f-8863-136acadf081d','f2e3cad3-ae26-4993-8688-8a3f6daa3ede','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StorageMgmtPort-jgx2t4zvfzxk','f2e3cad3-ae26-4993-8688-8a3f6daa3ede','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2593,'0557f281-780b-446e-8fe0-4b62eb20a10f','7f221c4c-e0f2-4771-8b8f-6e5961e29667','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','deployed-server','0218953d-5940-49ef-9237-c44f6db84d71','state changed','OS::Heat::DeployedServer',NULL,1585),(2594,'1df91dc6-2621-457c-887e-5af13045064b','cf28cac4-34aa-4626-ac53-50379876d788','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-InternalApiPort-zwuvbkwgbar6','cf28cac4-34aa-4626-ac53-50379876d788','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2595,'9a15d9bb-736a-494d-b2f7-8b597aa5b72e','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-TenantPort-akzswomd6iz2','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1593),(2596,'e4dc20f5-72a3-48de-b83d-f554bf0ad786','94f796fe-4051-4319-b1a4-3483a9c1332c','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ControllerExtraConfigPre-fhpgtiwgxiqi','94f796fe-4051-4319-b1a4-3483a9c1332c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2597,'245fd04d-29a3-4ce2-a7a9-3ce563577198','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NetHostMap-msawzuqymtbk','state changed','OS::Heat::Value',NULL,1590),(2598,'e0fd1086-2904-4bae-8f93-7b92bc12dae8','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-PreNetworkConfig-jb5iyto74imj','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2599,'2314e6e9-5e98-42f4-b854-bf8cf2149d57','5285c7e4-e4fd-4c60-a2c5-492d6bcbf9fb','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ExternalPort-q2zauj73qxi4','5285c7e4-e4fd-4c60-a2c5-492d6bcbf9fb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2600,'bfb058e3-3d2e-4489-8b75-f2884003f1a9','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','PreNetworkConfig','0a4e0169-7300-4edc-ae81-81e53345fd4e','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2601,'2270c09c-362b-49d0-8d6d-222fa47ec4b1','59d5de2b-0e09-4d4e-9d80-b2e2ab9a535a','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-TenantPort-akzswomd6iz2','59d5de2b-0e09-4d4e-9d80-b2e2ab9a535a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2602,'4fbd4696-0c31-40b4-8f39-6a48829f7922','cf28cac4-34aa-4626-ac53-50379876d788','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-InternalApiPort-zwuvbkwgbar6-InternalApiDeployedPort-3bj4idull7bj','state changed','OS::Heat::Value',NULL,1595),(2603,'b96f5076-66b0-4873-8ae7-76e6fa2c6396','7f221c4c-e0f2-4771-8b8f-6e5961e29667','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-Controller-2jbousrkdt2m','7f221c4c-e0f2-4771-8b8f-6e5961e29667','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2604,'7a2c209a-0b92-4a30-9103-df7212bbc522','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ControllerAnsibleHostVars-k5r6ascnbblv','state changed','OS::Heat::Value',NULL,1596),(2605,'b933c2f9-350d-4e20-91ba-c5cc6d34d22d','cf28cac4-34aa-4626-ac53-50379876d788','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-InternalApiPort-zwuvbkwgbar6-InternalApiDeployedPort-3bj4idull7bj','state changed','OS::Heat::Value',NULL,1595),(2606,'cd915350-30f3-4e3b-84a8-e22e88e454f3','cf28cac4-34aa-4626-ac53-50379876d788','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-InternalApiPort-zwuvbkwgbar6','cf28cac4-34aa-4626-ac53-50379876d788','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2607,'4bd1092a-5d7c-4406-9833-2bbc636ffc10','f2e3cad3-ae26-4993-8688-8a3f6daa3ede','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StorageMgmtPort-jgx2t4zvfzxk-StorageMgmtDeployedPort-ejmnh6rydqew','state changed','OS::Heat::Value',NULL,1597),(2608,'83740d96-2b86-436f-909d-31d158b3ff04','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ControllerAnsibleHostVars-k5r6ascnbblv','state changed','OS::Heat::Value',NULL,1596),(2609,'b66e83d6-bcae-4302-9942-91b04a896ee9','63c9e225-f84c-433f-a522-86fcd5af4653','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StoragePort-e7nfn76chdwf-StorageDeployedPort-jugsmqn5tnxf','state changed','OS::Heat::Value',NULL,1598),(2610,'eb543b79-a7ca-4156-b51f-ded6f2a39196','f2e3cad3-ae26-4993-8688-8a3f6daa3ede','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StorageMgmtPort-jgx2t4zvfzxk-StorageMgmtDeployedPort-ejmnh6rydqew','state changed','OS::Heat::Value',NULL,1597),(2611,'12f87c70-77e1-4f9a-acb3-854befd64274','63c9e225-f84c-433f-a522-86fcd5af4653','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StoragePort-e7nfn76chdwf-StorageDeployedPort-jugsmqn5tnxf','state changed','OS::Heat::Value',NULL,1598),(2612,'9bbbdec4-72b8-453e-8052-8775aac8a07b','f2e3cad3-ae26-4993-8688-8a3f6daa3ede','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StorageMgmtPort-jgx2t4zvfzxk','f2e3cad3-ae26-4993-8688-8a3f6daa3ede','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2613,'463af638-9d6a-4553-9bd3-f58ef6839992','5285c7e4-e4fd-4c60-a2c5-492d6bcbf9fb','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ExternalPort-q2zauj73qxi4-ExternalDeployedPort-gdoh2zlbb3m7','state changed','OS::Heat::Value',NULL,1599),(2614,'13a8c472-c4f8-4a2b-a982-2ead1ae1a492','59d5de2b-0e09-4d4e-9d80-b2e2ab9a535a','2026-06-15 07:52:55',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-TenantPort-akzswomd6iz2-TenantDeployedPort-tj2koiopbazj','state changed','OS::Heat::Value',NULL,1600),(2615,'6241f7df-acce-4a57-807f-9b4b3b395633','63c9e225-f84c-433f-a522-86fcd5af4653','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-StoragePort-e7nfn76chdwf','63c9e225-f84c-433f-a522-86fcd5af4653','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2616,'d5e82f71-7c5f-44e1-abef-957ce64a500d','59d5de2b-0e09-4d4e-9d80-b2e2ab9a535a','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-TenantPort-akzswomd6iz2-TenantDeployedPort-tj2koiopbazj','state changed','OS::Heat::Value',NULL,1600),(2617,'d0e05ebb-437a-4379-82fd-e84897181e79','5285c7e4-e4fd-4c60-a2c5-492d6bcbf9fb','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ExternalPort-q2zauj73qxi4-ExternalDeployedPort-gdoh2zlbb3m7','state changed','OS::Heat::Value',NULL,1599),(2618,'17893d1d-0010-4808-8d1d-b5ed87d94de4','59d5de2b-0e09-4d4e-9d80-b2e2ab9a535a','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-TenantPort-akzswomd6iz2','59d5de2b-0e09-4d4e-9d80-b2e2ab9a535a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2619,'8b988cea-1f97-4422-bd35-c7eab461251e','5285c7e4-e4fd-4c60-a2c5-492d6bcbf9fb','2026-06-15 07:52:55',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-ExternalPort-q2zauj73qxi4','5285c7e4-e4fd-4c60-a2c5-492d6bcbf9fb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2620,'35ae7ebc-496f-423b-9e58-2ddbeb7b5212','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','Controller','7f221c4c-e0f2-4771-8b8f-6e5961e29667','state changed','OS::TripleO::ControllerServer',NULL,1581),(2621,'25c6ba21-00de-489d-9b68-fcc3bb42e7d7','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','Controller','cbdc2426-f366-4587-8746-964c2c083238','state changed','OS::TripleO::ControllerServer',NULL,1578),(2622,'dea2cf97-0086-4a73-a1d5-c482e0e75019','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ExternalPort-bwqkikzfaogj','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1603),(2623,'795e5691-dff4-44d6-9d8d-cbbd806d88cf','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ControllerExtraConfigPre-tgoqxht3cdix','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1604),(2624,'e4530fbc-3569-4470-bd18-14e8463d1c9a','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-InternalApiPort-b67kzcg47zv7','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1606),(2625,'c4b5703f-20ae-4837-9f16-ded1d99c77f5','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StorageMgmtPort-7jxy4vxpgl26','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1605),(2626,'5384a636-4707-4439-9322-ac2e54013270','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-TenantPort-nswal72n5sxf','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1608),(2627,'165ea98a-cc02-4281-af62-6c66f490f5fd','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NetHostMap-tnnurx4c73w2','state changed','OS::Heat::Value',NULL,1607),(2628,'24a036fe-252b-4151-8c38-d2f40e7364a7','c27a9ffb-22b4-4e23-884c-9a078dd28dc9','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ExternalPort-bwqkikzfaogj','c27a9ffb-22b4-4e23-884c-9a078dd28dc9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2629,'2ea6cb57-4fba-4d9b-95d1-db3d7abbf5a6','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NodeTLSCAData-yfsnxgnhyfd2','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2630,'a355f3b7-b93e-49f3-ac71-54b69a49bb58','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NetHostMap-tnnurx4c73w2','state changed','OS::Heat::Value',NULL,1607),(2631,'feaaae5b-73db-4a46-92a6-cbd9a842af24','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-PreNetworkConfig-veghyiuujtjh','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2632,'0a16ec9c-5668-4075-a130-b45497a95c11','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','94f796fe-4051-4319-b1a4-3483a9c1332c','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1588),(2633,'c4e24b98-54cd-4c2f-8653-1a4ff2d22526','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NodeTLSCAData-calst63wdrdv','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2634,'7849df6b-2687-47fb-bb8b-f6580e60640b','2fa7e95f-0611-4bf8-998d-81b91babd006','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ControllerExtraConfigPre-tgoqxht3cdix','2fa7e95f-0611-4bf8-998d-81b91babd006','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2635,'f4821deb-821b-4fc4-9bf8-079d140a77ab','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-PreNetworkConfig-2duqolikgevk','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2636,'ca1b4948-e89c-4a8d-9d2e-35059eb28818','2fa7e95f-0611-4bf8-998d-81b91babd006','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ControllerExtraConfigPre-tgoqxht3cdix','2fa7e95f-0611-4bf8-998d-81b91babd006','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2637,'1abcf0e0-33c6-4039-b104-1ad3126e1c78','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StoragePort-vniffmimkcm3','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1609),(2638,'6bfeef8b-1bdd-4dee-9295-95780c92ae4d','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','PreNetworkConfig','4c819e12-6505-4b00-8393-02c3267b4773','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2639,'338310c7-9ec7-4ff1-8723-3e0bbbe98178','117cd16a-3c07-468a-92ab-3488ba7e99a2','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StorageMgmtPort-7jxy4vxpgl26','117cd16a-3c07-468a-92ab-3488ba7e99a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2640,'ec77d348-4e13-42fd-809d-a299caf1b4c9','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','NodeTLSCAData','63f3187e-3daa-44c1-a916-7c898b2af7b1','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2641,'10542a8c-d24d-4d4a-8d17-0305725d316e','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','StoragePort','63c9e225-f84c-433f-a522-86fcd5af4653','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1586),(2642,'31a162c2-0c5c-40de-a9f6-ed1f471e6f63','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-TenantPort-xzoo6p3wh3zl','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1610),(2643,'9b989b9d-4416-4b14-86ac-a6bf2a5aa5d0','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','StorageMgmtPort','f2e3cad3-ae26-4993-8688-8a3f6daa3ede','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1587),(2644,'560739a6-ec1e-4965-8d87-518ede690b98','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NetHostMap-bgylqhxp6vki','state changed','OS::Heat::Value',NULL,1613),(2645,'33201c51-1588-482c-aeed-2e7d77f806b3','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','NodeTLSCAData','ad43822d-35bd-4dee-bc46-5307d3f6ac30','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2646,'177f93cd-5f28-47de-b97c-531c710f54ba','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','InternalApiPort','cf28cac4-34aa-4626-ac53-50379876d788','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1589),(2647,'5d345c1d-4152-4489-a6fa-7749570c6fcb','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NodeExtraConfig-ll3kbfy6cliv','state changed','OS::TripleO::NodeExtraConfig',NULL,1615),(2648,'900e47e9-ca42-43b9-8b08-b42a0e4bb0a9','d079d28e-792b-49bc-8eea-34f0fad72c69','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-TenantPort-nswal72n5sxf','d079d28e-792b-49bc-8eea-34f0fad72c69','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2649,'cd750832-c4c4-4a6e-8a2f-b145b91d2793','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','ExternalPort','5285c7e4-e4fd-4c60-a2c5-492d6bcbf9fb','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1591),(2650,'8ba684fc-f14a-43bf-8253-99fde25584dd','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ControllerAnsibleHostVars-afk5qyvtczw6','state changed','OS::Heat::Value',NULL,1614),(2651,'2a35c3ef-ccbd-445d-a59a-3b7a6d27df3c','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','PreNetworkConfig','2b13aee0-277e-4145-9e90-3a17807043df','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2652,'152dab14-3d3d-4411-a921-49a219f88d66','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NetHostMap-bgylqhxp6vki','state changed','OS::Heat::Value',NULL,1613),(2653,'22791c05-43ca-4a0d-a73b-09eb71bee9ca','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','TenantPort','59d5de2b-0e09-4d4e-9d80-b2e2ab9a535a','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1593),(2654,'b35ca30e-7403-4e06-a11b-46c10d50822e','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ExternalPort-ofw7otwbotvn','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1618),(2655,'51240b0f-45c1-4e23-97bc-96dbb1e09231','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-InternalApiPort-mgemnjjed2xo','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1616),(2656,'1f2abd1c-a4d0-44a4-938f-d8b8790b546a','8722ee05-ae9b-4f7f-81e9-ecf2ea40d05b','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StoragePort-vniffmimkcm3','8722ee05-ae9b-4f7f-81e9-ecf2ea40d05b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2657,'48eb722f-c3c6-46dc-bf9d-1bb82b7c13de','4da39da9-2509-4684-998d-904c0313604f','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-InternalApiPort-b67kzcg47zv7','4da39da9-2509-4684-998d-904c0313604f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2658,'5b29688a-7eef-4961-9e93-3da4d6ccec41','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ControllerAnsibleHostVars-afk5qyvtczw6','state changed','OS::Heat::Value',NULL,1614),(2659,'cbd931e5-389d-4ee2-8a97-6077a3a45053','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StoragePort-hq7lak5nvg42','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1625),(2660,'f1550e24-44a1-4f45-be55-7ebb0eac409c','c27a9ffb-22b4-4e23-884c-9a078dd28dc9','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ExternalPort-bwqkikzfaogj-ExternalDeployedPort-7ormjqweske3','state changed','OS::Heat::Value',NULL,1623),(2661,'375d3255-d5ad-4ae9-8313-03485b63c613','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StorageMgmtPort-wcthzbrtusdx','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1620),(2662,'44a1b4c1-b4a8-4ee2-9f0a-1467c9e61a43','eb82931d-b53d-47b0-8a18-f8cfd1fa5c51','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-TenantPort-xzoo6p3wh3zl','eb82931d-b53d-47b0-8a18-f8cfd1fa5c51','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2663,'c34476e3-527e-4687-af35-3c76258516fe','c27a9ffb-22b4-4e23-884c-9a078dd28dc9','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ExternalPort-bwqkikzfaogj-ExternalDeployedPort-7ormjqweske3','state changed','OS::Heat::Value',NULL,1623),(2664,'dec190d7-524f-4e6a-b200-2c3fcdd849e6','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ControllerAnsibleHostVars-zksxlrky2zg7','state changed','OS::Heat::Value',NULL,1630),(2665,'03a456c6-8263-47d3-9864-90d1bfd40fe6','92f178d6-eb6d-4c4d-9867-416c81514676','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ExternalPort-ofw7otwbotvn','92f178d6-eb6d-4c4d-9867-416c81514676','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2666,'fee46c19-dde8-4a66-b479-1f5788cbdd1b','117cd16a-3c07-468a-92ab-3488ba7e99a2','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StorageMgmtPort-7jxy4vxpgl26-StorageMgmtDeployedPort-zlupj3jd7ire','state changed','OS::Heat::Value',NULL,1632),(2667,'70141978-2c90-46e0-8d52-f0a8baad8229','f3e0cc0f-5544-499f-8841-7d5e9b197f4b','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-InternalApiPort-mgemnjjed2xo','f3e0cc0f-5544-499f-8841-7d5e9b197f4b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2668,'a22fa35f-6e3a-4e93-aac4-20801f14e2cb','2fe4771e-1e34-42bf-9334-611c4dbacbe1','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NodeExtraConfig-ll3kbfy6cliv','2fe4771e-1e34-42bf-9334-611c4dbacbe1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2669,'38f8f549-f96d-4087-8caa-609b7fb46cc6','117cd16a-3c07-468a-92ab-3488ba7e99a2','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StorageMgmtPort-7jxy4vxpgl26-StorageMgmtDeployedPort-zlupj3jd7ire','state changed','OS::Heat::Value',NULL,1632),(2670,'316d0b01-2dde-4d2f-aced-ad06af703aed','c27a9ffb-22b4-4e23-884c-9a078dd28dc9','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-ExternalPort-bwqkikzfaogj','c27a9ffb-22b4-4e23-884c-9a078dd28dc9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2671,'7006efa4-1bab-41d7-bbe8-08505956efa6','117cd16a-3c07-468a-92ab-3488ba7e99a2','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StorageMgmtPort-7jxy4vxpgl26','117cd16a-3c07-468a-92ab-3488ba7e99a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2672,'880f4d97-193d-49b5-ad2c-4cd95a5d376a','8722ee05-ae9b-4f7f-81e9-ecf2ea40d05b','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StoragePort-vniffmimkcm3-StorageDeployedPort-b6cbddzdvpf3','state changed','OS::Heat::Value',NULL,1635),(2673,'94ba5cad-b9ac-4e13-a172-07a1029b532f','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ControllerAnsibleHostVars-zksxlrky2zg7','state changed','OS::Heat::Value',NULL,1630),(2674,'151c93d0-2198-43f7-9d45-32dd1ab81d9d','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ControllerExtraConfigPre-42j6urztkahq','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1633),(2675,'bbef4bb6-c576-4cd8-9e30-028171530ec4','8722ee05-ae9b-4f7f-81e9-ecf2ea40d05b','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StoragePort-vniffmimkcm3-StorageDeployedPort-b6cbddzdvpf3','state changed','OS::Heat::Value',NULL,1635),(2676,'cff526e8-06b7-459d-b91f-e384a1694471','8722ee05-ae9b-4f7f-81e9-ecf2ea40d05b','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StoragePort-vniffmimkcm3','8722ee05-ae9b-4f7f-81e9-ecf2ea40d05b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2677,'a7608286-a1ad-4980-84ad-4c87f307c02e','92f178d6-eb6d-4c4d-9867-416c81514676','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ExternalPort-ofw7otwbotvn-ExternalDeployedPort-rknzhvewh4z3','state changed','OS::Heat::Value',NULL,1637),(2678,'aece5cae-eeef-4ca7-8bae-501b6f38b4ab','92f178d6-eb6d-4c4d-9867-416c81514676','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ExternalPort-ofw7otwbotvn-ExternalDeployedPort-rknzhvewh4z3','state changed','OS::Heat::Value',NULL,1637),(2679,'3cbf4a23-a267-4856-accc-7da8c255b5d9','1d999974-f08b-42b3-98a8-66ba270d45be','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StorageMgmtPort-wcthzbrtusdx','1d999974-f08b-42b3-98a8-66ba270d45be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2680,'b51607b0-a8ca-4395-823d-1bb1f0425be5','2fe4771e-1e34-42bf-9334-611c4dbacbe1','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NodeExtraConfig-ll3kbfy6cliv','2fe4771e-1e34-42bf-9334-611c4dbacbe1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2681,'20115c4f-9756-4dc7-ae46-654ca554c8c8','f3e0cc0f-5544-499f-8841-7d5e9b197f4b','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-InternalApiPort-mgemnjjed2xo-InternalApiDeployedPort-4nnmqhfkpik5','state changed','OS::Heat::Value',NULL,1638),(2682,'fee22e33-d6f5-4672-afbd-ef78d07417a8','09475ba7-10bc-4f4b-969e-419028f17afc','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StoragePort-hq7lak5nvg42','09475ba7-10bc-4f4b-969e-419028f17afc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2683,'4b8afe41-9701-4d97-bf03-7d75a309a4b6','92f178d6-eb6d-4c4d-9867-416c81514676','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ExternalPort-ofw7otwbotvn','92f178d6-eb6d-4c4d-9867-416c81514676','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2684,'4510ddab-d760-439c-800a-3b8594bc69a2','d079d28e-792b-49bc-8eea-34f0fad72c69','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-TenantPort-nswal72n5sxf-TenantDeployedPort-luxt6qga3dtj','state changed','OS::Heat::Value',NULL,1639),(2685,'90be5b66-7f99-4a83-93d9-166eb1936cee','f3e0cc0f-5544-499f-8841-7d5e9b197f4b','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-InternalApiPort-mgemnjjed2xo-InternalApiDeployedPort-4nnmqhfkpik5','state changed','OS::Heat::Value',NULL,1638),(2686,'3f377232-2ebc-4b3f-a95d-0784f2d48172','9e3129f9-13c3-403a-af68-506eae963b6d','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ControllerExtraConfigPre-42j6urztkahq','9e3129f9-13c3-403a-af68-506eae963b6d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2687,'5ee1a91b-7cf1-4000-a1d4-91ffd1156d03','eb82931d-b53d-47b0-8a18-f8cfd1fa5c51','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-TenantPort-xzoo6p3wh3zl-TenantDeployedPort-izlot6o3dyay','state changed','OS::Heat::Value',NULL,1641),(2688,'676588d4-77c7-409c-b56e-cbb186a8c821','d079d28e-792b-49bc-8eea-34f0fad72c69','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-TenantPort-nswal72n5sxf-TenantDeployedPort-luxt6qga3dtj','state changed','OS::Heat::Value',NULL,1639),(2689,'9467b35d-aa1e-47e0-8a1e-00fd6b62e219','9e3129f9-13c3-403a-af68-506eae963b6d','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-ControllerExtraConfigPre-42j6urztkahq','9e3129f9-13c3-403a-af68-506eae963b6d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2690,'a9698f35-dee6-4005-ac28-100a31f1e2ff','eb82931d-b53d-47b0-8a18-f8cfd1fa5c51','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-TenantPort-xzoo6p3wh3zl-TenantDeployedPort-izlot6o3dyay','state changed','OS::Heat::Value',NULL,1641),(2691,'ba08d3f5-be16-4b42-b26a-4e0feb2784a6','eb82931d-b53d-47b0-8a18-f8cfd1fa5c51','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-TenantPort-xzoo6p3wh3zl','eb82931d-b53d-47b0-8a18-f8cfd1fa5c51','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2692,'1f21f242-3b4e-4d6c-ba81-77b1056d0d6c','4da39da9-2509-4684-998d-904c0313604f','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-InternalApiPort-b67kzcg47zv7-InternalApiDeployedPort-zudeiwtrc7z5','state changed','OS::Heat::Value',NULL,1642),(2693,'82ab8e6b-0bc6-482a-85f0-bb55ef356c8e','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','9e3129f9-13c3-403a-af68-506eae963b6d','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1633),(2694,'2b56f3b4-5d17-4f99-91ee-9335fd0464c1','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NetIpMap-lidzmstp3zjb','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1643),(2695,'a8578328-590f-4c2b-b574-d6f13b775cdd','d079d28e-792b-49bc-8eea-34f0fad72c69','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-TenantPort-nswal72n5sxf','d079d28e-792b-49bc-8eea-34f0fad72c69','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2696,'e1169b5e-dff1-4518-845b-d45c67f6a743','f3e0cc0f-5544-499f-8841-7d5e9b197f4b','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-InternalApiPort-mgemnjjed2xo','f3e0cc0f-5544-499f-8841-7d5e9b197f4b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2697,'d7818e61-bfec-480a-b302-8ffe6570ce3f','4da39da9-2509-4684-998d-904c0313604f','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-InternalApiPort-b67kzcg47zv7-InternalApiDeployedPort-zudeiwtrc7z5','state changed','OS::Heat::Value',NULL,1642),(2698,'73e6a807-e8a2-43b1-984a-2714954477c9','4da39da9-2509-4684-998d-904c0313604f','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-InternalApiPort-b67kzcg47zv7','4da39da9-2509-4684-998d-904c0313604f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2699,'11a1c692-7d91-4e95-866c-98be13fba6b0','09475ba7-10bc-4f4b-969e-419028f17afc','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StoragePort-hq7lak5nvg42-StorageDeployedPort-q3y3x2c47rse','state changed','OS::Heat::Value',NULL,1645),(2700,'c66ed7db-cc77-41ff-9d48-191ba2c32082','09475ba7-10bc-4f4b-969e-419028f17afc','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StoragePort-hq7lak5nvg42-StorageDeployedPort-q3y3x2c47rse','state changed','OS::Heat::Value',NULL,1645),(2701,'313f806e-b08b-4e5f-9588-19044ccf5ec5','1d999974-f08b-42b3-98a8-66ba270d45be','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StorageMgmtPort-wcthzbrtusdx-StorageMgmtDeployedPort-726iylyj5ue6','state changed','OS::Heat::Value',NULL,1646),(2702,'fdc39dfe-1039-46be-98b6-730b09f3c212','09475ba7-10bc-4f4b-969e-419028f17afc','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-StoragePort-hq7lak5nvg42','09475ba7-10bc-4f4b-969e-419028f17afc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2703,'fed4f902-7b49-46ea-9982-a2196dfc9244','1d999974-f08b-42b3-98a8-66ba270d45be','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StorageMgmtPort-wcthzbrtusdx-StorageMgmtDeployedPort-726iylyj5ue6','state changed','OS::Heat::Value',NULL,1646),(2704,'e25b6a1e-81fd-4158-9186-49e5c3833441','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NodeExtraConfig-ugbkucu54lyk','state changed','OS::TripleO::NodeExtraConfig',NULL,1647),(2705,'2c7faba2-c85e-474f-8d47-cf0f1d5062d9','1d999974-f08b-42b3-98a8-66ba270d45be','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-StorageMgmtPort-wcthzbrtusdx','1d999974-f08b-42b3-98a8-66ba270d45be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2706,'7478cced-af05-4998-a453-571903977420','7c3212ca-a810-4b83-a667-962883792a33','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NetIpMap-lidzmstp3zjb','7c3212ca-a810-4b83-a667-962883792a33','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2707,'c1f00e22-ead4-49f1-81fd-34b18fb5ee04','a5c9a5f6-1ccd-4b82-9792-3569d3f8aa5c','2026-06-15 07:52:56',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NodeExtraConfig-ugbkucu54lyk','a5c9a5f6-1ccd-4b82-9792-3569d3f8aa5c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2708,'72ccc039-5a11-4198-8aff-a354d84a9b3b','a5c9a5f6-1ccd-4b82-9792-3569d3f8aa5c','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NodeExtraConfig-ugbkucu54lyk','a5c9a5f6-1ccd-4b82-9792-3569d3f8aa5c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2709,'0fa4181c-f233-48d5-bd5e-857f9fe7a20f','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:56',NULL,'CREATE','COMPLETE','NodeExtraConfig','a5c9a5f6-1ccd-4b82-9792-3569d3f8aa5c','state changed','OS::TripleO::NodeExtraConfig',NULL,1647),(2710,'d8807136-7f1a-4df1-9ed4-f909212c24be','7c3212ca-a810-4b83-a667-962883792a33','2026-06-15 07:52:57',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NetIpMap-lidzmstp3zjb-NetIpMapValue-r6qiw2bhvyoq','state changed','OS::Heat::Value',NULL,1648),(2711,'dbacb8f7-43e8-4802-a2d4-b4f14cc512c5','7c3212ca-a810-4b83-a667-962883792a33','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NetIpMap-lidzmstp3zjb-NetIpMapValue-r6qiw2bhvyoq','state changed','OS::Heat::Value',NULL,1648),(2712,'e2f85087-b901-45ad-b08e-5e4b22e1d3e5','7c3212ca-a810-4b83-a667-962883792a33','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh-NetIpMap-lidzmstp3zjb','7c3212ca-a810-4b83-a667-962883792a33','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2713,'2daa5e9a-4bac-4f3e-80b6-b246564243db','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','ExternalPort','c27a9ffb-22b4-4e23-884c-9a078dd28dc9','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1603),(2714,'23c16c08-5d9e-4a23-9860-a92b5665c4cc','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','2fa7e95f-0611-4bf8-998d-81b91babd006','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1604),(2715,'8e55e08d-705f-4f9f-8dd4-4efaa60856b0','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','StorageMgmtPort','117cd16a-3c07-468a-92ab-3488ba7e99a2','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1605),(2716,'be9ea1a7-f8bb-4084-ae87-f275716c7826','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:57',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NodeExtraConfig-6bshiik7226g','state changed','OS::TripleO::NodeExtraConfig',NULL,1652),(2717,'9ab80226-e275-4303-a9b8-c1035f6646b7','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','TenantPort','d079d28e-792b-49bc-8eea-34f0fad72c69','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1608),(2718,'6d159c4b-5056-45e9-b778-ad76ba1cfa45','b52c15cf-91c7-4446-9173-ad4c8787b69b','2026-06-15 07:52:57',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NodeExtraConfig-6bshiik7226g','b52c15cf-91c7-4446-9173-ad4c8787b69b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2719,'806f9925-c68c-4c6a-a283-5e6f195ffbdd','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','StoragePort','8722ee05-ae9b-4f7f-81e9-ecf2ea40d05b','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1609),(2720,'ba54d379-428d-4381-8e86-7697df58fb34','b52c15cf-91c7-4446-9173-ad4c8787b69b','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NodeExtraConfig-6bshiik7226g','b52c15cf-91c7-4446-9173-ad4c8787b69b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2721,'ec908cf4-29be-436f-8c23-5e0d651dc75d','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','InternalApiPort','4da39da9-2509-4684-998d-904c0313604f','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1606),(2722,'e30cac4a-1aaa-4066-846b-446f7147b0c5','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','NodeExtraConfig','2fe4771e-1e34-42bf-9334-611c4dbacbe1','state changed','OS::TripleO::NodeExtraConfig',NULL,1615),(2723,'b2ccdca9-e9ef-44f2-bfbc-83796b691fa8','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','ExternalPort','92f178d6-eb6d-4c4d-9867-416c81514676','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1618),(2724,'6ec682d2-d5cb-4e38-a91a-e9d798a80cb7','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','TenantPort','eb82931d-b53d-47b0-8a18-f8cfd1fa5c51','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1610),(2725,'857ef81d-935d-4a62-aa4e-630590217cea','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','StoragePort','09475ba7-10bc-4f4b-969e-419028f17afc','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1625),(2726,'d196d1ef-087c-4eb4-a2e1-1632f39c435b','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','InternalApiPort','f3e0cc0f-5544-499f-8841-7d5e9b197f4b','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1616),(2727,'cdbee7db-bde1-4ab8-9c80-763af83957ec','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','StorageMgmtPort','1d999974-f08b-42b3-98a8-66ba270d45be','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1620),(2728,'e1bdd71d-c3cd-4afb-9f56-4de4ad789572','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:57',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NetIpMap-gbbykcvxhiku','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1671),(2729,'223a6a28-1ea2-406d-b429-e49d7d4f9ae3','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:57',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NetIpMap-f6hs2fs74vwq','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1672),(2730,'1d22f12f-5f36-4eee-ba6a-7386ab2c963a','b6a3cb83-7694-46b4-bdc0-80e3bf7d0987','2026-06-15 07:52:57',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NetIpMap-gbbykcvxhiku','b6a3cb83-7694-46b4-bdc0-80e3bf7d0987','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2731,'875298ac-dc23-4d06-a3e6-5523afea4d7f','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','NetIpMap','7c3212ca-a810-4b83-a667-962883792a33','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1643),(2732,'d7d5e153-4adc-40cf-a092-f9f5246b6436','0e01781d-92a8-4bed-b6b6-3d41928e2f0a','2026-06-15 07:52:57',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NetIpMap-f6hs2fs74vwq','0e01781d-92a8-4bed-b6b6-3d41928e2f0a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2733,'7f3546e8-2520-48df-9617-a037b287cf0c','e2a48c69-f617-49cb-b89a-efd3e2294e65','2026-06-15 07:52:57',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-0-z2vlxgcwnxnh','e2a48c69-f617-49cb-b89a-efd3e2294e65','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2734,'bc32f1c4-70d7-4f2a-b6c0-8f404208c6f3','b6a3cb83-7694-46b4-bdc0-80e3bf7d0987','2026-06-15 07:52:58',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NetIpMap-gbbykcvxhiku-NetIpMapValue-gspf5fwppgj7','state changed','OS::Heat::Value',NULL,1673),(2735,'dcb791bc-6811-41a1-9025-4e7e38351842','b6a3cb83-7694-46b4-bdc0-80e3bf7d0987','2026-06-15 07:52:58',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NetIpMap-gbbykcvxhiku-NetIpMapValue-gspf5fwppgj7','state changed','OS::Heat::Value',NULL,1673),(2736,'4ae030fd-a0fc-493d-91a3-7d3c74acc16d','b6a3cb83-7694-46b4-bdc0-80e3bf7d0987','2026-06-15 07:52:58',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m-NetIpMap-gbbykcvxhiku','b6a3cb83-7694-46b4-bdc0-80e3bf7d0987','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2737,'8f243a8d-7a96-4952-8576-5d84d7806278','0e01781d-92a8-4bed-b6b6-3d41928e2f0a','2026-06-15 07:52:58',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NetIpMap-f6hs2fs74vwq-NetIpMapValue-firgqg3zr6cd','state changed','OS::Heat::Value',NULL,1674),(2738,'8d0fd050-43ac-419b-a5a1-fc89e34359e6','0e01781d-92a8-4bed-b6b6-3d41928e2f0a','2026-06-15 07:52:58',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NetIpMap-f6hs2fs74vwq-NetIpMapValue-firgqg3zr6cd','state changed','OS::Heat::Value',NULL,1674),(2739,'c670dee4-3a09-4c59-9cd7-94bab9702941','0e01781d-92a8-4bed-b6b6-3d41928e2f0a','2026-06-15 07:52:58',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz-NetIpMap-f6hs2fs74vwq','0e01781d-92a8-4bed-b6b6-3d41928e2f0a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2740,'912dd9c3-8083-4c4a-9074-58a63b12fc91','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:58',NULL,'CREATE','COMPLETE','0','e2a48c69-f617-49cb-b89a-efd3e2294e65','state changed','OS::TripleO::Controller',NULL,1567),(2741,'11ccd7db-b932-4e90-98fc-8f3f2c7c4dc3','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:58',NULL,'CREATE','COMPLETE','NodeExtraConfig','b52c15cf-91c7-4446-9173-ad4c8787b69b','state changed','OS::TripleO::NodeExtraConfig',NULL,1652),(2742,'87fee9d3-20e0-4a02-a6ac-cd821da02308','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:58',NULL,'CREATE','COMPLETE','NetIpMap','b6a3cb83-7694-46b4-bdc0-80e3bf7d0987','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1671),(2743,'8bb226e8-d775-4022-8236-f33a1a14e580','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:58',NULL,'CREATE','COMPLETE','NetIpMap','0e01781d-92a8-4bed-b6b6-3d41928e2f0a','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1672),(2744,'61217b4e-daf3-4f95-817e-00e3ec0a2ccc','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','2026-06-15 07:52:59',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-2-o5uwshh7wz4m','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2745,'588d527b-a4fa-47fe-8402-5d7ec4b5d333','59aa56db-6284-4022-b695-77e8c210b187','2026-06-15 07:52:59',NULL,'CREATE','COMPLETE','overcloud-Controller-n72un4v4v7ig-1-jydtr6avxviz','59aa56db-6284-4022-b695-77e8c210b187','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2746,'cd62eedc-c28c-40fa-963b-1f1ea159a0e2','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:59',NULL,'CREATE','COMPLETE','1','59aa56db-6284-4022-b695-77e8c210b187','state changed','OS::TripleO::Controller',NULL,1570),(2747,'d79fab7e-ded0-4d95-8025-ecc9aaa827d7','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:59',NULL,'CREATE','COMPLETE','2','a2ceacea-b2e3-4ad2-a8e4-086cf766ba3c','state changed','OS::TripleO::Controller',NULL,1575),(2748,'e6abda2b-1773-4201-bca1-a9b21627b19d','4d78b488-1049-4329-bf32-1e85126915c2','2026-06-15 07:52:59',NULL,'UPDATE','COMPLETE','overcloud-Controller-n72un4v4v7ig','4d78b488-1049-4329-bf32-1e85126915c2','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(2749,'3e7a9f16-610c-4c9b-8961-ac0ccdc02e85','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:00',NULL,'CREATE','COMPLETE','Controller','4d78b488-1049-4329-bf32-1e85126915c2','state changed','OS::Heat::ResourceGroup',NULL,1558),(2750,'d718f7b4-0383-428c-9aa7-2e940fded3db','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','ServerIdMap','overcloud-ServerIdMap-oxjxcyeixghl','state changed','OS::Heat::Value',NULL,1690),(2751,'2e9d71a0-4e5d-4027-95a4-f028a13a38ac','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','COMPLETE','ServerIdMap','overcloud-ServerIdMap-oxjxcyeixghl','state changed','OS::Heat::Value',NULL,1690),(2752,'3c04243d-201b-4228-bfd4-8cd93294063a','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-ojqcm3pnxhjk','state changed','OS::Heat::Value',NULL,1691),(2753,'533c9efb-dee7-404b-82c1-49edf502e219','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','COMPLETE','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-ojqcm3pnxhjk','state changed','OS::Heat::Value',NULL,1691),(2754,'84407071-bf58-4397-a941-822bb8536131','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','BlacklistedHostnames','overcloud-BlacklistedHostnames-buq4jwyreaet','state changed','OS::Heat::Value',NULL,1692),(2755,'6d45c335-39c2-46ec-8204-96b8c6682d2e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','HostsEntryValue','overcloud-HostsEntryValue-s4xndvzh2lsc','state changed','OS::Heat::Value',NULL,1693),(2756,'17214f7c-fd43-4747-a3f5-7ef64b87c58e','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','COMPLETE','HostsEntryValue','overcloud-HostsEntryValue-s4xndvzh2lsc','state changed','OS::Heat::Value',NULL,1693),(2757,'2f9b14b9-071c-4adc-8d83-ddb0cd4d8136','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','AnsibleHostVars','overcloud-AnsibleHostVars-7otdgtchqfpr','state changed','OS::Heat::Value',NULL,1695),(2758,'8f3e5470-91cb-4cc9-a0e3-fb4d1006fe45','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-eeaiewlsc2x7','state changed','OS::Heat::Value',NULL,1696),(2759,'8cab7b82-5bbd-4f3d-9136-92e0acab84b4','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','COMPLETE','AnsibleHostVars','overcloud-AnsibleHostVars-7otdgtchqfpr','state changed','OS::Heat::Value',NULL,1695),(2760,'23db1e45-5b00-46ad-bf41-00951c72778d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','ControllerServers','overcloud-ControllerServers-5cjqlo5ak227','state changed','OS::Heat::Value',NULL,1697),(2761,'d0aec8f5-e203-4956-84a4-bcc0792929b8','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','COMPLETE','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-eeaiewlsc2x7','state changed','OS::Heat::Value',NULL,1696),(2762,'fa35cac7-78c8-4aa3-8a4c-1f42608f4922','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','COMPLETE','BlacklistedHostnames','overcloud-BlacklistedHostnames-buq4jwyreaet','state changed','OS::Heat::Value',NULL,1692),(2763,'2d41440d-a045-490c-a9e0-8882ca333daa','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','COMPLETE','ControllerServers','overcloud-ControllerServers-5cjqlo5ak227','state changed','OS::Heat::Value',NULL,1697),(2764,'3e52abc8-4d38-4556-9b61-0bef41367360','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','ControllerIpListMap','overcloud-ControllerIpListMap-bd7f7vmxcirj','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1699),(2765,'60e00d74-0904-44b8-8cea-ce8f32084b37','f39df799-f739-45bb-961c-bd671378c9f8','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerIpListMap-bd7f7vmxcirj','f39df799-f739-45bb-961c-bd671378c9f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2766,'c4009fbb-59be-4949-8e44-a894d5ee741b','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','AllNodesExtraConfig','overcloud-AllNodesExtraConfig-47sjcjcvxt3b','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2767,'13ad8f5f-adcc-4129-91b9-c2f55ea61964','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:01',NULL,'CREATE','COMPLETE','AllNodesExtraConfig','9201ef36-7949-4fdd-808a-1817b4d3bfa0','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2768,'a59cd426-016d-4c99-b047-77c28bb226f6','f39df799-f739-45bb-961c-bd671378c9f8','2026-06-15 07:53:01',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ControllerIpListMap-bd7f7vmxcirj-NetIpMapValue-2f2bw2kvqc5x','state changed','OS::Heat::Value',NULL,1702),(2769,'b6b5a6ab-ef5f-4814-9243-e1a3d7b73856','f39df799-f739-45bb-961c-bd671378c9f8','2026-06-15 07:53:01',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ControllerIpListMap-bd7f7vmxcirj-NetIpMapValue-2f2bw2kvqc5x','state changed','OS::Heat::Value',NULL,1702),(2770,'32c8bf88-e879-41f5-bdc6-d66191b5e904','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:02',NULL,'CREATE','IN_PROGRESS','AllNodesDeploySteps','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa','state changed','OS::TripleO::PostDeploySteps',NULL,1703),(2771,'78924066-c6d2-4380-998f-be217179bbff','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:02',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa','7647edd3-09ba-4ca5-b06a-6fe03703689d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2772,'9f6b5c3c-bd9a-4226-9fea-619f5ab118a5','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:02',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPost','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ControllerExtraConfigPost-tvs26qpj4pmu','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1705),(2773,'928d8769-7533-42d4-944c-a3f9a7265828','f39df799-f739-45bb-961c-bd671378c9f8','2026-06-15 07:53:02',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ControllerIpListMap-bd7f7vmxcirj-EnabledServicesValue-54t73sfxe4fm','state changed','OS::Heat::Value',NULL,1704),(2774,'c9b5455d-9819-433b-985d-ab260280786f','f39df799-f739-45bb-961c-bd671378c9f8','2026-06-15 07:53:02',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ControllerIpListMap-bd7f7vmxcirj-EnabledServicesValue-54t73sfxe4fm','state changed','OS::Heat::Value',NULL,1704),(2775,'feb88def-f6b2-4af2-a35f-56ec5808bbe8','f39df799-f739-45bb-961c-bd671378c9f8','2026-06-15 07:53:03',NULL,'CREATE','COMPLETE','overcloud-ControllerIpListMap-bd7f7vmxcirj','f39df799-f739-45bb-961c-bd671378c9f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2776,'766c86e9-f1ec-4f4b-84b1-c03c54f13ea0','9146cf6a-9c99-4b2c-883e-01ed00b79c12','2026-06-15 07:53:03',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ControllerExtraConfigPost-tvs26qpj4pmu','9146cf6a-9c99-4b2c-883e-01ed00b79c12','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2777,'df331ace-7566-43ca-ad1d-11afa47ee0b4','9146cf6a-9c99-4b2c-883e-01ed00b79c12','2026-06-15 07:53:03',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ControllerExtraConfigPost-tvs26qpj4pmu','9146cf6a-9c99-4b2c-883e-01ed00b79c12','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2778,'8f02edd1-a7cb-47bc-a54e-6d7f3743d40d','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:03',NULL,'CREATE','COMPLETE','ControllerIpListMap','f39df799-f739-45bb-961c-bd671378c9f8','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1699),(2779,'5396248c-a47b-4534-b263-220f4883755d','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:04',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-PreDeployStepTasks-6ukeagefk2sw','state changed','OS::Heat::Value',NULL,1706),(2780,'07fb18c2-409c-4b44-88c3-81749aacb185','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:04',NULL,'CREATE','COMPLETE','ControllerExtraConfigPost','9146cf6a-9c99-4b2c-883e-01ed00b79c12','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1705),(2781,'9daa0ec0-66fb-46eb-ab05-6753e45e6c78','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:04',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-PreDeployStepTasks-6ukeagefk2sw','state changed','OS::Heat::Value',NULL,1706),(2782,'a23f0b27-1fa7-4ffb-8152-f331dd064c42','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:05',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPost','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ComputeExtraConfigPost-gxxxveh7m5xt','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1708),(2783,'b5dd46d0-735e-4d0b-944d-76e02d6eecf0','52cce972-db31-43df-a4bc-e5d46d7029e9','2026-06-15 07:53:05',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ComputeExtraConfigPost-gxxxveh7m5xt','52cce972-db31-43df-a4bc-e5d46d7029e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2784,'d95c408b-7802-43cf-b3e8-ae63c18f959a','52cce972-db31-43df-a4bc-e5d46d7029e9','2026-06-15 07:53:05',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ComputeExtraConfigPost-gxxxveh7m5xt','52cce972-db31-43df-a4bc-e5d46d7029e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2785,'464d7a09-ad1f-4489-ab63-ff56b68da8f4','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:06',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ExternalUpdateTasks-c5evknoypfb3','state changed','OS::Heat::Value',NULL,1709),(2786,'9e058873-9766-4d6c-98c6-f33b0ec78565','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:06',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ExternalUpdateTasks-c5evknoypfb3','state changed','OS::Heat::Value',NULL,1709),(2787,'4d0b6e40-68bf-4751-8caf-fdd2af64d63e','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:06',NULL,'CREATE','COMPLETE','ComputeExtraConfigPost','52cce972-db31-43df-a4bc-e5d46d7029e9','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1708),(2788,'30622d3f-2527-46cc-a0ff-850ca4148282','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:06',NULL,'CREATE','IN_PROGRESS','ComputePostConfig','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ComputePostConfig-vwgbkjipvomc','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(2789,'88999f60-47c5-4339-bc7f-6573ce99453b','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:06',NULL,'CREATE','IN_PROGRESS','ControllerPostConfig','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ControllerPostConfig-26y4zkyjy3s6','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2790,'5a1ab54b-ad1f-415d-862d-a9ef9070b922','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:06',NULL,'CREATE','COMPLETE','ComputePostConfig','f0621f86-8fa9-4aae-a9d2-6be1ffdbc34c','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(2791,'548aa22c-8c9a-475d-9913-329482e13133','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:06',NULL,'CREATE','COMPLETE','ControllerPostConfig','7ffbc2b7-1c20-4288-883e-4a5587434da9','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2792,'dc494b65-1762-4d44-ba93-0bbdb5291619','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:07',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ScaleTasks-37qdai6tsgs2','state changed','OS::Heat::Value',NULL,1711),(2793,'a9158d62-ff1a-4e8c-b865-76a14a38b1c7','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:07',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ScaleTasks-37qdai6tsgs2','state changed','OS::Heat::Value',NULL,1711),(2794,'4bf1e99f-aebd-4439-935b-df8b0a0293cf','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:08',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ExternalPostDeployTasks-wk2yefctckg4','state changed','OS::Heat::Value',NULL,1712),(2795,'38a6def3-bb36-44e6-95b5-df3d40b99926','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:08',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ExternalPostDeployTasks-wk2yefctckg4','state changed','OS::Heat::Value',NULL,1712),(2796,'92ff6d2f-a8d5-485c-8a53-d0aab99dcf09','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:09',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ExternalDeployTasks-3sc7hcsvbueb','state changed','OS::Heat::Value',NULL,1713),(2797,'de273018-c03a-42c3-a255-3cac0716d142','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:09',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ExternalDeployTasks-3sc7hcsvbueb','state changed','OS::Heat::Value',NULL,1713),(2798,'97ed7073-9846-4c01-b6b6-df0f9d8896cc','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:10',NULL,'CREATE','IN_PROGRESS','BootstrapServerId','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-BootstrapServerId-go6g3hvaowr3','state changed','OS::Heat::Value',NULL,1714),(2799,'2ea187f3-d630-42b5-b81f-37f9c9f0407d','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:10',NULL,'CREATE','COMPLETE','BootstrapServerId','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-BootstrapServerId-go6g3hvaowr3','state changed','OS::Heat::Value',NULL,1714),(2800,'eafabd28-e4dc-4420-8ca1-ad39bc9f1888','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:11',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ExternalUpgradeTasks-kjv2g36izy27','state changed','OS::Heat::Value',NULL,1715),(2801,'03288466-c9a8-4caf-836b-23dd484c6a66','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:11',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa-ExternalUpgradeTasks-kjv2g36izy27','state changed','OS::Heat::Value',NULL,1715),(2802,'a9f73375-a81c-4e91-8794-f692def918da','7647edd3-09ba-4ca5-b06a-6fe03703689d','2026-06-15 07:53:11',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-kbuk2vkg7xaa','7647edd3-09ba-4ca5-b06a-6fe03703689d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2803,'c8a37009-e9bd-475d-8541-1aa429a5d403','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:11',NULL,'CREATE','COMPLETE','AllNodesDeploySteps','7647edd3-09ba-4ca5-b06a-6fe03703689d','state changed','OS::TripleO::PostDeploySteps',NULL,1703),(2804,'37cf25e3-e2fc-4191-868c-c997ff5d0850','55d3b7c3-cd20-479e-abcc-7e199d80ba59','2026-06-15 07:53:11',NULL,'CREATE','COMPLETE','overcloud','55d3b7c3-cd20-479e-abcc-7e199d80ba59','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL);
/*!40000 ALTER TABLE `event` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `migrate_version`
--

DROP TABLE IF EXISTS `migrate_version`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `migrate_version` (
  `repository_id` varchar(250) NOT NULL,
  `repository_path` text DEFAULT NULL,
  `version` int(11) DEFAULT NULL,
  PRIMARY KEY (`repository_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_swedish_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `migrate_version`
--

LOCK TABLES `migrate_version` WRITE;
/*!40000 ALTER TABLE `migrate_version` DISABLE KEYS */;
INSERT INTO `migrate_version` VALUES ('heat','/usr/lib/python3.9/site-packages/heat/db/sqlalchemy/migrate_repo',86);
/*!40000 ALTER TABLE `migrate_version` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `raw_template`
--

DROP TABLE IF EXISTS `raw_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `raw_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `template` longtext DEFAULT NULL,
  `files` longtext DEFAULT NULL,
  `environment` longtext DEFAULT NULL,
  `files_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `raw_tmpl_files_fkey_ref` (`files_id`),
  CONSTRAINT `raw_tmpl_files_fkey_ref` FOREIGN KEY (`files_id`) REFERENCES `raw_template_files` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=408 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `raw_template`
--

LOCK TABLES `raw_template` WRITE;
/*!40000 ALTER TABLE `raw_template` DISABLE KEYS */;
INSERT INTO `raw_template` VALUES (1,'2026-06-15 07:50:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deploy an OpenStack environment, consisting of several node types (roles), Controller, Compute, BlockStorage, SwiftStorage and CephStorage. The Storage roles enable independent scaling of the storage components, but the minimal deployment is one Controller and one Compute node.\\n\", \"parameters\": {\"CloudNameStorage\": {\"default\": \"overcloud.storage.localdomain\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.localdomain\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageMgmtVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageMgmtVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.localdomain\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"InternalApiVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the InternalApiVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudName\": {\"default\": \"overcloud.localdomain\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"PublicVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the PublicVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"ExternalVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ExternalVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.localdomain\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}, \"ExtraHostFileEntries\": {\"default\": [], \"description\": \"List of extra hosts entries to be appended to /etc/hosts\", \"type\": \"comma_delimited_list\"}, \"UndercloudHostsEntries\": {\"default\": [], \"description\": \"List of undercloud hosts entries to be appended to /etc/hosts. The value is populated with the HEAT_HOSTS entries on the undercloud by tripleoclient when running deploy.\\n\", \"type\": \"comma_delimited_list\"}, \"EndpointMapOverride\": {\"default\": {}, \"description\": \"Can be used to override the calcluated EndpointMap\", \"type\": \"json\"}, \"ExtraConfig\": {\"default\": {}, \"description\": \"Additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"DeployedServerPortMap\": {\"default\": {}, \"type\": \"json\"}, \"NeutronControlPlaneID\": {\"default\": \"ctlplane\", \"type\": \"string\", \"description\": \"Neutron ID or name for ctlplane network.\"}, \"NeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create for accessing external networks.\", \"type\": \"string\"}, \"NeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"Which interface to add to the NeutronPhysicalBridge.\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"DnsSearchDomains\": {\"default\": [], \"description\": \"A list of DNS search domains to be added (in order) to resolv.conf.\", \"type\": \"comma_delimited_list\"}, \"ControlFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ControlVirtualIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"RabbitCookieSalt\": {\"type\": \"string\", \"default\": \"unset\", \"description\": \"Salt for the rabbit cookie, change this to force the randomly generated rabbit cookie to change.\"}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API.\\n\", \"type\": \"json\"}, \"HypervisorNeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create on each hypervisor. This defaults to br-ex the same as the control plane nodes, as we have a uniform configuration of the openvswitch agent. Typically should not need to be changed.\\n\", \"type\": \"string\"}, \"HypervisorNeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"What interface to add to the HypervisorNeutronPhysicalBridge.\", \"type\": \"string\"}, \"NodeCreateBatchSize\": {\"default\": 30, \"description\": \"Maxiumum batch size for creating nodes\", \"type\": \"number\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaLocalMetadataPerCell\": {\"default\": false, \"description\": \"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\n\", \"type\": \"boolean\"}, \"BondInterfaceOvsOptions\": {\"default\": \"\", \"description\": \"The ovs_options or bonding_options string for the bond interface. Set things like lacp=active and/or bond_mode=balance-slb for OVS bonds or like mode=4 for Linux bonds using this option.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^((?!balance.tcp).)*$\", \"description\": \"The balance-tcp bond mode is known to cause packet loss and should not be used in BondInterfaceOvsOptions.\"}]}, \"NetworkConfigWithAnsible\": {\"description\": \"NetworkConfig with ansible flag\", \"type\": \"boolean\", \"default\": true}, \"ControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ControllerNetworkConfigTemplate\": {\"description\": \"Controller NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"controllerExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use CellControllerComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\"}, \"ControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Controller node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"ControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Controller ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Controller ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nControllerServiceChain resource and the Controller resource group.\\nFor example:\\nControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerNetworkConfigTemplate\": {\"description\": \"CellController NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellController node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"CellControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellController ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellController ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerServiceChain resource and the CellController resource group.\\nFor example:\\nCellControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerComputeNetworkConfigTemplate\": {\"description\": \"CellControllerCompute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellControllerCompute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-compute-%index%\"}, \"CellControllerComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellControllerCompute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellControllerCompute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerComputeServiceChain resource and the CellControllerCompute resource group.\\nFor example:\\nCellControllerComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ComputeNetworkConfigTemplate\": {\"description\": \"Compute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NovaComputeExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use ComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\"}, \"ComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Compute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-novacompute-%index%\"}, \"ComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Compute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Compute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NovaComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"DEPRECATED - use ComputeSchedulerHints instead\", \"default\": {}}, \"ComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nComputeServiceChain resource and the Compute resource group.\\nFor example:\\nComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"BlockStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"BlockStorageNetworkConfigTemplate\": {\"description\": \"BlockStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"BlockStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\"}, \"BlockStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"BlockStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"BlockStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"BlockStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for BlockStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-blockstorage-%index%\"}, \"BlockStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from BlockStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"BlockStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for BlockStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"BlockStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"BlockStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"BlockStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"BlockStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"BlockStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nBlockStorageServiceChain resource and the BlockStorage resource group.\\nFor example:\\nBlockStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"BlockStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ObjectStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ObjectStorageNetworkConfigTemplate\": {\"description\": \"ObjectStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ObjectStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\"}, \"ObjectStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ObjectStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ObjectStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for ObjectStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-objectstorage-%index%\"}, \"ObjectStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from ObjectStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ObjectStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for ObjectStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ObjectStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ObjectStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ObjectStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ObjectStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ObjectStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nObjectStorageServiceChain resource and the ObjectStorage resource group.\\nFor example:\\nObjectStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ObjectStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CephStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CephStorageNetworkConfigTemplate\": {\"description\": \"CephStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CephStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\"}, \"CephStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CephStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CephStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CephStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-cephstorage-%index%\"}, \"CephStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CephStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CephStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CephStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CephStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CephStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CephStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CephStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CephStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCephStorageServiceChain resource and the CephStorage resource group.\\nFor example:\\nCephStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CephStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"NetworkerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"NetworkerNetworkConfigTemplate\": {\"description\": \"Networker NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"NetworkerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\"}, \"NetworkerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"NetworkerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"NetworkerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Networker node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-networker-%index%\"}, \"NetworkerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Networker ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"NetworkerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Networker ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"NetworkerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NetworkerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"NetworkerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"NetworkerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"NetworkerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nNetworkerServiceChain resource and the Networker resource group.\\nFor example:\\nNetworkerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"NetworkerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"DeployIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AddVipsToEtcHosts\": {\"default\": true, \"type\": \"boolean\", \"description\": \"Set to true to append per network Vips to /etc/hosts on each node.\\n\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"GlobalConfigExtraMapData\": {\"type\": \"json\", \"default\": {}, \"description\": \"Map of extra global_config_settings data to set on each node.\"}, \"NetConfigDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"Configure os-net-config mappings for specific nodes Your environment file needs to look like:\\n  parameter_defaults:\\n    NetConfigDataLookup:\\n      node1:\\n        nic1: \\\"00:c8:7c:e6:f0:2e\\\"\\n      node2:\\n        nic1: \\\"00:18:7d:99:0c:b6\\\"\\n      node3:\\n        dmiString: \'system-uuid\'\\n        id: \'A8C85861-1B16-4803-8689-AFC62984F8F6\'\\n        nic1: em3\\n      # Dell PowerEdge\\n      nodegroup1:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"PowerEdge R630\\\"\\n        nic1: em3\\n        nic2: em1\\n        nic3: em2\\n      # Cisco UCS B200-M4\\\"\\n      nodegroup2:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"UCSB-B200-M4\\\"\\n        nic1: enp7s0\\n        nic2: enp6s0\\n\\nThis will result in the first node* entry where either a mac matches a local device or a DMI String matches the specified id being written as a mapping file for os-net-config. (/etc/os-net-config/mapping.yaml)\\n\"}, \"DnsServers\": {\"default\": [], \"description\": \"DNS servers to use for the Overcloud (2 max for some implementations). If not set the nameservers configured in the ctlplane subnet\'s dns_nameservers attribute will be used.\\n\", \"type\": \"comma_delimited_list\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"DnsServers\", \"NovaComputeSchedulerHints\", \"NovaComputeExtraConfig\"]}], \"conditions\": {\"add_vips_to_etc_hosts\": {\"equals\": [{\"get_param\": \"AddVipsToEtcHosts\"}, true]}, \"control_fixed_ip_not_set\": {\"equals\": [{\"get_param\": \"ControlFixedIPs\"}, []]}, \"storage_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageVirtualFixedIPs\"}, []]}}, \"storage_mgmt_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, []]}}, \"internal_api_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"InternalApiVirtualFixedIPs\"}, []]}}, \"tenant_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"TenantVirtualFixedIPs\"}, []]}}, \"public_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"PublicVirtualFixedIPs\"}, []]}}, \"set_default_mysql_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"MysqlCellInternal\"]}, \"\"]}]}]}, \"set_default_nova_vnc_proxy_cell_public\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaVNCProxyCellPublic\"]}, \"\"]}]}]}, \"set_default_nova_metadata_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaMetadataCellInternal\"]}, \"\"]}]}]}, \"dnsservers_set\": {\"not\": {\"equals\": [{\"get_param\": \"DnsServers\"}, []]}}}, \"resources\": {\"VipHosts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": [{\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"ctlplane\"]}, \"HOST\": {\"get_param\": \"CloudNameCtlplane\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage\"]}, \"HOST\": {\"get_param\": \"CloudNameStorage\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage_mgmt\"]}, \"HOST\": {\"get_param\": \"CloudNameStorageManagement\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"internal_api\"]}, \"HOST\": {\"get_param\": \"CloudNameInternal\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"external\"]}, \"HOST\": {\"get_param\": \"CloudName\"}}}}]}}, \"NetCidrMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_cidr_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"NetIpVersionMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_ip_version_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"subnets\", 0, \"ip_version\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"ServiceNetMap\": {\"type\": \"OS::TripleO::ServiceNetMap\"}, \"EndpointMap\": {\"type\": \"OS::TripleO::EndpointMap\", \"properties\": {\"CloudEndpoints\": {\"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}, \"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}}, \"NetIpMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}}}, \"EndpointMapData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"EndpointMap\", \"endpoint_map\"]}, {\"get_param\": \"EndpointMapOverride\"}, {\"if\": [\"set_default_mysql_cell_internal\", {\"MysqlCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"MysqlInternal\"]}}, {}]}, {\"if\": [\"set_default_nova_vnc_proxy_cell_public\", {\"NovaVNCProxyCellPublic\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaVNCProxyPublic\"]}}, {}]}, {\"if\": [\"set_default_nova_metadata_cell_internal\", {\"NovaMetadataCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaMetadataInternal\"]}}, {}]}]}}}, \"NodeAdminUserData\": {\"type\": \"OS::TripleO::NodeAdminUserData\"}, \"NodeTimesyncUserData\": {\"type\": \"OS::TripleO::NodeTimesyncUserData\"}, \"NodeUserData\": {\"type\": \"OS::TripleO::NodeUserData\"}, \"ControllerServiceChain\": {\"type\": \"OS::TripleO::ControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"ControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}}}, \"ControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ControllerServiceChain\", \"role_data\"]}}}, \"ControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"ControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}}}}]}}}, \"ControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ControllerServiceNetMap\"}}}}]}}}, \"ControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Controller\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"Controller\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Controller\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}}}, \"ControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Controller\", \"hostname_map\"]}]}}}}, \"ControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ControllerRoleUserData\": {\"type\": \"OS::TripleO::Controller::NodeUserData\"}, \"Controller\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ControllerCount\"}, \"removal_policies\": {\"get_param\": \"ControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Controller\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"ControllerUserData\"}}}}}, \"CellControllerServiceChain\": {\"type\": \"OS::TripleO::CellControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}}}, \"CellControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerServiceChain\", \"role_data\"]}}}, \"CellControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}}}}]}}}, \"CellControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerServiceNetMap\"}}}}]}}}, \"CellControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellController\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellController\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}}}, \"CellControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellController\", \"hostname_map\"]}]}}}}, \"CellControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerRoleUserData\": {\"type\": \"OS::TripleO::CellController::NodeUserData\"}, \"CellController\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellController\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerUserData\"}}}}}, \"CellControllerComputeServiceChain\": {\"type\": \"OS::TripleO::CellControllerComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}}}, \"CellControllerComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerComputeServiceChain\", \"role_data\"]}}}, \"CellControllerComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}}}}]}}}, \"CellControllerComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerComputeServiceNetMap\"}}}}]}}}, \"CellControllerComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellControllerCompute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}}}, \"CellControllerComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellControllerCompute\", \"hostname_map\"]}]}}}}, \"CellControllerComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerComputeRoleUserData\": {\"type\": \"OS::TripleO::CellControllerCompute::NodeUserData\"}, \"CellControllerCompute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerComputeCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellControllerCompute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerComputeUserData\"}}}}}, \"ComputeServiceChain\": {\"type\": \"OS::TripleO::ComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"ComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}}}, \"ComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ComputeServiceChain\", \"role_data\"]}}}, \"ComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NovaComputeExtraConfig\"}, {\"get_param\": \"ComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}}}}]}}}, \"ComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ComputeServiceNetMap\"}}}}]}}}, \"ComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Compute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Compute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}}}, \"ComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Compute\", \"hostname_map\"]}]}}}}, \"ComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ComputeRoleUserData\": {\"type\": \"OS::TripleO::Compute::NodeUserData\"}, \"Compute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ComputeCount\"}, \"removal_policies\": {\"get_param\": \"ComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NovaComputeSchedulerHints\"}, {\"get_param\": \"ComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"ComputeUserData\"}}}}}, \"BlockStorageServiceChain\": {\"type\": \"OS::TripleO::BlockStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"BlockStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}}}, \"BlockStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"BlockStorageServiceChain\", \"role_data\"]}}}, \"BlockStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"BlockStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"BlockStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"BlockStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}}}}]}}}, \"BlockStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"BlockStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"BlockStorageServiceNetMap\"}}}}]}}}, \"BlockStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"BlockStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}}}, \"BlockStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"BlockStorage\", \"hostname_map\"]}]}}}}, \"BlockStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"BlockStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"BlockStorageRoleUserData\": {\"type\": \"OS::TripleO::BlockStorage::NodeUserData\"}, \"BlockStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"BlockStorageCount\"}, \"removal_policies\": {\"get_param\": \"BlockStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"BlockStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::BlockStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"BlockStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"BlockStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"BlockStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"BlockStorageUserData\"}}}}}, \"ObjectStorageServiceChain\": {\"type\": \"OS::TripleO::ObjectStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"ObjectStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}}}, \"ObjectStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ObjectStorageServiceChain\", \"role_data\"]}}}, \"ObjectStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ObjectStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"ObjectStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ObjectStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}}}}]}}}, \"ObjectStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ObjectStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ObjectStorageServiceNetMap\"}}}}]}}}, \"ObjectStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"ObjectStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}}}, \"ObjectStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"ObjectStorage\", \"hostname_map\"]}]}}}}, \"ObjectStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ObjectStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ObjectStorageRoleUserData\": {\"type\": \"OS::TripleO::ObjectStorage::NodeUserData\"}, \"ObjectStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ObjectStorageCount\"}, \"removal_policies\": {\"get_param\": \"ObjectStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ObjectStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::ObjectStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ObjectStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ObjectStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ObjectStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"ObjectStorageUserData\"}}}}}, \"CephStorageServiceChain\": {\"type\": \"OS::TripleO::CephStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"CephStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}}}, \"CephStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CephStorageServiceChain\", \"role_data\"]}}}, \"CephStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CephStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"CephStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CephStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}}}}]}}}, \"CephStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CephStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CephStorageServiceNetMap\"}}}}]}}}, \"CephStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"EnabledServices\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CephStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}}}, \"CephStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CephStorage\", \"hostname_map\"]}]}}}}, \"CephStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CephStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CephStorageRoleUserData\": {\"type\": \"OS::TripleO::CephStorage::NodeUserData\"}, \"CephStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CephStorageCount\"}, \"removal_policies\": {\"get_param\": \"CephStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CephStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CephStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CephStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CephStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CephStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"CephStorageUserData\"}}}}}, \"NetworkerServiceChain\": {\"type\": \"OS::TripleO::NetworkerServices\", \"properties\": {\"Services\": {\"get_param\": \"NetworkerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}}}, \"NetworkerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"NetworkerServiceChain\", \"role_data\"]}}}, \"NetworkerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"NetworkerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NetworkerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"NetworkerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}}]}}}, \"NetworkerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"NetworkerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetworkerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"NetworkerServiceNetMap\"}}}}]}}}, \"NetworkerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Networker\", \"ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Networker\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"NetworkerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Networker\", \"hostname_map\"]}]}}}}, \"NetworkerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NetworkerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"NetworkerRoleUserData\": {\"type\": \"OS::TripleO::Networker::NodeUserData\"}, \"Networker\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"NetworkerCount\"}, \"removal_policies\": {\"get_param\": \"NetworkerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"NetworkerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Networker\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"NetworkerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"NetworkerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NetworkerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}, \"UserData\": {\"get_resource\": \"NetworkerUserData\"}}}}}, \"ControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Controller\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Controller\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellController\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellController\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerCompute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellControllerCompute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Compute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Compute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"BlockStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"BlockStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ObjectStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"ObjectStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CephStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CephStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"NetworkerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Networker\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Networker\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ServerIdMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"server_ids\": {\"Controller\": {\"get_attr\": [\"Controller\", \"nova_server_resource\"]}, \"CellController\": {\"get_attr\": [\"CellController\", \"nova_server_resource\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}, \"Compute\": {\"get_attr\": [\"Compute\", \"nova_server_resource\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorage\", \"nova_server_resource\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorage\", \"nova_server_resource\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorage\", \"nova_server_resource\"]}, \"Networker\": {\"get_attr\": [\"Networker\", \"nova_server_resource\"]}}, \"bootstrap_server_id\": {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}}}}}}, \"DeploymentServerBlacklistDict\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"hostname\": 1}, \"for_each\": {\"hostname\": {\"get_param\": \"DeploymentServerBlacklist\"}}}}}}}, \"HostsEntryValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": {\"list_concat\": [[{\"get_param\": \"UndercloudHostsEntries\"}], [{\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}], {\"get_attr\": [\"Controller\", \"hosts_entry\"]}, {\"get_attr\": [\"CellController\", \"hosts_entry\"]}, {\"get_attr\": [\"CellControllerCompute\", \"hosts_entry\"]}, {\"get_attr\": [\"Compute\", \"hosts_entry\"]}, {\"get_attr\": [\"BlockStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"ObjectStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"CephStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"Networker\", \"hosts_entry\"]}, [{\"get_param\": \"ExtraHostFileEntries\"}]]}}}}, \"CloudNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"cloud_name_storage\": {\"get_param\": \"CloudNameStorage\"}, \"cloud_name_storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"cloud_name_internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"cloud_name_external\": {\"get_param\": \"CloudName\"}, \"cloud_name_ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}, \"GlobalConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}]}}}, \"Networks\": {\"type\": \"OS::TripleO::Network\", \"depends_on\": \"ServiceNetMap\", \"properties\": {\"CtlplaneNetworkCidrs\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}]}, \"ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}]}, \"edge_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}]}, \"edge_ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}]}}}}, \"ControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}}}}, \"ControllerNetworkConfig\": {\"type\": \"OS::TripleO::Controller::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"CellControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\"], \"service_net_map\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}}}}, \"CellControllerNetworkConfig\": {\"type\": \"OS::TripleO::CellController::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"CellControllerComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}}}}, \"CellControllerComputeNetworkConfig\": {\"type\": \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"ComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"compute\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}}}}, \"ComputeNetworkConfig\": {\"type\": \"OS::TripleO::Compute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"BlockStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"BlockStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"BlockStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}}}}, \"BlockStorageNetworkConfig\": {\"type\": \"OS::TripleO::BlockStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"ObjectStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ObjectStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ObjectStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}}}}, \"ObjectStorageNetworkConfig\": {\"type\": \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"CephStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CephStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CephStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"ceph\", \"storage\"], \"service_net_map\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}}}}, \"CephStorageNetworkConfig\": {\"type\": \"OS::TripleO::CephStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}}}, \"NetworkerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"NetworkerLocalMtu\"}, \"role_networks\": [\"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"NetworkerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}}}}, \"NetworkerNetworkConfig\": {\"type\": \"OS::TripleO::Networker::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ControlVirtualIP\": {\"depends_on\": \"ServiceNetMap\", \"type\": \"OS::TripleO::Network::Ports::ControlPlaneVipPort\", \"properties\": {\"name\": \"control_virtual_ip\", \"dns_name\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameCtlplane\"}, 0]}, \"network\": {\"get_param\": \"NeutronControlPlaneID\"}, \"fixed_ips\": {\"if\": [\"control_fixed_ip_not_set\", [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}}], {\"get_param\": \"ControlFixedIPs\"}]}, \"replacement_policy\": \"AUTO\", \"tags\": [\"tripleo_vip_net=ctlplane\", {\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"OS::stack_name\"}}}}]}}, \"StorageVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorage\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_virtual_fixed_ip_set\", {\"get_param\": \"StorageVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"Storage\"]}}]]}, \"IsVirtualIP\": true}}, \"StorageMgmtVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageMgmtVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorageManagement\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_mgmt_virtual_fixed_ip_set\", {\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"StorageMgmt\"]}}]]}, \"IsVirtualIP\": true}}, \"InternalApiVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::InternalApiVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"internal_api_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameInternal\"}, 0]}, \"FixedIPs\": {\"if\": [\"internal_api_virtual_fixed_ip_set\", {\"get_param\": \"InternalApiVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"InternalApi\"]}}]]}, \"IsVirtualIP\": true}}, \"PublicVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::ExternalVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"external_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudName\"}, 0]}, \"FixedIPs\": {\"if\": [\"public_virtual_fixed_ip_set\", {\"get_param\": \"PublicVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"External\"]}}]]}, \"IsVirtualIP\": true}}, \"VipMap\": {\"type\": \"OS::TripleO::Network::Ports::NetVipMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"StorageIp\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address\"]}, \"StorageIpUri\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address_uri\"]}, \"ExternalIp\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address\"]}, \"ExternalIpUri\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address_uri\"]}}, \"depends_on\": \"ServiceNetMap\"}, \"AllNodesExtraConfig\": {\"type\": \"OS::TripleO::AllNodesExtraConfig\", \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}}}, \"BlacklistedIpAddresses\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellController\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Compute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Networker\", \"blacklist_ip_address\"]}]}}}, \"AnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"Controller\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"ansible_host_vars_map\"]}]}}, \"CellController\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellController\", \"ansible_host_vars_map\"]}]}}, \"CellControllerCompute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellControllerCompute\", \"ansible_host_vars_map\"]}]}}, \"Compute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Compute\", \"ansible_host_vars_map\"]}]}}, \"BlockStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"BlockStorage\", \"ansible_host_vars_map\"]}]}}, \"ObjectStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"ObjectStorage\", \"ansible_host_vars_map\"]}]}}, \"CephStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CephStorage\", \"ansible_host_vars_map\"]}]}}, \"Networker\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Networker\", \"ansible_host_vars_map\"]}]}}}}}, \"BlacklistedHostnames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellController\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Compute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Networker\", \"blacklist_hostname\"]}]}}}, \"AllNodesDeploySteps\": {\"type\": \"OS::TripleO::PostDeploySteps\", \"depends_on\": [\"AllNodesExtraConfig\"], \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"role_data\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}, \"ServiceNetMapLower\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, \"PingTestGatewayIPsMap\": {\"Controller\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"CellController\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"Compute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"CephStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}]}}, \"Networker\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}}, \"PingTestIpsMap\": {\"Controller\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"external_ip_address\"]}}}]]}, \"CellController\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}}}]]}, \"CellControllerCompute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}}}]]}, \"Compute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}}}]]}, \"BlockStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}}}]]}, \"ObjectStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}}}]]}, \"CephStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}}}]]}, \"Networker\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}}}]]}}, \"HostsEntry\": {\"get_attr\": [\"HostsEntryValue\", \"value\"]}, \"EnabledServices\": {\"list_concat\": [{\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}]}, \"ControlVirtualIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"EnabledNetworks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"NetVipMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"CloudNames\": {\"get_attr\": [\"CloudNames\", \"value\"]}, \"UndercloudHostsEntries\": {\"get_param\": \"UndercloudHostsEntries\"}, \"ExtraHostsEntries\": {\"get_param\": \"ExtraHostFileEntries\"}, \"VipHostsEntries\": {\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}, \"KeystoneResourcesConfigs\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"keystone_resources\"]}]}, \"NetCidrMap\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}}}}, \"outputs\": {\"ManagedEndpoints\": {\"description\": \"Asserts that the keystone endpoints have been provisioned.\", \"value\": true}, \"KeystoneURL\": {\"description\": \"URL for the Overcloud Keystone service\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\", \"KeystonePublic\", \"uri_no_suffix\"]}}, \"KeystoneAdminVip\": {\"description\": \"Keystone Admin VIP endpoint\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\", \"KeystoneAdminApiNetwork\"]}]}}, \"EndpointMap\": {\"description\": \"Mapping of the resources with the needed info for their endpoints.\\nThis includes the protocol used, the IP, port and also a full\\nrepresentation of the URI.\\n\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}}, \"HostsEntry\": {\"description\": \"The content that should be appended to your /etc/hosts if you want to get\\nhostname-based access to the deployed nodes (useful for testing without\\nsetting up a DNS).\\n\", \"value\": {\"list_concat_unique\": [{\"get_attr\": [\"HostsEntryValue\", \"value\"]}, {\"get_attr\": [\"VipHosts\", \"value\"]}]}}, \"EnabledServices\": {\"description\": \"The services enabled on each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}, \"RoleData\": {\"description\": \"The configuration data associated with each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}}, \"RoleConfig\": {\"description\": \"The configuration workflows associated with each role\", \"value\": {\"get_attr\": [\"AllNodesDeploySteps\", \"RoleConfig\"]}}, \"RoleNetIpMap\": {\"description\": \"Mapping of each network to a list of IPs for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerIpListMap\", \"net_ip_map\"]}, \"CellController\": {\"get_attr\": [\"CellControllerIpListMap\", \"net_ip_map\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeIpListMap\", \"net_ip_map\"]}, \"Compute\": {\"get_attr\": [\"ComputeIpListMap\", \"net_ip_map\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageIpListMap\", \"net_ip_map\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageIpListMap\", \"net_ip_map\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageIpListMap\", \"net_ip_map\"]}, \"Networker\": {\"get_attr\": [\"NetworkerIpListMap\", \"net_ip_map\"]}}}, \"RoleGroupVars\": {\"description\": \"Mapping of roles to ansible group_vars to be applied config in those roles\", \"value\": {\"Controller\": {\"map_merge\": [{\"get_attr\": [\"ControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"ControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ControllerExtraGroupVars\"}]}, \"CellController\": {\"map_merge\": [{\"get_attr\": [\"CellControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerExtraGroupVars\"}]}, \"CellControllerCompute\": {\"map_merge\": [{\"get_attr\": [\"CellControllerComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerComputeExtraGroupVars\"}]}, \"Compute\": {\"map_merge\": [{\"get_attr\": [\"ComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"ComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ComputeExtraGroupVars\"}]}, \"BlockStorage\": {\"map_merge\": [{\"get_attr\": [\"BlockStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"BlockStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"BlockStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"BlockStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"BlockStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"BlockStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"BlockStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"BlockStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"BlockStorageExtraGroupVars\"}]}, \"ObjectStorage\": {\"map_merge\": [{\"get_attr\": [\"ObjectStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"ObjectStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ObjectStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ObjectStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ObjectStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ObjectStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ObjectStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ObjectStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ObjectStorageExtraGroupVars\"}]}, \"CephStorage\": {\"map_merge\": [{\"get_attr\": [\"CephStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"CephStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CephStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CephStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CephStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CephStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CephStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CephStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CephStorageExtraGroupVars\"}]}, \"Networker\": {\"map_merge\": [{\"get_attr\": [\"NetworkerGroupVars\", \"value\"]}, {\"get_attr\": [\"NetworkerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"NetworkerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"NetworkerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"NetworkerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"NetworkerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"NetworkerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"NetworkerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"NetworkerExtraGroupVars\"}]}}}, \"RoleNetHostnameMap\": {\"description\": \"Mapping of each network to a list of hostnames for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"RoleTags\": {\"description\": \"Tags for each role, as defined in roles_data.yaml\", \"value\": {\"Controller\": [\"primary\", \"controller\", \"external_bridge\"], \"CellController\": [\"primary\", \"controller\"], \"CellControllerCompute\": [\"primary\", \"controller\", \"external_bridge\"], \"Compute\": [\"compute\", \"external_bridge\"], \"BlockStorage\": [\"storage\"], \"ObjectStorage\": [\"storage\"], \"CephStorage\": [\"ceph\", \"storage\"], \"Networker\": [\"external_bridge\"]}}, \"VipMap\": {\"description\": \"Mapping of each network to VIP addresses. Also includes the Redis and OVN DBs VIPs.\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}}, \"ServerIdData\": {\"description\": \"Mapping of each role to a list of nova server IDs and the bootstrap ID\", \"value\": {\"get_attr\": [\"ServerIdMap\", \"value\"]}}, \"BlacklistedHostnames\": {\"description\": \"List of blacklisted hostnames\", \"value\": {\"get_attr\": [\"BlacklistedHostnames\", \"value\"]}}, \"BlacklistedIpAddresses\": {\"description\": \"List of blacklisted ctlplane IP addresses\", \"value\": {\"get_attr\": [\"BlacklistedIpAddresses\", \"value\"]}}, \"GlobalConfig\": {\"description\": \"The global_config (hieradata).\", \"value\": {\"get_attr\": [\"GlobalConfig\", \"value\"]}}, \"RoleNetworkConfigMap\": {\"description\": \"Mapping of roles to network config\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkConfig\", \"config\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkConfig\", \"config\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkConfig\", \"config\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkConfig\", \"config\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkConfig\", \"config\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkConfig\", \"config\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkConfig\", \"config\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkConfig\", \"config\"]}}}, \"AnsibleHostVarsMap\": {\"description\": \"Map of Ansible Host variables per role\", \"value\": {\"get_attr\": [\"AnsibleHostVars\", \"value\"]}}, \"TripleoHeatTemplatesJinja2RenderingDataSources\": {\"description\": \"The role_data and the network_data used when rendering the THT Jinja2 templates\", \"value\": {\"roles_data\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"networks_data\": [{\"name\": \"Storage\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage\", \"dns_domain\": \"storage.ooo.test.\", \"service_net_map_replace\": \"storage\", \"subnets\": {\"storage_subnet\": {\"vlan\": 21, \"ip_subnet\": \"172.18.0.0/24\", \"allocation_pools\": [{\"start\": \"172.18.0.120\", \"end\": \"172.18.0.250\"}]}}, \"idx\": 0}, {\"name\": \"StorageMgmt\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage_mgmt\", \"dns_domain\": \"storagemgmt.ooo.test.\", \"service_net_map_replace\": \"storage_mgmt\", \"subnets\": {\"storage_mgmt_subnet\": {\"vlan\": 23, \"ip_subnet\": \"172.20.0.0/24\", \"allocation_pools\": [{\"start\": \"172.20.0.120\", \"end\": \"172.20.0.250\"}]}}, \"idx\": 1}, {\"name\": \"InternalApi\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"internal_api\", \"dns_domain\": \"internal-api.ooo.test.\", \"service_net_map_replace\": \"internal_api\", \"subnets\": {\"internal_api_subnet\": {\"vlan\": 20, \"ip_subnet\": \"172.17.0.0/24\", \"allocation_pools\": [{\"start\": \"172.17.0.120\", \"end\": \"172.17.0.250\"}]}}, \"idx\": 2}, {\"name\": \"Tenant\", \"mtu\": 1500, \"vip\": false, \"name_lower\": \"tenant\", \"dns_domain\": \"tenant.ooo.test.\", \"service_net_map_replace\": \"tenant\", \"subnets\": {\"tenant_subnet\": {\"vlan\": 22, \"ip_subnet\": \"172.19.0.0/24\", \"allocation_pools\": [{\"start\": \"172.19.0.120\", \"end\": \"172.19.0.250\"}]}}, \"idx\": 3}, {\"name\": \"External\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"external\", \"dns_domain\": \"external.ooo.test.\", \"service_net_map_replace\": \"external\", \"subnets\": {\"external_subnet\": {\"vlan\": 44, \"ip_subnet\": \"172.21.0.0/24\", \"allocation_pools\": [{\"start\": \"172.21.0.120\", \"end\": \"172.21.0.250\"}]}}, \"idx\": 4}]}}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"value\": {\"get_param\": \"AdminPassword\"}}, \"KeystoneRegion\": {\"description\": \"Keystone region for endpoint\", \"value\": {\"get_param\": \"KeystoneRegion\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(2,'2026-06-15 07:51:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(3,'2026-06-15 07:51:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mapping of service_name_network -> network name\\n\", \"parameters\": {\"ServiceNetMap\": {\"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults. Note that the key in this map must match the service_name in the service template, e.g if the service_name is heat_api the key must be either heat_api_network, or optionally HeatApiNetwork (which will be internally converted to transform captalization to underscores).\", \"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"VipSubnetMap\": {\"description\": \"Map of (network_name or service_name) -> subnet_name that defines which subnet to host the VIP. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\", \"default\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMapDeprecatedMapping\": {\"default\": {\"RabbitMqNetwork\": \"RabbitmqNetwork\", \"CephPublicNetwork\": \"CephMonNetwork\", \"SwiftMgmtNetwork\": \"SwiftStorageNetwork\"}, \"description\": \"Mapping older deprecated service names, intended for internal use only, this will be removed in future.\", \"type\": \"json\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"ServiceNetMapDeprecatedMapping\"]}], \"resources\": {\"ServiceNetMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"map_replace\": [{\"get_param\": \"ServiceNetMap\"}, {\"values\": {\"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}, \"keys\": {\"get_param\": \"ServiceNetMapDeprecatedMapping\"}}]}, {\"NovaVncProxyNetwork\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}]}}}}, \"outputs\": {\"service_net_map\": {\"value\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}, \"service_net_map_lower\": {\"value\": {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}}}}, \"vip_subnet_map\": {\"value\": {\"map_replace\": [{\"get_param\": \"VipSubnetMap\"}, {\"values\": {\"ctlplane-subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(4,'2026-06-15 07:51:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(5,'2026-06-15 07:51:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Control Plane network.\\n\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ControlPlaneVipData\": {\"description\": \"Control Plane Virtual IP data\\n\", \"default\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"type\": \"json\"}}, \"outputs\": {\"name\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"name\"]}}, \"fixed_ips\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"fixed_ips\"]}}, \"network\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"network\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"subnets\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"control_virtual_ip\", \"dns_name\": \"overcloud\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_vip_net=ctlplane,tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(6,'2026-06-15 07:51:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(7,'2026-06-15 07:51:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(8,'2026-06-15 07:51:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Create networks to split out Overcloud traffic\", \"parameters\": {\"DeployedNetworkEnvironment\": {\"type\": \"json\", \"description\": \"Deployed network environment\", \"default\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}}, \"CtlplaneNetworkCidrs\": {\"type\": \"json\", \"description\": \"Cidrs for the ctlplane network.\"}, \"CtlplaneNetworkAttributes\": {\"type\": \"json\", \"default\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"description\": \"A map containing attributes of the undercloud ctlplane network and subnets. NOTE: The value for this parameter is automatically populated in the plan environment by tripleoclient.\\n\"}}, \"resources\": {\"NetworkExtraConfig\": {\"type\": \"OS::TripleO::Network::ExtraConfig\"}, \"NetworkAttributesMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkAttributes\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_attributes_map\"]}]}}}, \"NetworkCidrMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkCidrs\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_cidr_map\"]}]}}}, \"NetworkIpVersionMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"yaql\": {\"expression\": \"$.data.items().first().last().ip_version\", \"data\": {\"get_param\": [\"CtlplaneNetworkAttributes\", \"subnets\"]}}}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_ip_version_map\"]}]}}}}, \"outputs\": {\"net_cidr_map\": {\"value\": {\"get_attr\": [\"NetworkCidrMap\", \"value\"]}}, \"net_ip_version_map\": {\"value\": {\"get_attr\": [\"NetworkIpVersionMap\", \"value\"]}}, \"net_attributes_map\": {\"value\": {\"get_attr\": [\"NetworkAttributesMap\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"CtlplaneNetworkCidrs\": \"[\\\"192.168.122.0/24\\\"]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (9,'2026-06-15 07:51:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(10,'2026-06-15 07:51:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(11,'2026-06-15 07:51:07',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"node_admin_username\": {\"type\": \"string\", \"default\": \"heat-admin\"}, \"node_admin_extra_ssh_keys\": {\"type\": \"comma_delimited_list\", \"default\": []}}, \"description\": \"Uses cloud-init to create an additional user with a known name, in addition to the distro-default user created by the cloud-init default.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"user_config\"}}]}}, \"user_config\": {\"type\": \"OS::Heat::CloudConfig\", \"properties\": {\"cloud_config\": {\"user\": {\"get_param\": \"node_admin_username\"}, \"ssh_authorized_keys\": {\"get_param\": \"node_admin_extra_ssh_keys\"}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(12,'2026-06-15 07:51:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(13,'2026-06-15 07:51:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(14,'2026-06-15 07:51:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(15,'2026-06-15 07:51:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the External network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"External network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"external_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"external_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(16,'2026-06-15 07:51:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"internal_api_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(17,'2026-06-15 07:51:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(18,'2026-06-15 07:51:11',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIp\": {\"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"StorageIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageIpSubnet\": {\"description\": \"IP address/subnet on the storage network\", \"default\": \"\", \"type\": \"string\"}, \"StorageIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpSubnet\": {\"description\": \"IP address/subnet on the storage_mgmt network\", \"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIp\": {\"default\": \"\", \"type\": \"string\"}, \"InternalApiIpSubnet\": {\"description\": \"IP address/subnet on the internal_api network\", \"default\": \"\", \"type\": \"string\"}, \"InternalApiIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIp\": {\"default\": \"\", \"type\": \"string\"}, \"TenantIpSubnet\": {\"description\": \"IP address/subnet on the tenant network\", \"default\": \"\", \"type\": \"string\"}, \"TenantIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIp\": {\"default\": \"\", \"type\": \"string\"}, \"ExternalIpSubnet\": {\"description\": \"IP address/subnet on the external network\", \"default\": \"\", \"type\": \"string\"}, \"ExternalIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"resources\": {\"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"ctlplane\": {\"get_param\": \"ControlPlaneIp\"}, \"ctlplane_subnet\": {\"list_join\": [\"\", [{\"get_param\": \"ControlPlaneIp\"}, \"/\", {\"get_param\": \"ControlPlaneSubnetCidr\"}]]}, \"ctlplane_uri\": {\"str_replace\": {\"template\": {\"make_url\": {\"host\": {\"get_param\": \"ControlPlaneIp\"}}}, \"params\": {\"//\": \"\"}}}, \"storage\": {\"get_param\": \"StorageIp\"}, \"storage_subnet\": {\"get_param\": \"StorageIpSubnet\"}, \"storage_uri\": {\"get_param\": \"StorageIpUri\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIp\"}, \"storage_mgmt_subnet\": {\"get_param\": \"StorageMgmtIpSubnet\"}, \"storage_mgmt_uri\": {\"get_param\": \"StorageMgmtIpUri\"}, \"internal_api\": {\"get_param\": \"InternalApiIp\"}, \"internal_api_subnet\": {\"get_param\": \"InternalApiIpSubnet\"}, \"internal_api_uri\": {\"get_param\": \"InternalApiIpUri\"}, \"tenant\": {\"get_param\": \"TenantIp\"}, \"tenant_subnet\": {\"get_param\": \"TenantIpSubnet\"}, \"tenant_uri\": {\"get_param\": \"TenantIpUri\"}, \"external\": {\"get_param\": \"ExternalIp\"}, \"external_subnet\": {\"get_param\": \"ExternalIpSubnet\"}, \"external_uri\": {\"get_param\": \"ExternalIpUri\"}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"storage_mgmt_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"storage_mgmt_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"internal_api_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"internal_api_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"tenant_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"tenant_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"external\": {\"get_param\": \"ExternalNetName\"}, \"external_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}, \"external_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIp\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"StorageIp\": \"172.18.0.239\", \"StorageIpUri\": \"172.18.0.239\", \"StorageMgmtIp\": \"172.20.0.213\", \"StorageMgmtIpUri\": \"172.20.0.213\", \"InternalApiIp\": \"172.17.0.148\", \"InternalApiIpUri\": \"172.17.0.148\", \"ExternalIp\": \"172.21.0.154\", \"ExternalIpUri\": \"172.21.0.154\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(19,'2026-06-15 07:51:11',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"NtpService\": {\"default\": \"chrony\", \"description\": \"NTP Service to use for the timesync bootstrap.\", \"type\": \"string\"}}, \"description\": \"Uses cloud-init to bootstrap timesync configuration to ensure it is done as soon as possible. We do additional and more complex configurations as part of the deployment itself.\\n\", \"conditions\": {\"use_chrony\": {\"equals\": [{\"get_param\": \"NtpService\"}, \"chrony\"]}}, \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"timesync_chrony\"}}, {\"config\": {\"get_resource\": \"timesync_sync\"}}]}}, \"timesync_chrony\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nif [ \\\"$service\\\" != \\\"chrony\\\" ]; then\\n  exit 0\\nfi\\nset -x\\nSERVERS=\\\"$ntp_servers\\\"\\nPOOLS=\\\"$ntp_pools\\\"\\nsystemctl is-active --quiet chronyd || systemctl start chronyd\\nfor server in $SERVERS; do\\n  chronyc add server \\\"${server}\\\" iburst\\ndone\\nfor pool in $POOLS; do\\n  chronyc add server \\\"${pool}\\\" iburst\\ndone\\nchronyc sources\\n\", \"params\": {\"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}, \"$ntp_pools\": {\"list_join\": [\" \", {\"get_param\": \"NtpPool\"}]}, \"$service\": {\"get_param\": \"NtpService\"}}}}}}, \"timesync_sync\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nset -x\\nif [ \\\"$service\\\" = \\\"chrony\\\" ]; then\\n    if command -v chronyc >/dev/null; then\\n        chronyc makestep\\n        chronyc waitsync 30\\n    else\\n        echo \\\"No chronyc available, skipping sync\\\"\\n    fi\\nelif [ \\\"$service\\\" = \\\"ntp\\\" ]; then\\n    if command -v ntpdate >/dev/null; then\\n        ntpdate -u $ntp_servers\\n    else\\n        echo \\\"No ntpdate available, skipping sync\\\"\\n    fi\\nfi\\nhwclock --systohc --utc\\n\", \"params\": {\"$service\": {\"get_param\": \"NtpService\"}, \"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}}}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (20,'2026-06-15 07:51:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(21,'2026-06-15 07:51:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"A map of OpenStack endpoints. Since the endpoints are URLs, we need to have brackets around IPv6 IP addresses. The inputs to these parameters come from net_ip_uri_map, which will include these brackets in IPv6 addresses.\", \"parameters\": {\"NetIpMap\": {\"type\": \"json\", \"default\": {}, \"description\": \"The Net IP map\"}, \"ServiceNetMap\": {\"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"The Service Net map\"}, \"EndpointMap\": {\"type\": \"json\", \"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}, \"CloudEndpoints\": {\"type\": \"json\", \"default\": {}, \"description\": \"A map containing the DNS names for the different endpoints (external, internal_api, etc.)\"}}, \"outputs\": {\"endpoint_map\": {\"value\": {\"AodhAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}}, \"AodhInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}}, \"AodhPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}}, \"BarbicanAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}}, \"BarbicanInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}}, \"BarbicanPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}}, \"CephDashboardInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}}, \"CephGrafanaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}}, \"CephRgwAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}}}}, \"CephRgwInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}}}}, \"CephRgwPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}}}}, \"CinderAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV2Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV2Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV2Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"DesignateAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}}}}, \"DesignateInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}}}}, \"DesignatePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}}}}, \"DockerRegistryInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}}, \"GaneshaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}}, \"GlanceAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}}, \"GlanceInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, \"GlancePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}}, \"GnocchiAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}}, \"GnocchiInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}}, \"GnocchiPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}}, \"HeatAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}}}}, \"HeatInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}}}}, \"HeatPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}}}}, \"HeatCfnAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}}}}, \"HeatCfnInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}}}}, \"HeatCfnPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}}, \"HorizonPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"path\": \"/dashboard\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}}}}, \"IronicAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}}}}, \"IronicInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}}}}, \"IronicPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}}}}, \"IronicInspectorAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}}, \"IronicInspectorInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}}, \"IronicInspectorPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}}, \"KeystoneAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystonePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"KeystoneV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystoneV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"ManilaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"ManilaV1Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaV1Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaV1Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"MetricsQdrPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}}, \"MysqlInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}}, \"NeutronAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}}, \"NeutronInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}}, \"NeutronPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}}, \"NovaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}}}}, \"NovaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}}}}, \"NovaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}}}}, \"NovaMetadataInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}}, \"NovaVNCProxyAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}}, \"NovaVNCProxyInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}}, \"NovaVNCProxyPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}}, \"NovajoinAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}}}}, \"NovajoinInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}}}}, \"NovajoinPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}}}}, \"OctaviaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}}, \"OctaviaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}}, \"OctaviaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}}, \"PlacementAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}}}}, \"PlacementInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}}}}, \"PlacementPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}}}}, \"SwiftAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}, \"SwiftS3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftS3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftS3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NetIpMap\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"CloudEndpoints\": {\"ctlplane\": \"overcloud.ctlplane.ooo.test\", \"storage\": \"overcloud.storage.ooo.test\", \"storage_mgmt\": \"overcloud.storagemgmt.ooo.test\", \"internal_api\": \"overcloud.internalapi.ooo.test\", \"external\": \"overcloud.ooo.test\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(22,'2026-06-15 07:51:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(23,'2026-06-15 07:51:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::CeilometerAgentCentral,OS::TripleO::Services::CeilometerAgentNotification,OS::TripleO::Services::CinderApi,OS::TripleO::Services::CinderBackup,OS::TripleO::Services::CinderScheduler,OS::TripleO::Services::CinderVolume,OS::TripleO::Services::Clustercheck,OS::TripleO::Services::Collectd,OS::TripleO::Services::ContainerImagePrepare,OS::TripleO::Services::GlanceApi,OS::TripleO::Services::GlanceApiInternal,OS::TripleO::Services::HAproxy,OS::TripleO::Services::HeatApi,OS::TripleO::Services::HeatApiCloudwatch,OS::TripleO::Services::HeatApiCfn,OS::TripleO::Services::HeatEngine,OS::TripleO::Services::Horizon,OS::TripleO::Services::IpaClient,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::Keystone,OS::TripleO::Services::ManilaApi,OS::TripleO::Services::ManilaBackendCephFs,OS::TripleO::Services::ManilaScheduler,OS::TripleO::Services::ManilaShare,OS::TripleO::Services::Memcached,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQL,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NeutronApi,OS::TripleO::Services::NeutronCorePlugin,OS::TripleO::Services::NovaApi,OS::TripleO::Services::NovaConductor,OS::TripleO::Services::NovaMetadata,OS::TripleO::Services::NovaScheduler,OS::TripleO::Services::NovaVncProxy,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::OVNDBs,OS::TripleO::Services::OVNController,OS::TripleO::Services::Pacemaker,OS::TripleO::Services::PlacementApi,OS::TripleO::Services::OsloMessagingRpc,OS::TripleO::Services::OsloMessagingNotify,OS::TripleO::Services::Podman,OS::TripleO::Services::Redis,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::SwiftProxy,OS::TripleO::Services::SwiftRingBuilder,OS::TripleO::Services::SwiftStorage,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(24,'2026-06-15 07:51:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(25,'2026-06-15 07:51:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CephStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (26,'2026-06-15 07:51:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::Collectd,OS::TripleO::Services::ComputeCeilometerAgent,OS::TripleO::Services::CeilometerAgentIpmi,OS::TripleO::Services::IpaClient,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NovaCompute,OS::TripleO::Services::NovaLibvirt,OS::TripleO::Services::NovaLibvirtGuests,OS::TripleO::Services::NovaMigrationTarget,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::Podman,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned,OS::TripleO::Services::OVNController,OS::TripleO::Services::OVNMetadataAgent\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(27,'2026-06-15 07:51:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::BlockStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(28,'2026-06-15 07:51:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::NetworkerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(29,'2026-06-15 07:51:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ObjectStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(30,'2026-06-15 07:51:15',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (31,'2026-06-15 07:51:15',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::ComputeCeilometerAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CeilometerAgentIpmi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::IpaClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::NovaCompute\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::NovaLibvirt\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::NovaLibvirtGuests\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::NovaMigrationTarget\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::OVNMetadataAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"21\"]}}, \"outputs\": {\"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(32,'2026-06-15 07:51:16',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (33,'2026-06-15 07:51:15',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::CeilometerAgentCentral\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::CeilometerAgentNotification\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CinderApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::CinderBackup\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::CinderScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::CinderVolume\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::Clustercheck\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::ContainerImagePrepare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::GlanceApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::GlanceApiInternal\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::HAproxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::HeatApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::HeatApiCloudwatch\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::HeatApiCfn\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::HeatEngine\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Horizon\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::IpaClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::Keystone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::ManilaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::ManilaBackendCephFs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::ManilaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"21\"]}, \"26\": {\"type\": \"OS::TripleO::Services::ManilaShare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"22\"]}, \"27\": {\"type\": \"OS::TripleO::Services::Memcached\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"23\"]}, \"28\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"24\"]}, \"29\": {\"type\": \"OS::TripleO::Services::MySQL\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"25\"]}, \"30\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"26\"]}, \"31\": {\"type\": \"OS::TripleO::Services::NeutronApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"27\"]}, \"32\": {\"type\": \"OS::TripleO::Services::NeutronCorePlugin\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"28\"]}, \"33\": {\"type\": \"OS::TripleO::Services::NovaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"29\"]}, \"34\": {\"type\": \"OS::TripleO::Services::NovaConductor\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"30\"]}, \"35\": {\"type\": \"OS::TripleO::Services::NovaMetadata\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"31\"]}, \"36\": {\"type\": \"OS::TripleO::Services::NovaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"32\"]}, \"37\": {\"type\": \"OS::TripleO::Services::NovaVncProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"33\"]}, \"38\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"34\"]}, \"39\": {\"type\": \"OS::TripleO::Services::OVNDBs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"35\"]}, \"40\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"36\"]}, \"41\": {\"type\": \"OS::TripleO::Services::Pacemaker\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"37\"]}, \"42\": {\"type\": \"OS::TripleO::Services::PlacementApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"38\"]}, \"43\": {\"type\": \"OS::TripleO::Services::OsloMessagingRpc\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"39\"]}, \"44\": {\"type\": \"OS::TripleO::Services::OsloMessagingNotify\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"40\"]}, \"45\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"41\"]}, \"46\": {\"type\": \"OS::TripleO::Services::Redis\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"42\"]}, \"47\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"43\"]}, \"48\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"44\"]}, \"49\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"45\"]}, \"50\": {\"type\": \"OS::TripleO::Services::SwiftProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"46\"]}, \"51\": {\"type\": \"OS::TripleO::Services::SwiftRingBuilder\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"47\"]}, \"52\": {\"type\": \"OS::TripleO::Services::SwiftStorage\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"48\"]}, \"53\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"49\"]}, \"54\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"50\"]}, \"55\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"51\"]}, \"56\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"52\"]}, \"57\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"53\"]}}, \"outputs\": {\"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"26\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"27\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"28\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"29\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"30\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"31\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"32\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"33\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"34\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"35\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"36\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"37\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"38\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"39\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"40\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"41\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"42\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"43\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"44\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"45\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"46\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"47\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"48\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"49\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"50\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"51\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"52\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"53\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"54\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"55\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"56\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"57\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"step_config\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"26\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"27\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"28\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"29\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"30\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"31\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"32\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"33\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"34\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"35\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"36\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"37\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"38\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"39\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"40\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"41\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"42\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"43\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"44\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"45\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"46\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"47\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"48\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"49\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"50\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"51\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"52\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"53\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"54\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"55\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"56\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"57\", \"role_data\", \"config_settings\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_names\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"docker_config\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_name\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}, {\"get_attr\": [\"26\", \"role_data\"]}, {\"get_attr\": [\"27\", \"role_data\"]}, {\"get_attr\": [\"28\", \"role_data\"]}, {\"get_attr\": [\"29\", \"role_data\"]}, {\"get_attr\": [\"30\", \"role_data\"]}, {\"get_attr\": [\"31\", \"role_data\"]}, {\"get_attr\": [\"32\", \"role_data\"]}, {\"get_attr\": [\"33\", \"role_data\"]}, {\"get_attr\": [\"34\", \"role_data\"]}, {\"get_attr\": [\"35\", \"role_data\"]}, {\"get_attr\": [\"36\", \"role_data\"]}, {\"get_attr\": [\"37\", \"role_data\"]}, {\"get_attr\": [\"38\", \"role_data\"]}, {\"get_attr\": [\"39\", \"role_data\"]}, {\"get_attr\": [\"40\", \"role_data\"]}, {\"get_attr\": [\"41\", \"role_data\"]}, {\"get_attr\": [\"42\", \"role_data\"]}, {\"get_attr\": [\"43\", \"role_data\"]}, {\"get_attr\": [\"44\", \"role_data\"]}, {\"get_attr\": [\"45\", \"role_data\"]}, {\"get_attr\": [\"46\", \"role_data\"]}, {\"get_attr\": [\"47\", \"role_data\"]}, {\"get_attr\": [\"48\", \"role_data\"]}, {\"get_attr\": [\"49\", \"role_data\"]}, {\"get_attr\": [\"50\", \"role_data\"]}, {\"get_attr\": [\"51\", \"role_data\"]}, {\"get_attr\": [\"52\", \"role_data\"]}, {\"get_attr\": [\"53\", \"role_data\"]}, {\"get_attr\": [\"54\", \"role_data\"]}, {\"get_attr\": [\"55\", \"role_data\"]}, {\"get_attr\": [\"56\", \"role_data\"]}, {\"get_attr\": [\"57\", \"role_data\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (34,'2026-06-15 07:51:16',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(35,'2026-06-15 07:51:16',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(36,'2026-06-15 07:51:16',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(37,'2026-06-15 07:51:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(38,'2026-06-15 07:51:17',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(39,'2026-06-15 07:51:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a ObjectStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(40,'2026-06-15 07:51:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CellControllerCompute server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(41,'2026-06-15 07:51:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Compute service\\n\", \"parameters\": {\"ContainerCeilometerComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerCompute\": {\"default\": \"overcloud-ceilometer-agent-compute\", \"type\": \"string\"}, \"InstanceDiscoveryMethod\": {\"default\": \"libvirt_metadata\", \"description\": \"Method used to discover instances running on compute node\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"naive\", \"libvirt_metadata\", \"workload_partitioning\"]}]}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerComputeImage\": \"ContainerCeilometerComputeImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerComputeImage\": {\"get_param\": \"ContainerCeilometerComputeImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Compute role.\", \"value\": {\"service_name\": \"ceilometer_agent_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::polling::instance_discovery_method\": {\"get_param\": \"InstanceDiscoveryMethod\"}}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"compute_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"ceilometer_agent_compute\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerComputeImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_libvirt.target\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(42,'2026-06-15 07:51:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a BlockStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(43,'2026-06-15 07:51:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a Networker server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"internal_api\", \"tenant\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (44,'2026-06-15 07:51:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Add services and subhosts to IPA server\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"PythonInterpreter\": {\"type\": \"string\", \"description\": \"The python interpreter to use for python and ansible actions\", \"default\": \"$(command -v python3 || command -v python)\"}, \"IdMDomain\": {\"default\": \"ooo.test\", \"description\": \"IDM domain to register IDM client. Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"string\"}, \"IdMServer\": {\"default\": \"ipa.ooo.test\", \"description\": \"FQDN for the FreeIPA server.  If you set this value, IdMDomain also has to be provided.  Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"comma_delimited_list\"}, \"IdMNovaKeytab\": {\"default\": \"FILE:/etc/novajoin/krb5.keytab\", \"description\": \"keytab for the nova/[host fqdn] user on the FreeIPA server.\", \"type\": \"string\"}, \"IdMNovaCredentialCache\": {\"default\": \"/etc/novajoin/krb5.cache\", \"description\": \"credential cache for nova/[host fqdn] user\", \"type\": \"string\"}, \"MakeHomeDir\": {\"type\": \"boolean\", \"description\": \"Configure PAM to create a users home directory if it does not exist.\", \"default\": false}, \"IdMNoNtpSetup\": {\"default\": false, \"description\": \"Set to true to add --no-ntp to the IDM client install call. This will cause IDM client install not to set up NTP.\", \"type\": \"boolean\"}, \"IdMEnrollBaseServer\": {\"default\": true, \"description\": \"Set to true to enroll the base server (computes, controllers)\", \"type\": \"boolean\"}, \"IdMInstallClientPackages\": {\"default\": false, \"description\": \"Set to True to have ansible-freeipa install ipa client packages on the overcloud node.\", \"type\": \"boolean\"}, \"IdMModifyDNS\": {\"default\": true, \"description\": \"Set to false to disable DNS records manipulation in the FreeIPA server.\", \"type\": \"boolean\"}, \"IdMZoneSplitIPv4\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}, \"IdMZoneSplitIPv6\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}}, \"conditions\": {\"idm_server_provided\": {\"not\": {\"equals\": [{\"get_param\": \"IdMServer\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ipaservice service\", \"value\": {\"service_name\": \"ipaservice\", \"upgrade_tasks\": [], \"step_config\": \"\", \"ipa_registration_tasks\": [{\"name\": \"Get undercloud FQDN\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"set_fact\": {\"undercloud_fqdn\": \"{{ ansible_facts[\'fqdn\'] }}\"}}, {\"include_role\": {\"name\": \"tripleo_ipa_registration\", \"apply\": {\"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ undercloud_fqdn }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}}, \"vars\": {\"tripleo_ipa_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}, \"tripleo_ipa_delegate_server\": \"{{ inventory_hostname }}\", \"tripleo_ipa_base_server_fqdn\": \"{{ fqdn_canonical }}\", \"tripleo_ipa_server_metadata\": \"{{ service_metadata_settings | to_json }}\"}, \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}, {\"name\": \"Enroll the node as an ipa client\", \"vars\": {\"ipaclient_install_packages\": {\"get_param\": \"IdMInstallClientPackages\"}, \"idm_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}}, \"block\": [{\"name\": \"check if default.conf exists\", \"stat\": {\"path\": \"/etc/ipa/default.conf\"}, \"register\": \"ipa_conf_exists\"}, {\"name\": \"install openssl-perl\", \"become\": true, \"package\": {\"name\": \"openssl-perl\", \"state\": \"present\"}, \"when\": [\"ipaclient_install_packages|bool\"]}, {\"name\": \"register as an ipa client\", \"include_role\": {\"name\": \"ipaclient\", \"apply\": {\"become\": true}}, \"vars\": {\"map_merge\": [{\"state\": \"present\", \"ipaclient_otp\": \"{{ ipa_host_otp }}\", \"ipaclient_mkhomedir\": {\"get_param\": \"MakeHomeDir\"}, \"ipaclient_no_ntp\": {\"get_param\": \"IdMNoNtpSetup\"}, \"ipaclient_force\": true, \"ipaclient_hostname\": \"{{ fqdn_canonical }}\", \"ansible_fqdn\": \"{{ ipaclient_hostname }}\", \"ipaclients\": [\"ipaclient_hostname\"], \"ansible_distribution\": \"{{ ansible_facts[\'distribution\'] }}\", \"ansible_distribution_major_version\": \"{{ ansible_facts[\'distribution_major_version\'] }}\", \"ansible_distribution_release\": \"{{ ansible_facts[\'distribution_release\'] }}\", \"ansible_distribution_version\": \"{{ ansible_facts[\'distribution_version\'] }}\", \"ansible_os_family\": \"{{ ansible_facts[\'os_family\'] }}\"}, {\"if\": [\"idm_server_provided\", {\"ipaclient_servers\": {\"get_param\": \"IdMServer\"}, \"ipaclient_domain\": {\"get_param\": \"IdMDomain\"}}]}]}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"restart certmonger service\", \"become\": true, \"systemd\": {\"state\": \"restarted\", \"daemon_reload\": true, \"name\": \"certmonger.service\"}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"set discovered ipa realm\", \"set_fact\": {\"idm_realm\": {\"str_replace\": {\"template\": \"{{ lookup(\'ini\', \'realm default=DEFAULT section=global file=/etc/ipa/default.conf\')}}\", \"params\": {\"DEFAULT\": {\"yaql\": {\"expression\": \"$.data.toUpper()\", \"data\": {\"get_param\": \"IdMDomain\"}}}}}}}}], \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}], \"external_deploy_tasks\": [{\"name\": \"add the DNS entries into IPA in step 1\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"tripleo_ipa_dns\"}, \"vars\": {\"tripleo_ipa_ptr_zone_split_ipv4\": {\"get_param\": \"IdMZoneSplitIPv4\"}, \"tripleo_ipa_ptr_zone_split_ipv6\": {\"get_param\": \"IdMZoneSplitIPv6\"}}, \"when\": {\"get_param\": \"IdMModifyDNS\"}}], \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ ansible_facts[\'fqdn\'] }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}], \"scale_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"down\", \"block\": [{\"name\": \"unregister node from ipa server\", \"import_role\": {\"name\": \"tripleo_ipa_cleanup\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"vars\": {\"tripleo_ipa_keytab\": {\"get_param\": \"IdMNovaKeytab\"}, \"tripleo_ipa_hosts_to_delete\": [\"{{ fqdn_canonical }}\"]}}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"check if ipa server has required permissions\", \"import_role\": {\"name\": \"tls_everywhere\", \"tasks_from\": \"ipa-server-check\"}, \"tags\": [\"opendev-validation\", \"opendev-validation-tls-everywhere\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(45,'2026-06-15 07:51:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(46,'2026-06-15 07:51:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(47,'2026-06-15 07:51:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(48,'2026-06-15 07:51:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Ipmi service\\n\", \"parameters\": {\"ContainerCeilometerIpmiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentIpmiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.ipmi\", \"file\": \"/var/log/containers/ceilometer/ipmi.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\"}, \"MonitoringSubscriptionCeilometerIpmi\": {\"default\": \"overcloud-ceilometer-agent-ipmi\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CeilometerAgentCentralBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerIpmiImage\": \"ContainerCeilometerIpmiImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerIpmiImage\": {\"get_param\": \"ContainerCeilometerIpmiImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Ipmi role.\", \"value\": {\"service_name\": \"ceilometer_agent_ipmi\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerIpmi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"ipmi_namespace\": true}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_ipmi\": [{\"get_param\": \"CeilometerAgentIpmiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_ipmi\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(49,'2026-06-15 07:51:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(50,'2026-06-15 07:51:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(51,'2026-06-15 07:51:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Migration Target service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DockerNovaMigrationSshdPort\": {\"default\": 2022, \"description\": \"Port that dockerized nova migration target sshd service binds to.\", \"type\": \"number\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"SshdBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Migration Target service.\", \"value\": {\"service_name\": \"nova_migration_target\", \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept libvirt subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept api subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"SshdBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\": [{\"get_param\": [\"MigrationSshKey\", \"public_key\"]}], \"tripleo::profile::base::nova::migration::target::ssh_localaddrs\": [\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\", \"%{hiera(\'live_migration_ssh_inbound_addr\')}\"], \"live_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"cold_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"tripleo::profile::base::sshd::port\": [22]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"SshdBase\", \"role_data\", \"step_config\"]}, \"include tripleo::profile::base::nova::migration::target\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova-migration-target.json\": {\"command\": {\"str_replace\": {\"template\": \"dumb-init --single-child -- /usr/sbin/sshd -D -p SSHDPORT\", \"params\": {\"SSHDPORT\": {\"get_param\": \"DockerNovaMigrationSshdPort\"}}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/host-ssh/ssh_host_*_key\", \"dest\": \"/etc/ssh/\", \"owner\": \"root\", \"perm\": \"0600\"}]}}, \"host_prep_tasks\": [{\"name\": \"Create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"loop\": [{\"path\": \"/run/libvirt\", \"setype\": \"virt_var_run_t\"}]}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}], \"docker_config\": {\"step_4\": {\"nova_migration_target\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/etc/ssh:/host-ssh:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"validate nova-migration-target container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_migration_target\"}, \"register\": \"nova_migration_target_infos\", \"failed_when\": [\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], \"update_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}], \"upgrade_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (52,'2026-06-15 07:51:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CellController server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(53,'2026-06-15 07:51:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CephStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(54,'2026-06-15 07:51:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"MGRnIM4wMti8nqhqt2uJkphYX\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lAltaQRZMJ8lMeTuITOttJN7X\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"89Vk5RNyVwiA8aj5GHvgz6wY\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(55,'2026-06-15 07:51:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"MGRnIM4wMti8nqhqt2uJkphYX\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lAltaQRZMJ8lMeTuITOttJN7X\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"89Vk5RNyVwiA8aj5GHvgz6wY\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(56,'2026-06-15 07:51:22',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(57,'2026-06-15 07:51:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(58,'2026-06-15 07:51:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lAltaQRZMJ8lMeTuITOttJN7X\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(59,'2026-06-15 07:51:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"MGRnIM4wMti8nqhqt2uJkphYX\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lAltaQRZMJ8lMeTuITOttJN7X\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"89Vk5RNyVwiA8aj5GHvgz6wY\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(60,'2026-06-15 07:51:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Iscsid service\\n\", \"parameters\": {\"ContainerIscsidImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"ContainerIscsidConfigImage\": {\"description\": \"The container image to use for the iscsid config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LVMFilterEnabled\": {\"default\": false, \"description\": \"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"LVMFilterAllowlist\": {\"default\": [], \"description\": \"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LVMFilterDenylist\": {\"default\": [\".*\"], \"description\": \"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"IscsidCHAPAlgorithms\": {\"default\": \"SHA3-256,SHA256,SHA1,MD5\", \"description\": \"A comma separated list of algorithms to be used for the CHAP algorithm.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo_tripleo_lvmfilter_enabled\": \"LVMFilterEnabled\", \"tripleo_tripleo_lvmfilter_devices_allowlist\": \"LVMFilterAllowlist\", \"tripleo_tripleo_lvmfilter_devices_denylist\": \"LVMFilterDenylist\", \"ContainerIscsidImage\": \"ContainerIscsidImage\", \"ContainerIscsidConfigImage\": \"ContainerIscsidConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"LVMFilterEnabled\": {\"get_param\": \"LVMFilterEnabled\"}, \"LVMFilterAllowlist\": {\"get_param\": \"LVMFilterAllowlist\"}, \"LVMFilterDenylist\": {\"get_param\": \"LVMFilterDenylist\"}, \"ContainerIscsidImage\": {\"get_param\": \"ContainerIscsidImage\"}, \"ContainerIscsidConfigImage\": {\"get_param\": \"ContainerIscsidConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Iscsid role.\", \"value\": {\"service_name\": \"iscsid\", \"config_settings\": {\"tripleo::profile::base::iscsid::chap_algs\": {\"get_param\": \"IscsidCHAPAlgorithms\"}}, \"service_config_settings\": {}, \"deploy_steps_tasks\": [{\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}], \"ansible_group_vars\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidConfigImage\"]}, \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"iscsid\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}], \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (61,'2026-06-15 07:51:22',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(62,'2026-06-15 07:51:22',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"external_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(63,'2026-06-15 07:51:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(64,'2026-06-15 07:51:22',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(65,'2026-06-15 07:51:23',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(66,'2026-06-15 07:51:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(67,'2026-06-15 07:51:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"yes\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}}, \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"config_settings\": {\"tripleo::profile::base::sshd::bannertext\": {\"get_param\": \"BannerText\"}, \"tripleo::profile::base::sshd::motd\": {\"get_param\": \"MessageOfTheDay\"}, \"tripleo::profile::base::sshd::options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo::profile::base::sshd::password_authentication\": {\"get_param\": \"PasswordAuthentication\"}}, \"step_config\": \"include tripleo::profile::base::sshd\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(68,'2026-06-15 07:51:23',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(69,'2026-06-15 07:51:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Load kernel modules with kmod and configure kernel options with sysctl.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelPidMax\": {\"default\": 1048576, \"description\": \"Configures sysctl kernel.pid_max key\", \"type\": \"number\"}, \"KernelDisableIPv6\": {\"default\": 0, \"description\": \"Configures sysctl net.ipv6.{default/all}.disable_ipv6 keys\", \"type\": \"number\"}, \"KernelIpForward\": {\"default\": 1, \"description\": \"Configures net.ipv4.ip_forward key\", \"type\": \"number\"}, \"KernelIpv6ConfAllForwarding\": {\"default\": 0, \"description\": \"Configures the net.ipv6.conf.all.forwarding key\", \"type\": \"number\"}, \"KernelIpv4ConfAllRpFilter\": {\"default\": 1, \"description\": \"Configures the net.ipv4.conf.all.rp_filter key\", \"type\": \"number\"}, \"KernelIpNonLocalBind\": {\"default\": 1, \"description\": \"Configures net.ipv{4,6}.ip_nonlocal_bind key\", \"type\": \"number\"}, \"NeighbourGcThreshold1\": {\"default\": 1024, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh1 value. This is the minimum number of entries to keep in the ARP cache. The garbage collector will not run if there are fewer than this number of entries in the cache.\", \"type\": \"number\"}, \"NeighbourGcThreshold2\": {\"default\": 2048, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh2 value. This is the soft maximum number of entries to keep in the ARP cache. The garbage collector will  allow the number of entries to exceed this for 5 seconds before collection will be performed.\", \"type\": \"number\"}, \"NeighbourGcThreshold3\": {\"default\": 4096, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh3 value. This is the hard maximum number of entries to keep in the ARP cache. The garbage collector will always run if there are more than this number of entries in the cache.\", \"type\": \"number\"}, \"InotifyInstancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}, \"BridgeNfCallArpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-arptables key\", \"type\": \"number\"}, \"BridgeNfCallIpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-iptables key\", \"type\": \"number\"}, \"BridgeNfCallIp6Tables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-ip6tables key\", \"type\": \"number\"}, \"ExtraKernelModules\": {\"default\": {}, \"description\": \"Hash of extra Kernel modules to load.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraKernelPackages\": {\"default\": {}, \"description\": \"List of extra kernel related packages to install.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraSysctlSettings\": {\"default\": {}, \"description\": \"Hash of extra sysctl settings to apply.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"FsAioMaxNumber\": {\"default\": 0, \"description\": \"The kernel allocates aio memory on demand, and this number limits the number of parallel aio requests; the only drawback of a larger limit is that a malicious guest could issue parallel requests to cause the kernel to set aside memory.  Set this number at least as large as\\n  128 * (number of virtual disks on the host)\\nLibvirt uses a default of 1M requests to allow 8k disks, with at most 64M of kernel memory if all disks hit an aio request at the same time.\\n\", \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"InotifyIntancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"InotifyIntancesMax\"]}], \"conditions\": {\"ipv6_disabled\": {\"equals\": [{\"get_param\": \"KernelDisableIPv6\"}, 1]}, \"is_inotify_intances_max_default\": {\"equals\": [{\"get_param\": \"InotifyIntancesMax\"}, 1024]}, \"fs_aio_max_number_set\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, 0]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, \"\"]}}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_kernel_modules\": \"ExtraKernelModules\", \"extra_kernel_packages\": \"ExtraKernelPackages\", \"extra_sysctl_settings\": \"ExtraSysctlSettings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraKernelModules\": {\"get_param\": \"ExtraKernelModules\"}, \"ExtraKernelPackages\": {\"get_param\": \"ExtraKernelPackages\"}, \"ExtraSysctlSettings\": {\"get_param\": \"ExtraSysctlSettings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Kernel modules\", \"value\": {\"service_name\": \"kernel\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_kernel\"}}], \"ansible_group_vars\": {\"hieradata_localhost_address\": {\"if\": [\"ipv6_disabled\", \"127.0.0.1\", \"localhost\"]}, \"tripleo_kernel_extra_modules\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_modules\"]}, \"tripleo_kernel_extra_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_packages\"]}, \"tripleo_kernel_sysctl_extra_settings\": {\"map_merge\": [{\"net.ipv6.conf.default.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": {\"get_param\": \"KernelIpForward\"}}, \"net.ipv4.conf.all.rp_filter\": {\"value\": {\"get_param\": \"KernelIpv4ConfAllRpFilter\"}}, \"net.ipv6.conf.all.forwarding\": {\"value\": {\"get_param\": \"KernelIpv6ConfAllForwarding\"}}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"kernel.pid_max\": {\"value\": {\"get_param\": \"KernelPidMax\"}}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": {\"get_param\": \"NeighbourGcThreshold1\"}}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": {\"get_param\": \"NeighbourGcThreshold2\"}}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": {\"get_param\": \"NeighbourGcThreshold3\"}}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": {\"get_param\": \"BridgeNfCallArpTables\"}}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": {\"get_param\": \"BridgeNfCallIpTables\"}}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": {\"get_param\": \"BridgeNfCallIp6Tables\"}}, \"fs.inotify.max_user_instances\": {\"value\": {\"if\": [\"is_inotify_intances_max_default\", {\"get_param\": \"InotifyInstancesMax\"}, {\"get_param\": \"InotifyIntancesMax\"}]}}}, {\"if\": [\"fs_aio_max_number_set\", {\"fs.aio-max-nr\": {\"value\": {\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}}}]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_sysctl_settings\"]}]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (70,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lAltaQRZMJ8lMeTuITOttJN7X\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(71,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(72,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(73,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"SNMP client configured with Puppet, to facilitate Ceilometer Hardware monitoring in the undercloud. This service is required to enable hardware monitoring.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"89Vk5RNyVwiA8aj5GHvgz6wY\"}, \"SnmpdBindHost\": {\"description\": \"An array of bind host addresses on which SNMP daemon will listen.\", \"type\": \"comma_delimited_list\", \"default\": [\"udp:161\", \"udp6:[::1]:161\"]}, \"SnmpdOptions\": {\"description\": \"A string containing the commandline options passed to snmpd\", \"type\": \"string\", \"default\": \"-LS0-5d\"}, \"SnmpdIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the snmpd network. If empty (default), SnmpdNetwork will be taken.\", \"type\": \"string\"}}, \"conditions\": {\"snmpd_network_unset\": {\"equals\": [{\"get_param\": \"SnmpdIpSubnet\"}, \"\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the SNMP services\", \"value\": {\"service_name\": \"snmp\", \"firewall_rules\": {\"if\": [\"snmpd_network_unset\", {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"SnmpdNetwork\"]}]}}, \"template\": {\"124 snmp <%net_cidr%>\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"<%net_cidr%>\"}}}}}, {\"124 snmp\": {\"dport\": 161, \"proto\": \"udp\", \"source\": {\"get_param\": \"SnmpdIpSubnet\"}}}]}, \"config_settings\": {\"tripleo::profile::base::snmp::snmpd_user\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"tripleo::profile::base::snmp::snmpd_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"snmp::agentaddress\": {\"get_param\": \"SnmpdBindHost\"}, \"snmp::snmpd_options\": {\"get_param\": \"SnmpdOptions\"}}, \"step_config\": \"include tripleo::profile::base::snmp\\n\", \"upgrade_tasks\": [{\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(74,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(75,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(76,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(77,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder API service\\n\", \"parameters\": {\"ContainerCinderApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.api\", \"file\": \"/var/log/containers/cinder/cinder-api.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"CinderDefaultVolumeType\": {\"default\": \"tripleo\", \"description\": \"The name of Cinder\'s default volume type.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \".*\\\\S.*\", \"description\": \"The default volume type name cannot be empty.\\n\"}]}, \"CinderEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Cinder database.\\n\", \"type\": \"boolean\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"puJEUVV5bncg9PX1nMb3Jnk25\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionCinderApi\": {\"default\": \"overcloud-cinder-api\", \"type\": \"string\"}, \"CinderWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for cinder::wsgi::apache\", \"default\": 1}, \"CinderApiPolicies\": {\"description\": \"A hash of policies to configure for Cinder API.\\ne.g. { cinder-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"CinderApiWsgiTimeout\": {\"default\": 60, \"description\": \"The number of seconds until a Cinder API WSGI connection times out.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderApiImage\": \"ContainerCinderApiImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderApiImage\": {\"get_param\": \"ContainerCinderApiImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder API role.\", \"value\": {\"service_name\": \"cinder_api\", \"firewall_rules\": {\"119 cinder\": {\"dport\": [8776]}}, \"firewall_frontend_rules\": {\"100 cinder_haproxy_frontend\": {\"dport\": [8776]}}, \"firewall_ssl_frontend_rules\": {\"100 cinder_haproxy_frontend_ssl\": {\"dport\": [13776]}}, \"keystone_resources\": {\"cinder\": {\"users\": {\"cinder\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}}, \"cinderv3\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"CinderV3Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"CinderV3Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"CinderV3Admin\", \"uri\"]}}, \"users\": {\"cinderv3\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"volumev3\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"keystone_resources_managed\": false}, {\"cinder::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::authtoken::project_name\": \"service\", \"cinder::keystone::authtoken::user_domain_name\": \"Default\", \"cinder::keystone::authtoken::project_domain_name\": \"Default\", \"cinder::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::keystone::authtoken::interface\": \"internal\", \"cinder::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"cinder::policy::policies\": {\"get_param\": \"CinderApiPolicies\"}, \"cinder::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"cinder::api::default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}, \"cinder::api::enable_proxy_headers_parsing\": true, \"tripleo::profile::base::cinder::cinder_enable_db_purge\": {\"get_param\": \"CinderEnableDBPurge\"}, \"cinder::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"cinder::api::service_name\": \"httpd\", \"cinder::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::vhost_custom_fragment\": {\"str_replace\": {\"template\": \"Timeout TIMEOUT\", \"params\": {\"TIMEOUT\": {\"get_param\": \"CinderApiWsgiTimeout\"}}}}, \"cinder::wsgi::apache::workers\": {\"get_param\": \"CinderWorkers\"}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_api\": [{\"get_param\": \"CinderApiLoggingSource\"}]}, \"mysql\": {\"cinder::db::mysql::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::db::mysql::user\": \"cinder\", \"cinder::db::mysql::host\": \"%\", \"cinder::db::mysql::dbname\": \"cinder\"}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line,cinder_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec cinder_api su cinder -s /bin/bash -c \'cinder-manage db sync --bump-versions\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"cinder_api_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_3\": {\"cinder_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"cinder_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"cinder_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron cinder\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/cinder-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}, {\"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_api\", \"cinder_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}], \"external_deploy_tasks\": [{\"name\": \"Clean up legacy Cinder keystone catalog entries\", \"become\": true, \"openstack.cloud.catalog_service\": {\"cloud\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}, \"name\": \"{{ item.service_name }}\", \"service_type\": \"{{ item.service_type }}\", \"state\": \"absent\"}, \"loop\": [{\"service_name\": \"cinderv2\", \"service_type\": \"volumev2\"}, {\"service_name\": \"cinderv3\", \"service_type\": \"volume\"}], \"loop_control\": {\"index_var\": \"cinder_api_service\"}, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"]}, {\"name\": \"Manage Cinder\'s default volume type\", \"become\": true, \"vars\": {\"default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}}, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"when\": [\"step|int == 5\", \"not ansible_check_mode|bool\"], \"shell\": \"if ! openstack volume type show \\\"{{ default_volume_type }}\\\"; then\\n    openstack volume type create --public \\\"{{ default_volume_type }}\\\"\\nfi\\neval $(openstack volume type show __DEFAULT__ -f shell -c id -c description)\\nif [ -n \\\"$id\\\" ]; then\\n    if ! openstack volume type delete $id ; then\\n        tripleo_descr=\\\"For internal use, \'{{ default_volume_type }}\' is the default volume type\\\"\\n        if [ \\\"$description\\\" != \\\"$tripleo_descr\\\" ]; then\\n            openstack volume type set $id --description \\\"$tripleo_descr\\\"\\n        fi\\n    fi\\nfi\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"changed_when\": false}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(78,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (79,'2026-06-15 07:51:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(80,'2026-06-15 07:51:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Modular Libvirt Service\\n\", \"parameters\": {\"ContainerNovaLibvirtImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtUlimit\": {\"default\": [\"nofile=131072\", \"nproc=126960\"], \"description\": \"ulimit for Nova Libvirt Container\", \"type\": \"comma_delimited_list\"}, \"ContainerNovaLibvirtPidsLimit\": {\"default\": 65536, \"description\": \"Tune nova_libvirt container PID limit (set to 0 for unlimited) (defaults to 65536)\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"UseCustomGnuTlsQemuCryptoPolicy\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If set to true, will use CustomGnuTlsQemuCryptoPolicy in crypto policy.\"}, \"CustomGnuTlsQemuCryptoPolicy\": {\"default\": \"QEMU=NONE:+ECDHE-RSA:+ECDHE-ECDSA:+RSA:+DHE-RSA:+GROUP-X25519:+GROUP-X448:+GROUP-SECP256R1:+GROUP-SECP384R1:+GROUP-SECP521R1:+GROUP-FFDHE2048:+GROUP-FFDHE3072:+GROUP-FFDHE4096:+GROUP-FFDHE6144:+GROUP-FFDHE8192:+CHACHA20-POLY1305:+AEAD:+SHA1:+SHA512:+SIGN-ECDSA-SHA256:+SIGN-ECDSA-SECP256R1-SHA256:+SIGN-ECDSA-SHA384:+SIGN-ECDSA-SECP384R1-SHA384:+SIGN-ECDSA-SHA512:+SIGN-ECDSA-SECP521R1-SHA512:+SIGN-EdDSA-Ed25519:+SIGN-EdDSA-Ed448:+SIGN-RSA-PSS-SHA256:+SIGN-RSA-PSS-SHA384:+SIGN-RSA-PSS-SHA512:+SIGN-RSA-PSS-RSAE-SHA256:+SIGN-RSA-PSS-RSAE-SHA384:+SIGN-RSA-PSS-RSAE-SHA512:+SIGN-RSA-SHA256:+SIGN-RSA-SHA384:+SIGN-RSA-SHA512:+VERS-TLS1.3:+VERS-TLS1.2:+VERS-DTLS1.2\", \"description\": \"Custom GnuTls Crypto Policy for QEMU\", \"type\": \"string\"}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"UseTLSTransportForVnc\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\"}, \"UseTLSTransportForNbd\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt NBD and configure the relevant keys for libvirt.\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"LibvirtCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuServerCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuClientCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for TLS in libvirt. This file will be symlinked to the default CA path in libvirt, which is /etc/pki/CA/cacert.pem. Note that due to limitations GNU TLS, which is the TLS backend for libvirt, the file must be less than 65K (so we can\'t use the system\'s CA bundle). This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"QemuCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for qemu. This file will be symlinked to the default CA path, which is /etc/pki/qemu/ca-cert.pem. This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"VhostuserSocketGroup\": {\"default\": \"qemu\", \"description\": \"The vhost-user socket directory group name. Defaults to \'qemu\'. When vhostuser mode is \'dpdkvhostuserclient\' (which is the default mode), the vhost socket is created by qemu.\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtType\": {\"type\": \"string\", \"default\": \"qemu\"}, \"LibvirtEnabledPerfEvents\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"This is a performance event list which could be used as monitor. For example - ``enabled_perf_events = cmt, mbml, mbmt`` The supported events list can be found in https://libvirt.org/html/libvirt-libvirt-domain.html , which you may need to search key words ``VIR_PERF_PARAM_*``\"}, \"MonitoringSubscriptionNovaLibvirt\": {\"default\": \"overcloud-nova-libvirt\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"LibvirtTLSPassword\": {\"description\": \"The password for the libvirt service when TLS is enabled\", \"type\": \"string\", \"hidden\": true, \"default\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\"}, \"QemuDefaultTLSVerify\": {\"description\": \"Whether to enable or disable TLS client certificate verification. Enabling this option will reject any client who does not have a certificate signed by the CA in /etc/pki/qemu/ca-cert.pem\\n\", \"default\": true, \"type\": \"boolean\"}, \"LibvirtLogFilters\": {\"description\": \"Defines a filter in libvirt daemon to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\"}, \"LibvirtVirtlogdLogFilters\": {\"description\": \"Defines a filter in virtlogd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:logging 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtsecretdLogFilters\": {\"description\": \"Defines a filter in virtsecretd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtnodedevdLogFilters\": {\"description\": \"Defines a filter in virtnodedevd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtstoragedLogFilters\": {\"description\": \"Defines a filter in virtstoraged to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtqemudLogFilters\": {\"description\": \"Defines a filter in virtqemud to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtproxydLogFilters\": {\"description\": \"Defines a filter in virtproxyd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtTLSPriority\": {\"description\": \"Override the compile time default TLS priority string.\\n\", \"type\": \"string\", \"default\": \"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\"}, \"NovaLibvirtOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaEnableVirtlogdContainerWrapper\": {\"description\": \"Generate a virtlogd wrapper script so that virtlogd launches in a separate container and won\'t get restarted e.g. on minor updates.\", \"type\": \"boolean\", \"default\": true}, \"VirtlogdWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}}, \"conditions\": {\"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"libvirt_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCACert\"}, \"\"]}}, \"need_libvirt_secret\": {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaEnableRbdBackend\"}, true]}]}, {\"get_param\": \"CinderEnableRbdBackend\"}]}, \"use_tls_for_vnc\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForVnc\"}]}, \"libvirt_vnc_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtVncCACert\"}, \"\"]}}, \"use_tls_for_nbd\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForNbd\"}]}, \"qemu_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuCACert\"}, \"\"]}}, \"key_size_libvirt_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_client_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuClientCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_server_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuServerCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"vhostuser_socket_group\": \"VhostuserSocketGroup\", \"nova_libvirt_opt_volumes\": \"NovaLibvirtOptVolumes\", \"ContainerNovaLibvirtImage\": \"ContainerNovaLibvirtImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"VhostuserSocketGroup\": {\"get_param\": \"VhostuserSocketGroup\"}, \"NovaLibvirtOptVolumes\": {\"get_param\": \"NovaLibvirtOptVolumes\"}, \"ContainerNovaLibvirtImage\": {\"get_param\": \"ContainerNovaLibvirtImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}, \"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NovaLibvirtLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaLibvirt\"}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLibvirtCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Libvirt service.\", \"value\": {\"service_name\": \"nova_libvirt\", \"firewall_rules\": {\"200 nova_libvirt\": {\"dport\": [16514, \"61152-61215\", \"5900-6923\"]}}, \"ansible_group_vars\": {\"tripleo_nova_libvirt_virsh_container\": \"nova_virtproxyd\"}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaLibvirt\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"config_settings\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\": {\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\": \"/var/lib/container-config-scripts/virtlogd_wrapper\", \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"tripleo::profile::base::nova::virtlogd_wrapper::debug\": {\"if\": [{\"get_param\": \"VirtlogdWrapperDebug\"}, true, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}]}, \"nova::compute::libvirt::migration_support\": false, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::nova::migration::client::libvirt_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::libvirt::services::libvirt_virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::enabled_perf_events\": {\"get_param\": \"LibvirtEnabledPerfEvents\"}, \"nova::compute::libvirt::qemu::configure_qemu\": true, \"nova::compute::libvirt::qemu::max_files\": 32768, \"nova::compute::libvirt::qemu::max_processes\": 131072, \"nova::migration::qemu::configure_qemu\": true, \"nova::migration::qemu::migration_port_min\": 61152, \"nova::migration::qemu::migration_port_max\": 61215, \"nova::compute::libvirt::vncserver_listen\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::libvirt::log_filters\": {\"get_param\": \"LibvirtLogFilters\"}, \"nova::compute::libvirt::virtlogd::log_filters\": {\"get_param\": \"LibvirtVirtlogdLogFilters\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::compute::libvirt::virtsecretd::log_filters\": {\"get_param\": \"LibvirtVirtsecretdLogFilters\"}, \"nova::compute::libvirt::virtnodedevd::log_filters\": {\"get_param\": \"LibvirtVirtnodedevdLogFilters\"}, \"nova::compute::libvirt::virtstoraged::log_filters\": {\"get_param\": \"LibvirtVirtstoragedLogFilters\"}, \"nova::compute::libvirt::virtqemud::log_filters\": {\"get_param\": \"LibvirtVirtqemudLogFilters\"}, \"nova::compute::libvirt::virtproxyd::log_filters\": {\"get_param\": \"LibvirtVirtproxydLogFilters\"}, \"tripleo::profile::base::nova::libvirt::modular_libvirt\": true, \"nova::compute::libvirt::services::modular_libvirt\": true, \"nova::compute::libvirt::modular_libvirt\": true, \"nova::migration::libvirt::modular_libvirt\": true}, {\"if\": [\"use_tls_for_live_migration\", {\"tripleo::profile::base::nova::migration::client::libvirt_tls\": true, \"tripleo::profile::base::nova::libvirt::tls_password\": {\"get_param\": [\"LibvirtTLSPassword\"]}, \"nova::compute::libvirt::qemu::default_tls_verify\": {\"get_param\": \"QemuDefaultTLSVerify\"}, \"nova::compute::libvirt::tls_priority\": {\"get_param\": \"LibvirtTLSPriority\"}, \"nova::migration::libvirt::listen_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, {\"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}]}, {\"if\": [\"use_tls_for_vnc\", {\"nova::compute::libvirt::qemu::vnc_tls\": true, \"nova::compute::libvirt::qemu::vnc_tls_verify\": true}]}, {\"if\": [\"use_tls_for_nbd\", {\"nova::compute::libvirt::qemu::nbd_tls\": true, \"nova::migration::libvirt::live_migration_with_native_tls\": true}]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_virtlogd.json\": {\"command\": {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"/usr/local/bin/virtlogd_wrapper\", \"/usr/sbin/virtlogd --config /etc/libvirt/virtlogd.conf\"]}, \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtsecretd.json\": {\"command\": \"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtnodedevd.json\": {\"command\": \"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtstoraged.json\": {\"command\": \"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtqemud.json\": {\"command\": \"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtproxyd.json\": {\"command\": \"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}}, \"container_config_scripts\": {\"nova_libvirt_init_secret.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_libvirt_init_secret.sh\"}}}, \"docker_config\": {\"step_2\": {\"nova_virtqemud_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"net\": \"none\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"user\": \"root\", \"volumes\": [\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R tss:tss /var/log/swtpm\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"create_virtlogd_wrapper\": {\"start_order\": 1, \"detach\": false, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::nova::virtlogd_wrapper\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_3\": {\"map_merge\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, {\"nova_virtlogd_wrapper\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {\"nova_virtlogd\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}, {\"nova_virtsecretd\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtnodedevd\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtstoraged\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtqemud\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\", {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, \"/etc/crypto-policies:/etc/crypto-policies:ro\"]}]]}}}, {\"nova_virtproxyd\": {\"start_order\": 5, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}]}, \"step_4\": {\"if\": [\"need_libvirt_secret\", {\"nova_libvirt_init_secret\": {\"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"security_opt\": [\"label=disable\"], \"privileged\": false, \"user\": \"root\", \"cgroupns\": \"host\", \"net\": \"host\", \"environment\": {\"LIBVIRT_DEFAULT_URI\": \"qemu:///system\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/nova_libvirt/etc/nova:/etc/nova\", \"/etc/libvirt:/etc/libvirt\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/lib/container-config-scripts/nova_libvirt_init_secret.sh:/nova_libvirt_init_secret.sh:ro\", {\"str_replace\": {\"template\": \"HOST_CEPH:/etc/ceph:ro\", \"params\": {\"HOST_CEPH\": {\"get_param\": \"CephConfigPath\"}}}}]]}, \"command\": {\"list_join\": [\" \", [{\"str_replace\": {\"template\": \"/nova_libvirt_init_secret.sh CLUSTER:USER\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}], {\"repeat\": {\"template\": \"<%ceph_info%>\", \"for_each\": {\"<%ceph_info%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\":\\\" + $.get(\\\"CephClientUserName\\\", $u))\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Ensure recovery of containerized virtqemud\", \"when\": \"step|int == 4\", \"become\": true, \"block\": [{\"name\": \"Create virtqemud recovery script\", \"copy\": {\"dest\": \"/usr/libexec/recover_tripleo_nova_virtqemud.sh\", \"mode\": \"0755\", \"content\": \"#!/bin/bash\\npgrep -f /sbin/virtqemud\\n[ $? -eq 0 ] && exit 0\\nkill -9 $(cat /run/nova_virtqemud.pid)\\n\"}}, {\"name\": \"Create virtqemud recovery trigger service\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud\\nAfter=tripleo_nova_virtqemud.service\\nRequisite=tripleo_nova_virtqemud.service\\n[Service]\\nType=oneshot\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Create virtqemud recovery trigger timer\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\nPartOf=tripleo_nova_virtqemud.service\\n[Timer]\\nOnCalendar=*:5/10\\nOnActiveSec=120\\nOnUnitActiveSec=60\\nRandomizedDelaySec=1m\\n[Install]\\nWantedBy=timers.target\\n\"}}, {\"name\": \"Enable virtqemud recovery trigger service\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.service\", \"enabled\": true, \"daemon_reload\": true}}, {\"name\": \"Enable virtqemud recovery trigger timer\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.timer\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"register\": \"virtqemud_recover_timer_result\"}, {\"name\": \"Really enable virtqemud recovery trigger timer\", \"shell\": {\"cmd\": \"systemctl enable --now tripleo_nova_virtqemud_recover.timer\"}, \"when\": \"virtqemud_recover_timer_result.status.UnitFileState != \\\"enabled\\\"\"}]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/libvirt\", \"/etc/pki/libvirt/private\", \"/etc/pki/qemu\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"libvirt-server-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to libvirt dirs\\ncp CACERT /etc/pki/CA/cacert.pem\\nchown root:root /etc/pki/CA/cacert.pem\\nchmod 644 /etc/pki/CA/cacert.pem\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"params\": {\"CACERT\": {\"if\": [\"libvirt_specific_ca_set\", {\"get_param\": \"LibvirtCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"libvirt-client-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to libvirt dirs\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-server-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to qemu dir\\ncp CACERT /etc/pki/qemu/ca-cert.pem\\nchown root:root /etc/pki/qemu/ca-cert.pem\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\nchgrp qemu /etc/pki/qemu/server-*\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\nchmod 0640 /etc/pki/qemu/server-key.pem\\n\", \"params\": {\"CACERT\": {\"if\": [\"qemu_specific_ca_set\", {\"get_param\": \"QemuCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_qemu_server_override_set\", {\"get_param\": \"QemuServerCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-client-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to qemu dir\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\nchgrp qemu /etc/pki/qemu/client-*\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\nchmod 0640 /etc/pki/qemu/client-key.pem\\n\", \"key_size\": {\"if\": [\"key_size_qemu_client_override_set\", {\"get_param\": \"QemuClientCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]]}, [{\"name\": \"Set up systemd target for libvirt services\", \"when\": \"step|int == 4\", \"block\": [{\"name\": \"Create systemd file\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt.target\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"[Unit]\\nWants=tripleo_nova_virtsecretd.service\\nWants=tripleo_nova_virtnodedevd.service\\nWants=tripleo_nova_virtstoraged.service\\nWants=tripleo_nova_virtproxyd.service\\nWants=tripleo_nova_virtqemud.service\\nAfter=tripleo_nova_virtsecretd.service\\nAfter=tripleo_nova_virtnodedevd.service\\nAfter=tripleo_nova_virtstoraged.service\\nAfter=tripleo_nova_virtproxyd.service\\nAfter=tripleo_nova_virtqemud.service\\n\"}, \"become\": true, \"register\": \"libvirt_target_result\"}, {\"name\": \"Reload systemd\", \"systemd\": {\"name\": \"tripleo_nova_libvirt.target\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"become\": true, \"when\": \"libvirt_target_result.changed\"}]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\", \"mode\": \"{{ item.mode | default(omit) }}\"}, \"with_items\": [{\"path\": \"/etc/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/secrets\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/qemu\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/cache/libvirt\"}, {\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/run/libvirt\"}, {\"path\": \"/var/log/containers/libvirt/swtpm\", \"setype\": \"container_file_t\", \"mode\": \"0770\"}]}, {\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}, {\"name\": \"create directory for vhost-user sockets with qemu ownership\", \"file\": {\"path\": \"/var/lib/vhost_sockets\", \"state\": \"directory\", \"owner\": \"qemu\", \"group\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"vhostuser_socket_group\"]}, \"setype\": \"virt_cache_t\", \"seuser\": \"system_u\"}}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"with_items\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": \"libvirt_installed.rc == 0\"}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}, {\"name\": \"Enable os_enable_vtpm SELinux boolean for vTPM\", \"seboolean\": {\"name\": \"os_enable_vtpm\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, [{\"name\": \"set gnutls_qemu_config_crypto_policy fact\", \"set_fact\": {\"gnutls_qemu_config_crypto_policy\": {\"get_param\": \"CustomGnuTlsQemuCryptoPolicy\"}}}, {\"name\": \"create gnutls-qemu.config\", \"copy\": {\"dest\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"{{ gnutls_qemu_config_crypto_policy }}\\n\"}, \"register\": \"update_gnutls_config\"}], [{\"name\": \"remove gnutls-qemu.config\", \"file\": {\"path\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"state\": \"absent\"}, \"register\": \"update_gnutls_config\"}]]}, {\"name\": \"update crypto policies\", \"command\": \"update-crypto-policies\", \"when\": \"update_gnutls_config.changed\"}]]}, \"metadata_settings\": {\"list_concat\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"libvirt\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"qemu\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"libvirt-vnc\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}]]}]}, \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Fail if we are on RHEL8 as this is monolithic libvirt deployment\", \"when\": [\"step|int == 0\", \"\'system_upgrade\' not in ansible_run_tags\", \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"], \"fail\": {\"msg\": \"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\"}}, {\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Get container virtlogd image\", \"when\": \"step|int == 1\", \"tags\": \"always\", \"set_fact\": {\"virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}}}, {\"name\": \"Force pull image novalibvirt\", \"when\": [\"step|int == 1\"], \"containers.podman.podman_image\": {\"name\": \"{{ virtlogd_image }}\", \"force\": true}}, {\"name\": \"Diff OS release in container image and baremetal\", \"when\": \"step|int == 1\", \"shell\": \"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"failed_when\": false, \"register\": \"libvirt_ubi_diff\"}, {\"name\": \"Fail if UBI of the container does not match RHEL of running host\", \"when\": [\"\'system_upgrade\' not in ansible_run_tags\", \"step|int == 1\", \"libvirt_ubi_diff.rc == 1\"], \"fail\": {\"msg\": \"The host operating system versus container UBI does not match.\\n{{ libvirt_ubi_diff.stdout }}\\nMost likely container passed to NovaLibvirt was EL8 one.\\nYou have to pass the correct container for container-image-prepare.\\nIf you would continue all running workloads would get destroyed.\\n\"}}], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [{\"name\": \"Switch virtlogd image before system upgrade\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade\"], \"block\": [{\"name\": \"Get running image version\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"old_virtlogd_image\"}, {\"name\": \"Switch running image to new image in wrapper script\", \"shell\": \"set -o pipefail\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\n\", \"when\": [\"old_virtlogd_image.stdout != virtlogd_image\", \"old_virtlogd_image.stdout != \'\'\"]}]}]]}]}, \"update_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtCommon\", \"update_tasks\"]}, [{\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(81,'2026-06-15 07:51:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Notification service\\n\", \"parameters\": {\"ContainerCeilometerNotificationImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentNotificationLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.notification\", \"file\": \"/var/log/containers/ceilometer/agent-notification.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerNotification\": {\"default\": \"overcloud-ceilometer-agent-notification\", \"type\": \"string\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"CeilometerQdrPublishEvents\": {\"default\": false, \"description\": \"Whether to send events to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrPublishMetrics\": {\"default\": false, \"description\": \"Whether to send telemetry data to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrEventsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"event\"}, \"description\": \"Configuration for notifier publisher for events.\", \"type\": \"json\"}, \"CeilometerQdrMetricsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"metering\"}, \"description\": \"Configuration for notifier publisher for metrics.\", \"type\": \"json\"}, \"ManageEventPipeline\": {\"default\": true, \"description\": \"Whether to manage event_pipeline.yaml.\", \"type\": \"boolean\"}, \"EventPipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in event_pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManageEventPipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}, \"ManagePipeline\": {\"default\": false, \"description\": \"Whether to manage pipeline.yaml.\", \"type\": \"boolean\"}, \"PipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManagePipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerNotificationImage\": \"ContainerCeilometerNotificationImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerNotificationImage\": {\"get_param\": \"ContainerCeilometerNotificationImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"conditions\": {\"ceilometer_qdr_publish\": {\"or\": [{\"get_param\": \"CeilometerQdrPublishEvents\"}, {\"get_param\": \"CeilometerQdrPublishMetrics\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Notification role.\", \"value\": {\"service_name\": \"ceilometer_agent_notification\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerNotification\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::notification::manage_event_pipeline\": {\"get_param\": \"ManageEventPipeline\"}, \"ceilometer::agent::notification::manage_pipeline\": {\"get_param\": \"ManagePipeline\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_enabled\": {\"get_param\": \"CeilometerQdrPublishMetrics\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_events_enabled\": {\"get_param\": \"CeilometerQdrPublishEvents\"}, \"tripleo::profile::base::ceilometer::agent::notification::pipeline_publishers\": {\"get_param\": \"PipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::event_pipeline_publishers\": {\"get_param\": \"EventPipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_params\": {\"get_param\": \"CeilometerQdrMetricsConfig\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_event_params\": {\"get_param\": \"CeilometerQdrEventsConfig\"}}, {\"if\": [\"ceilometer_qdr_publish\", {\"tripleo::profile::base::ceilometer::agent::notification::notifier_host_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_host_port\": {\"get_param\": \"MetricsQdrPort\"}}]}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_notification\": [{\"get_param\": \"CeilometerAgentNotificationLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::notification\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_notification.json\": {\"command\": \"/usr/bin/ceilometer-agent-notification --logfile /var/log/ceilometer/agent-notification.log\", \"config_files\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]]}}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_notification\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_notification.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent notification container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_notification\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_notification\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(82,'2026-06-15 07:51:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"eljGPqsTubd1MRdmVjF5MppaC\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"OorljNRFSWJ6uLOrYiwbnwsqY\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"9ppduM3vEiUPQ7DOtXGTm17h0\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": true, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(83,'2026-06-15 07:51:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Compute service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"DockerNovaComputeUlimit\": {\"default\": [\"nofile=131072\", \"memlock=67108864\"], \"description\": \"ulimit for Nova Compute Container\", \"type\": \"comma_delimited_list\"}, \"NovaComputeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.compute\", \"file\": \"/var/log/containers/nova/nova-compute.log\"}}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"NovaComputeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaComputeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"NovaComputeStartupDelay\": {\"default\": 0, \"description\": \"Delays the startup of nova-compute service after compute node is booted. This is to give a chance to ceph to get back healthy before booting instances after and overcloud reboot.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 0, \"max\": 600}}], \"tags\": [\"role_specific\"]}, \"EnableInstanceHA\": {\"default\": false, \"description\": \"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\", \"type\": \"boolean\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"NovaMkisofsCmd\": {\"default\": \"mkisofs\", \"description\": \"Name or path of the tool used for ISO image creation.\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsEnabled\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Nova\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsOptions\": {\"default\": \"context=system_u:object_r:nfs_t:s0\", \"description\": \"NFS mount options for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsVersion\": {\"default\": \"4.2\", \"description\": \"NFS version used for nova storage (when NovaNfsEnabled is true). Since NFSv3 does not support full locking a NFSv4 version need to be used.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^4.?[0-9]?\"}], \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeForceRawImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to convert non-raw cached base images to raw format.\\nSet to \\\"False\\\" if you have a system with slow I/O or low available space,\\ntrading the higher CPU requirements of compression for that of minimized input\\nbandwidth.\\nNotes::\\n- The Compute service removes any compression from the base image during\\n  compression, to avoid CPU bottlenecks. Converted images cannot have backing\\n  files, which might be a security issue.\\n- The raw image format uses more space than other image formats, for example,\\n  qcow2.\\n  Raw base images are always used with libvirt_images_type=lvm.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeUseCowImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to use CoW (Copy on Write) images in cqow2 format for libvirt\\ninstance disks. With CoW, depending on the backing store and host caching,\\nthere might be better concurrency achieved by having each instance operate\\non its own copy.\\nSet to \\\"False\\\" to use the raw format. Raw format uses more space for common\\nparts of the disk image.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtPreAllocateImages\": {\"default\": \"none\", \"description\": \"Specifies the preallocation mode for libvirt instance disks.\\nSet to one of the following valid values::\\n- none - No storage is provisioned at instance start.\\n- space - Storage is fully allocated at instance start using fallocate,\\n          which can help with both space guarantees and I/O performance.\\n\\nEven when not using CoW instance disks, the copy each instance gets is sparse\\nand so the instance might fail unexpectedly at run time with ENOSPC. By\\nrunning fallocate(1) on the instance disk images, the Compute service\\nimmediately and efficiently allocates the space for them in the file system,\\nif supported. Run time performance should also be improved because the file\\nsystem does not have to dynamically allocate blocks at run time, which reduces\\nCPU overhead and file fragmentation.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"space\"]}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheManagerInterval\": {\"default\": 2400, \"description\": \"Specifies the number of seconds to wait between runs of the image cache\\nmanager, which impacts base image caching on Compute nodes. This period\\nis used in the auto removal of unused cached images configured with\\nremove_unused_base_images and remove_unused_original_minimum_age_seconds.\\n\\nSet to \\\"0\\\" to run at the default interval of 60 seconds (not recommended)\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": -1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to automatically remove unused base images from the cache\\nat intervals configured by using image_cache_manager_interval. Images\\nare defined as unused if they have not been accessed during the time\\nspecified by using remove_unused_original_minimum_age_seconds.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"default\": 3600, \"description\": \"Specifies the minimum age that an unused resized base image must be to\\nbe removed from the cache, in seconds. Unused unresized base images\\nyounger than this will not be removed.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCachePrecacheConcurrency\": {\"default\": 1, \"description\": \"Maximum number of Compute nodes to trigger image precaching in parallel.\\nWhen an image precache request is made, Compute nodes are contacted {by\\nwho/which service} to initiate the download.\\n\\nHigher numbers will cause more computes to work in parallel and may result\\nin reduced time to complete the operation, but may also DDoS the image\\nservice. Lower numbers will result in more sequential operation, lower\\nimage service load, but likely longer runtime to completion.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaPCIPassthrough\": {\"description\": \"List of PCI Passthrough whitelist parameters. Example - NovaPCIPassthrough:\\n  - vendor_id: \\\"8086\\\"\\n    product_id: \\\"154c\\\"\\n    address: \\\"0000:05:00.0\\\"\\n    physical_network: \\\"datacentre\\\"\\nFor different formats, refer to the nova.conf documentation for pci_passthrough_whitelist configuration\\n\", \"type\": \"json\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeCpuSharedSet\": {\"description\": \"The behavior of this option depends on the deprecated `NovaVcpuPinSet` option:\\n\\n* `NovaVcpuPinSet` is not set: `NovaComputeCpuSharedSet` is set to a\\n  comma-separated list or range of physical host CPU numbers used to:\\n\\n  - provide vCPU inventory\\n  - determine the host CPUs that unpinned instances can be scheduled to\\n  - determine the host CPUS that instance emulator threads should be\\n    offloaded to for instances configured with the share emulator thread\\n    policy, `hw:emulator_threads_policy=share`\\n\\n* `NovaVcpuPinSet` is set: `NovaComputeCpuSharedSet` is set to a list or\\n  range of host CPU cores used to determine the host CPUs that instance\\n  emulator threads should be offloaded to for instances configured with\\n  the share emulator thread policy (`hw:emulator_threads_policy=share`).\\n  In this case, `NovaVcpuPinSet` is used to provide vCPU inventory and to\\n  determine the host CPUs that both pinned and unpinned instances can be\\n  scheduled to.\\n\\nEx. NovaComputeCpuSharedSet: [4-12,^8,15] will reserve cores from 4-12\\nand 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaComputeCpuDedicatedSet\": {\"description\": \"A list or range of host CPU cores to which processes for pinned instance CPUs (PCPUs) can be scheduled. Ex. NovaComputeCpuDedicatedSet: [4-12,^8,15] will reserve cores from 4-12 and 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaReservedHostMemory\": {\"description\": \"Reserved RAM for host processes.\\n\", \"type\": \"number\", \"default\": 512, \"constraints\": [{\"range\": {\"min\": 512}}], \"tags\": [\"role_specific\"]}, \"NovaReservedHugePages\": {\"description\": \"A list of valid key=value which reflect NUMA node ID, page size (Default unit is KiB) and number of pages to be reserved. Example - NovaReservedHugePages: [\\\"node:0,size:2048,count:64\\\",\\\"node:1,size:1GB,count:1\\\"] will reserve on NUMA node 0 64 pages of 2MiB and on NUMA node 1 1 page of 1GiB\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"OvsDpdkSocketMemory\": {\"default\": \"\", \"description\": \"Sets the amount of hugepage memory to assign per NUMA node. It is recommended to use the socket closest to the PCIe slot used for the desired DPDK NIC.  The format should be in \\\"<socket 0 mem>, <socket 1 mem>, <socket n mem>\\\", where the value is specified in MB.  For example: \\\"1024,0\\\".\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"MonitoringSubscriptionNovaCompute\": {\"default\": \"overcloud-nova-compute\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"VerifyGlanceSignatures\": {\"default\": false, \"description\": \"Whether to verify image signatures.\", \"type\": \"boolean\"}, \"NovaAutoDisabling\": {\"default\": \"10\", \"description\": \"Max number of consecutive build failures before the nova-compute will disable itself.\", \"type\": \"string\"}, \"NeutronPhysnetNUMANodesMapping\": {\"description\": \"Map of physnet name as key and NUMA nodes as value.\\nEx. NeutronPhysnetNUMANodesMapping: {\'foo\': [0, 1], \'bar\': [1]} where `foo` and `bar` are\\nphysnet names and corresponding values are list of associated numa_nodes.\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NeutronTunnelNUMANodes\": {\"description\": \"Used to configure NUMA affinity for all tunneled networks.\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtRxQueueSize\": {\"description\": \"virtio-net RX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtTxQueueSize\": {\"description\": \"virtio-net TX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtFileBackedMemory\": {\"description\": \"Available capacity in MiB for file-backed memory. When configured, the ``NovaRAMAllocationRatio`` and ``NovaReservedHostMemory`` parameters must be set to 0.\\n\", \"default\": 0, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtVolumeUseMultipath\": {\"default\": false, \"description\": \"Whether to enable or not the multipath connection of the volumes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaHWMachineType\": {\"description\": \"To specify a default machine type per host architecture.\\n\", \"default\": \"x86_64=pc-q35-rhel9.0.0\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaComputeEnableKsm\": {\"default\": false, \"description\": \"Whether to enable KSM on compute nodes or not. Especially in NFV use case one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"XITaEkVaorHTSEBU67xsjmkmx\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"puJEUVV5bncg9PX1nMb3Jnk25\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NovaLibvirtNumPciePorts\": {\"description\": \"Set `num_pcie_ports` to specify the number of PCIe ports an instance will get. Libvirt allows a custom number of PCIe ports (pcie-root-port controllers) a target instance will get. Some will be used by default, rest will be available for hotplug use.\\n\", \"default\": 16, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"description\": \"A number of seconds to memory usage statistics period, zero or negative value mean to disable memory usage statistics.\\n\", \"default\": 10, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationWaitForVIFPlug\": {\"description\": \"Whether to wait for `network-vif-plugged` events before starting guest transfer.\", \"default\": true, \"type\": \"boolean\"}, \"NovaLiveMigrationPermitPostCopy\": {\"description\": \"If \\\"True\\\" activates the instance on the destination node before migration is complete, and to set an upper bound on the memory that needs to be transferred. Post copy gets enabled per default if the compute roles is not a realtime role or disabled by this parameter.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationPermitAutoConverge\": {\"description\": \"Defaults to \\\"True\\\" to slow down the instance CPU until the memory copy process is faster than the instance\'s memory writes when the migration performance is slow and might not complete. Auto converge will only be used if this flag is set to True and post copy is not permitted or post copy is unavailable due to the version of libvirt and QEMU.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"NovaCPUAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual CPU to physical CPU allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaRAMAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual RAM to physical RAM allocation ratio.\", \"default\": 1.0, \"tags\": [\"role_specific\"]}, \"NovaDiskAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual disk to physical disk allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaEnableVTPM\": {\"type\": \"boolean\", \"description\": \"Whether to enable support for enumlated Trusted Platform Module (TPM) devices.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaMaxDiskDevicesToAttach\": {\"type\": \"number\", \"description\": \"Maximum number of disk devices allowed to attach to a single server. Note that the number of disks supported by an server depends on the bus used. For example, the ide disk bus is limited to 4 attached devices. The configured maximum is enforced during server create, rebuild, evacuate, unshelve, live migrate, and attach volume. Operators changing this parameter on a compute service that is hosting servers should be aware that it could cause rebuilds to fail, if the maximum is decreased lower than the number of devices already attached to servers. Operators should also be aware that during a cold migration, the configured maximum is only enforced in-place and the destination is not checked before the move. -1 means unlimited\\n\", \"default\": -1, \"tags\": [\"role_specific\"]}, \"NovaPMEMMappings\": {\"type\": \"string\", \"description\": \"PMEM namespace mappings as backend for vPMEM feature. This parameter sets Nova\'s `pmem_namespaces` configuration options. PMEM namespaces needs to be create manually or with conjunction with `NovaPMEMNamespaces` parameter. Requires format: $LABEL:$NSNAME[|$NSNAME][,$LABEL:$NSNAME[|$NSNAME]].\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaPMEMNamespaces\": {\"type\": \"string\", \"description\": \"Creates PMEM namespaces on the host server using `ndctl` tool through Ansible. Requires format: $SIZE:$NSNAME[,$SIZE:$NSNAME...]. $SIZE supports the suffixes \\\"k\\\" or \\\"K\\\" for KiB, \\\"m\\\" or \\\"M\\\" for MiB, \\\"g\\\" or \\\"G\\\" for GiB and \\\"t\\\" or \\\"T\\\" for TiB. NOTE: This requires properly configured NVDIMM regions and enough space for requested namespaces.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaImageCacheTTL\": {\"type\": \"number\", \"description\": \"Time in seconds that nova compute should continue caching an image once it is no longer used by any instances on the host\\n\", \"default\": 86400, \"tags\": [\"role_specific\"]}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"type\": \"json\", \"description\": \"Map of vgpu type(s) the instances can get as key and list of corresponding device addresses as value. Ex. NovaVGPUTypesDeviceAddressesMapping: {\'nvidia-35\': [\'0000:84:00.0\', \'0000:85:00.0\'],\\n                                  \'nvidia-36\': [\'0000:86:00.0\']}\\nwhere `nvidia-35` and `nvidia-36` are vgpu types and corresponding values are list of associated device addresses.\\n\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NovaComputeDisableIrqBalance\": {\"default\": false, \"description\": \"Whether to disable irqbalance on compute nodes or not. Especially in Realtime Compute role one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUMode\": {\"type\": \"string\", \"description\": \"The libvirt CPU mode to configure. Defaults to \'host-model\' if virt_type is set to kvm, otherwise defaults to \'none\'\\n\", \"default\": \"host-model\", \"constraints\": [{\"allowed_values\": [\"custom\", \"host-model\", \"none\", \"host-passthrough\"]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModels\": {\"type\": \"comma_delimited_list\", \"description\": \"The named libvirt CPU model (see names listed in /usr/share/libvirt/cpu_map.xml). Only has effect if cpu_mode=\\\"custom\\\" and virt_type=\\\"kvm|qemu\\\"\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModelExtraFlags\": {\"type\": \"string\", \"description\": \"This allows specifying granular CPU feature flags when specifying CPU models. Only has effect if cpu_mode is not set to \'none\'.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaDisableImageDownloadToRbd\": {\"type\": \"boolean\", \"description\": \"Refuse to boot an instance if it would require downloading from glance and uploading to ceph instead of a COW clone.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaDisableComputeServiceCheckForFfu\": {\"type\": \"boolean\", \"description\": \"Facilitate a Fast-Forward upgrade where new control services are being started before compute nodes have been able to update their service record.\\n\", \"default\": false}, \"NovaStatedirOwnershipSkip\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths relative to nova_statedir to ignore when recursively setting the ownership and selinux context.\\n\", \"default\": [\"triliovault-mounts\"]}, \"NovaImageTypeExcludeList\": {\"type\": \"comma_delimited_list\", \"description\": \"List of image formats that should not be advertised as supported by the compute service.\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtMaxQueues\": {\"type\": \"number\", \"description\": \"Add parameter to configure the libvirt max_queues. The maximum number of virtio queue pairs that can be enabled when creating a multiqueue guest. The number of virtio queues allocated will be the lesser of the CPUs requested by the guest and the max value defined. Default 0 corresponds to not set\\n\", \"default\": 0, \"tags\": [\"role_specific\"]}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"NovaGlanceEnableRbdDownload\": {\"type\": \"boolean\", \"description\": \"Enable download of Glance images directly via RBD.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdDownloadMultistoreID\": {\"type\": \"string\", \"description\": \"The hash key, which is the backend ID, of the GlanceMultistoreConfig to be used for the role where NovaGlanceEnableRbdDownload is enabled and defaults should be overridden. If CephClientUserName or GlanceRbdPoolName are not set in the GlanceMultistoreConfig, the global values of those parameters will be used.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"NovaGlanceRbdCopyPollInterval\": {\"type\": \"number\", \"description\": \"The interval in seconds with which to poll Glance after asking for it to copy an image to the local rbd store.\\n\", \"default\": 15, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdCopyTimeout\": {\"type\": \"number\", \"description\": \"The overall maximum time we will wait for Glance to complete an image copy to our local rbd store.\\n\", \"default\": 600, \"tags\": [\"role_specific\"]}, \"CustomProviderInventories\": {\"description\": \"Array of hashes describing the custom providers for the compute role.\\nFormat:\\nname/uuid - Resource providers to target can be identified by either\\nUUID or name. In addition, the value $COMPUTE_NODE can be used in\\nthe UUID field to identify all nodes managed by the service.\\nExactly one of uuid or name is mandatory. If neither uuid or name\\nis provided, the special uuid $COMPUTE_NODE gets set in the template.\\n\\ninventories - (Optional) Hash of custom provider inventories. \'total\' is\\na mandatory property. Any other optional properties not populated will\\nbe given a default value by placement. If overriding a pre-existing\\nprovider values will not be preserved from the existing inventory.\\n\\ntraits - (Optional) Array of additional traits.\\nExample:\\nComputeParameters:\\n  CustomProviderInventories:\\n    - uuid: $COMPUTE_NODE\\n      inventories:\\n        CUSTOM_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n          reserved: 0\\n          min_unit: 1\\n          max_unit: 10\\n          step_size: 1\\n          allocation_ratio: 1.0\\n        CUSTOM_ANOTHER_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n      traits:\\n        - CUSTOM_P_STATE_ENABLED\\n        - CUSTOM_C_STATE_ENABLED\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaVcpuPinSet\": {\"description\": \"A list or range of host CPU cores to which processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is set, or to which both emulator threads and processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is unset. Ex. NovaVcpuPinSet: [\'4-12\',\'^8\'] will reserve cores from 4-12 excluding 8\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenstack mailing list.\\n\", \"parameters\": [\"NovaVcpuPinSet\"]}], \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"compute_startup_delay\": {\"and\": [{\"not\": {\"get_param\": \"EnableInstanceHA\"}}, {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaComputeStartupDelay\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, \"\"]}]}]}}]}, \"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"enable_live_migration_tunnelled\": {\"and\": [{\"or\": [{\"and\": [{\"get_param\": \"NovaNfsEnabled\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, true]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}]}, {\"not\": \"use_tls_for_live_migration\"}]}, \"libvirt_file_backed_memory_enabled\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtFileBackedMemory\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, \"\"]}]}]}}, \"reserved_huge_pages_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaReservedHugePages\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaReservedHugePages\"}, []]}]}}, \"is_realtime\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"TunedProfileName\"]}, \"realtime-virtual-host\"]}, \"ovs_dpdk_socket_memory_not_set\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"OvsDpdkSocketMemory\"}, \"\"]}]}, \"nova_libvirt_max_queues_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtMaxQueues\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, 0]}]}]}}, \"glance_enable_rbd_download_set\": {\"or\": [{\"and\": [{\"get_param\": \"NovaGlanceEnableRbdDownload\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, true]}]}, \"nova_glance_rbd_download_multistore_id_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceRbdDownloadMultistoreID\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"\"]}]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"NovaComputeCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"NovaServiceName\": \"compute\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::vcpu_pin_set\": \"NovaVcpuPinSet\", \"nova::compute::cpu_shared_set\": \"NovaComputeCpuSharedSet\", \"nova::compute::cpu_dedicated_set\": \"NovaComputeCpuDedicatedSet\", \"nova::compute::reserved_host_memory\": \"NovaReservedHostMemory\", \"nova::compute::reserved_huge_pages\": \"NovaReservedHugePages\", \"nova::compute::neutron_physnets_numa_nodes_mapping\": \"NeutronPhysnetNUMANodesMapping\", \"nova::compute::neutron_tunnel_numa_nodes\": \"NeutronTunnelNUMANodes\", \"nova::compute::resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt::rx_queue_size\": \"NovaLibvirtRxQueueSize\", \"nova::compute::libvirt::tx_queue_size\": \"NovaLibvirtTxQueueSize\", \"nova::compute::libvirt::file_backed_memory\": \"NovaLibvirtFileBackedMemory\", \"nova::compute::libvirt::volume_use_multipath\": \"NovaLibvirtVolumeUseMultipath\", \"nova::compute::libvirt::hw_machine_type\": \"NovaHWMachineType\", \"nova::compute::mkisofs_cmd\": \"NovaMkisofsCmd\", \"compute_enable_ksm\": \"NovaComputeEnableKsm\", \"nova::compute::rbd::libvirt_images_rbd_pool\": \"NovaRbdPoolName\", \"tripleo::profile::base::nova::compute::nova_nfs_enabled\": \"NovaNfsEnabled\", \"nfs_backend_enable\": \"NovaNfsEnabled\", \"nfs_share\": \"NovaNfsShare\", \"nfs_options\": \"NovaNfsOptions\", \"nfs_vers\": \"NovaNfsVersion\", \"nova::compute::libvirt::num_pcie_ports\": \"NovaLibvirtNumPciePorts\", \"nova::compute::libvirt::mem_stats_period_seconds\": \"NovaLibvirtMemStatsPeriodSeconds\", \"nova::compute::rbd::ephemeral_storage\": \"NovaEnableRbdBackend\", \"resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::cpu_allocation_ratio\": \"NovaCPUAllocationRatio\", \"nova::ram_allocation_ratio\": \"NovaRAMAllocationRatio\", \"nova::disk_allocation_ratio\": \"NovaDiskAllocationRatio\", \"nova::compute::max_disk_devices_to_attach\": \"NovaMaxDiskDevicesToAttach\", \"nova::compute::libvirt::pmem_namespaces\": \"NovaPMEMMappings\", \"nova_pmem_namespaces\": \"NovaPMEMNamespaces\", \"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\": \"NovaImageCacheTTL\", \"nova::compute::libvirt::swtpm_enabled\": \"NovaEnableVTPM\", \"nova::compute::vgpu::vgpu_types_device_addresses_mapping\": \"NovaVGPUTypesDeviceAddressesMapping\", \"compute_disable_irqbalance\": \"NovaComputeDisableIrqBalance\", \"nova::compute::libvirt::cpu_mode\": \"NovaLibvirtCPUMode\", \"nova::compute::libvirt::cpu_models\": \"NovaLibvirtCPUModels\", \"nova::compute::libvirt::cpu_model_extra_flags\": \"NovaLibvirtCPUModelExtraFlags\", \"nova_compute_opt_volumes\": \"NovaComputeOptVolumes\", \"nova_compute_startup_delay\": \"NovaComputeStartupDelay\", \"nova_compute_opt_env_vars\": \"NovaComputeOptEnvVars\", \"nova::workarounds::never_download_image_if_on_rbd\": \"NovaDisableImageDownloadToRbd\", \"nova::compute::image_type_exclude_list\": \"NovaImageTypeExcludeList\", \"nova_permit_post_copy\": \"NovaLiveMigrationPermitPostCopy\", \"nova_permit_auto_converge\": \"NovaLiveMigrationPermitAutoConverge\", \"nova_libvirt_max_queues\": \"NovaLibvirtMaxQueues\", \"nova_glance_enable_rbd_download\": \"NovaGlanceEnableRbdDownload\", \"nova_glance_rbd_download_multistore_id\": \"NovaGlanceRbdDownloadMultistoreID\", \"nova::compute::force_raw_images\": \"NovaComputeForceRawImages\", \"nova::compute::use_cow_images\": \"NovaComputeUseCowImages\", \"nova::compute::libvirt::preallocate_images\": \"NovaComputeLibvirtPreAllocateImages\", \"nova::compute::image_cache::manager_interval\": \"NovaComputeImageCacheManagerInterval\", \"nova::compute::image_cache::remove_unused_base_images\": \"NovaComputeImageCacheRemoveUnusedBaseImages\", \"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\", \"nova::compute::image_cache::precache_concurrency\": \"NovaComputeImageCachePrecacheConcurrency\", \"nova::compute::provider::custom_inventories\": \"CustomProviderInventories\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\": \"NovaGlanceRbdCopyPollInterval\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\": \"NovaGlanceRbdCopyTimeout\", \"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaVcpuPinSet\": {\"get_param\": \"NovaVcpuPinSet\"}, \"NovaComputeCpuSharedSet\": {\"get_param\": \"NovaComputeCpuSharedSet\"}, \"NovaComputeCpuDedicatedSet\": {\"get_param\": \"NovaComputeCpuDedicatedSet\"}, \"NovaReservedHostMemory\": {\"get_param\": \"NovaReservedHostMemory\"}, \"NovaReservedHugePages\": {\"if\": [\"reserved_huge_pages_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"if\": [\"ovs_dpdk_socket_memory_not_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"repeat\": {\"for_each\": {\"<%node%>\": {\"yaql\": {\"expression\": \"range(0,len($.data.dpdk_p)).join(\\\",\\\").split(\\\",\\\")\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}}}}, \"<%size%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\")) -> [$hz]*len($.data.dpdk_p)\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}, \"<%count%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>int(switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\"))) -> $.data.dpdk_p.select(int($)*1024/$hz).join(\\\",\\\").split(\',\')\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}}, \"template\": \"node:<%node%>,size:<%size%>,count:<%count%>\", \"permutations\": false}}]}]}, \"NeutronPhysnetNUMANodesMapping\": {\"get_param\": \"NeutronPhysnetNUMANodesMapping\"}, \"NeutronTunnelNUMANodes\": {\"get_param\": \"NeutronTunnelNUMANodes\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaLibvirtRxQueueSize\": {\"get_param\": \"NovaLibvirtRxQueueSize\"}, \"NovaLibvirtTxQueueSize\": {\"get_param\": \"NovaLibvirtTxQueueSize\"}, \"NovaLibvirtFileBackedMemory\": {\"get_param\": \"NovaLibvirtFileBackedMemory\"}, \"NovaLibvirtVolumeUseMultipath\": {\"get_param\": \"NovaLibvirtVolumeUseMultipath\"}, \"NovaHWMachineType\": {\"get_param\": \"NovaHWMachineType\"}, \"NovaComputeEnableKsm\": {\"get_param\": \"NovaComputeEnableKsm\"}, \"NovaRbdPoolName\": {\"get_param\": \"NovaRbdPoolName\"}, \"NovaMkisofsCmd\": {\"get_param\": \"NovaMkisofsCmd\"}, \"NovaNfsEnabled\": {\"get_param\": \"NovaNfsEnabled\"}, \"NovaNfsShare\": {\"get_param\": \"NovaNfsShare\"}, \"NovaNfsOptions\": {\"get_param\": \"NovaNfsOptions\"}, \"NovaNfsVersion\": {\"get_param\": \"NovaNfsVersion\"}, \"NovaLibvirtNumPciePorts\": {\"get_param\": \"NovaLibvirtNumPciePorts\"}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"get_param\": \"NovaLibvirtMemStatsPeriodSeconds\"}, \"NovaEnableRbdBackend\": {\"get_param\": \"NovaEnableRbdBackend\"}, \"NovaCPUAllocationRatio\": {\"get_param\": \"NovaCPUAllocationRatio\"}, \"NovaRAMAllocationRatio\": {\"get_param\": \"NovaRAMAllocationRatio\"}, \"NovaDiskAllocationRatio\": {\"get_param\": \"NovaDiskAllocationRatio\"}, \"NovaEnableVTPM\": {\"get_param\": \"NovaEnableVTPM\"}, \"NovaMaxDiskDevicesToAttach\": {\"get_param\": \"NovaMaxDiskDevicesToAttach\"}, \"NovaPMEMMappings\": {\"get_param\": \"NovaPMEMMappings\"}, \"NovaPMEMNamespaces\": {\"get_param\": \"NovaPMEMNamespaces\"}, \"NovaImageCacheTTL\": {\"get_param\": \"NovaImageCacheTTL\"}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"get_param\": \"NovaVGPUTypesDeviceAddressesMapping\"}, \"NovaComputeDisableIrqBalance\": {\"get_param\": \"NovaComputeDisableIrqBalance\"}, \"NovaLibvirtCPUMode\": {\"get_param\": \"NovaLibvirtCPUMode\"}, \"NovaLibvirtCPUModels\": {\"get_param\": \"NovaLibvirtCPUModels\"}, \"NovaLibvirtCPUModelExtraFlags\": {\"get_param\": \"NovaLibvirtCPUModelExtraFlags\"}, \"NovaComputeOptVolumes\": {\"get_param\": \"NovaComputeOptVolumes\"}, \"NovaComputeStartupDelay\": {\"get_param\": \"NovaComputeStartupDelay\"}, \"NovaComputeOptEnvVars\": {\"get_param\": \"NovaComputeOptEnvVars\"}, \"NovaDisableImageDownloadToRbd\": {\"get_param\": \"NovaDisableImageDownloadToRbd\"}, \"NovaImageTypeExcludeList\": {\"get_param\": \"NovaImageTypeExcludeList\"}, \"NovaLiveMigrationPermitPostCopy\": {\"get_param\": \"NovaLiveMigrationPermitPostCopy\"}, \"NovaLiveMigrationPermitAutoConverge\": {\"get_param\": \"NovaLiveMigrationPermitAutoConverge\"}, \"NovaLibvirtMaxQueues\": {\"get_param\": \"NovaLibvirtMaxQueues\"}, \"NovaGlanceEnableRbdDownload\": {\"get_param\": \"NovaGlanceEnableRbdDownload\"}, \"NovaGlanceRbdDownloadMultistoreID\": {\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"NovaComputeForceRawImages\": {\"get_param\": \"NovaComputeForceRawImages\"}, \"NovaComputeUseCowImages\": {\"get_param\": \"NovaComputeUseCowImages\"}, \"NovaComputeLibvirtPreAllocateImages\": {\"get_param\": \"NovaComputeLibvirtPreAllocateImages\"}, \"NovaComputeImageCacheManagerInterval\": {\"get_param\": \"NovaComputeImageCacheManagerInterval\"}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedBaseImages\"}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\"}, \"NovaComputeImageCachePrecacheConcurrency\": {\"get_param\": \"NovaComputeImageCachePrecacheConcurrency\"}, \"CustomProviderInventories\": {\"get_param\": \"CustomProviderInventories\"}, \"NovaGlanceRbdCopyPollInterval\": {\"get_param\": \"NovaGlanceRbdCopyPollInterval\"}, \"NovaGlanceRbdCopyTimeout\": {\"get_param\": \"NovaGlanceRbdCopyTimeout\"}, \"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"nova_compute_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for nova_compute\", \"value\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}, \"role_data\": {\"description\": \"Role data for the Nova Compute service.\", \"value\": {\"service_name\": \"nova_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"nova::compute::pci::passthrough\": {\"str_replace\": {\"template\": \"JSON_PARAM\", \"params\": {\"map_replace\": [{\"map_replace\": [{\"JSON_PARAM\": \"NovaPCIPassthrough\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaPCIPassthrough\": {\"get_param\": \"NovaPCIPassthrough\"}}}]}}}, \"nova::compute::libvirt::migration_support\": false, \"tripleo::profile::base::nova::migration::client::nova_compute_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::rbd::libvirt_images_rbd_glance_store_name\": {\"get_param\": \"GlanceBackendID\"}, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"tripleo::profile::base::nova::compute::cinder_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::cinder::username\": \"cinder\", \"nova::cinder::auth_type\": \"v3password\", \"nova::cinder::project_name\": \"service\", \"nova::cinder::password\": {\"get_param\": \"CinderPassword\"}, \"nova::cinder::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::cinder::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"nova::compute::instance_usage_audit\": true, \"nova::compute::instance_usage_audit_period\": \"hour\", \"nova::compute::consecutive_build_service_disable_threshold\": {\"get_param\": \"NovaAutoDisabling\"}, \"nova::compute::live_migration_wait_for_vif_plug\": {\"get_param\": \"NovaLiveMigrationWaitForVIFPlug\"}, \"nova::migration::libvirt::live_migration_permit_post_copy\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_post_copy\"]}]}, \"nova::migration::libvirt::live_migration_permit_auto_converge\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_auto_converge\"]}]}, \"nova::migration::libvirt::live_migration_tunnelled\": false, \"nova::compute::vncserver_proxyclient_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"protocol\"]}, \"nova::vncproxy::common::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"port\"]}, \"nova::compute::verify_glance_signatures\": {\"get_param\": [\"VerifyGlanceSignatures\"]}, \"nova::ram_allocation_ratio\": {\"if\": [\"libvirt_file_backed_memory_enabled\", \"1.0\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::ram_allocation_ratio\"]}]}, \"nova::compute::libvirt::max_queues\": {\"if\": [\"nova_libvirt_max_queues_set\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_max_queues\"]}]}, \"nova::workarounds::disable_compute_service_check_for_ffu\": {\"get_param\": \"NovaDisableComputeServiceCheckForFfu\"}}, {\"if\": [\"glance_enable_rbd_download_set\", {\"nova::glance::enable_rbd_download\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_enable_rbd_download\"]}, \"nova::glance::rbd_user\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_ceph_client_user_name) -> $.data.multistore.get($k).get(\\\"CephClientUserName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_ceph_client_user_name\": {\"get_param\": \"CephClientUserName\"}}}}, {\"get_param\": \"CephClientUserName\"}]}, \"nova::glance::rbd_pool\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_glance_rbd_pool_name) -> $.data.multistore.get($k).get(\\\"GlanceRbdPoolName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_glance_rbd_pool_name\": {\"get_param\": \"GlanceRbdPoolName\"}}}}, {\"get_param\": \"GlanceRbdPoolName\"}]}, \"nova::glance::rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key) -> list(coalesce($.data.multistore, {}).get($k)).flatten().select($.get(\\\"CephClusterName\\\"))\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}, {\"get_param\": \"CephClusterName\"}]}, \".conf\"]]}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_nova_compute\": [{\"get_param\": \"NovaComputeLoggingSource\"}]}, \"collectd\": {\"tripleo.collectd.plugins.nova_compute\": [\"virt\"], \"collectd::plugin::virt::connection\": \"qemu:///system\"}}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"nova_config\", \"step_config\": \"# TODO(emilien): figure how to deal with libvirt profile.\\n# We\'ll probably treat it like we do with Neutron plugins.\\n# Until then, just include it in the default nova-compute role.\\ninclude tripleo::profile::base::nova::compute::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_compute.json\": {\"command\": {\"list_join\": [\" \", [{\"if\": [\"compute_startup_delay\", {\"str_replace\": {\"template\": \"/var/lib/nova/delay-nova-compute --delay DELAY --nova-binary\", \"params\": {\"DELAY\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}}]}, \"/usr/bin/nova-compute\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}, {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\": {\"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"get_attr\": [\"NovaComputeCommon\", \"container_config_scripts\"]}]}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"nova_statedir_owner\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"none\", \"user\": \"root\", \"security_opt\": [\"label=disable\"], \"privileged\": false, \"detach\": false, \"volumes\": [\"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"], \"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\", \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}, \"NOVA_STATEDIR_OWNERSHIP_SKIP\": {\"list_join\": [\":\", {\"get_param\": \"NovaStatedirOwnershipSkip\"}]}}}}, \"step_5\": {\"map_merge\": [{\"nova_compute\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"ulimit\": {\"get_param\": \"DockerNovaComputeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"nova\", \"restart\": \"always\", \"depends_on\": {\"list_concat\": [[\"tripleo_nova_libvirt.target\"], {\"if\": [{\"get_param\": \"NovaNfsEnabled\"}, [\"var-lib-nova-instances.mount\"]]}]}, \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_volumes\"]}, [\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/run/nova:/run/nova:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/sys/class/net:/sys/class/net\", \"/sys/bus/pci:/sys/bus/pci\", \"/boot:/boot:ro\", \"/var/lib/nova:/var/lib/nova:shared\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_env_vars\"]}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, {\"LIBGUESTFS_BACKEND\": \"direct\"}]}}}, {\"if\": [{\"not\": {\"get_param\": \"NovaAdditionalCell\"}}, {\"nova_wait_for_compute_service\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/var/lib/container-config-scripts:/container-config-scripts\"]]}, \"user\": \"nova\", \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}}}}]}]}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check for /var/lib/nova/instances directory exitance\", \"stat\": {\"path\": \"/var/lib/nova/instances\"}, \"register\": \"check_nova_instances_result\"}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/_nova_secontext\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/nova/instances\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/tmpfiles.d\"}]}, {\"name\": \"ensure /run/nova is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-nova.conf\", \"content\": \"d /run/nova 0777 root root - -\\n\"}}, {\"name\": \"create tempfiles\", \"command\": \"systemd-tmpfiles --create\"}], [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}], [{\"name\": \"delay installation of systemd-container\", \"when\": \"check_nova_instances_result.stat.exists\", \"block\": [{\"name\": \"check systemd-container package installed or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\", \"failed_when\": false}, {\"name\": \"get latest package from downloaded package versions\", \"shell\": \"ls -1t /var/tmp/systemd-container* | head -1\", \"register\": \"latest_systemd_container_package\", \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"], \"failed_when\": false}, {\"name\": \"Install systemd-container package on boot\", \"copy\": {\"dest\": \"/etc/systemd/system/install-systemd-container.service\", \"content\": \"[Unit]\\nDescription=Install systemd container package on system boot\\nBefore=tripleo_nova_virtqemud.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\nExecStartPost=rm -f /var/tmp/systemd-container*\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": [\"latest_systemd_container_package is defined\", \"(\'stdout\' in latest_systemd_container_package)\", \"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"enable install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"state\": \"stopped\", \"enabled\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"check if install-systemd-container service exists\", \"stat\": {\"path\": \"/etc/systemd/system/install-systemd-container.service\"}, \"register\": \"install_systemd_container_result\"}, {\"name\": \"disable and mask install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"not is_systemd_container_package.changed\", \"install_systemd_container_result.stat.exists\"]}]}, {\"name\": \"is Nova Resume Guests State On Host Boot enabled\", \"set_fact\": {\"resume_guests_state_on_host_boot_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"resume_guests_state_on_host_boot\"]}}}, {\"name\": \"install libvirt-guests systemd unit file (docker)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'docker\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs\", \"copy\": {\"dest\": \"/etc/systemd/system/libvirt-guests.service\", \"content\": \"[Unit]\\nDescription=Suspend/Resume Running libvirt Guests\\nAfter=network.target\\nAfter=time-sync.target\\nAfter=virt-guest-shutdown.target\\nAfter=docker.service\\nAfter=tripleo-container-shutdown.service\\nAfter=rhel-push-plugin.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\n# Hack just call traditional service until we factor\\n# out the code\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\nExecStop=/bin/{{container_cli}} stop nova_compute\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"libvirt-guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"libvirt-guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"install tripleo_nova_libvirt_guests systemd unit file (podman)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'podman\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\"}, {\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\"}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"tripleo_nova_libvirt_guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Do we prepend nova startup with a delay\", \"set_fact\": {\"nova_compute_delay\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}, {\"name\": \"install nova-compute delay wrapper script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/scripts/delay-nova-compute\"}, \"dest\": \"/var/lib/nova/delay-nova-compute\", \"mode\": 493}, \"when\": \"nova_compute_delay|int > 0\"}, {\"name\": \"Is irqbalance enabled\", \"set_fact\": {\"compute_irqbalance_disabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_disable_irqbalance\"]}}}, {\"name\": \"disable irqbalance service on compute\", \"when\": \"compute_irqbalance_disabled|bool\", \"service\": {\"name\": \"irqbalance.service\", \"state\": \"stopped\", \"enabled\": false}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"deploy_steps_tasks\": [{\"name\": \"install systemd-container for a greenfield\", \"when\": [\"step|int == 1\", \"not check_nova_instances_result.stat.exists\"], \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}}, {\"name\": \"validate nova-compute container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_compute\"}, \"register\": \"nova_compute_infos\", \"failed_when\": [\"nova_compute_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 6\"]}, {\"name\": \"manage PMEM namespaces for vPMEM\", \"include_role\": {\"name\": \"tripleo_nvdimm\"}, \"vars\": {\"tripleo_nvdimm_pmem_namespaces\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_pmem_namespaces\"]}}, \"when\": [\"step|int == 1\", \"tripleo_nvdimm_pmem_namespaces != \'\'\"]}, {\"name\": \"manage OS version 9 specific sysctls\", \"when\": [\"step|int == 1\", \"ansible_facts[\'os_family\'] == \'RedHat\'\", \"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"], \"block\": [{\"name\": \"Enable post-copy by setting unprivileged_userfaultfd\", \"sysctl\": {\"name\": \"vm.unprivileged_userfaultfd\", \"value\": 1, \"sysctl_set\": true, \"sysctl_file\": \"/etc/sysctl.d/99-tripleo-postcopy.conf\", \"state\": \"present\", \"reload\": true}}]}, {\"name\": \"enable/disable ksm\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"is KSM enabled\", \"set_fact\": {\"compute_ksm_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_enable_ksm\"]}}}, {\"name\": \"disable KSM on compute\", \"when\": \"not compute_ksm_enabled|bool\", \"block\": [{\"name\": \"Check for ksm\", \"shell\": \"systemctl is-active ksm.service || systemctl is-enabled ksm.service\", \"become\": true, \"failed_when\": false, \"register\": \"ksm_service_check\"}, {\"name\": \"disable KSM services\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"], \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\"], \"register\": \"ksmdisabled\"}, {\"name\": \"delete PageKSM after disable ksm on compute\", \"command\": \"echo 2 >/sys/kernel/mm/ksm/run\", \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\", \"ksmdisabled is changed\"]}]}, {\"name\": \"enable KSM on compute\", \"when\": \"compute_ksm_enabled|bool\", \"block\": [{\"name\": \"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\", \"package\": {\"name\": \"qemu-kvm-common\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"]}, {\"name\": \"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\", \"package\": {\"name\": \"ksmtuned\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"]}, {\"name\": \"enable ksmtunded\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"started\", \"enabled\": true}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"]}]}]}], \"external_post_deploy_tasks\": {\"get_attr\": [\"NovaComputeCommon\", \"nova_compute_common_deploy_steps_tasks\"]}, \"upgrade_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}, {\"name\": \"nova_compute pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"absent\", \"fstype\": \"nfs4\"}, \"when\": \"nfs_backend_enable|bool\"}]}, {\"name\": \"nova_compute post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}], \"update_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}], \"post_update_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"post_upgrade_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get nova-compute service ID\", \"command\": \"openstack compute service list --service nova-compute --column ID --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"is additional Cell?\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"Set fact for nova_compute services\", \"set_fact\": {\"nova_compute_service\": \"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Check search output\", \"fail\": {\"msg\": \"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\"}, \"when\": [\"(nova_compute_service | length) > 1\"]}, {\"name\": \"Disable nova services\", \"when\": [\"(nova_compute_service | length) == 1\"], \"block\": [{\"name\": \"Disable nova-compute service\", \"command\": \"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"when\": [\"not is_additional_cell|bool\"]}, {\"name\": \"Stop nova-compute container\", \"service\": {\"name\": \"tripleo_nova_compute\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_nova_compute\", \"failed_when\": \"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\"}, {\"name\": \"Delete nova-compute service\", \"command\": \"openstack compute service delete {{ nova_compute_service[0].ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(84,'2026-06-15 07:51:25',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"external_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(85,'2026-06-15 07:51:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"MGRnIM4wMti8nqhqt2uJkphYX\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lAltaQRZMJ8lMeTuITOttJN7X\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"89Vk5RNyVwiA8aj5GHvgz6wY\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (86,'2026-06-15 07:51:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Firewall settings\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ExtraFirewallRules\": {\"default\": {}, \"description\": \"Mapping of firewall rules.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_firewall_rules\": \"ExtraFirewallRules\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraFirewallRules\": {\"get_param\": \"ExtraFirewallRules\"}}}]}}}}, \"conditions\": {\"no_ctlplane\": {\"equals\": [{\"get_params\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}, null]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO firewall settings\", \"value\": {\"service_name\": \"tripleo_firewall\", \"config_settings\": {\"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false}, \"ansible_group_vars\": {\"tripleo_nftables_debug\": {\"get_param\": \"Debug\"}}, \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"003 accept ssh from ctlplane subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": 22}}}}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_firewall_rules\"]}]}, \"host_prep_tasks\": [{\"if\": [\"no_ctlplane\", {\"name\": \"Failure - ctlplane subnet is unset\", \"fail\": {\"msg\": \"No CIDRs found in the ctlplane network tags.\\nPlease refer to the documentation in order to\\nset the correct network tags in DeployedServerPortMap.\\n\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}]}], \"host_firewall_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}], \"update_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}], \"upgrade_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(87,'2026-06-15 07:51:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(88,'2026-06-15 07:51:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"NovaServiceName\": \"compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(89,'2026-06-15 07:51:26',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(90,'2026-06-15 07:51:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(91,'2026-06-15 07:51:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(92,'2026-06-15 07:51:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(93,'2026-06-15 07:51:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"MGRnIM4wMti8nqhqt2uJkphYX\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lAltaQRZMJ8lMeTuITOttJN7X\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"89Vk5RNyVwiA8aj5GHvgz6wY\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (94,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for nova-compute containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"nova_statedir_ownership.py\": {\"mode\": \"0700\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_statedir_ownership.py\"}}, \"nova_wait_for_compute_service.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_wait_for_compute_service.py\"}}}}, \"nova_compute_common_deploy_steps_tasks\": {\"description\": \"Common host prep tasks for nova-compute services (compute + ironic)\", \"value\": [{\"block\": [{\"name\": \"is additonal Cell?\", \"set_fact\": {\"nova_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"check if discover hosts is required\", \"when\": [\"not nova_additional_cell|bool\", \"nova_cellv2_discovery_done is not defined\"], \"block\": [{\"name\": \"discover via nova_manager?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_manager\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_manager\"}, \"when\": [\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\"]}, {\"name\": \"discover via nova_api?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_api\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_api\"}, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\", \"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\"]}, {\"name\": \"Warn if no discovery host available\", \"fail\": {\"msg\": \"No hosts available to run nova cell_v2 host discovery.\"}, \"ignore_errors\": true, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\"]}, {\"name\": \"Discovering nova hosts\", \"command\": \"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\", \"become\": true, \"changed_when\": false, \"delegate_to\": \"{{ nova_cellv2_discovery_delegate_host }}\", \"when\": [\"nova_cellv2_discovery_delegate_host is defined\"]}, {\"set_fact\": {\"nova_cellv2_discovery_done\": true}}]}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(95,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"puJEUVV5bncg9PX1nMb3Jnk25\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"eljGPqsTubd1MRdmVjF5MppaC\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(96,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized OVN Metadata agent\\n\", \"parameters\": {\"ContainerOvnMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\"}, \"ContainerNeutronConfigImage\": {\"description\": \"The container image to use for the neutron config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"OvnMetadataAgentLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.neutron.agent.ovn-metadata\", \"file\": \"/var/log/containers/neutron/networking-ovn-metadata-agent.log\"}}, \"OVNEnableHaproxyDockerWrapper\": {\"description\": \"Generate a wrapper script so that haproxy is launched in a separate container.\", \"type\": \"boolean\", \"default\": true}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"OVNWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NeutronMetadataProxySharedSecret\": {\"description\": \"Shared secret to prevent spoofing\", \"type\": \"string\", \"hidden\": true, \"default\": \"NFzMNmBHe4LKwprV3ucg9SrGP\"}, \"NeutronMetadataWorkers\": {\"default\": 1, \"description\": \"Sets the number of worker processes for the neutron OVN metadata agent.\\nThe default value results in the configuration being left unset and a\\nsystem-dependent default will be chosen (usually the number of\\nprocessors). Please note that this can result in a large number of\\nprocesses and memory consumption on systems with a large core count. On\\nsuch systems it is recommended that a non-default value be selected that\\nmatches the load requirements.\\n\", \"type\": \"string\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"OorljNRFSWJ6uLOrYiwbnwsqY\"}, \"OVNNorthboundServerPort\": {\"description\": \"Port of the OVN Northbound DB server\", \"type\": \"number\", \"default\": 6641}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the OVN Southbound DB server\", \"type\": \"number\", \"default\": 6642}, \"OVNDbConnectionTimeout\": {\"description\": \"Timeout in seconds for the OVSDB connection transaction\", \"type\": \"number\", \"default\": 180}, \"OVNOvsdbProbeInterval\": {\"description\": \"Probe interval in ms for the OVSDB session\", \"type\": \"number\", \"default\": 60000}, \"MonitoringSubscriptionOvnMetadata\": {\"default\": \"overcloud-ovn-metadata\", \"type\": \"string\"}, \"OvnMetadataAgentDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging for OVN Metadata agent.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"DockerAdditionalSockets\": {\"default\": [\"/var/lib/openstack/docker.sock\"], \"description\": \"Additional domain sockets for the docker daemon to bind to (useful for mounting into containers that launch other containers)\", \"type\": \"comma_delimited_list\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"OvnMetadataCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OvnHardwareOffloadedQos\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable the QoS support for hardware offloaded ports\"}, \"OVNMetadataImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNMetadataUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}}, \"conditions\": {\"haproxy_wrapper_enabled\": {\"equals\": [{\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"neutron_metadata_workers_unset\": {\"equals\": [{\"get_param\": \"NeutronMetadataWorkers\"}, \"\"]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"OvnMetadataCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NeutronBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NeutronLogging\": {\"type\": \"OS::TripleO::Services::Logging::NeutronCommon\", \"properties\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerOvnMetadataImage\": \"ContainerOvnMetadataImage\", \"ContainerNeutronConfigImage\": \"ContainerNeutronConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerOvnMetadataImage\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"ContainerNeutronConfigImage\": {\"get_param\": \"ContainerNeutronConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for OVNMetadata agent\", \"value\": {\"service_name\": \"ovn_metadata\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionOvnMetadata\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NeutronLogging\", \"config_settings\"]}, {\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\": \"/var/lib/neutron/ovn_metadata_haproxy_wrapper\", \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo::profile::base::neutron::container_cli\": {\"get_param\": \"ContainerCli\"}, \"neutron::agents::ovn_metadata::shared_secret\": {\"get_param\": \"NeutronMetadataProxySharedSecret\"}, \"neutron::agents::ovn_metadata::auth_password\": {\"get_param\": \"NeutronPassword\"}, \"neutron::agents::ovn_metadata::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"neutron::agents::ovn_metadata::auth_tenant\": \"service\", \"neutron::agents::ovn_metadata::metadata_host\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataCellInternal\", \"host_nobrackets\"]}, \"neutron::agents::ovn_metadata::ovsdb_connection_timeout\": {\"get_param\": \"OVNDbConnectionTimeout\"}, \"neutron::agents::ovn_metadata::ovsdb_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}, \"neutron::agents::ovn_metadata::hwol_qos_enabled\": {\"get_param\": \"OvnHardwareOffloadedQos\"}, \"ovn::northbound::port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"neutron::agents::ovn_metadata::debug\": {\"if\": [{\"get_param\": \"OvnMetadataAgentDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::agents::ovn_metadata::metadata_protocol\": {\"if\": [\"internal_tls_enabled\", \"https\", \"http\"]}}, {\"if\": [\"neutron_metadata_workers_unset\", {}, {\"neutron::agents::ovn_metadata::metadata_workers\": {\"get_param\": \"NeutronMetadataWorkers\"}}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::protocol\": \"ssl\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\"}, {}]}]}, \"puppet_config\": {\"puppet_tags\": \"neutron_config,ovn_metadata_agent_config\", \"config_volume\": \"neutron\", \"step_config\": \"include tripleo::profile::base::neutron::ovn_metadata\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_metadata_agent.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini\", {\"get_attr\": [\"NeutronLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/var/lib/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/ovn_metadata.key\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_2\": {\"create_haproxy_wrapper\": {\"start_order\": 1, \"detach\": false, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\"]]}}}, \"step_4\": {\"setup_ovs_manager\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"exec\", \"include tripleo::profile::base::neutron::ovn_metadata\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_metadata_agent\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"cgroupns\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NeutronLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\", \"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\", \"/run/netns:/run/netns:shared\", \"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\"], {\"if\": [\"docker_enabled\", [\"/var/lib/openstack:/var/lib/openstack\"], null]}, {\"if\": [\"haproxy_wrapper_enabled\", [\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\"], null]}, {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\", \"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"metadata_settings\"]}, {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_metadata\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_metadata\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_metadata/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_metadata_agent\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"OvnMetadataCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NeutronLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create /run/netns with temp namespace\", \"command\": \"ip netns add ns_temp\", \"register\": \"ipnetns_add_result\", \"failed_when\": false}, {\"name\": \"remove temp namespace\", \"command\": \"ip netns delete ns_temp\", \"failed_when\": false, \"when\": [\"ipnetns_add_result.rc is defined\", \"ipnetns_add_result.rc == 0\"]}, {\"name\": \"create /var/lib/neutron\", \"file\": {\"path\": \"/var/lib/neutron\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"set conditions\", \"set_fact\": {\"haproxy_wrapper_enabled\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"debug_enabled\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"docker_additional_sockets\": {\"get_param\": \"DockerAdditionalSockets\"}}}, {\"name\": \"create kill_scripts directory within /var/lib/neutron\", \"file\": {\"state\": \"directory\", \"path\": \"/var/lib/neutron/kill_scripts\"}}, {\"name\": \"create haproxy kill script\", \"when\": \"haproxy_wrapper_enabled|bool\", \"copy\": {\"dest\": \"/var/lib/neutron/kill_scripts/haproxy-kill\", \"mode\": 493, \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/kill-script\"}}}]]}, \"upgrade_tasks\": [], \"external_update_tasks\": [{\"name\": \"Check if python3-openvswitch3.1 workaround is needed\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": \"step|int == 1\", \"shell\": \"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\n\", \"register\": \"metadata_python_ovs_3_1\", \"failed_when\": false, \"loop\": \"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}, {\"name\": \"Update ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"become\": true, \"loop\": \"{{ hosts_to_update_metadata }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_metadata_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_metadata_agent image pull successful.\", \"when\": [\"\'results\' in ovn_metadata_image_update\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_metadata_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"tags\": [\"ovn_metadata_parallel\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0}]}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"never\", \"ovn_metadata_serial\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"loop_control\": {\"pause\": 1}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(97,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(98,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(99,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(100,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Qpid dispatch router service for metrics and monitoring purposes\\n\", \"parameters\": {\"ContainerMetricsQdrImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ContainerMetricsQdrConfigImage\": {\"description\": \"The container image to use for the qdrouterd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionQdr\": {\"default\": \"overcloud-qdr\", \"type\": \"string\"}, \"MetricsQdrLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MetricsQdrConnectors\": {\"default\": [], \"description\": \"Connectors configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrSSLProfiles\": {\"default\": [{\"name\": \"sslProfile\"}], \"description\": \"SSL Profiles for the connectors (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAddresses\": {\"default\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"description\": \"Addresses configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAutoLinks\": {\"default\": [], \"description\": \"AutoLinks for the Configured Addresses\", \"type\": \"json\"}, \"MetricsQdrUseSSL\": {\"default\": false, \"description\": \"Set to true if it is required to use SSL or TLS on the connection for the local listener. !WARNING! Currently breaks connections from collectd and ceilometer.\", \"type\": \"boolean\"}, \"MetricsQdrUseEncryption\": {\"default\": false, \"description\": \"Set to true if it is required to encrypt connection to the peer for listener. Not currently implemented, use EnableInternalTLS instead. This option can be ignored.\", \"type\": \"boolean\"}, \"MetricsQdrSaslMechanisms\": {\"default\": \"ANONYMOUS\", \"description\": \"List of accepted SASL auth mechanisms for listener in format of comma separated list.\", \"type\": \"string\"}, \"MetricsQdrSslCertDb\": {\"default\": \"/etc/ipa/ca.crt\", \"description\": \"Path to SSL certificate db for listener.\", \"type\": \"string\"}, \"MetricsQdrSslCertFile\": {\"default\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"description\": \"Path to SSL certificate file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslKeyFile\": {\"default\": \"/etc/pki/tls/private/metrics_qdr.key\", \"description\": \"Path to SSL private key file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPwFile\": {\"default\": \"\", \"description\": \"Path to SSL password file for certificate key for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPassword\": {\"default\": \"\", \"description\": \"SSL password to be supplied for listener.\", \"type\": \"string\"}, \"MetricsQdrTrustedCerts\": {\"default\": \"\", \"description\": \"Path to file containing trusted certificates for listener.\", \"type\": \"string\"}, \"MetricsQdrAuthenticateClient\": {\"default\": false, \"description\": \"Authenticate the client using SSL/TLS\", \"type\": \"boolean\"}, \"MetricsQdrExternalEndpoint\": {\"default\": false, \"description\": \"Whether QDR should listen on external network interface. To enable listening on external network one must deploy QDRs in mesh mode.\", \"type\": \"boolean\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableSTF\": {\"default\": false, \"description\": \"Set to true to enable configuration for STF client.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"QdrCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"listener_ssl_enabled\": {\"equals\": [{\"get_param\": \"MetricsQdrUseSSL\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"QdrCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMetricsQdrImage\": \"ContainerMetricsQdrImage\", \"ContainerMetricsQdrConfigImage\": \"ContainerMetricsQdrConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMetricsQdrImage\": {\"get_param\": \"ContainerMetricsQdrImage\"}, \"ContainerMetricsQdrConfigImage\": {\"get_param\": \"ContainerMetricsQdrConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the metrics Qdr role.\", \"value\": {\"service_name\": \"metrics_qdr\", \"firewall_rules\": {\"map_merge\": [{\"109 metrics qdr\": {\"dport\": [{\"get_param\": \"MetricsQdrPort\"}]}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"109 accept internal metrics qdr ctlplane subnet <%net_cidr%>\": {\"dport\": [5667, 5668]}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionQdr\"}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_metrics_qdr\": [{\"get_param\": \"MetricsQdrLoggingSource\"}]}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::qdr::listener_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::haproxy::metrics_qdr\": {\"get_param\": \"MetricsQdrExternalEndpoint\"}, \"tripleo::profile::base::metrics::qdr::listener_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::qdr::username\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::qdr::password\": {\"get_param\": \"MetricsQdrPassword\"}, \"tripleo::profile::base::metrics::qdr::connectors\": {\"get_param\": \"MetricsQdrConnectors\"}, \"tripleo::profile::base::metrics::qdr::addresses\": {\"get_param\": \"MetricsQdrAddresses\"}, \"tripleo::profile::base::metrics::qdr::autolink_addresses\": {\"get_param\": \"MetricsQdrAutoLinks\"}, \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": {\"if\": [\"listener_ssl_enabled\", true, false]}, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": {\"get_param\": \"MetricsQdrUseEncryption\"}, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": {\"get_param\": \"MetricsQdrSaslMechanisms\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": {\"get_param\": \"MetricsQdrSslCertDb\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": {\"get_param\": \"MetricsQdrSslCertFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": {\"get_param\": \"MetricsQdrSslKeyFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": {\"get_param\": \"MetricsQdrSslPwFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": {\"get_param\": \"MetricsQdrSslPassword\"}, \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": {\"get_param\": \"MetricsQdrTrustedCerts\"}, \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": {\"get_param\": \"MetricsQdrAuthenticateClient\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"list_concat\": [{\"get_param\": \"MetricsQdrSSLProfiles\"}, [{\"name\": \"tlsProfile\", \"certFile\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"keyFile\": \"/etc/pki/tls/private/metrics_qdr.key\", \"caCertFile\": {\"get_param\": \"InternalTLSCAFile\"}}]]}}, {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"get_param\": \"MetricsQdrSSLProfiles\"}}]}, {\"if\": [\"enable_stf\", {\"tripleo::profile::base::metrics::qdr::interior_mesh_nodes\": \"\", \"tripleo::profile::base::metrics::qdr::router_mode\": \"edge\"}, null]}]}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"metrics_qdr\", \"network\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}, \"type\": \"node\"}], null]}, \"puppet_config\": {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\", \"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"principal\": {\"str_replace\": {\"template\": \"metrics_qdr/{{fqdn_NETWORK}}@{{idm_realm}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"QdrCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(101,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBackupBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"CinderBackupBackend\": {\"get_param\": \"CinderBackupBackend\"}, \"CinderBackupRbdPoolName\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"CephClientUserName\": {\"get_param\": \"CephClientUserName\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::cinder::backup_bundle::cinder_backup_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::backup_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::backup::manage_service\": false, \"cinder::backup::enabled\": false}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"puppet_config\", \"step_config\"]}, \"include tripleo::profile::pacemaker::cinder::backup_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Backup tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Backup HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-backup temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-backup\", \"tripleo_ha_image_update_new_image\": \"{{cinder_backup_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_backup_image}}\"}, \"when\": [\"(pcmk_cinder_backup_image != \\\"\\\")\", \"(pcmk_cinder_backup_image != cinder_backup_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-backup container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_backup_image == cinder_backup_image_latest\", \"fail_msg\": \"cinder-backup image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder-backup container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"cinder_backup fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder backup bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA cinder_backup container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"Prepare switch of cinder_backup image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_backup image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-backup | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_backup_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_backup image facts\", \"set_fact\": {\"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_backup_image_current\": \"{{cinder_backup_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_backup image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image_current}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}, {\"name\": \"Create cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_backup_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_backup_bootstrap_node={{cinder_backup_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_backup retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_backup_bootstrap_node\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Update the cinder_backup bundle to use the new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-backup container image={{cinder_backup_image_latest}}\"}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_backup retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}, {\"name\": \"Retag the pacemaker image for cinder_backup\", \"when\": [\"step|int == 3\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step3\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (102,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(103,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(104,'2026-06-15 07:51:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Scheduler service\\n\", \"parameters\": {\"ContainerCinderSchedulerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderSchedulerLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.scheduler\", \"file\": \"/var/log/containers/cinder/cinder-scheduler.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCinderScheduler\": {\"default\": \"overcloud-cinder-scheduler\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderSchedulerImage\": \"ContainerCinderSchedulerImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderSchedulerImage\": {\"get_param\": \"ContainerCinderSchedulerImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Scheduler role.\", \"value\": {\"service_name\": \"cinder_scheduler\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderScheduler\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::scheduler::scheduler_driver\": \"cinder.scheduler.filter_scheduler.FilterScheduler\"}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_scheduler\": [{\"get_param\": \"CinderSchedulerLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::scheduler\"], [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_scheduler.json\": {\"command\": \"/usr/bin/cinder-scheduler --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}}, \"docker_config\": {\"step_2\": {\"cinder_scheduler_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_scheduler\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_common_volumes\"]}, [\"/var/lib/kolla/config_files/cinder_scheduler.json:/var/lib/kolla/config_files/config.json:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder scheduler container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_scheduler\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(105,'2026-06-15 07:51:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(106,'2026-06-15 07:51:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(107,'2026-06-15 07:51:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(108,'2026-06-15 07:51:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(109,'2026-06-15 07:51:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.  This mapping overrides those in ServiceNetMapDefaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}}, \"conditions\": {\"memory_backing_dir_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"QemuMemoryBackingDir\"}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"QemuMemoryBackingDir\"]}, \"\"]}]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::libvirt::qemu::memory_backing_dir\": \"QemuMemoryBackingDir\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"QemuMemoryBackingDir\": {\"get_param\": \"QemuMemoryBackingDir\"}}}]}}}}, \"outputs\": {\"kolla_config_files\": {\"description\": \"Common kolla config_files.\", \"value\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}]]}}, \"kolla_permissions\": {\"description\": \"Common kolla permissions.\", \"value\": {\"list_concat\": [[{\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"config_settings\": {\"description\": \"Extra hieradata for all modular virt daemons.\", \"value\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}}, \"volumes\": {\"description\": \"Common volumes for all modular virt daemons.\", \"value\": {\"list_concat\": [[\"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\", \"/etc/pki/libvirt:/etc/pki/libvirt:ro\", \"/etc/pki/qemu:/etc/pki/qemu:ro\"]]}, {\"if\": [\"memory_backing_dir_set\", [{\"str_replace\": {\"template\": \"MEMORY_BACKING_DIR:MEMORY_BACKING_DIR\", \"params\": {\"MEMORY_BACKING_DIR\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::compute::libvirt::qemu::memory_backing_dir\"]}}}}]]}]}}, \"update_tasks\": {\"description\": \"Common update tasks for modular virt daemons\", \"value\": [{\"name\": \"check systemd-container package present or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\"}, {\"name\": \"download systemd-container package if not present\", \"yum\": {\"name\": \"systemd-container\", \"state\": \"present\", \"download_only\": true, \"download_dir\": \"/var/tmp/\"}, \"when\": \"is_systemd_container_package.changed\"}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(110,'2026-06-15 07:51:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron base service. Shared for all Neutron agents.\\n\", \"parameters\": {\"DatabaseSyncTimeout\": {\"default\": 900, \"description\": \"DB Sync Timeout default\", \"type\": \"number\"}, \"NeutronDhcpAgentsPerNetwork\": {\"type\": \"number\", \"default\": 0, \"description\": \"The number of neutron dhcp agents to schedule per network\"}, \"DhcpAgentNotification\": {\"default\": false, \"description\": \"Whether or not to enable DHCP agent notifications.\", \"type\": \"boolean\"}, \"NeutronDnsDomain\": {\"type\": \"string\", \"default\": \"ooo.test\", \"description\": \"Domain to use for building the hostnames.\"}, \"NeutronCorePlugin\": {\"default\": \"ml2\", \"description\": \"The core plugin for Neutron. The value should be the entrypoint to be loaded\\nfrom neutron.core_plugins namespace.\\n\", \"type\": \"string\"}, \"NeutronServicePlugins\": {\"default\": \"qos,ovn-router,trunk,segments,port_forwarding,log\", \"description\": \"Comma-separated list of service plugin entrypoints to be loaded from the\\nneutron.service_plugins namespace.\\n\", \"type\": \"comma_delimited_list\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NeutronDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Neutron services.\", \"type\": \"boolean\"}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"NeutronGlobalPhysnetMtu\": {\"type\": \"number\", \"default\": 1350, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(If this is not changed TenantNetPhysnetMtu will be used.)\\n\"}, \"TenantNetPhysnetMtu\": {\"type\": \"number\", \"default\": 1500, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(The mtu setting of the Tenant network in network_data.yaml\\ncontrol\'s this parameter.)\\n\"}, \"NeutronDBSyncExtraParams\": {\"default\": \"\", \"description\": \"String of extra command line parameters to append to the neutron-db-manage\\nupgrade head command.\\n\", \"type\": \"string\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"NeutronGlobalReportInterval\": {\"default\": 300, \"description\": \"Seconds between nodes reporting state to server; should be less than NeutronAgentDownTime, best if it is half or less than NeutronAgentDownTime.\\n\", \"type\": \"number\"}}, \"conditions\": {\"dhcp_agents_zero\": {\"equals\": [{\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}, 0]}, \"global_physnet_mtu_unset\": {\"equals\": [{\"get_param\": \"NeutronGlobalPhysnetMtu\"}, 0]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron base service.\", \"value\": {\"service_name\": \"neutron_base\", \"config_settings\": {\"map_merge\": [{\"neutron::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"neutron::core_plugin\": {\"get_param\": \"NeutronCorePlugin\"}, \"neutron::service_plugins\": {\"get_param\": \"NeutronServicePlugins\"}, \"neutron::report_interval\": {\"get_param\": \"NeutronGlobalReportInterval\"}, \"neutron::logging::debug\": {\"if\": [{\"get_param\": \"NeutronDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"neutron::allow_overlapping_ips\": true, \"neutron::dhcp_agent_notification\": {\"get_param\": \"DhcpAgentNotification\"}, \"neutron::dns_domain\": {\"get_param\": \"NeutronDnsDomain\"}, \"neutron::rabbit_heartbeat_timeout_threshold\": 60, \"neutron::host\": \"%{hiera(\'fqdn_canonical\')}\", \"neutron::db::database_db_max_retries\": -1, \"neutron::db::database_max_retries\": -1, \"neutron::db::sync::db_sync_timeout\": {\"get_param\": \"DatabaseSyncTimeout\"}, \"neutron::global_physnet_mtu\": {\"if\": [\"global_physnet_mtu_unset\", {\"get_param\": \"TenantNetPhysnetMtu\"}, {\"get_param\": \"NeutronGlobalPhysnetMtu\"}]}, \"neutron::db::sync::extra_params\": {\"get_param\": \"NeutronDBSyncExtraParams\"}, \"neutron::vlan_transparent\": {\"get_param\": \"EnableVLANTransparency\"}, \"neutron::rabbit_heartbeat_in_pthread\": false}, {\"if\": [\"dhcp_agents_zero\", {}, {\"tripleo::profile::base::neutron::dhcp_agents_per_network\": {\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (111,'2026-06-15 07:51:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(112,'2026-06-15 07:51:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(113,'2026-06-15 07:51:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(114,'2026-06-15 07:51:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(115,'2026-06-15 07:51:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova libvirt service\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"LibvirtDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Set to True to enable debugging libvirt services.\"}, \"LibvirtLogLevel\": {\"default\": 3, \"description\": \"Defines log level in libvirt to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtlogdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtlogd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtsecretdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtsecretd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtnodedevdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtnodedevd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtqemudLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtqemud to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtproxydLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtproxyd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtstoragedLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtstoraged to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": {\"nova::compute::libvirt::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/libvirtd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtLogLevel\"}]}}}}, \"nova::compute::libvirt::virtlogd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtlogd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtlogdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtsecretd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtsecretd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtsecretdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtnodedevd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtnodedevd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtnodedevdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtqemud::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtqemud.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtqemudLogLevel\"}]}}}}, \"nova::compute::libvirt::virtproxyd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtproxyd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtproxydLogLevel\"}]}}}}, \"nova::compute::libvirt::virtstoraged::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtstoraged.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtstoragedLogLevel\"}]}}}}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to file in the host.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/libvirt\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(116,'2026-06-15 07:51:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::pacemaker::cinder::volume_bundle::cinder_volume_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::volume_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::volume::manage_service\": false, \"cinder::volume::enabled\": false, \"cinder::backend_host\": \"hostgroup\"}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\"], [\"include tripleo::profile::pacemaker::cinder::volume_bundle\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Volume tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Volume HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-volume temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-volume\", \"tripleo_ha_image_update_new_image\": \"{{cinder_volume_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_volume_image}}\"}, \"when\": [\"(pcmk_cinder_volume_image != \\\"\\\")\", \"(pcmk_cinder_volume_image != cinder_volume_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-volume container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_volume_image == cinder_volume_image_latest\", \"fail_msg\": \"cinder-volume image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"cinder_volume fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder volume bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"Prepare switch of cinder_volume image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_volume image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-volume | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_volume_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_volume image facts\", \"set_fact\": {\"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_volume_image_current\": \"{{cinder_volume_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_volume image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image_current}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}, {\"name\": \"Create cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_volume_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_volume_bootstrap_node={{cinder_volume_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_volume retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_volume_bootstrap_node\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"pcs resource bundle update cinder_volume for new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-volume container image={{cinder_volume_image_latest}}\"}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_volume retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}, {\"name\": \"Retag pacemaker cinder_volume\", \"when\": [\"step|int == 3\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"absent\"}}]}], {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}]}, \"post_upgrade_tasks\": [{\"name\": \"Start cinder_volume service (pacemaker)\", \"become\": true, \"when\": \"step|int == 1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(117,'2026-06-15 07:51:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Neutron service\\n\", \"parameters\": {\"NeutronServiceName\": {\"description\": \"service name\", \"type\": \"string\"}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": {\"str_replace\": {\"template\": \"--log-file=/var/log/neutron/SERVICE.log\", \"params\": {\"SERVICE\": {\"get_param\": \"NeutronServiceName\"}}}}}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/neutron:/var/log/neutron:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/neutron\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(118,'2026-06-15 07:51:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(119,'2026-06-15 07:51:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"eljGPqsTubd1MRdmVjF5MppaC\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"OorljNRFSWJ6uLOrYiwbnwsqY\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"9ppduM3vEiUPQ7DOtXGTm17h0\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": true, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (120,'2026-06-15 07:51:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure libvirt-guests\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsShutdownTimeout\": {\"default\": 300, \"description\": \"Number of seconds we\'re willing to wait for a guest to shut down. If this is 0, then there is no time out (use with caution, as guests might not respond to a shutdown request). The default value is 300 seconds (5 minutes).\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt_guests::shutdown_timeout\": \"NovaResumeGuestsShutdownTimeout\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaResumeGuestsShutdownTimeout\": {\"get_param\": \"NovaResumeGuestsShutdownTimeout\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for libvirt-guests\", \"value\": {\"service_name\": \"nova_libvirt_guests\", \"config_settings\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::compute::libvirt_guests\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(121,'2026-06-15 07:51:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(122,'2026-06-15 07:51:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupWorkers\": {\"type\": \"number\", \"default\": 1, \"description\": \"The number of cinder-backup processes to launch.\"}, \"CinderBackupMaxOperations\": {\"type\": \"number\", \"default\": 15, \"description\": \"The maximum number of concurrent cinder backup/restore operations (0 means unlimited).\"}, \"CinderBackupCompressionAlgorithm\": {\"default\": \"zlib\", \"description\": \"The compression algorithm used by Cinder Backup backends that are based on Cinder\'s \\\"chunked\\\" backup driver. This includes the swift, nfs, gcs and s3 backends. The ceph backend does not support the feature.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"zlib\", \"bzip2\", \"zstd\"]}]}, \"CinderBackupRbdClusterName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The Ceph cluster where backups are to be stored. If no value is specified then the CephClusterName value is used.\"}, \"CinderBackupRbdClientUserName\": {\"default\": \"\", \"type\": \"string\", \"description\": \"The Ceph client name used by the backup service. If no value is specified then the CephClientUserName value is used.\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CinderBackupNfsShare\": {\"default\": \"\", \"description\": \"NFS share to be mounted\", \"type\": \"string\"}, \"CinderBackupNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options passed to the NFS client. See NFS man page for details.\", \"type\": \"string\"}, \"CinderBackupGcsCredentials\": {\"default\": {}, \"description\": \"The GCS service account credentials, in JSON format.\", \"type\": \"json\"}, \"CinderBackupGcsProjectId\": {\"default\": \"\", \"description\": \"The GCS project ID.\", \"type\": \"string\"}, \"CinderBackupGcsBucket\": {\"default\": \"volumebackups\", \"description\": \"The GCS bucket where backups are to be stored.\", \"type\": \"string\"}, \"CinderBackupGcsBucketLocation\": {\"default\": \"\", \"description\": \"If set, it specifies the location where the GCS bucket should be created.\", \"type\": \"string\"}, \"CinderBackupS3EndpointUrl\": {\"default\": \"\", \"description\": \"The URL where the S3 server is listening.\", \"type\": \"string\"}, \"CinderBackupS3AccessKey\": {\"default\": \"\", \"description\": \"The S3 query token access key.\", \"type\": \"string\"}, \"CinderBackupS3SecretKey\": {\"default\": \"\", \"description\": \"The S3 query token secret key.\", \"type\": \"string\"}, \"CinderBackupS3Bucket\": {\"default\": \"volumebackups\", \"description\": \"The S3 bucket where backups are to be stored.\", \"type\": \"string\"}, \"MonitoringSubscriptionCinderBackup\": {\"default\": \"overcloud-cinder-backup\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderBackup\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::backup::backup_workers\": {\"get_param\": \"CinderBackupWorkers\"}, \"cinder::backup::backup_max_operations\": {\"get_param\": \"CinderBackupMaxOperations\"}}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, {\"cinder::backup::ceph::backup_ceph_user\": {\"str_replace\": {\"template\": \"USERNAME\", \"params\": {\"USERNAME\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClientUserName\"}, \"\"]}, {\"get_param\": \"CephClientUserName\"}, {\"get_param\": \"CinderBackupRbdClientUserName\"}]}}}}, \"cinder::backup::ceph::backup_ceph_pool\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"cinder::backup::ceph::backup_ceph_conf\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.conf\", \"params\": {\"CLUSTER\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClusterName\"}, \"\"]}, {\"get_param\": \"CephClusterName\"}, {\"get_param\": \"CinderBackupRbdClusterName\"}]}}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"swift\"]}, {\"cinder::backup::swift::backup_swift_container\": \"volumebackups\", \"cinder::backup::swift::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}, \"cinder::backup::swift::swift_catalog_info\": \"object-store:swift:internalURL\"}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"nfs\"]}, {\"cinder::backup::nfs::backup_share\": {\"get_param\": \"CinderBackupNfsShare\"}, \"cinder::backup::nfs::backup_mount_options\": {\"get_param\": \"CinderBackupNfsMountOptions\"}, \"cinder::backup::nfs::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"gcs\"]}, {\"tripleo::profile::base::cinder::backup::gcs::credentials\": {\"get_param\": \"CinderBackupGcsCredentials\"}, \"cinder::backup::google::backup_gcs_project_id\": {\"get_param\": \"CinderBackupGcsProjectId\"}, \"cinder::backup::google::backup_gcs_bucket\": {\"get_param\": \"CinderBackupGcsBucket\"}, \"cinder::backup::google::backup_gcs_bucket_location\": {\"get_param\": \"CinderBackupGcsBucketLocation\"}, \"cinder::config::cinder_config\": {\"DEFAULT/backup_compression_algorithm\": {\"value\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"s3\"]}, {\"cinder::backup::s3::backup_s3_endpoint_url\": {\"get_param\": \"CinderBackupS3EndpointUrl\"}, \"cinder::backup::s3::backup_s3_store_access_key\": {\"get_param\": \"CinderBackupS3AccessKey\"}, \"cinder::backup::s3::backup_s3_store_secret_key\": {\"get_param\": \"CinderBackupS3SecretKey\"}, \"cinder::backup::s3::backup_s3_store_bucket\": {\"get_param\": \"CinderBackupS3Bucket\"}, \"cinder::backup::s3::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_backup\": [{\"get_param\": \"DockerCinderBackupLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"str_replace\": {\"template\": \"include tripleo::profile::base::cinder::backup::DRIVER\", \"params\": {\"DRIVER\": {\"get_param\": \"CinderBackupBackend\"}}}}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_backup\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"deploy_steps_tasks\": [{\"name\": \"Clean up when switching cinder-backup from pcmk to active-active\", \"when\": [\"step|int == 1\"], \"become\": true, \"block\": [{\"name\": \"Check if cinder-backup is running under pacemaker\", \"command\": \"pcs status\", \"register\": \"cinder_backup_pcs_status\", \"check_mode\": false, \"failed_when\": false, \"changed_when\": false}, {\"when\": [\"\\\"cinder-backup\\\" in cinder_backup_pcs_status.stdout\"], \"block\": [{\"name\": \"Remove the openstack-cinder-backup pcs resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"delete\"}, \"run_once\": true}, {\"name\": \"Identify the cinder-backup pcmklatest container image\", \"shell\": \"{{container_cli}} images | awk \'$1 ~ \\\"cinder-backup\\\" && $2 == \\\"pcmklatest\\\" {print $1\\\":\\\"$2}\'\", \"register\": \"cinder_backup_pcmklatest_image\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Remove the cinder-backup pcmklatest container image\", \"command\": \"{{container_cli}} rmi {{cinder_backup_pcmklatest_image.stdout}}\", \"when\": [\"cinder_backup_pcmklatest_image.stdout|length > 0\"]}]}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder backup container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_backup\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_backup\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"CephClientUserName\": \"openstack\", \"CinderBackupBackend\": \"swift\", \"CinderBackupRbdPoolName\": \"backups\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(123,'2026-06-15 07:51:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(124,'2026-06-15 07:51:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(125,'2026-06-15 07:51:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(126,'2026-06-15 07:51:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(127,'2026-06-15 07:51:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(128,'2026-06-15 07:51:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized rsyslogd service for purposes of centralized log collection of OpenStack services\' logs.\\n\", \"parameters\": {\"ContainerRsyslogImage\": {\"description\": \"The container image to use for container\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"ContainerRsyslogConfigImage\": {\"description\": \"The container image to use for the rsyslog config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RsyslogReopenOnTruncate\": {\"default\": true, \"description\": \"Rsyslog imfile reopenOnTruncate parameter\", \"type\": \"boolean\"}, \"RsyslogElasticsearchSetting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-elasticsearch plugin\", \"type\": \"json\"}, \"RsyslogElasticsearchTlsCACert\": {\"default\": \"\", \"description\": \"Contains content of the CA cert for the CA that issued Elasticsearch server cert.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientCert\": {\"default\": \"\", \"description\": \"Contains content of the client cert for doing client cert auth against Elasticsearch.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientKey\": {\"default\": \"\", \"description\": \"Contains content of the private key corresponding to the cert RsyslogElasticsearchTlsClientCert.\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RsyslogAmqp1Setting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-omamqp1 plugin\", \"type\": \"json\"}, \"RsyslogAmqp1Local\": {\"default\": true, \"description\": \"Set to false to disable prefilling host connection value to local QDR in RsyslogAmqp1Setting.\", \"type\": \"boolean\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"RsyslogMaxMessageSize\": {\"default\": \"32k\", \"description\": \"Maximum supported message size (both for sending and receiving) for rsyslogd.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRsyslogImage\": \"ContainerRsyslogImage\", \"ContainerRsyslogConfigImage\": \"ContainerRsyslogConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRsyslogImage\": {\"get_param\": \"ContainerRsyslogImage\"}, \"ContainerRsyslogConfigImage\": {\"get_param\": \"ContainerRsyslogConfigImage\"}}}]}}}}, \"conditions\": {\"use_tls\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}, \"\"]}]}}, \"use_elasticsearch\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {}]}}, \"use_amqp1\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {}]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the rsyslog role.\", \"value\": {\"service_name\": \"rsyslog\", \"config_settings\": {\"map_merge\": [{\"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": {\"get_param\": \"RsyslogMaxMessageSize\"}}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": {\"get_param\": \"CloudName\"}, \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": {\"get_param\": \"KeystoneRegion\"}, \"format\": \"jsonf\"}}]}}}, {\"if\": [\"use_elasticsearch\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch\": {\"map_merge\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {\"template\": \"rsyslog-record\", \"searchIndex\": \"rsyslog-node-index\", \"dynSearchIndex\": \"on\", \"errorfile\": \"/var/log/rsyslog/omelasticsearch.log\"}]}}, {}]}, {\"if\": [\"use_amqp1\", {\"tripleo::profile::base::logging::rsyslog::amqp1\": {\"map_merge\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {\"template\": \"rsyslog-record\"}, {\"if\": [{\"get_param\": \"RsyslogAmqp1Local\"}, {\"host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}:$PORT\", \"params\": {\"$PORT\": {\"get_param\": \"MetricsQdrPort\"}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}}]}]}}, {}]}, {\"if\": [{\"get_param\": \"RsyslogReopenOnTruncate\"}, {\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\"}, {}]}, {\"if\": [\"use_tls\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_ca_cert\": {\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_cert\": {\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_key\": {\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}}]}]}, \"puppet_config\": {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_3\": {\"rsyslog\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (129,'2026-06-15 07:51:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(130,'2026-06-15 07:51:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(131,'2026-06-15 07:51:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(132,'2026-06-15 07:51:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(133,'2026-06-15 07:51:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"puJEUVV5bncg9PX1nMb3Jnk25\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"eljGPqsTubd1MRdmVjF5MppaC\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(134,'2026-06-15 07:51:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(135,'2026-06-15 07:51:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL HA clustercheck service deployment using puppet This service is used by HAProxy in a HA scenario to report whether the local galera node is synced\\n\", \"parameters\": {\"ContainerClustercheckImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerClustercheckConfigImage\": {\"description\": \"The container image to use for the clustercheck config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ClustercheckListener\": {\"default\": \"socat\", \"description\": \"How to expose the clustercheck service over TCP\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"socat\", \"xinetd\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlPuppetBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerClustercheckImage\": \"ContainerClustercheckImage\", \"ContainerClustercheckConfigImage\": \"ContainerClustercheckConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerClustercheckImage\": {\"get_param\": \"ContainerClustercheckImage\"}, \"ContainerClustercheckConfigImage\": {\"get_param\": \"ContainerClustercheckConfigImage\"}}}]}}}}, \"conditions\": {\"socat_listener\": {\"equals\": [{\"get_param\": \"ClustercheckListener\"}, \"socat\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service clustercheck using composable services.\", \"value\": {\"service_name\": \"clustercheck\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlPuppetBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::clustercheck::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$FQDN$NETWORK\')}\", \"params\": {\"$FQDN\": {\"if\": [\"socat_listener\", \"\", \"fqdn_\"]}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}}]}, \"puppet_config\": {\"config_volume\": \"clustercheck\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::pacemaker::clustercheck\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/clustercheck.json\": {\"command\": {\"if\": [\"socat_listener\", \"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\" \\\"$TRIPLEO_SOCAT_BIND\\\" system:\\\"grep -qPe \\\\\\\"^\\\\\\\\r\\\\$\\\\\\\" && /usr/bin/clustercheck\\\"\", \"/usr/sbin/xinetd -dontfork\"]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"clustercheck\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckImage\"]}, \"restart\": \"always\", \"net\": \"host\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\", \"/var/lib/mysql:/var/lib/mysql\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": null, \"upgrade_tasks\": null, \"update_tasks\": null, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop clustercheck container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"clustercheck\"], \"tripleo_delegate_to\": \"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(136,'2026-06-15 07:51:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized logrotate with crond for containerized service logs rotation\\n\", \"parameters\": {\"ContainerCrondImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"ContainerCrondConfigImage\": {\"description\": \"The container image to use for the crond config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LogrotateMaxsize\": {\"description\": \"Configures the maxsize param for containerized logrotate.\", \"type\": \"string\", \"default\": \"10M\"}, \"LogrotateRotationInterval\": {\"description\": \"Configures rotation interval for containerized logrotate.\", \"type\": \"string\", \"default\": \"daily\", \"constraints\": [{\"allowed_values\": [\"hourly\", \"daily\", \"weekly\", \"monthly\"]}]}, \"LogrotateRotate\": {\"description\": \"Configures the rotate param for containerized logrotate.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotatePurgeAfterDays\": {\"description\": \"Enforces life time (days) of rotated and compressed files.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotateDateExt\": {\"description\": \"Enable/disable dateext parameter.\", \"type\": \"boolean\", \"default\": false}, \"LogrotateDateFormat\": {\"description\": \"Configures dateformat strings for containerized logrotate. This is valid when LogrotateDateExt is true. The allowed specifiers are only %Y %m %d %H %M %S %V and %s.\", \"type\": \"string\", \"default\": \"-%Y%m%d\", \"constraints\": [{\"allowed_pattern\": \"-(%[YmdHMSVs])+$\"}]}, \"LogrotateDateYesterday\": {\"description\": \"Configures dateyesterday paramter for containerized logrotate. This is valid when LogrotateDateExt is true.\", \"type\": \"boolean\", \"default\": false}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCrondImage\": \"ContainerCrondImage\", \"ContainerCrondConfigImage\": \"ContainerCrondConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCrondImage\": {\"get_param\": \"ContainerCrondImage\"}, \"ContainerCrondConfigImage\": {\"get_param\": \"ContainerCrondConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the crond role.\", \"value\": {\"service_name\": \"logrotate_crond\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::logging::logrotate::maxsize\": {\"get_param\": \"LogrotateMaxsize\"}, \"tripleo::profile::base::logging::logrotate::rotation\": {\"get_param\": \"LogrotateRotationInterval\"}, \"tripleo::profile::base::logging::logrotate::rotate\": {\"get_param\": \"LogrotateRotate\"}, \"tripleo::profile::base::logging::logrotate::purge_after_days\": {\"get_param\": \"LogrotatePurgeAfterDays\"}, \"tripleo::profile::base::logging::logrotate::dateext\": {\"get_param\": \"LogrotateDateExt\"}}, {\"if\": [{\"get_param\": \"LogrotateDateExt\"}, {\"tripleo::profile::base::logging::logrotate::dateformat\": {\"get_param\": \"LogrotateDateFormat\"}, \"tripleo::profile::base::logging::logrotate::dateyesterday\": {\"get_param\": \"LogrotateDateYesterday\"}}]}]}, \"host_prep_tasks\": [{\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"deploy_steps_tasks\": [{\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": {\"get_param\": \"LogrotatePurgeAfterDays\"}}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}], \"update_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"upgrade_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"puppet_config\": {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"logrotate_crond\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondImage\"]}, \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (137,'2026-06-15 07:51:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(138,'2026-06-15 07:51:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(139,'2026-06-15 07:51:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Chrony time service deployment using ansible, this YAML file creates the interface between the HOT template and the ansible role that actually installs and configure chronyd.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"ChronyGlobalServerOptions\": {\"default\": \"\", \"description\": \"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"ChronyGlobalPoolOptions\": {\"default\": \"\", \"description\": \"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"NtpIburstEnable\": {\"default\": true, \"description\": \"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\", \"type\": \"boolean\"}, \"MaxPoll\": {\"description\": \"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 10, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"MinPoll\": {\"description\": \"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 6, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"ChronyAclRules\": {\"default\": [\"deny all\"], \"description\": \"Access Control List of NTP clients.  By default no clients are permitted.\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"chrony_global_server_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalServerOptions\"}, \"\"]}, \"chrony_global_pool_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalPoolOptions\"}, \"\"]}, \"ntp_iburst\": {\"equals\": [{\"get_param\": \"NtpIburstEnable\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role chrony using composable timesync services.\", \"value\": {\"service_name\": \"chrony\", \"firewall_rules\": {\"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}}, \"host_prep_tasks\": [{\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}], \"ansible_group_vars\": {\"chrony_role_action\": \"all\", \"chrony_ntp_servers\": {\"get_param\": \"NtpServer\"}, \"chrony_ntp_pools\": {\"get_param\": \"NtpPool\"}, \"chrony_global_server_settings\": {\"if\": [\"chrony_global_server_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalServerOptions\"}]}, \"chrony_global_pool_settings\": {\"if\": [\"chrony_global_pool_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalPoolOptions\"}]}, \"chrony_manage_package\": {\"get_param\": \"EnablePackageInstall\"}, \"chrony_acl_rules\": {\"get_param\": \"ChronyAclRules\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(140,'2026-06-15 07:51:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(141,'2026-06-15 07:51:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(142,'2026-06-15 07:51:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"puJEUVV5bncg9PX1nMb3Jnk25\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"eljGPqsTubd1MRdmVjF5MppaC\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(143,'2026-06-15 07:51:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Composable Timezone service\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Timezone role using composable services.\", \"value\": {\"service_name\": \"timezone\", \"host_prep_tasks\": [{\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": {\"get_param\": \"TimeZone\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(144,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"DockerCinderVolumeUlimit\": {\"default\": [\"nofile=131072\"], \"description\": \"ulimit for Cinder Volume Container\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CinderISCSIAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the Iscsi Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderISCSIHelper\": {\"default\": \"lioadm\", \"description\": \"The iSCSI helper to use with cinder.\", \"type\": \"string\"}, \"CinderISCSIProtocol\": {\"default\": \"iscsi\", \"description\": \"Whether to use TCP (\'iscsi\') or iSER RDMA (\'iser\') for iSCSI\", \"type\": \"string\"}, \"CinderNfsAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NFS Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options for NFS mounts used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNfsServers\": {\"default\": \"\", \"description\": \"NFS servers used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderNfsSnapshotSupport\": {\"default\": false, \"description\": \"Whether to enable support for snapshots in the NFS driver. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"boolean\"}, \"CinderNasSecureFileOperations\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file operations are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNasSecureFilePermissions\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file permissions are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderRbdBackendName\": {\"type\": \"comma_delimited_list\", \"default\": \"tripleo_ceph\", \"description\": \"A list of Cinder RBD backend names.\"}, \"CinderRbdAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the RBD Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderRbdFlattenVolumeFromSnapshot\": {\"default\": false, \"description\": \"Whether RBD volumes created from a snapshot should be flattened in order to remove a dependency on the snapshot.\\n\", \"type\": \"boolean\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\"}, \"MonitoringSubscriptionCinderVolume\": {\"default\": \"overcloud-cinder-volume\", \"type\": \"string\"}, \"CinderEtcdLocalConnect\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When running Cinder A/A, whether to connect to Etcd via the local IP for the Etcd network. If set to true, the ip on the local node will be used. If set to false, the VIP on the Etcd network will be used instead. Defaults to false.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"120 iscsi initiator\": {\"dport\": 3260}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderVolume\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"CinderCommon\", \"cinder_volume_config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::base::cinder::volume::cinder_enable_iscsi_backend\": {\"get_param\": \"CinderEnableIscsiBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_rbd_backend\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_volume_cluster\": {\"get_param\": \"CinderVolumeCluster\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_mount_options\": {\"get_param\": \"CinderNfsMountOptions\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_servers\": {\"get_param\": \"CinderNfsServers\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_snapshot_support\": {\"get_param\": \"CinderNfsSnapshotSupport\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_operations\": {\"get_param\": \"CinderNasSecureFileOperations\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_permissions\": {\"get_param\": \"CinderNasSecureFilePermissions\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_helper\": {\"get_param\": \"CinderISCSIHelper\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_protocol\": {\"get_param\": \"CinderISCSIProtocol\"}, \"tripleo::profile::base::cinder::volume::rbd::backend_name\": {\"get_param\": \"CinderRbdBackendName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_pool_name\": {\"get_param\": \"CinderRbdPoolName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_user_name\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_flatten_volume_from_snapshot\": {\"get_param\": \"CinderRbdFlattenVolumeFromSnapshot\"}, \"tripleo::profile::base::cinder::volume::rbd::multi_config\": {\"get_param\": \"CinderRbdMultiConfig\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderISCSIAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::iscsi::backend_availability_zone\": {\"get_param\": \"CinderISCSIAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNfsAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nfs::backend_availability_zone\": {\"get_param\": \"CinderNfsAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderRbdAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::rbd::backend_availability_zone\": {\"get_param\": \"CinderRbdAvailabilityZone\"}}]}, {\"if\": [{\"get_param\": \"CinderEtcdLocalConnect\"}, {\"tripleo::profile::base::cinder::volume::etcd_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"EtcdNetwork\"]}}}}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_volume\": [{\"get_param\": \"CinderVolumeLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\", \"include tripleo::profile::base::cinder::volume\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_volume\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"ulimit\": {\"get_param\": \"DockerCinderVolumeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"upgrade_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder volume container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_volume\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_volume\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (145,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(146,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(147,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure tuned\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"TunedCustomProfile\": {\"default\": \"\", \"description\": \"The definition of a new tuned profile in INI format which will be named after the TunedProfileName and applied to the host. E.g. if TunedProfileName is \'my_profile\', it creates the file \'/etc/tuned/my_profile/tuned.conf\' on host whose content is the value of TunedCustomProfile, e.g. \\\"[main]\\\\n include=throughput-performance\\\\n[sysctl]\\\\nvm.dirty_ratio=10\\\"\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"description\": \"Tuned Profile to apply to the host\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"tuned_custom_profile\": \"TunedCustomProfile\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"TunedCustomProfile\": {\"get_param\": \"TunedCustomProfile\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for tuned\", \"value\": {\"service_name\": \"tuned\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tuned\"}}], \"ansible_group_vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_custom_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_custom_profile\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(148,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(149,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(150,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(151,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment with pacemaker bundle\\n\", \"parameters\": {\"ContainerMysqlImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerMysqlConfigImage\": {\"description\": \"The container image to use for the mysql config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"gXmAIg0MPC\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"wPypJaa7B9wxCHWkqAtXwO5K7\"}, \"MysqlUpgradePersist\": {\"type\": \"boolean\", \"default\": false}, \"MysqlUpgradeTransfer\": {\"type\": \"boolean\", \"default\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"MysqlGaleraSSTMethod\": {\"type\": \"string\", \"default\": \"rsync\", \"description\": \"Method used by galera to perform State Snapshot Transfers\", \"constraints\": [{\"allowed_values\": [\"rsync\", \"mariabackup\"]}]}, \"MysqlMariabackupUser\": {\"type\": \"string\", \"default\": \"mariabackup\", \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\"}, \"MysqlMariabackupPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\", \"default\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\"}, \"MysqlGaleraSSLCipher\": {\"type\": \"string\", \"default\": \"AES128-SHA256\", \"description\": \"Symmetric cipher to use.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMysqlImage\": \"ContainerMysqlImage\", \"ContainerMysqlConfigImage\": \"ContainerMysqlConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMysqlImage\": {\"get_param\": \"ContainerMysqlImage\"}, \"ContainerMysqlConfigImage\": {\"get_param\": \"ContainerMysqlConfigImage\"}}}]}}}}, \"conditions\": {\"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service MySQL using composable services.\", \"value\": {\"service_name\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::ca_file\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": {\"get_param\": \"MysqlGaleraSSTMethod\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": {\"get_param\": \"MysqlMariabackupUser\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": {\"get_param\": \"MysqlMariabackupPassword\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": {\"get_param\": \"MysqlGaleraSSLCipher\"}}]}, \"puppet_config\": {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\", \"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\", \"echo -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\", \"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\", \"kolla_set_configs\", \"sudo -u mysql -E kolla_extend_start\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\", \"mysqld_safe --skip-networking --wsrep-on=OFF &\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\"], {\"if\": [{\"equals\": [{\"get_param\": \"MysqlGaleraSSTMethod\"}, \"mariabackup\"]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\"\"]]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\", \"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": {\"get_param\": \"MysqlMariabackupUser\"}, \"DB_MARIABACKUP_PASSWORD\": {\"get_param\": \"MysqlMariabackupPassword\"}}}}, \"step_2\": {\"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], {\"if\": [{\"get_param\": \"ConfigDebug\"}, [\"--debug\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"]]}]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}], \"post_update_tasks\": [{\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}], [{\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}], {\"get_attr\": [\"MysqlBase\", \"mysql_drop_unused_users\"]}, [{\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], [\"/var/log/containers/mysql:/var/log/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": {\"list_join\": [\"\\n\", [\"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\", {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}, \"mysqladmin shutdown\"]]}}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}]]}, \"external_upgrade_tasks\": [{\"vars\": {\"mysql_upgrade_transfer\": {\"get_param\": \"MysqlUpgradeTransfer\"}}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(152,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Prepare container images\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImagePrepare\": {\"default\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images.\", \"type\": \"json\"}, \"ContainerImagePrepareLogFile\": {\"default\": \"/var/log/tripleo-container-image-prepare.log\", \"type\": \"string\", \"description\": \"Used to store outputs of \\\"openstack tripleo container image prepare\\\".\"}, \"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NeutronMechanismDrivers\": {\"default\": \"ovn\", \"description\": \"The mechanism drivers for the Neutron tenant network.\\n\", \"type\": \"comma_delimited_list\"}, \"DockerRegistryMirror\": {\"description\": \"Optional. Mirror to use for registry docker.io\", \"default\": \"\", \"type\": \"string\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ContainerImagePrepareDebug\": {\"default\": false, \"description\": \"Whether or not we want to activate --debug in tripleo container image prepare.\", \"type\": \"boolean\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"AdditionalArchitectures\": {\"default\": [], \"description\": \"List of additional architectures to enable.\", \"type\": \"comma_delimited_list\"}, \"ControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 3}, \"CellControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CellControllerComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 3}, \"BlockStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for container image prepare\", \"value\": {\"service_name\": \"container_image_prepare\", \"external_deploy_tasks\": [{\"name\": \"Run tripleo-container-image-prepare role\", \"import_role\": {\"name\": \"tripleo_container_image_prepare\"}, \"vars\": {\"tripleo_container_image_prepare_log_file\": {\"get_param\": \"ContainerImagePrepareLogFile\"}, \"tripleo_container_image_prepare_debug\": {\"if\": [{\"get_param\": \"ContainerImagePrepareDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo_container_image_prepare_roles\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"tripleo_container_image_prepare_content\": {\"parameter_defaults\": {\"ContainerImagePrepare\": {\"get_param\": \"ContainerImagePrepare\"}, \"DockerInsecureRegistryAddress\": {\"get_param\": \"DockerInsecureRegistryAddress\"}, \"NeutronMechanismDrivers\": {\"get_param\": \"NeutronMechanismDrivers\"}, \"DockerRegistryMirror\": {\"get_param\": \"DockerRegistryMirror\"}, \"ContainerImageRegistryCredentials\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"AdditionalArchitectures\": {\"get_param\": \"AdditionalArchitectures\"}, \"ControllerContainerImagePrepare\": {\"get_param\": \"ControllerContainerImagePrepare\"}, \"ControllerServices\": {\"get_param\": \"ControllerServices\"}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerContainerImagePrepare\": {\"get_param\": \"CellControllerContainerImagePrepare\"}, \"CellControllerServices\": {\"get_param\": \"CellControllerServices\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeContainerImagePrepare\": {\"get_param\": \"CellControllerComputeContainerImagePrepare\"}, \"CellControllerComputeServices\": {\"get_param\": \"CellControllerComputeServices\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeContainerImagePrepare\": {\"get_param\": \"ComputeContainerImagePrepare\"}, \"ComputeServices\": {\"get_param\": \"ComputeServices\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageContainerImagePrepare\": {\"get_param\": \"BlockStorageContainerImagePrepare\"}, \"BlockStorageServices\": {\"get_param\": \"BlockStorageServices\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageContainerImagePrepare\": {\"get_param\": \"ObjectStorageContainerImagePrepare\"}, \"ObjectStorageServices\": {\"get_param\": \"ObjectStorageServices\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageContainerImagePrepare\": {\"get_param\": \"CephStorageContainerImagePrepare\"}, \"CephStorageServices\": {\"get_param\": \"CephStorageServices\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerContainerImagePrepare\": {\"get_param\": \"NetworkerContainerImagePrepare\"}, \"NetworkerServices\": {\"get_param\": \"NetworkerServices\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}}}}, \"when\": [\"(step | int) == 1\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (153,'2026-06-15 07:51:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"yes\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"SshServerOptionsOverrides\"]}], \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}, \"ssh_banner_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"BannerText\"}, \"\"]}}, \"ssh_motd_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"MessageOfTheDay\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo_sshd_password_authentication\": {\"get_param\": \"PasswordAuthentication\"}, \"tripleo_sshd_banner_enabled\": {\"if\": [\"ssh_banner_text_set\", true, false]}, \"tripleo_sshd_banner_text\": {\"get_param\": \"BannerText\"}, \"tripleo_sshd_motd_enabled\": {\"if\": [\"ssh_motd_text_set\", true, false]}, \"tripleo_sshd_message_of_the_day\": {\"get_param\": \"MessageOfTheDay\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(154,'2026-06-15 07:51:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment using puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MysqlMaxConnections\": {\"description\": \"Configures MySQL max_connections config setting\", \"type\": \"number\", \"default\": 4096}, \"MysqlIncreaseFileLimit\": {\"description\": \"Flag to increase MySQL open-files-limit to 16384\", \"type\": \"boolean\", \"default\": true}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"gXmAIg0MPC\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"wPypJaa7B9wxCHWkqAtXwO5K7\"}, \"EnableGalera\": {\"default\": true, \"description\": \"Whether to use Galera instead of regular MariaDB.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableMysqlAuthEd25519\": {\"type\": \"boolean\", \"description\": \"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\", \"default\": false}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"MysqlInnodbBufferPoolSize\": {\"type\": \"string\", \"description\": \"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\", \"default\": \"128M\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MysqlCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, \"innodb_buffer_pool_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlInnodbBufferPoolSize\"}, \"\"]}}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlCertificateKeySize\"}, \"\"]}}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"mysql_upgrade_db.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}}}}, \"mysql_drop_unused_users\": {\"description\": \"Ansible block to clean up unusued Openstack DB users\", \"value\": [{\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}]}, \"role_data\": {\"description\": \"Service MySQL using composable services.\", \"value\": {\"service_name\": \"mysql\", \"config_settings\": {\"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"mysql_max_connections\": {\"get_param\": \"MysqlMaxConnections\"}, \"mysql::server::root_password\": {\"get_param\": \"MysqlRootPassword\"}, \"mysql_clustercheck_password\": {\"get_param\": \"MysqlClustercheckPassword\"}, \"enable_galera\": {\"get_param\": \"EnableGalera\"}, \"mysql_auth_ed25519\": {\"get_param\": \"EnableMysqlAuthEd25519\"}, \"mysql_bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": {\"get_param\": \"MysqlIncreaseFileLimit\"}, \"tripleo::profile::base::database::mysql::certificate_specs\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"service_certificate\": \"/etc/pki/tls/certs/mysql.crt\", \"service_key\": \"/etc/pki/tls/private/mysql.key\"}]}, \"innodb_buffer_pool_size\": {\"if\": [\"innodb_buffer_pool_set\", {\"get_param\": \"MysqlInnodbBufferPoolSize\"}]}}, \"step_config\": \"include tripleo::profile::base::database::mysql\\n\", \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MysqlCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(155,'2026-06-15 07:51:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ovn Controller agent.\\n\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ContainerOvnControllerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"ContainerOvnControllerConfigImage\": {\"description\": \"The container image to use for the ovn_controller config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the Southbound DB Server\", \"type\": \"number\", \"default\": 6642}, \"NeutronBridgeMappings\": {\"description\": \"The OVS logical->physical bridge mappings to use. See the Neutron documentation for details. Defaults to mapping br-ex - the external bridge on hosts - to a physical name \'datacentre\' which can be used to create provider networks (and we use this for the default floating network) - if changing this either use different post-install network scripts or be sure to keep \'datacentre\' as a mapping network name.\\n\", \"type\": \"comma_delimited_list\", \"default\": \"datacentre:br-ex\", \"tags\": [\"role_specific\"]}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"OVNEncapType\": {\"description\": \"Type of encapsulation used in OVN. It can be \\\"geneve\\\" or \\\"vxlan\\\".\\n\", \"type\": \"string\", \"default\": \"geneve\", \"constraints\": [{\"allowed_values\": [\"geneve\", \"vxlan\"]}]}, \"OVNIntegrationBridge\": {\"description\": \"Name of the OVS bridge to use as integration bridge by OVN Controller.\\n\", \"type\": \"string\", \"default\": \"br-int\"}, \"OVNMetadataEnabled\": {\"description\": \"Whether Metadata Service has to be enabled\", \"type\": \"boolean\", \"default\": true}, \"OVNAvailabilityZone\": {\"description\": \"The az options to configure in ovs db. eg. [\'az-0\', \'az-1\', \'az-2\']\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"OVNCMSOptions\": {\"description\": \"The CMS options to configure in ovs db\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNEncapTos\": {\"description\": \"The value to be applied to OVN tunnel interface\'s option:tos as specified in the Open_vSwitch database Interface table. This feature is supported from OVN v21.12.0.\\n\", \"type\": \"string\", \"default\": \"0\", \"tags\": [\"role_specific\"]}, \"OvsHwOffload\": {\"default\": false, \"description\": \"Enable OVS Hardware Offload. This feature supported from OVS 2.8.0\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"OVNRemoteProbeInterval\": {\"description\": \"Probe interval in ms\", \"type\": \"number\", \"default\": 60000}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"OVNOpenflowProbeInterval\": {\"description\": \"The inactivity probe interval of the OpenFlow connection to the OpenvSwitch integration bridge, in seconds.\\n\", \"type\": \"number\", \"default\": 60}, \"OVNOfctrlWaitBeforeClear\": {\"description\": \"Sets the time ovn-controller will wait on startup before clearing all openflow rules and installing the new ones, in ms.\\n\", \"type\": \"number\", \"default\": 8000}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ContainerOvnCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OVNContainerCpusetCpus\": {\"description\": \"Limit the specific CPUs or cores a container can use. It can be specified as a single core (ex. 0), as a comma-separated list (ex. 0,1), as a range (ex. 0-3) or a combination if previous methods (ex 0-3,7,11-15).  The selected cores should be isolated from guests and hypervisor in order to obtain best possible performance.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNStaticBridgeMacMappings\": {\"type\": \"json\", \"default\": {}, \"description\": \"Static OVN Bridge MAC address mappings. Unique OVN bridge mac addresses\\nis dynamically allocated by creating neutron ports. When neutron isn\'t\\navailable, for instance in the standalone deployment, use this parameter\\nto provide static OVN bridge mac addresses. For example:\\n   controller-0:\\n     datacenter: 00:00:5E:00:53:00\\n     provider: 00:00:5E:00:53:01\\n   compute-0:\\n     datacenter: 00:00:5E:00:54:00\\n     provider: 00:00:5E:00:54:01\\n\", \"tags\": [\"role_specific\"]}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}, \"OVNControllerImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerGarpMaxTimeout\": {\"description\": \"When used, this configuration value specifies the maximum timeout (in seconds) between two consecutive GARP packets sent by ovn-controller.\\n\", \"type\": \"number\", \"default\": 0}}, \"conditions\": {\"force_config_drive\": {\"equals\": [{\"get_param\": \"OVNMetadataEnabled\"}, false]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}, \"enable_vlan_transparency\": {\"equals\": [{\"get_param\": \"EnableVLANTransparency\"}, true]}, \"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"ovn_cpu_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"OVNContainerCpusetCpus\"}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNContainerCpusetCpus\"]}, \"\"]}}]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}}, \"az_ovn_unset\": {\"and\": [{\"equals\": [{\"get_param\": \"OVNAvailabilityZone\"}, []]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn::controller::ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn::controller::ovn_cms_options\": {\"if\": [\"az_ovn_unset\", \"OVNCMSOptions\", \"OVNCMSOptionsMerged\"]}, \"ovn::controller::ovn_encap_tos\": \"OVNEncapTos\", \"vswitch::ovs::enable_hw_offload\": \"OvsHwOffload\", \"container_cpuset_cpus\": \"OVNContainerCpusetCpus\", \"ContainerOvnControllerImage\": \"ContainerOvnControllerImage\", \"ContainerOvnControllerConfigImage\": \"ContainerOvnControllerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}, \"OVNCMSOptionsMerged\": {\"list_join\": [\"\", [{\"str_replace\": {\"template\": \"$OVNCMSOptions\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}, \"\"]}}, {\"$OVNCMSOptions\": {\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}}, {\"$OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}}]}}}, {\"str_replace\": {\"template\": \",availability-zones=$OVNAvailabilityZone\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}}, {\"$OVNAvailabilityZone\": {\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}}, {\"$OVNAvailabilityZone\": {\"list_join\": [\",\", {\"get_param\": \"OVNAvailabilityZone\"}]}}]}}}]]}, \"OVNEncapTos\": {\"get_param\": \"OVNEncapTos\"}, \"OvsHwOffload\": {\"get_param\": \"OvsHwOffload\"}, \"OVNContainerCpusetCpus\": {\"get_param\": \"OVNContainerCpusetCpus\"}, \"ContainerOvnControllerImage\": {\"get_param\": \"ContainerOvnControllerImage\"}, \"ContainerOvnControllerConfigImage\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}}]}}}, \"OVNBridgeMappingsValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn_static_bridge_mac_mappings\": \"OVNStaticBridgeMacMappings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNStaticBridgeMacMappings\": {\"get_param\": \"OVNStaticBridgeMacMappings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ovn Controller agent.\", \"value\": {\"service_name\": \"ovn_controller\", \"firewall_rules\": {\"118 neutron vxlan networks\": {\"proto\": \"udp\", \"dport\": 4789, \"state\": []}, \"119 neutron geneve networks\": {\"proto\": \"udp\", \"dport\": 6081, \"state\": []}, \"120 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"OUTPUT\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}, \"121 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"PREROUTING\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"ovn::controller::ovn_encap_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronTenantNetwork\"]}}}}, \"ovn::controller::ovn_encap_type\": {\"get_param\": \"OVNEncapType\"}, \"ovn::controller::ovn_bridge\": {\"get_param\": \"OVNIntegrationBridge\"}, \"ovn::controller::hostname\": \"%{hiera(\'fqdn_canonical\')}\", \"ovn::controller::ovn_remote_probe_interval\": {\"get_param\": \"OVNRemoteProbeInterval\"}, \"ovn::controller::ovn_openflow_probe_interval\": {\"get_param\": \"OVNOpenflowProbeInterval\"}, \"ovn::controller::ovn_ofctrl_wait_before_clear\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}, \"ovn::controller::garp_max_timeout_sec\": {\"get_param\": \"OVNControllerGarpMaxTimeout\"}, \"ovn::controller::ovn_monitor_all\": true}, {\"if\": [\"force_config_drive\", {\"nova::compute::force_config_drive\": true}, {}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::agents::ovn::protocol\": \"ssl\"}, {}]}, {\"if\": [\"enable_vlan_transparency\", {\"vswitch::ovs::vlan_limit\": 0}, {}]}]}, \"service_config_settings\": {}, \"puppet_config\": {\"puppet_tags\": \"vs_config,exec\", \"config_volume\": \"ovn_controller\", \"step_config\": \"include tripleo::profile::base::neutron::agents::ovn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/etc/sysconfig/modules:/etc/sysconfig/modules\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_controller.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock\", {\"if\": [\"internal_tls_enabled\", {\"list_join\": [\" \", [\"-p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C\", {\"get_param\": \"InternalTLSCAFile\"}]]}, \"\"]}]]}, \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_controller\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}, \"docker_config\": {\"step_4\": {\"configure_cms_options\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\"$CMS_OPTS\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\"], \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_controller\": {\"map_merge\": [{\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"depends_on\": [\"openvswitch.service\"]}, {\"if\": [\"ovn_cpu_set\", {\"cpuset_cpus\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"container_cpuset_cpus\"]}}]}, {\"healthcheck\": {\"test\": {\"list_join\": [\" \", [\"/openstack/healthcheck\", {\"yaql\": {\"expression\": \"str($.data.port)\", \"data\": {\"port\": {\"get_param\": \"OVNSouthboundServerPort\"}}}}]]}}, \"volumes\": {\"list_concat\": [[\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}, \"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\", \"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_controller\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_controller/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_controller\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"ContainerOvnCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/openvswitch\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/openvswitch/ovn\", \"setype\": \"container_file_t\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Copy in cleanup script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup\"}, \"dest\": \"/usr/libexec/neutron-cleanup\", \"force\": true, \"mode\": \"0755\"}}, {\"name\": \"Copy in cleanup service\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup.service\"}, \"dest\": \"/usr/lib/systemd/system/neutron-cleanup.service\", \"force\": true}}, {\"name\": \"Enabling the cleanup service\", \"service\": {\"name\": \"neutron-cleanup\", \"enabled\": true}, \"when\": \"not (ansible_check_mode|bool)\"}], \"external_deploy_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"ovn_controller_external_deploy_init\", \"block\": [{\"name\": {\"str_replace\": {\"template\": \"create ovn mac address for $ROLE_NAME role nodes\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"tripleo_ovn_mac_addresses\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": {\"get_param\": \"RootStackName\"}, \"role_name\": {\"get_param\": \"RoleName\"}, \"server_resource_names\": {\"str_replace\": {\"template\": \"{{ groups[\\\"$ROLE_NAME\\\"] }}\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"ovn_bridge_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_bridge_mappings\"]}, \"ovn_static_bridge_mac_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_static_bridge_mac_mappings\"]}}}]}], \"external_update_tasks\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 1\", \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_controller image pull successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_image_update\"], \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"OVN Container image used\", \"debug\": {\"msg\": \"ovn container will be using {{ image }}\"}, \"vars\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovs_vsctl\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Was the update of OVN OVS related parameter successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovs_vsctl\"], \"become\": true, \"tags\": [\"ovn\"], \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovs_vsctl.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"set_fact\": {\"any_ovn_host\": \"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\"}, \"tags\": \"ovn\", \"when\": \"step|int == 1\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"delegate_to\": \"{{ any_ovn_host }}\", \"when\": \"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\", \"tags\": [\"ovn\"], \"become\": true}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\", \"query\": \"results[?item == \'{{item}}\'].stdout\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\", \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_update\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile | json_query(query) | first }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Was the ovn_controller successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_update\"], \"tags\": \"ovn\", \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 1\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}], \"upgrade_tasks\": [{\"name\": \"Fetch running ovn_controller image\", \"shell\": \"set -e\\npodman inspect --format \\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\" ovn_controller\\n\", \"register\": \"running_ovn_image\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\", \"ovn_image\"]}, {\"name\": \"Run ovn_controller upgrade\", \"tags\": [\"ovn\", \"ovn_image\"], \"vars\": {\"ovn_controller_image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": [\"step|int == 4\", \"running_ovn_image.stdout != ovn_controller_image\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 4\", \"tags\": [\"ovn\", \"ovn_image\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"]}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile.stdout }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 4\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get neutron agents ID\", \"command\": \"openstack network agent list --column ID --column Host --column Binary --format yaml\", \"register\": \"neutron_agents_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Filter only current host\", \"set_fact\": {\"neutron_agents\": \"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Deleting OVN agents\", \"block\": [{\"name\": \"Stop OVN containers\", \"loop\": [\"tripleo_ovn_controller\", \"tripleo_ovn_metadata_agent\"], \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_containers\", \"failed_when\": \"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\"}, {\"name\": \"Delete neutron agents\", \"loop\": \"{{ neutron_agents }}\", \"loop_control\": {\"loop_var\": \"agent\", \"label\": \"{{ agent.Host }}/{{ agent.Binary }}\"}, \"command\": \"openstack network agent delete {{ agent.ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(156,'2026-06-15 07:51:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Package installation settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"UpgradeLeappEnabled\": {\"description\": \"Use Leapp for operating system upgrade\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDebug\": {\"description\": \"Print debugging output when running Leapp\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDevelSkip\": {\"description\": \"Skip Leapp checks by setting env variables when running Leapp in\\ndevelopment/testing. For example, LEAPP_DEVEL_SKIP_RHSM=1.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappCommandOptions\": {\"description\": \"In case or using UpgradeLeappDevelSkip with LEAPP_NO_RHSM=1 user\\ncan specify --enablerepo <repo1> --enablerepo <repo2> options for\\nleapp to use these repositories for the upgrade process.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappRebootTimeout\": {\"description\": \"Timeout (seconds) for the OS upgrade phase via Leapp\", \"type\": \"number\", \"default\": 3600}, \"UpgradeLeappPostRebootDelay\": {\"description\": \"Maximum (seconds) to wait for machine to reboot and respond to a test\\ncommand.\\n\", \"type\": \"number\", \"default\": 120}, \"UpgradeLeappToRemove\": {\"default\": [], \"description\": \"List of packages to remove during Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappToInstall\": {\"default\": [], \"description\": \"List of packages to install after Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappUnloadKernelDrivers\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of modules to unload from the system due to being incompatible\\nwith the next RHEL version. If not being unloaded Leapp will\\ninhibit the upgrade.\\n\"}, \"LeappActorsToRemove\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of actors to remove from the leapp process to prevent them\\nfrom inhibiting the upgrade.\\n\"}, \"LeappRepoInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the Leapp process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds to get Leapp working.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NICsPrefixesToUdev\": {\"default\": [], \"description\": \"List of NIC prefixes to hardcode into udev in order to prevent\\nrenaming.\\n\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappPreRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds before rebooting into Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappPostRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds after rebooting from Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"SkipPackageUpdate\": {\"default\": false, \"description\": \"Set to true to skip the update all packages\", \"type\": \"boolean\"}, \"SkipRhelEnforcement\": {\"default\": false, \"description\": \"Whether to avoid or not RHEL/OSP policies enforcement on Red Hat. Mainly for CI purpose.  It shouldn\'t matter on other distributions where it\'s disabled in the role. Set to true to skip the enforcement.\", \"type\": \"boolean\"}, \"DnfStreams\": {\"default\": [], \"description\": \"List of streams to be configured before updating packages. Each list element contains a dictionary with the following values defined module[mandatory], stream[mandatory], distribution_version[mandatory] and profile[optional]. If the profile is not specified \'common\' will be used instead.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"BaseTripleoPackages\": {\"default\": [], \"description\": \"List of packages to install.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"dnf_module_list\": \"DnfStreams\", \"upgrade_leapp_devel_skip\": \"UpgradeLeappDevelSkip\", \"upgrade_leapp_command_options\": \"UpgradeLeappCommandOptions\", \"upgrade_leapp_to_remove\": \"UpgradeLeappToRemove\", \"upgrade_leapp_to_install\": \"UpgradeLeappToInstall\", \"leapp_repo_init_command\": \"LeappRepoInitCommand\", \"leapp_init_command\": \"LeappInitCommand\", \"nics_prefixes_to_keep\": \"NICsPrefixesToUdev\", \"upgrade_leapp_modules_to_unload\": \"LeappUnloadKernelDrivers\", \"upgrade_leapp_actors_to_remove\": \"LeappActorsToRemove\", \"upgrade_init_command\": \"UpgradeInitCommand\", \"base_tripleo_packages\": \"BaseTripleoPackages\", \"leapp_pre_reboot_command\": \"LeappPreRebootCommand\", \"leapp_post_reboot_command\": \"LeappPostRebootCommand\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"DnfStreams\": {\"get_param\": \"DnfStreams\"}, \"UpgradeLeappDevelSkip\": {\"get_param\": \"UpgradeLeappDevelSkip\"}, \"UpgradeLeappCommandOptions\": {\"get_param\": \"UpgradeLeappCommandOptions\"}, \"UpgradeLeappToRemove\": {\"get_param\": \"UpgradeLeappToRemove\"}, \"UpgradeLeappToInstall\": {\"get_param\": \"UpgradeLeappToInstall\"}, \"LeappUnloadKernelDrivers\": {\"get_param\": \"LeappUnloadKernelDrivers\"}, \"LeappPreRebootCommand\": {\"get_param\": \"LeappPreRebootCommand\"}, \"LeappPostRebootCommand\": {\"get_param\": \"LeappPostRebootCommand\"}, \"LeappActorsToRemove\": {\"get_param\": \"LeappActorsToRemove\"}, \"UpgradeInitCommand\": {\"get_param\": \"UpgradeInitCommand\"}, \"LeappRepoInitCommand\": {\"get_param\": \"LeappRepoInitCommand\"}, \"LeappInitCommand\": {\"get_param\": \"LeappInitCommand\"}, \"NICsPrefixesToUdev\": {\"get_param\": \"NICsPrefixesToUdev\"}, \"BaseTripleoPackages\": {\"get_param\": \"BaseTripleoPackages\"}}}]}}}, \"Podman\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"conditions\": {\"podman_requires_login\": {\"equals\": [{\"get_param\": \"ContainerImageRegistryLogin\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO package settings\", \"value\": {\"service_name\": \"tripleo_packages\", \"config_settings\": {\"tripleo::packages::enable_install\": {\"get_param\": \"EnablePackageInstall\"}}, \"step_config\": \"include ::tripleo::packages\\n\", \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": {\"get_param\": \"UpgradeLeappDebug\"}, \"upgrade_leapp_devel_skip\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_devel_skip\"]}, \"upgrade_leapp_command_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_command_options\"]}, \"upgrade_leapp_reboot_timeout\": {\"get_param\": \"UpgradeLeappRebootTimeout\"}, \"upgrade_leapp_post_reboot_delay\": {\"get_param\": \"UpgradeLeappPostRebootDelay\"}}, \"vars\": {\"_upgradeLeappEnabled\": {\"get_param\": \"UpgradeLeappEnabled\"}}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_repo_init_command\"]}]]}}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_init_command\"]}]]}}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_remove\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_install\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_modules_to_unload\"]}}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_actors_to_remove\"]}}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nics_prefixes_to_keep\"]}}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_pre_reboot_command\"]}]]}}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_post_reboot_command\"]}]]}}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", \"if [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_init_command\"]}]]}}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_param\": \"UpgradeInitCommonCommand\"}]]}}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"base_tripleo_packages\"]}}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}], {\"if\": [\"podman_requires_login\", {\"get_attr\": [\"Podman\", \"role_data\", \"workaround_upgrade_tasks\"]}, []]}]}, \"external_upgrade_tasks\": [{\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"update_tasks\": [{\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": {\"get_param\": \"SkipRhelEnforcement\"}}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(157,'2026-06-15 07:51:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(158,'2026-06-15 07:51:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(159,'2026-06-15 07:51:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(160,'2026-06-15 07:51:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (161,'2026-06-15 07:51:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"parameters\": {\"ContainerHeatApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"ContainerHeatApiConfigImage\": {\"description\": \"The container image to use for the heat_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api\", \"file\": \"/var/log/containers/heat/heat_api.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"HeatApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatApiOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lRfTtulpjIZx2SuWRPc7LPTx6\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApi\": {\"default\": \"overcloud-heat-api\", \"type\": \"string\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"376BfcZQI6aGoCYfKxTIQgXSQ\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiImage\": \"ContainerHeatApiImage\", \"ContainerHeatApiConfigImage\": \"ContainerHeatApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiImage\": {\"get_param\": \"ContainerHeatApiImage\"}, \"ContainerHeatApiConfigImage\": {\"get_param\": \"ContainerHeatApiConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API role.\", \"value\": {\"service_name\": \"heat_api\", \"firewall_rules\": {\"125 heat_api\": {\"dport\": [8004]}}, \"firewall_frontend_rules\": {\"100 heat_api_haproxy_frontend\": {\"dport\": [8004]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_haproxy_frontend_ssl\": {\"dport\": [13004]}}, \"keystone_resources\": {\"heat\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"uri\"]}}, \"users\": {\"heat\": {\"password\": {\"get_param\": \"HeatPassword\"}}, \"heat_stack_domain_admin\": {\"password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"roles\": [\"admin\"], \"domain\": \"heat_stack\"}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"orchestration\", \"roles\": [\"heat_stack_user\"], \"domains\": [\"heat_stack\"]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiLogging\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::wsgi::apache_api::vhost_custom_fragment\": \"Timeout 600\", \"heat::api::service_name\": \"httpd\", \"heat::wsgi::apache_api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api\": [{\"get_param\": \"HeatApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api\", \"puppet_tags\": \"heat_config,file,concat,file_line,heat_api_paste_ini\", \"step_config\": \"include tripleo::profile::base::heat::api\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, {\"get_param\": \"HeatApiOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatApiOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"heat_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron heat\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api\", \"heat_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(162,'2026-06-15 07:51:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(163,'2026-06-15 07:51:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(164,'2026-06-15 07:51:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/heat:/var/log/heat:z\", \"/var/log/containers/httpd/heat-api:/var/log/httpd:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/heat\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/heat-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(165,'2026-06-15 07:51:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(166,'2026-06-15 07:51:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"puJEUVV5bncg9PX1nMb3Jnk25\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"eljGPqsTubd1MRdmVjF5MppaC\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(167,'2026-06-15 07:51:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(168,'2026-06-15 07:51:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance internal service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"GlanceApiInternalLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api_internal.log\"}}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiInternalConfigImage\": {\"description\": \"The container image to use for the glance_api_internal config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"GlanceApi\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiInternalConfigImage\": \"ContainerGlanceApiInternalConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiInternalConfigImage\": {\"get_param\": \"ContainerGlanceApiInternalConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the internal Glance API.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\"]}, {\"service_name\": \"glance_api_internal\", \"firewall_rules\": {\"112 glance_api_internal\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 glance_api_internal_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"keystone_resources\": {}, \"config_settings\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_glance_api_internal\": [{\"get_param\": \"GlanceApiInternalLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"glance_api_internal\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [{\"str_replace\": {\"template\": \"class { \'tripleo::profile::base::glance::api\':\\n  bind_port => PORT,\\n  tls_proxy_port => PORT,\\n  log_file => \'/var/log/glance/api_internal.log\',\\n  show_image_direct_url => true,\\n  show_multiple_locations => true,\\n}\\n\", \"params\": {\"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiInternalConfigImage\"]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"glance_api_internal\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\", \"volumes\"]}}}}}]}, \"glance_api_internal_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\", \"volumes\"]}}}}}]}]}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api internal container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api_internal\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api_internal\'] | default([]) }}\"}}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (169,'2026-06-15 07:51:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lRfTtulpjIZx2SuWRPc7LPTx6\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(170,'2026-06-15 07:51:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(171,'2026-06-15 07:51:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(172,'2026-06-15 07:51:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(173,'2026-06-15 07:51:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (174,'2026-06-15 07:51:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a Compute server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[{\\\"service_name\\\": \\\"boot_params_service\\\", \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Configure tuned before reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}, \\\"vars\\\": {\\\"tuned_profile\\\": \\\"throughput-performance\\\", \\\"tuned_isolated_cores\\\": \\\"\\\"}}, {\\\"name\\\": \\\"Configure kernel args and reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"kernelargs.yml\\\"}, \\\"vars\\\": {\\\"tripleo_kernel_args\\\": \\\"\\\", \\\"tripleo_kernel_hugepages\\\": {}, \\\"tripleo_kernel_hugepages_remove\\\": false, \\\"tripleo_kernel_defer_reboot\\\": false, \\\"tripleo_kernel_reboot_timeout\\\": 900}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"upgrade prepare for leapp to align kernel arg shortcommings in leapp\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"fix grub entries to have name start with GRUB_\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\\\", \\\"replace\\\": \\\"GRUB_\\\\\\\\1\\\\\\\\2\\\"}}, {\\\"name\\\": \\\"fix grub entries in append statement\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\\\", \\\"replace\\\": \\\"\\\\\\\\1{GRUB_\\\\\\\\2}\\\\\\\\3\\\"}}]}]}, {\\\"service_name\\\": \\\"ca_certs\\\", \\\"config_settings\\\": {\\\"tripleo::trusted_cas::ca_map\\\": {}}, \\\"step_config\\\": \\\"include tripleo::trusted_cas\\\"}, {\\\"service_name\\\": \\\"collectd\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::metrics::collectd::enable_file_logging\\\": true, \\\"collectd::plugin::logfile::log_file\\\": \\\"/var/log/collectd/collectd.log\\\", \\\"collectd::manage_repo\\\": false, \\\"collectd::purge\\\": true, \\\"collectd::recurse\\\": true, \\\"collectd::purge_config\\\": true, \\\"collectd::minimum_version\\\": \\\"5.7\\\", \\\"collectd::interval\\\": 120, \\\"collectd::plugin::unixsock::socketgroup\\\": \\\"root\\\", \\\"collectd::plugin::unixsock::socketfile\\\": \\\"/run/collectd-socket\\\", \\\"collectd::plugin::unixsock::deletesocket\\\": true, \\\"collectd::plugin::cpu::reportbycpu\\\": true, \\\"collectd::plugin::cpu::reportbystate\\\": true, \\\"collectd::plugin::cpu::reportnumcpu\\\": false, \\\"collectd::plugin::cpu::valuespercentage\\\": true, \\\"collectd::plugin::df::ignoreselected\\\": true, \\\"collectd::plugin::df::reportbydevice\\\": true, \\\"collectd::plugin::df::fstypes\\\": [\\\"xfs\\\"], \\\"collectd::plugin::load::reportrelative\\\": true, \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\", \\\"collectd::plugin::virt::extra_stats\\\": \\\"pcpu cpu_util vcpu memory disk disk_err disk_allocation disk_capacity disk_physical domain_state job_stats_background perf\\\", \\\"collectd::plugin::virt::hostname_format\\\": \\\"hostname\\\", \\\"tripleo.collectd.plugins.collectd\\\": [\\\"cpu\\\", \\\"df\\\", \\\"disk\\\", \\\"hugepages\\\", \\\"interface\\\", \\\"load\\\", \\\"memory\\\", \\\"unixsock\\\", \\\"uptime\\\"], \\\"tripleo::profile::base::metrics::collectd::amqp_transport_name\\\": \\\"metrics\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_address\\\": \\\"collectd\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_instances\\\": {}, \\\"tripleo::profile::base::metrics::collectd::amqp_retry_delay\\\": 1, \\\"tripleo::profile::base::metrics::collectd::amqp_host\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_port\\\": 5666, \\\"tripleo::profile::base::metrics::collectd::amqp_user\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_password\\\": \\\"guest\\\"}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_collectd\\\": [{\\\"tag\\\": \\\"collectd\\\", \\\"file\\\": \\\"/var/log/containers/collectd/collectd.log\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"collectd\\\", \\\"puppet_tags\\\": \\\"collectd_client_config,exec\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::collectd\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/collectd.json\\\": {\\\"command\\\": \\\"/usr/sbin/collectd -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/collectd.d\\\", \\\"dest\\\": \\\"/etc/\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/collectd\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/config-scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"collectd_check_health.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2022 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n\\\\nimport json\\\\nimport os\\\\nimport re\\\\nimport shutil\\\\nimport subprocess\\\\nimport sys\\\\n\\\\nfrom pkg_resources import packaging\\\\n\\\\n\\\\nSOCKET = \\\\\\\"unix:/run/podman/podman.sock\\\\\\\"\\\\nPS_FORMAT = (\'{\\\\\\\"service\\\\\\\": \\\\\\\"{{.Names}}\\\\\\\", \\\\\\\"container\\\\\\\": \\\\\\\"{{.ID}}\\\\\\\", \'\\\\n             \'\\\\\\\"status\\\\\\\": \\\\\\\"{{.State}}\\\\\\\", \\\\\\\"healthy\\\\\\\": \\\\\\\"{{.Status}}\\\\\\\"},\')\\\\nBASE_FORMAT = \\\\\\\"{service: .Name, container: .Id, status: .State.Running, \\\\\\\"\\\\nRUNNING_REX = re.compile(r\\\\\\\"Up .*(?P<health>\\\\\\\\(u?n?healthy\\\\\\\\))\\\\\\\")\\\\nSKIP_LIST = [\'.*_bootstrap\', \'container-puppet-.*\', \'.*_db_sync\',\\\\n             \'.*_cron\', \'create_.*_wrapper\', \'.*_wait_bundle\',\\\\n             \'configure_.*\', \'.*_fix_perms\', \'.*_init_logs?\',\\\\n             \'.*_init_perm\', \'(nova|placement)_wait_for_.*\', \'nova_.*ensure_\',\\\\n             \'(swift_)?setup_.*\', \'mysql_data_ownership\', \'swift_copy_rings\',\\\\n             \'nova_statedir_owner\']\\\\n\\\\n\\\\nclass ExecuteError(Exception):\\\\n    def __init__(self, rc, msg):\\\\n        self.rc = rc\\\\n        self.msg = msg\\\\n        super().__init__()\\\\n\\\\n\\\\ndef execute(cmd, workdir: str = None,\\\\n            prev_proc: subprocess.Popen = None) -> subprocess.Popen:\\\\n    # Note(mmagr): When this script is executed by collectd-sensubility started\\\\n    #              via collectd the script has non-root permission but inherits\\\\n    #              environment from collectd with root permission. We need\\\\n    #              to avoid sensubility access /root when using podman-remote.\\\\n    #              See https://bugzilla.redhat.com/show_bug.cgi?id=2091076 for\\\\n    #              more info.\\\\n    proc_env = os.environ.copy()\\\\n    proc_env[\\\\\\\"HOME\\\\\\\"] = \\\\\\\"/tmp\\\\\\\"\\\\n    if type(cmd[0]) is list:  # multiple piped commands\\\\n        last = prev_proc\\\\n        for c in cmd:\\\\n            last = execute(c, workdir, last)\\\\n        return last\\\\n    else:  # single command\\\\n        inpipe = prev_proc.stdout if prev_proc is not None else None\\\\n        proc = subprocess.Popen(cmd, cwd=workdir, env=proc_env, stdin=inpipe,\\\\n                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)\\\\n        if prev_proc is not None:\\\\n            prev_proc.stdout.close()\\\\n            prev_proc.stderr.close()\\\\n        return proc\\\\n\\\\n\\\\ndef get_health_from_status(status):\\\\n    healthy = status in (\'healthy\', \'running\')\\\\n    return int(healthy)\\\\n\\\\n\\\\ndef fetch_state_from_inspect(cont, fmt):\\\\n    proc = execute([\\\\n        [shutil.which(\'podman-remote\'),\\\\n           \'--url\', SOCKET, \'inspect\', cont[\\\\\\\"container\\\\\\\"]],\\\\n        [shutil.which(\'jq\'), \'.[] | %s\' % fmt]\\\\n    ])\\\\n    o, e = proc.communicate()\\\\n    if proc.returncode != 0:\\\\n        msg = \\\\\\\"Failed to fetch status of %s: %s\\\\\\\" % (cont, e.decode())\\\\n        raise ExecuteError(proc.returncode, msg)\\\\n\\\\n    item = json.loads(o.decode())\\\\n    item[\'status\'] = \'running\' if item[\'status\'] else \'stopped\'\\\\n    if len(item[\'healthy\']) > 0 and item[\'status\'] != \'stopped\':\\\\n        item[\'status\'] = item[\'healthy\']\\\\n\\\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\\\n    return item\\\\n\\\\n\\\\ndef fetch_state(item):\\\\n    if \'up \' in item[\'status\'].lower():\\\\n        item[\'status\'] = \'running\'\\\\n    if item[\'status\'] != \'running\':\\\\n        item[\'status\'] = \'stopped\'\\\\n\\\\n    match = RUNNING_REX.match(item[\'healthy\'])\\\\n    if match:\\\\n        health = match.group(\'health\')\\\\n    else:\\\\n        health = \'\'\\\\n    if health:\\\\n        item[\'status\'] = health.strip(\\\\\\\"()\\\\\\\")\\\\n\\\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\\\n    return item\\\\n\\\\n\\\\ndef fetch_container_health(ps_result, inspect_fmt):\\\\n\\\\n    def container_filter(item):\\\\n        for rx in [re.compile(i) for i in SKIP_LIST]:\\\\n            if rx.match(item[\\\\\\\"service\\\\\\\"]):\\\\n                return False\\\\n        return True\\\\n    try:\\\\n        containers = filter(container_filter, json.loads(ps_result))\\\\n    except json.decoder.JSONDecodeError:\\\\n        return 1, \\\\\\\"%s\\\\\\\\nFailed to parse above output.\\\\\\\" % ps_result\\\\n\\\\n    out = []\\\\n    for cont in containers:\\\\n        try:\\\\n            out.append(fetch_state(cont))\\\\n        except Exception:\\\\n            # fallback to slow inspect way in case of any error\\\\n            try:\\\\n                out.append(fetch_state_from_inspect(cont, inspect_fmt))\\\\n            except ExecuteError as ex:\\\\n                return ex.rc, ex.msg\\\\n    return 0, out\\\\n\\\\n\\\\nif __name__ == \\\\\\\"__main__\\\\\\\":\\\\n    proc = execute([shutil.which(\'podman-remote\'),\\\\n                    \'--url\', SOCKET, \'version\',\\\\n                    \'--format\', r\'{{.Server.Version}}\'])\\\\n    o, e = proc.communicate()\\\\n    try:\\\\n        if packaging.version.parse(o.decode().strip()) >= packaging.version.parse(\\\\\\\"4.0.0\\\\\\\"):\\\\n            inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Health.Status}\\\\\\\"\\\\n        else:\\\\n            inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Healthcheck.Status}\\\\\\\"\\\\n    except Exception:\\\\n        # keep podman-4.0.0+ format in case of version decoding error\\\\n        inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Health.Status}\\\\\\\"\\\\n\\\\n    proc = execute([shutil.which(\'podman-remote\'), \'--url\', SOCKET,\\\\n                    \'ps\', \'--all\', \'--format\', PS_FORMAT])\\\\n    o, e = proc.communicate()\\\\n    if proc.returncode != 0:\\\\n        print(\\\\\\\"Failed to list containers:\\\\\\\\n%s\\\\\\\\n%s\\\\\\\" % (o.decode(), e.decode()))\\\\n        sys.exit(1)\\\\n\\\\n    rc, status = fetch_container_health(\\\\\\\"[%s]\\\\\\\" % o.decode().strip(\\\\\\\"\\\\\\\\n,\\\\\\\"), inspect_fmt)\\\\n    if rc != 0:\\\\n        print(\\\\\\\"Failed to inspect containers:\\\\\\\\n%s\\\\\\\" % status)\\\\n        sys.exit(rc)\\\\n    print(json.dumps(status))\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"collectd\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"memory\\\": \\\"512m\\\", \\\"cap_add\\\": [\\\"IPC_LOCK\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\\\", \\\"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/collectd:/var/log/collectd:rw,z\\\", \\\"/var/lib/container-config-scripts:/config-scripts:ro\\\", \\\"/var/lib/container-user-scripts:/scripts:z\\\", \\\"/run:/run:rw\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/collectd\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/container-user-scripts/\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}]}, {\\\"name\\\": \\\"import provision_mcelog\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_provision_mcelog\\\"}, \\\"when\\\": false}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"set enable_sensubility fact\\\", \\\"set_fact\\\": {\\\"enable_sensubility\\\": false}}, {\\\"name\\\": \\\"create podman socket for sensubility purposes\\\", \\\"block\\\": [{\\\"name\\\": \\\"create podman socket and appropriate systemd service\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_service\\\"}, \\\"vars\\\": {\\\"tripleo_podman_socket_path\\\": \\\"/var/lib/tripleo-podman/collectd/podman.sock\\\"}}, {\\\"name\\\": \\\"create systemd service for ensuring socket file ACL contains collectd\\\", \\\"become\\\": true, \\\"ansible.builtin.copy\\\": {\\\"content\\\": \\\"[Unit]\\\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\\\nRequires=tripleo_collectd.service\\\\nAfter=tripleo_podman.service\\\\nAfter=tripleo_collectd.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\", \\\"dest\\\": \\\"/etc/systemd/system/tripleo_podman_collectd_acl.service\\\", \\\"mode\\\": 420}}, {\\\"name\\\": \\\"enable podman.sock ACL service\\\", \\\"ansible.builtin.service\\\": {\\\"name\\\": \\\"tripleo_podman_collectd_acl.service\\\", \\\"enabled\\\": true}}, {\\\"name\\\": \\\"create directory for downloads of users\' scripts\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/container-user-scripts\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"download exec scripts\\\", \\\"ansible.builtin.get_url\\\": {\\\"url\\\": \\\"{{ item.source }}\\\", \\\"checksum\\\": \\\"{{ item.checksum }}\\\", \\\"dest\\\": \\\"/var/lib/container-user-scripts/{{ item.name }}\\\", \\\"mode\\\": \\\"0755\\\"}, \\\"with_items\\\": []}], \\\"when\\\": [\\\"enable_sensubility|bool\\\", \\\"step|int == 1\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}, {\\\"name\\\": \\\"Force pull image collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 3\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"UBI8 to UBI9 switch of collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update collectd to UBI9\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_3\\\", \\\"config_patterns\\\": \\\"collectd.json\\\", \\\"config_id\\\": [\\\"tripleo_step3\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\"collectd\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\"}}}}]}]}, {\\\"service_name\\\": \\\"ceilometer_agent_compute\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ceilometer-agent-compute\\\", \\\"config_settings\\\": {\\\"ceilometer::logging::debug\\\": true, \\\"ceilometer::agent::polling::manage_polling\\\": false, \\\"ceilometer::agent::service_credentials::password\\\": \\\"lAltaQRZMJ8lMeTuITOttJN7X\\\", \\\"ceilometer::agent::service_credentials::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"ceilometer::agent::service_credentials::region_name\\\": \\\"regionOne\\\", \\\"ceilometer::agent::service_credentials::project_name\\\": \\\"service\\\", \\\"ceilometer::agent::service_credentials::user_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::auth_project_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::interface\\\": \\\"internalURL\\\", \\\"ceilometer::notification_driver\\\": [\\\"noop\\\"], \\\"ceilometer::amqp_rpc_address_prefix\\\": \\\"\\\", \\\"ceilometer::amqp_notify_address_prefix\\\": \\\"\\\", \\\"ceilometer::telemetry_secret\\\": \\\"MGRnIM4wMti8nqhqt2uJkphYX\\\", \\\"ceilometer::snmpd_readonly_username\\\": \\\"ro_snmp_user\\\", \\\"ceilometer::snmpd_readonly_user_password\\\": \\\"89Vk5RNyVwiA8aj5GHvgz6wY\\\", \\\"ceilometer::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ceilometer::rabbit_heartbeat_in_pthread\\\": false, \\\"ceilometer::cache::enabled\\\": true, \\\"ceilometer::cache::tls_enabled\\\": true, \\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"ceilometer::cache::enable_socket_keepalive\\\": true, \\\"ceilometer::agent::polling::instance_discovery_method\\\": \\\"libvirt_metadata\\\", \\\"ceilometer_redis_password\\\": \\\"JDaTXcJCyBDjrUGXoIFUsKtgP\\\", \\\"compute_namespace\\\": true, \\\"ceilometer::agent::polling::tenant_name_discovery\\\": false}, \\\"service_config_settings\\\": {\\\"keystone\\\": {\\\"tripleo::profile::base::keystone::ceilometer_notification_topics\\\": [\\\"notifications\\\"]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"ceilometer_agent_compute\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_libvirt.target\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]}, {\\\"service_name\\\": \\\"ceilometer_agent_ipmi\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ceilometer-agent-ipmi\\\", \\\"config_settings\\\": {\\\"ceilometer::logging::debug\\\": true, \\\"ceilometer::agent::polling::manage_polling\\\": false, \\\"ceilometer::agent::service_credentials::password\\\": \\\"lAltaQRZMJ8lMeTuITOttJN7X\\\", \\\"ceilometer::agent::service_credentials::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"ceilometer::agent::service_credentials::region_name\\\": \\\"regionOne\\\", \\\"ceilometer::agent::service_credentials::project_name\\\": \\\"service\\\", \\\"ceilometer::agent::service_credentials::user_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::auth_project_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::interface\\\": \\\"internalURL\\\", \\\"ceilometer::notification_driver\\\": [\\\"noop\\\"], \\\"ceilometer::amqp_rpc_address_prefix\\\": \\\"\\\", \\\"ceilometer::amqp_notify_address_prefix\\\": \\\"\\\", \\\"ceilometer::telemetry_secret\\\": \\\"MGRnIM4wMti8nqhqt2uJkphYX\\\", \\\"ceilometer::snmpd_readonly_username\\\": \\\"ro_snmp_user\\\", \\\"ceilometer::snmpd_readonly_user_password\\\": \\\"89Vk5RNyVwiA8aj5GHvgz6wY\\\", \\\"ceilometer::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ceilometer::rabbit_heartbeat_in_pthread\\\": false, \\\"ceilometer::cache::enabled\\\": true, \\\"ceilometer::cache::tls_enabled\\\": true, \\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"ceilometer::cache::enable_socket_keepalive\\\": true, \\\"ceilometer_redis_password\\\": \\\"JDaTXcJCyBDjrUGXoIFUsKtgP\\\", \\\"ipmi_namespace\\\": true}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_ceilometer_agent_ipmi\\\": [{\\\"tag\\\": \\\"openstack.ceilometer.agent.ipmi\\\", \\\"file\\\": \\\"/var/log/containers/ceilometer/ipmi.log\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"ceilometer_init_log\\\": {\\\"start_order\\\": 0, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R ceilometer:ceilometer /var/log/ceilometer\\\"], \\\"volumes\\\": [\\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]}}, \\\"step_4\\\": {\\\"ceilometer_agent_ipmi\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}, {\\\"service_name\\\": \\\"ipaservice\\\", \\\"upgrade_tasks\\\": [], \\\"step_config\\\": \\\"\\\", \\\"ipa_registration_tasks\\\": [{\\\"name\\\": \\\"Get undercloud FQDN\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"set_fact\\\": {\\\"undercloud_fqdn\\\": \\\"{{ ansible_facts[\'fqdn\'] }}\\\"}}, {\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ipa_registration\\\", \\\"apply\\\": {\\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"environment\\\": {\\\"IPA_USER\\\": \\\"nova/{{ undercloud_fqdn }}\\\", \\\"KRB5_CLIENT_KTNAME\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"KRB5CCNAME\\\": \\\"/etc/novajoin/krb5.cache\\\", \\\"IPA_HOST\\\": \\\"ipa.ooo.test\\\"}}}, \\\"vars\\\": {\\\"tripleo_ipa_enroll_base_server\\\": true, \\\"tripleo_ipa_delegate_server\\\": \\\"{{ inventory_hostname }}\\\", \\\"tripleo_ipa_base_server_fqdn\\\": \\\"{{ fqdn_canonical }}\\\", \\\"tripleo_ipa_server_metadata\\\": \\\"{{ service_metadata_settings | to_json }}\\\"}, \\\"when\\\": \\\"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\\\"}, {\\\"name\\\": \\\"Enroll the node as an ipa client\\\", \\\"vars\\\": {\\\"ipaclient_install_packages\\\": false, \\\"idm_enroll_base_server\\\": true}, \\\"block\\\": [{\\\"name\\\": \\\"check if default.conf exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/ipa/default.conf\\\"}, \\\"register\\\": \\\"ipa_conf_exists\\\"}, {\\\"name\\\": \\\"install openssl-perl\\\", \\\"become\\\": true, \\\"package\\\": {\\\"name\\\": \\\"openssl-perl\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ipaclient_install_packages|bool\\\"]}, {\\\"name\\\": \\\"register as an ipa client\\\", \\\"include_role\\\": {\\\"name\\\": \\\"ipaclient\\\", \\\"apply\\\": {\\\"become\\\": true}}, \\\"vars\\\": {\\\"state\\\": \\\"present\\\", \\\"ipaclient_otp\\\": \\\"{{ ipa_host_otp }}\\\", \\\"ipaclient_mkhomedir\\\": false, \\\"ipaclient_no_ntp\\\": false, \\\"ipaclient_force\\\": true, \\\"ipaclient_hostname\\\": \\\"{{ fqdn_canonical }}\\\", \\\"ansible_fqdn\\\": \\\"{{ ipaclient_hostname }}\\\", \\\"ipaclients\\\": [\\\"ipaclient_hostname\\\"], \\\"ansible_distribution\\\": \\\"{{ ansible_facts[\'distribution\'] }}\\\", \\\"ansible_distribution_major_version\\\": \\\"{{ ansible_facts[\'distribution_major_version\'] }}\\\", \\\"ansible_distribution_release\\\": \\\"{{ ansible_facts[\'distribution_release\'] }}\\\", \\\"ansible_distribution_version\\\": \\\"{{ ansible_facts[\'distribution_version\'] }}\\\", \\\"ansible_os_family\\\": \\\"{{ ansible_facts[\'os_family\'] }}\\\", \\\"ipaclient_servers\\\": [\\\"ipa.ooo.test\\\"], \\\"ipaclient_domain\\\": \\\"ooo.test\\\"}, \\\"when\\\": [\\\"idm_enroll_base_server|bool\\\", \\\"not ipa_conf_exists.stat.exists\\\"]}, {\\\"name\\\": \\\"restart certmonger service\\\", \\\"become\\\": true, \\\"systemd\\\": {\\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true, \\\"name\\\": \\\"certmonger.service\\\"}, \\\"when\\\": [\\\"idm_enroll_base_server|bool\\\", \\\"not ipa_conf_exists.stat.exists\\\"]}, {\\\"name\\\": \\\"set discovered ipa realm\\\", \\\"set_fact\\\": {\\\"idm_realm\\\": \\\"{{ lookup(\'ini\', \'realm default=OOO.TEST section=global file=/etc/ipa/default.conf\')}}\\\"}}], \\\"when\\\": \\\"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\\\"}], \\\"external_deploy_tasks\\\": [{\\\"name\\\": \\\"add the DNS entries into IPA in step 1\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ipa_dns\\\"}, \\\"vars\\\": {\\\"tripleo_ipa_ptr_zone_split_ipv4\\\": \\\"1\\\", \\\"tripleo_ipa_ptr_zone_split_ipv6\\\": \\\"1\\\"}, \\\"when\\\": true}], \\\"environment\\\": {\\\"IPA_USER\\\": \\\"nova/{{ ansible_facts[\'fqdn\'] }}\\\", \\\"KRB5_CLIENT_KTNAME\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"KRB5CCNAME\\\": \\\"/etc/novajoin/krb5.cache\\\", \\\"IPA_HOST\\\": \\\"ipa.ooo.test\\\"}}], \\\"scale_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"down\\\", \\\"block\\\": [{\\\"name\\\": \\\"unregister node from ipa server\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ipa_cleanup\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"vars\\\": {\\\"tripleo_ipa_keytab\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"tripleo_ipa_hosts_to_delete\\\": [\\\"{{ fqdn_canonical }}\\\"]}}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"check if ipa server has required permissions\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tls_everywhere\\\", \\\"tasks_from\\\": \\\"ipa-server-check\\\"}, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-tls-everywhere\\\"]}]}]}, {\\\"service_name\\\": \\\"iscsid\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::iscsid::chap_algs\\\": \\\"SHA3-256,SHA256,SHA1,MD5\\\"}, \\\"service_config_settings\\\": {}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Run lvmfilter role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_lvmfilter\\\"}, \\\"when\\\": [\\\"step|int == 1\\\"]}], \\\"ansible_group_vars\\\": {\\\"tripleo_tripleo_lvmfilter_enabled\\\": false, \\\"tripleo_tripleo_lvmfilter_devices_allowlist\\\": [], \\\"tripleo_tripleo_lvmfilter_devices_denylist\\\": [\\\".*\\\"], \\\"ContainerIscsidImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"ContainerIscsidConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"iscsid\\\", \\\"puppet_tags\\\": \\\"iscsid_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::iscsid\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"volumes\\\": [\\\"/etc/iscsi:/tmp/iscsi.host:z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/iscsid.json\\\": {\\\"command\\\": \\\"/usr/sbin/iscsid -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"iscsid\\\": {\\\"start_order\\\": 2, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys:/sys\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/etc/target:/etc/target:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext entry for iscsi\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"{{ item.path }}(/.*)?\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"stat /lib/systemd/system/iscsid.socket\\\", \\\"stat\\\": \\\"path=/lib/systemd/system/iscsid.socket\\\", \\\"register\\\": \\\"stat_iscsid_socket\\\"}, {\\\"name\\\": \\\"Stop and disable iscsid.socket service\\\", \\\"service\\\": \\\"name=iscsid.socket state=stopped enabled=no\\\", \\\"when\\\": \\\"stat_iscsid_socket.stat.exists\\\"}, {\\\"name\\\": \\\"Check if iscsi.service is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet iscsi.service\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"iscsi_service_enabled_result\\\"}, {\\\"name\\\": \\\"Stop iscsi.service\\\", \\\"service\\\": \\\"name=iscsi.service state=stopped enabled=no\\\", \\\"when\\\": [\\\"iscsi_service_enabled_result is changed\\\", \\\"iscsi_service_enabled_result.rc == 0\\\"]}], \\\"upgrade_tasks\\\": []}, {\\\"service_name\\\": \\\"kernel\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\"}}], \\\"ansible_group_vars\\\": {\\\"hieradata_localhost_address\\\": \\\"localhost\\\", \\\"tripleo_kernel_extra_modules\\\": {}, \\\"tripleo_kernel_extra_packages\\\": {}, \\\"tripleo_kernel_sysctl_extra_settings\\\": {\\\"net.ipv6.conf.default.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_local_reserved_ports\\\": {\\\"value\\\": \\\"35357,49000-49001\\\"}, \\\"net.ipv6.conf.all.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv6.conf.lo.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_forward\\\": {\\\"value\\\": 1}, \\\"net.ipv4.conf.all.rp_filter\\\": {\\\"value\\\": 1}, \\\"net.ipv6.conf.all.forwarding\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_nonlocal_bind\\\": {\\\"value\\\": 1}, \\\"net.ipv6.ip_nonlocal_bind\\\": {\\\"value\\\": 1}, \\\"kernel.pid_max\\\": {\\\"value\\\": 1048576}, \\\"net.ipv4.neigh.default.gc_thresh1\\\": {\\\"value\\\": 1024}, \\\"net.ipv4.neigh.default.gc_thresh2\\\": {\\\"value\\\": 2048}, \\\"net.ipv4.neigh.default.gc_thresh3\\\": {\\\"value\\\": 4096}, \\\"net.bridge.bridge-nf-call-arptables\\\": {\\\"value\\\": 1}, \\\"net.bridge.bridge-nf-call-iptables\\\": {\\\"value\\\": 1}, \\\"net.bridge.bridge-nf-call-ip6tables\\\": {\\\"value\\\": 1}, \\\"fs.inotify.max_user_instances\\\": {\\\"value\\\": 1024}, \\\"fs.aio-max-nr\\\": {\\\"value\\\": 1048576}}}}, {\\\"service_name\\\": \\\"metrics_qdr\\\", \\\"firewall_rules\\\": {\\\"109 metrics qdr\\\": {\\\"dport\\\": [5666]}, \\\"109 accept internal metrics qdr ctlplane subnet 192.168.122.0/24\\\": {\\\"dport\\\": [5667, 5668]}}, \\\"monitoring_subscription\\\": \\\"overcloud-qdr\\\", \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_metrics_qdr\\\": [{\\\"tag\\\": \\\"openstack.nova.consoleauth\\\", \\\"file\\\": \\\"/var/log/containers/metrics_qdr/metrics_qdr.log\\\", \\\"startmsg.regex\\\": \\\"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\\\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\\\\\\\\\([a-z]+\\\\\\\\\\\\\\\\) \\\"}]}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::metrics::qdr::listener_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::haproxy::metrics_qdr\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_port\\\": 5666, \\\"tripleo::profile::base::metrics::qdr::username\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::qdr::password\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::qdr::connectors\\\": [], \\\"tripleo::profile::base::metrics::qdr::addresses\\\": [{\\\"prefix\\\": \\\"collectd\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/metering.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/event.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}], \\\"tripleo::profile::base::metrics::qdr::autolink_addresses\\\": [], \\\"tripleo::profile::base::metrics::qdr::listener_require_ssl\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_require_encrypt\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_sasl_mech\\\": \\\"ANONYMOUS\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\\\": \\\"\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_password\\\": \\\"\\\", \\\"tripleo::profile::base::metrics::qdr::listener_trusted_certs\\\": \\\"\\\", \\\"qdr::log_enable\\\": \\\"info+\\\", \\\"qdr::log_output\\\": \\\"/var/log/qdrouterd/metrics_qdr.log\\\", \\\"qdr::listener_auth_peer\\\": false, \\\"tripleo::profile::base::metrics::qdr::ssl_profiles\\\": [{\\\"name\\\": \\\"sslProfile\\\"}, {\\\"name\\\": \\\"tlsProfile\\\", \\\"certFile\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"keyFile\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"caCertFile\\\": \\\"/etc/ipa/ca.crt\\\"}]}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"metrics_qdr\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"metrics_qdr\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::qdr\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/metrics_qdr.json\\\": {\\\"command\\\": \\\"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/qdrouterd\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"metrics_qdr_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\\\"]}, \\\"metrics_qdr\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"qdrouterd\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\\\", \\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\", \\\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\\\", \\\"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"metrics_qdr\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"metrics_qdr/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep metrics_qdr)\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/metrics_qdr.key\\\\n# Copy the new cert from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n# Copy the new key from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a container restart to read the new certificate\\\\n{{container_cli}} restart \\\\\\\"$container_name\\\\\\\"\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}]}, {\\\"service_name\\\": \\\"mysql_client\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::database::mysql::client::enable_ssl\\\": true, \\\"tripleo::profile::base::database::mysql::client::ssl_ca\\\": \\\"/etc/ipa/ca.crt\\\"}, \\\"step_config\\\": \\\"include tripleo::profile::base::database::mysql::client\\\"}, {\\\"service_name\\\": \\\"nova_compute\\\", \\\"monitoring_subscription\\\": \\\"overcloud-nova-compute\\\", \\\"config_settings\\\": {\\\"nova::my_ip\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::rabbit_use_ssl\\\": \\\"True\\\", \\\"nova::keystone::service_user::send_service_user_token\\\": true, \\\"nova::keystone::service_user::project_name\\\": \\\"service\\\", \\\"nova::keystone::service_user::password\\\": \\\"eljGPqsTubd1MRdmVjF5MppaC\\\", \\\"nova::keystone::service_user::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::keystone::service_user::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::project_name\\\": \\\"service\\\", \\\"nova::placement::password\\\": \\\"9ppduM3vEiUPQ7DOtXGTm17h0\\\", \\\"nova::placement::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::placement::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::valid_interfaces\\\": \\\"internal\\\", \\\"nova::os_region_name\\\": \\\"regionOne\\\", \\\"nova::logging::debug\\\": true, \\\"nova::purge_config\\\": false, \\\"nova::network::neutron::project_name\\\": \\\"service\\\", \\\"nova::network::neutron::username\\\": \\\"neutron\\\", \\\"nova::network::neutron::region_name\\\": \\\"regionOne\\\", \\\"nova::dhcp_domain\\\": \\\"\\\", \\\"nova::network::neutron::password\\\": \\\"OorljNRFSWJ6uLOrYiwbnwsqY\\\", \\\"nova::network::neutron::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::network::neutron::valid_interfaces\\\": \\\"internal\\\", \\\"nova::glance::valid_interfaces\\\": \\\"internal\\\", \\\"nova::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"nova::cinder_catalog_info\\\": \\\"volumev3:cinderv3:internalURL\\\", \\\"nova::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"nova::notify_on_state_change\\\": \\\"vm_and_task_state\\\", \\\"nova::notification_driver\\\": [\\\"noop\\\"], \\\"nova::notification_format\\\": \\\"unversioned\\\", \\\"nova::network::neutron::auth_type\\\": \\\"v3password\\\", \\\"nova::db::database_db_max_retries\\\": -1, \\\"nova::db::database_max_retries\\\": -1, \\\"nova::network::neutron::ovs_bridge\\\": \\\"br-int\\\", \\\"nova::compute::sync_power_state_interval\\\": 600, \\\"nova_is_additional_cell\\\": false, \\\"nova::cross_az_attach\\\": true, \\\"nova::cache::enabled\\\": true, \\\"nova::cache::tls_enabled\\\": true, \\\"nova::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"nova::rabbit_heartbeat_in_pthread\\\": false, \\\"nova::ovsdb_connection\\\": \\\"\\\", \\\"nova::compute::vcpu_pin_set\\\": [], \\\"nova::compute::cpu_shared_set\\\": [], \\\"nova::compute::cpu_dedicated_set\\\": [], \\\"nova::compute::reserved_host_memory\\\": 512, \\\"nova::compute::reserved_huge_pages\\\": [], \\\"nova::compute::neutron_physnets_numa_nodes_mapping\\\": {}, \\\"nova::compute::neutron_tunnel_numa_nodes\\\": [], \\\"nova::compute::resume_guests_state_on_host_boot\\\": false, \\\"nova::compute::libvirt::rx_queue_size\\\": 512, \\\"nova::compute::libvirt::tx_queue_size\\\": 512, \\\"nova::compute::libvirt::file_backed_memory\\\": 0, \\\"nova::compute::libvirt::volume_use_multipath\\\": false, \\\"nova::compute::libvirt::hw_machine_type\\\": \\\"x86_64=pc-q35-rhel9.0.0\\\", \\\"nova::compute::mkisofs_cmd\\\": \\\"mkisofs\\\", \\\"compute_enable_ksm\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_pool\\\": \\\"vms\\\", \\\"tripleo::profile::base::nova::compute::nova_nfs_enabled\\\": false, \\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\", \\\"nova::compute::libvirt::num_pcie_ports\\\": 16, \\\"nova::compute::libvirt::mem_stats_period_seconds\\\": 10, \\\"nova::compute::rbd::ephemeral_storage\\\": false, \\\"resume_guests_state_on_host_boot\\\": false, \\\"nova::cpu_allocation_ratio\\\": 0.0, \\\"nova::ram_allocation_ratio\\\": 1.0, \\\"nova::disk_allocation_ratio\\\": 0.0, \\\"nova::compute::max_disk_devices_to_attach\\\": -1, \\\"nova::compute::libvirt::pmem_namespaces\\\": \\\"\\\", \\\"nova_pmem_namespaces\\\": \\\"\\\", \\\"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\\\": 86400, \\\"nova::compute::libvirt::swtpm_enabled\\\": false, \\\"nova::compute::vgpu::vgpu_types_device_addresses_mapping\\\": {}, \\\"compute_disable_irqbalance\\\": false, \\\"nova::compute::libvirt::cpu_mode\\\": \\\"host-model\\\", \\\"nova::compute::libvirt::cpu_models\\\": [], \\\"nova::compute::libvirt::cpu_model_extra_flags\\\": \\\"\\\", \\\"nova_compute_opt_volumes\\\": [], \\\"nova_compute_startup_delay\\\": 0, \\\"nova_compute_opt_env_vars\\\": {}, \\\"nova::workarounds::never_download_image_if_on_rbd\\\": false, \\\"nova::compute::image_type_exclude_list\\\": [], \\\"nova_permit_post_copy\\\": true, \\\"nova_permit_auto_converge\\\": true, \\\"nova_libvirt_max_queues\\\": 0, \\\"nova_glance_enable_rbd_download\\\": false, \\\"nova_glance_rbd_download_multistore_id\\\": \\\"\\\", \\\"nova::compute::force_raw_images\\\": true, \\\"nova::compute::use_cow_images\\\": true, \\\"nova::compute::libvirt::preallocate_images\\\": \\\"none\\\", \\\"nova::compute::image_cache::manager_interval\\\": 2400, \\\"nova::compute::image_cache::remove_unused_base_images\\\": true, \\\"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\\\": 3600, \\\"nova::compute::image_cache::precache_concurrency\\\": 1, \\\"nova::compute::provider::custom_inventories\\\": {}, \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\\\": 15, \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\\\": 600, \\\"ContainerNovaComputeImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"nova::compute::pci::passthrough\\\": \\\"\\\", \\\"nova::compute::libvirt::migration_support\\\": false, \\\"tripleo::profile::base::nova::migration::client::nova_compute_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": 2022, \\\"nova::compute::rbd::libvirt_images_rbd_glance_store_name\\\": \\\"default_backend\\\", \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": \\\"/etc/ceph/ceph.conf\\\", \\\"nova::compute::rbd::libvirt_rbd_user\\\": \\\"openstack\\\", \\\"nova::compute::rbd::rbd_keyring\\\": \\\"client.openstack\\\", \\\"tripleo::profile::base::nova::compute::cinder_nfs_backend\\\": false, \\\"rbd_persistent_storage\\\": false, \\\"rbd_disk_cachemodes\\\": [\\\"network=writeback\\\"], \\\"nova::cinder::username\\\": \\\"cinder\\\", \\\"nova::cinder::auth_type\\\": \\\"v3password\\\", \\\"nova::cinder::project_name\\\": \\\"service\\\", \\\"nova::cinder::password\\\": \\\"puJEUVV5bncg9PX1nMb3Jnk25\\\", \\\"nova::cinder::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::cinder::region_name\\\": \\\"regionOne\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": \\\"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": \\\"3740e1ef-a43e-4451-a74a-f194469d07d9\\\", \\\"nova::compute::instance_usage_audit\\\": true, \\\"nova::compute::instance_usage_audit_period\\\": \\\"hour\\\", \\\"nova::compute::consecutive_build_service_disable_threshold\\\": \\\"10\\\", \\\"nova::compute::live_migration_wait_for_vif_plug\\\": true, \\\"nova::migration::libvirt::live_migration_permit_post_copy\\\": true, \\\"nova::migration::libvirt::live_migration_permit_auto_converge\\\": true, \\\"nova::migration::libvirt::live_migration_tunnelled\\\": false, \\\"nova::compute::vncserver_proxyclient_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::compute::vncproxy_host\\\": \\\"overcloud.ooo.test\\\", \\\"nova::vncproxy::common::vncproxy_protocol\\\": \\\"https\\\", \\\"nova::vncproxy::common::vncproxy_host\\\": \\\"overcloud.ooo.test\\\", \\\"nova::vncproxy::common::vncproxy_port\\\": \\\"13080\\\", \\\"nova::compute::verify_glance_signatures\\\": false, \\\"nova::workarounds::disable_compute_service_check_for_ffu\\\": false}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_compute\\\": [{\\\"tag\\\": \\\"openstack.nova.compute\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-compute.log\\\"}]}, \\\"collectd\\\": {\\\"tripleo.collectd.plugins.nova_compute\\\": [\\\"virt\\\"], \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\"}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"nova_config\\\", \\\"step_config\\\": \\\"# TODO(emilien): figure how to deal with libvirt profile.\\\\n# We\'ll probably treat it like we do with Neutron plugins.\\\\n# Until then, just include it in the default nova-compute role.\\\\ninclude tripleo::profile::base::nova::compute::libvirt\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_compute.json\\\": {\\\"command\\\": \\\"/usr/bin/nova-compute \\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/*\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\\\": {\\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"nova_statedir_ownership.py\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\nimport logging\\\\nimport os\\\\nimport pwd\\\\nimport selinux\\\\nimport stat\\\\nimport sys\\\\n\\\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\\\n\\\\nif debug.lower() == \'true\':\\\\n    loglevel = logging.DEBUG\\\\nelse:\\\\n    loglevel = logging.INFO\\\\n\\\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\\\nLOG = logging.getLogger(\'nova_statedir\')\\\\n\\\\n\\\\nclass PathManager(object):\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"Helper class to manipulate ownership of a given path\\\\\\\"\\\\\\\"\\\\\\\"\\\\n    def __init__(self, path):\\\\n        self.path = path\\\\n        self.uid = None\\\\n        self.gid = None\\\\n        self.is_dir = None\\\\n        self.secontext = None\\\\n        self._update()\\\\n\\\\n    def _update(self):\\\\n        try:\\\\n            statinfo = os.stat(self.path)\\\\n            self.is_dir = stat.S_ISDIR(statinfo.st_mode)\\\\n            self.uid = statinfo.st_uid\\\\n            self.gid = statinfo.st_gid\\\\n            self.secontext = selinux.lgetfilecon(self.path)[1]\\\\n        except Exception:\\\\n            LOG.exception(\'Could not update metadata for %s\', self.path)\\\\n            raise\\\\n\\\\n    def __str__(self):\\\\n        return \\\\\\\"uid: {} gid: {} path: {}{}\\\\\\\".format(\\\\n            self.uid,\\\\n            self.gid,\\\\n            self.path,\\\\n            \'/\' if self.is_dir else \'\'\\\\n        )\\\\n\\\\n    def has_owner(self, uid, gid):\\\\n        return self.uid == uid and self.gid == gid\\\\n\\\\n    def has_either(self, uid, gid):\\\\n        return self.uid == uid or self.gid == gid\\\\n\\\\n    def chown(self, uid, gid):\\\\n        target_uid = -1\\\\n        target_gid = -1\\\\n        if self.uid != uid:\\\\n            target_uid = uid\\\\n        if self.gid != gid:\\\\n            target_gid = gid\\\\n        if (target_uid, target_gid) != (-1, -1):\\\\n            LOG.info(\'Changing ownership of %s from %d:%d to %d:%d\',\\\\n                     self.path,\\\\n                     self.uid,\\\\n                     self.gid,\\\\n                     self.uid if target_uid == -1 else target_uid,\\\\n                     self.gid if target_gid == -1 else target_gid)\\\\n            try:\\\\n                os.chown(self.path, target_uid, target_gid)\\\\n                self._update()\\\\n            except Exception:\\\\n                LOG.exception(\'Could not change ownership of %s: \',\\\\n                              self.path)\\\\n                raise\\\\n        else:\\\\n            LOG.info(\'Ownership of %s already %d:%d\',\\\\n                     self.path,\\\\n                     uid,\\\\n                     gid)\\\\n\\\\n    def chcon(self, context):\\\\n        # If dir returns whether to recusively set context\\\\n        try:\\\\n            try:\\\\n                selinux.lsetfilecon(self.path, context)\\\\n                LOG.info(\'Setting selinux context of %s to %s\',\\\\n                     self.path, context)\\\\n                return True\\\\n            except OSError as e:\\\\n                if self.is_dir and e.errno == 95:\\\\n                    # Operation not supported, assume NFS mount and skip\\\\n                    LOG.info(\'Setting selinux context not supported for %s\',\\\\n                             self.path)\\\\n                    return False\\\\n                else:\\\\n                    raise\\\\n        except Exception:\\\\n            LOG.exception(\'Could not set selinux context of %s to %s:\',\\\\n                          self.path, context)\\\\n            raise\\\\n\\\\n\\\\nclass NovaStatedirOwnershipManager(object):\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"Class to manipulate the ownership of the nova statedir (/var/lib/nova).\\\\n\\\\n       The nova uid/gid differ on the host and container images. An upgrade\\\\n       that switches from host systemd services to docker requires a change in\\\\n       ownership. Previously this was a naive recursive chown, however this\\\\n       causes issues if nova instance are shared via an NFS mount: any open\\\\n       filehandles in qemu/libvirt fail with an I/O error (LP1778465).\\\\n\\\\n       Instead the upgrade/FFU ansible tasks now lay down a marker file when\\\\n       stopping and disabling the host systemd services. We use this file to\\\\n       determine the host nova uid/gid. We then walk the tree and update any\\\\n       files that have the host uid/gid to the docker nova uid/gid. As files\\\\n       owned by root/qemu etc... are ignored this avoids the issues with open\\\\n       filehandles. The marker is removed once the tree has been walked.\\\\n\\\\n       For subsequent runs, or for a new deployment, we simply ensure that the\\\\n       docker nova user/group owns all directories. This is required as the\\\\n       directories are created with root ownership in host_prep_tasks (the\\\\n       docker nova uid/gid is not known in this context).\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"\\\\n    def __init__(self, statedir, upgrade_marker=\'upgrade_marker\',\\\\n                 nova_user=\'nova\', secontext_marker=\'../_nova_secontext\',\\\\n                 exclude_paths=None):\\\\n        self.statedir = statedir\\\\n        self.nova_user = nova_user\\\\n\\\\n        self.upgrade_marker_path = os.path.join(statedir, upgrade_marker)\\\\n        self.secontext_marker_path = os.path.normpath(os.path.join(statedir, secontext_marker))\\\\n        self.upgrade = os.path.exists(self.upgrade_marker_path)\\\\n\\\\n        self.exclude_paths = [self.upgrade_marker_path]\\\\n        if exclude_paths is not None:\\\\n            for p in exclude_paths:\\\\n                if not p.startswith(os.path.sep):\\\\n                    p = os.path.join(self.statedir, p)\\\\n                self.exclude_paths.append(p)\\\\n\\\\n        self.target_uid, self.target_gid = self._get_nova_ids()\\\\n        self.previous_uid, self.previous_gid = self._get_previous_nova_ids()\\\\n        self.id_change = (self.target_uid, self.target_gid) != \\\\\\\\\\\\n            (self.previous_uid, self.previous_gid)\\\\n        self.target_secontext = self._get_secontext()\\\\n\\\\n    def _get_nova_ids(self):\\\\n        nova_uid, nova_gid = pwd.getpwnam(self.nova_user)[2:4]\\\\n        return nova_uid, nova_gid\\\\n\\\\n    def _get_previous_nova_ids(self):\\\\n        if self.upgrade:\\\\n            statinfo = os.stat(self.upgrade_marker_path)\\\\n            return statinfo.st_uid, statinfo.st_gid\\\\n        else:\\\\n            return self._get_nova_ids()\\\\n\\\\n    def _get_secontext(self):\\\\n        if os.path.exists(self.secontext_marker_path):\\\\n            return selinux.lgetfilecon(self.secontext_marker_path)[1]\\\\n        else:\\\\n            return None\\\\n\\\\n    def _walk(self, top, chcon=True):\\\\n        for f in os.listdir(top):\\\\n            pathname = os.path.join(top, f)\\\\n\\\\n            if pathname in self.exclude_paths:\\\\n                continue\\\\n\\\\n            try:\\\\n                pathinfo = PathManager(pathname)\\\\n                LOG.info(\\\\\\\"Checking %s\\\\\\\", pathinfo)\\\\n                if pathinfo.is_dir:\\\\n                    # Always chown the directories\\\\n                    pathinfo.chown(self.target_uid, self.target_gid)\\\\n                    chcon_r = chcon\\\\n                    if chcon:\\\\n                        chcon_r = pathinfo.chcon(self.target_secontext)\\\\n                    self._walk(pathname, chcon_r)\\\\n                elif self.id_change:\\\\n                    # Only chown files if it\'s an upgrade and the file is owned by\\\\n                    # the host nova uid/gid\\\\n                    pathinfo.chown(\\\\n                        self.target_uid if pathinfo.uid == self.previous_uid\\\\n                        else pathinfo.uid,\\\\n                        self.target_gid if pathinfo.gid == self.previous_gid\\\\n                        else pathinfo.gid\\\\n                    )\\\\n                    if chcon:\\\\n                        pathinfo.chcon(self.target_secontext)\\\\n            except Exception:\\\\n                # Likely to have been caused by external systems\\\\n                # interacting with this directory tree,\\\\n                # especially on NFS e.g snapshot dirs.\\\\n                # Just ignore it and continue on to the next entry\\\\n                continue\\\\n\\\\n    def run(self):\\\\n        LOG.info(\'Applying nova statedir ownership\')\\\\n        LOG.info(\'Target ownership for %s: %d:%d\',\\\\n                 self.statedir,\\\\n                 self.target_uid,\\\\n                 self.target_gid)\\\\n\\\\n        pathinfo = PathManager(self.statedir)\\\\n        LOG.info(\\\\\\\"Checking %s\\\\\\\", pathinfo)\\\\n        pathinfo.chown(self.target_uid, self.target_gid)\\\\n        chcon = self.target_secontext is not None\\\\n\\\\n        if chcon:\\\\n            pathinfo.chcon(self.target_secontext)\\\\n\\\\n        self._walk(self.statedir, chcon)\\\\n\\\\n        if self.upgrade:\\\\n            LOG.info(\'Removing upgrade_marker %s\',\\\\n                     self.upgrade_marker_path)\\\\n            os.unlink(self.upgrade_marker_path)\\\\n\\\\n        LOG.info(\'Nova statedir ownership complete\')\\\\n\\\\n\\\\ndef get_exclude_paths():\\\\n    exclude_paths = os.environ.get(\'NOVA_STATEDIR_OWNERSHIP_SKIP\')\\\\n    if exclude_paths is not None:\\\\n        exclude_paths = exclude_paths.split(os.pathsep)\\\\n    return exclude_paths\\\\n\\\\n\\\\nif __name__ == \'__main__\':\\\\n    NovaStatedirOwnershipManager(\'/var/lib/nova\', exclude_paths=get_exclude_paths()).run()\\\\n\\\"}, \\\"nova_wait_for_compute_service.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\nimport argparse\\\\nimport logging\\\\nimport os\\\\nimport six\\\\nimport socket\\\\nimport sys\\\\nimport time\\\\n\\\\n\\\\nfrom keystoneauth1 import loading\\\\nfrom keystoneauth1 import session\\\\n\\\\nfrom novaclient import client\\\\n\\\\n# In python3 SafeConfigParser was renamed to ConfigParser and the default\\\\n# for duplicate options default to true. In case of nova it is valid to\\\\n# have duplicate option lines, e.g. passthrough_whitelist which leads to\\\\n# issues reading the nova.conf\\\\n# https://bugs.launchpad.net/tripleo/+bug/1827775\\\\nif six.PY3:\\\\n    from six.moves.configparser import ConfigParser\\\\n    config = ConfigParser(strict=False)\\\\nelse:\\\\n    from six.moves.configparser import SafeConfigParser\\\\n    config = SafeConfigParser()\\\\n\\\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\\\n\\\\nif debug.lower() == \'true\':\\\\n    loglevel = logging.DEBUG\\\\nelse:\\\\n    loglevel = logging.INFO\\\\n\\\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\\\nLOG = logging.getLogger(\'nova_wait_for_compute_service\')\\\\n\\\\niterations = 60\\\\ntimeout = 10\\\\nnova_cfg = \'/etc/nova/nova.conf\'\\\\n\\\\nif __name__ == \'__main__\':\\\\n    parser = argparse.ArgumentParser(usage=\'%(prog)s [options]\')\\\\n    parser.add_argument(\'-k\', \'--insecure\',\\\\n                        action=\\\\\\\"store_false\\\\\\\",\\\\n                        dest=\'insecure\',\\\\n                        default=True,\\\\n                        help=\'Allow insecure connection when using SSL\')\\\\n\\\\n    args = parser.parse_args()\\\\n    LOG.debug(\'Running with parameter insecure = %s\',\\\\n              args.insecure)\\\\n\\\\n    if os.path.isfile(nova_cfg):\\\\n        try:\\\\n            config.read(nova_cfg)\\\\n        except Exception:\\\\n            LOG.exception(\'Error while reading nova.conf:\')\\\\n    else:\\\\n        LOG.error(\'Nova configuration file %s does not exist\', nova_cfg)\\\\n        sys.exit(1)\\\\n\\\\n    my_host = config.get(\'DEFAULT\', \'host\')\\\\n    if not my_host:\\\\n        # If host isn\'t set nova defaults to this\\\\n        my_host = socket.gethostname()\\\\n\\\\n    loader = loading.get_plugin_loader(\'password\')\\\\n    auth = loader.load_from_options(\\\\n        auth_url=config.get(\'neutron\',\\\\n                            \'auth_url\'),\\\\n        username=config.get(\'neutron\',\\\\n                            \'username\'),\\\\n        password=config.get(\'neutron\',\\\\n                            \'password\'),\\\\n        project_name=config.get(\'neutron\',\\\\n                                \'project_name\'),\\\\n        project_domain_name=config.get(\'neutron\',\\\\n                                       \'project_domain_name\'),\\\\n        user_domain_name=config.get(\'neutron\',\\\\n                                    \'user_domain_name\'))\\\\n    sess = session.Session(auth=auth, verify=args.insecure)\\\\n    nova = client.Client(\'2.11\', session=sess, endpoint_type=\'internal\',\\\\n                         region_name=config.get(\'neutron\', \'region_name\'))\\\\n\\\\n    # Wait until this host is listed in the service list\\\\n    for i in range(iterations):\\\\n        try:\\\\n            service_list = nova.services.list(binary=\'nova-compute\')\\\\n            for entry in service_list:\\\\n                host = getattr(entry, \'host\', \'\')\\\\n                zone = getattr(entry, \'zone\', \'\')\\\\n                if host == my_host and zone != \'internal\':\\\\n                    LOG.info(\'Nova-compute service registered\')\\\\n                    sys.exit(0)\\\\n            LOG.info(\'Waiting for nova-compute service to register\')\\\\n        except Exception:\\\\n            LOG.exception(\\\\n                \'Error while waiting for nova-compute service to register\')\\\\n        time.sleep(timeout)\\\\nsys.exit(1)\\\\n\\\\n# vim: set et ts=4 sw=4 :\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"nova_compute_init_log\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/nova:/var/log/nova:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R nova:nova /var/log/nova\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781509833\\\"}}}, \\\"step_3\\\": {\\\"nova_statedir_owner\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"privileged\\\": false, \\\"detach\\\": false, \\\"volumes\\\": [\\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts:z\\\"], \\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\\\", \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781509833\\\", \\\"__OS_DEBUG\\\": \\\"true\\\", \\\"NOVA_STATEDIR_OWNERSHIP_SKIP\\\": \\\"triliovault-mounts\\\"}}}, \\\"step_5\\\": {\\\"nova_compute\\\": {\\\"start_order\\\": 3, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"memlock=67108864\\\"], \\\"ipc\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"nova\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_libvirt.target\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck 5672\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/nova:/var/log/nova\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/dev:/dev\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/run/nova:/run/nova:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/sys/class/net:/sys/class/net\\\", \\\"/sys/bus/pci:/sys/bus/pci\\\", \\\"/boot:/boot:ro\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"LIBGUESTFS_BACKEND\\\": \\\"direct\\\"}}, \\\"nova_wait_for_compute_service\\\": {\\\"start_order\\\": 4, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/nova:/var/log/nova\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts\\\"], \\\"user\\\": \\\"nova\\\", \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"__OS_DEBUG\\\": \\\"true\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/nova\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"Check for /var/lib/nova/instances directory exitance\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/nova/instances\\\"}, \\\"register\\\": \\\"check_nova_instances_result\\\"}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/_nova_secontext\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/nova/instances\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/tmpfiles.d\\\"}]}, {\\\"name\\\": \\\"ensure /run/nova is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-nova.conf\\\", \\\"content\\\": \\\"d /run/nova 0777 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"create tempfiles\\\", \\\"command\\\": \\\"systemd-tmpfiles --create\\\"}, {\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\"}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}, {\\\"name\\\": \\\"delay installation of systemd-container\\\", \\\"when\\\": \\\"check_nova_instances_result.stat.exists\\\", \\\"block\\\": [{\\\"name\\\": \\\"check systemd-container package installed or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"get latest package from downloaded package versions\\\", \\\"shell\\\": \\\"ls -1t /var/tmp/systemd-container* | head -1\\\", \\\"register\\\": \\\"latest_systemd_container_package\\\", \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"], \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Install systemd-container package on boot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Install systemd container package on system boot\\\\nBefore=tripleo_nova_virtqemud.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\\\nExecStartPost=rm -f /var/tmp/systemd-container*\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": [\\\"latest_systemd_container_package is defined\\\", \\\"(\'stdout\' in latest_systemd_container_package)\\\", \\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"enable install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"check if install-systemd-container service exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\"}, \\\"register\\\": \\\"install_systemd_container_result\\\"}, {\\\"name\\\": \\\"disable and mask install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"not is_systemd_container_package.changed\\\", \\\"install_systemd_container_result.stat.exists\\\"]}]}, {\\\"name\\\": \\\"is Nova Resume Guests State On Host Boot enabled\\\", \\\"set_fact\\\": {\\\"resume_guests_state_on_host_boot_enabled\\\": false}}, {\\\"name\\\": \\\"install libvirt-guests systemd unit file (docker)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'docker\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/libvirt-guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend/Resume Running libvirt Guests\\\\nAfter=network.target\\\\nAfter=time-sync.target\\\\nAfter=virt-guest-shutdown.target\\\\nAfter=docker.service\\\\nAfter=tripleo-container-shutdown.service\\\\nAfter=rhel-push-plugin.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\\\n# Hack just call traditional service until we factor\\\\n# out the code\\\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\\\nExecStop=/bin/{{container_cli}} stop nova_compute\\\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"libvirt-guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"libvirt-guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"install tripleo_nova_libvirt_guests systemd unit file (podman)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'podman\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt_guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Do we prepend nova startup with a delay\\\", \\\"set_fact\\\": {\\\"nova_compute_delay\\\": 0}}, {\\\"name\\\": \\\"install nova-compute delay wrapper script\\\", \\\"copy\\\": {\\\"content\\\": \\\"#!/usr/libexec/platform-python\\\\n\\\\\\\"\\\\\\\"\\\\\\\"\\\\nThis wrapper was created to add an optional delay to the startup of nova-compute.\\\\nWe know that instances will fail to boot, after a compute reboot, if ceph is not\\\\nhealthy.\\\\n\\\\nIdeally, we would poll ceph to get its health, but it\'s not guaranteed that the\\\\ncompute node will have access to the keys.\\\\n\\\\\\\"\\\\\\\"\\\\\\\"\\\\n\\\\nimport os\\\\nimport sys\\\\nimport time\\\\nimport logging\\\\nimport argparse\\\\n\\\\nparser = argparse.ArgumentParser(description=\'Process some integers.\')\\\\nparser.add_argument(\'--config-file\', dest=\'nova_config\', action=\'store\',\\\\n                    default=\\\\\\\"/etc/nova/nova.conf\\\\\\\",\\\\n                    help=\'path to nova configuration (default: /etc/nova/nova.conf)\')\\\\nparser.add_argument(\'--nova-binary\', dest=\'nova_binary\', action=\'store\',\\\\n                    default=\\\\\\\"/usr/bin/nova-compute\\\\\\\",\\\\n                    help=\'path to nova compute binary (default: /usr/bin/nova-compute)\')\\\\nparser.add_argument(\'--delay\', dest=\'delay\', action=\'store\',\\\\n                    default=120, type=int,\\\\n                    help=\'Number of seconds to wait until nova-compute is started\')\\\\nparser.add_argument(\'--state-dir\', dest=\'state_dir\', action=\'store\',\\\\n                    default=\\\\\\\"/run/nova/startup\\\\\\\", help=\'state-file directory\')\\\\nparser.add_argument(\'--state-file\', dest=\'state_file\', action=\'store\',\\\\n                    default=\\\\\\\"nova-compute-delayed\\\\\\\",\\\\n                    help=\'file exists if we already delayed nova-compute startup\')\\\\n\\\\n\\\\nsections = {}\\\\n(args, remaining) = parser.parse_known_args(sys.argv)\\\\n\\\\nreal_args = [args.nova_binary, \'--config-file\', args.nova_config]\\\\nreal_args.extend(remaining[1:])\\\\n\\\\nif not os.path.isdir(args.state_dir):\\\\n  os.makedirs(args.state_dir, mode = 0o751)\\\\n\\\\nstate_file_name = os.path.join(args.state_dir, args.state_file)\\\\n\\\\nif not os.path.isfile(state_file_name):\\\\n    logging.info(\\\\\\\"Delaying nova-compute startup by %s seconds\\\\\\\" % args.delay)\\\\n    time.sleep(args.delay)\\\\n    open(state_file_name, \'a\').close()\\\\n\\\\nlogging.info(\\\\\\\"Executing %s\\\\\\\" % real_args)\\\\nos.execv(args.nova_binary, real_args)\\\\n\\\", \\\"dest\\\": \\\"/var/lib/nova/delay-nova-compute\\\", \\\"mode\\\": 493}, \\\"when\\\": \\\"nova_compute_delay|int > 0\\\"}, {\\\"name\\\": \\\"Is irqbalance enabled\\\", \\\"set_fact\\\": {\\\"compute_irqbalance_disabled\\\": false}}, {\\\"name\\\": \\\"disable irqbalance service on compute\\\", \\\"when\\\": \\\"compute_irqbalance_disabled|bool\\\", \\\"service\\\": {\\\"name\\\": \\\"irqbalance.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"install systemd-container for a greenfield\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"not check_nova_instances_result.stat.exists\\\"], \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"validate nova-compute container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_compute\\\"}, \\\"register\\\": \\\"nova_compute_infos\\\", \\\"failed_when\\\": [\\\"nova_compute_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 6\\\"]}, {\\\"name\\\": \\\"manage PMEM namespaces for vPMEM\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_nvdimm\\\"}, \\\"vars\\\": {\\\"tripleo_nvdimm_pmem_namespaces\\\": \\\"\\\"}, \\\"when\\\": [\\\"step|int == 1\\\", \\\"tripleo_nvdimm_pmem_namespaces != \'\'\\\"]}, {\\\"name\\\": \\\"manage OS version 9 specific sysctls\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"ansible_facts[\'os_family\'] == \'RedHat\'\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Enable post-copy by setting unprivileged_userfaultfd\\\", \\\"sysctl\\\": {\\\"name\\\": \\\"vm.unprivileged_userfaultfd\\\", \\\"value\\\": 1, \\\"sysctl_set\\\": true, \\\"sysctl_file\\\": \\\"/etc/sysctl.d/99-tripleo-postcopy.conf\\\", \\\"state\\\": \\\"present\\\", \\\"reload\\\": true}}]}, {\\\"name\\\": \\\"enable/disable ksm\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"is KSM enabled\\\", \\\"set_fact\\\": {\\\"compute_ksm_enabled\\\": false}}, {\\\"name\\\": \\\"disable KSM on compute\\\", \\\"when\\\": \\\"not compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for ksm\\\", \\\"shell\\\": \\\"systemctl is-active ksm.service || systemctl is-enabled ksm.service\\\", \\\"become\\\": true, \\\"failed_when\\\": false, \\\"register\\\": \\\"ksm_service_check\\\"}, {\\\"name\\\": \\\"disable KSM services\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"], \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\"], \\\"register\\\": \\\"ksmdisabled\\\"}, {\\\"name\\\": \\\"delete PageKSM after disable ksm on compute\\\", \\\"command\\\": \\\"echo 2 >/sys/kernel/mm/ksm/run\\\", \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\", \\\"ksmdisabled is changed\\\"]}]}, {\\\"name\\\": \\\"enable KSM on compute\\\", \\\"when\\\": \\\"compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\\\", \\\"package\\\": {\\\"name\\\": \\\"qemu-kvm-common\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"]}, {\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\\\", \\\"package\\\": {\\\"name\\\": \\\"ksmtuned\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"]}, {\\\"name\\\": \\\"enable ksmtunded\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"started\\\", \\\"enabled\\\": true}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"]}]}]}], \\\"external_post_deploy_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"is additonal Cell?\\\", \\\"set_fact\\\": {\\\"nova_additional_cell\\\": false}}, {\\\"name\\\": \\\"check if discover hosts is required\\\", \\\"when\\\": [\\\"not nova_additional_cell|bool\\\", \\\"nova_cellv2_discovery_done is not defined\\\"], \\\"block\\\": [{\\\"name\\\": \\\"discover via nova_manager?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_manager\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_manager\\\"}, \\\"when\\\": [\\\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\\\"]}, {\\\"name\\\": \\\"discover via nova_api?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_api\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_api\\\"}, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\", \\\"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\\\"]}, {\\\"name\\\": \\\"Warn if no discovery host available\\\", \\\"fail\\\": {\\\"msg\\\": \\\"No hosts available to run nova cell_v2 host discovery.\\\"}, \\\"ignore_errors\\\": true, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\"]}, {\\\"name\\\": \\\"Discovering nova hosts\\\", \\\"command\\\": \\\"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\\\", \\\"become\\\": true, \\\"changed_when\\\": false, \\\"delegate_to\\\": \\\"{{ nova_cellv2_discovery_delegate_host }}\\\", \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is defined\\\"]}, {\\\"set_fact\\\": {\\\"nova_cellv2_discovery_done\\\": true}}]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}, {\\\"name\\\": \\\"nova_compute pre system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Unmount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"absent\\\", \\\"fstype\\\": \\\"nfs4\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}, {\\\"name\\\": \\\"nova_compute post system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 5\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\"}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": \\\"overcloud\\\"}, \\\"block\\\": [{\\\"name\\\": \\\"Get nova-compute service ID\\\", \\\"command\\\": \\\"openstack compute service list --service nova-compute --column ID --column Host --format yaml\\\", \\\"register\\\": \\\"nova_compute_service_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"is additional Cell?\\\", \\\"set_fact\\\": {\\\"is_additional_cell\\\": false}}, {\\\"name\\\": \\\"Set fact for nova_compute services\\\", \\\"set_fact\\\": {\\\"nova_compute_service\\\": \\\"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Check search output\\\", \\\"fail\\\": {\\\"msg\\\": \\\"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\\\"}, \\\"when\\\": [\\\"(nova_compute_service | length) > 1\\\"]}, {\\\"name\\\": \\\"Disable nova services\\\", \\\"when\\\": [\\\"(nova_compute_service | length) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable nova-compute service\\\", \\\"command\\\": \\\"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"when\\\": [\\\"not is_additional_cell|bool\\\"]}, {\\\"name\\\": \\\"Stop nova-compute container\\\", \\\"service\\\": {\\\"name\\\": \\\"tripleo_nova_compute\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_nova_compute\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete nova-compute service\\\", \\\"command\\\": \\\"openstack compute service delete {{ nova_compute_service[0].ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}, {\\\"service_name\\\": \\\"nova_libvirt\\\", \\\"firewall_rules\\\": {\\\"200 nova_libvirt\\\": {\\\"dport\\\": [16514, \\\"61152-61215\\\", \\\"5900-6923\\\"]}}, \\\"ansible_group_vars\\\": {\\\"tripleo_nova_libvirt_virsh_container\\\": \\\"nova_virtproxyd\\\"}, \\\"monitoring_subscription\\\": \\\"overcloud-nova-libvirt\\\", \\\"config_settings\\\": {\\\"nova::my_ip\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::rabbit_use_ssl\\\": \\\"True\\\", \\\"nova::keystone::service_user::send_service_user_token\\\": true, \\\"nova::keystone::service_user::project_name\\\": \\\"service\\\", \\\"nova::keystone::service_user::password\\\": \\\"eljGPqsTubd1MRdmVjF5MppaC\\\", \\\"nova::keystone::service_user::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::keystone::service_user::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::project_name\\\": \\\"service\\\", \\\"nova::placement::password\\\": \\\"9ppduM3vEiUPQ7DOtXGTm17h0\\\", \\\"nova::placement::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::placement::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::valid_interfaces\\\": \\\"internal\\\", \\\"nova::os_region_name\\\": \\\"regionOne\\\", \\\"nova::logging::debug\\\": true, \\\"nova::purge_config\\\": false, \\\"nova::network::neutron::project_name\\\": \\\"service\\\", \\\"nova::network::neutron::username\\\": \\\"neutron\\\", \\\"nova::network::neutron::region_name\\\": \\\"regionOne\\\", \\\"nova::dhcp_domain\\\": \\\"\\\", \\\"nova::network::neutron::password\\\": \\\"OorljNRFSWJ6uLOrYiwbnwsqY\\\", \\\"nova::network::neutron::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::network::neutron::valid_interfaces\\\": \\\"internal\\\", \\\"nova::glance::valid_interfaces\\\": \\\"internal\\\", \\\"nova::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"nova::cinder_catalog_info\\\": \\\"volumev3:cinderv3:internalURL\\\", \\\"nova::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"nova::notify_on_state_change\\\": \\\"vm_and_task_state\\\", \\\"nova::notification_driver\\\": [\\\"noop\\\"], \\\"nova::notification_format\\\": \\\"unversioned\\\", \\\"nova::network::neutron::auth_type\\\": \\\"v3password\\\", \\\"nova::db::database_db_max_retries\\\": -1, \\\"nova::db::database_max_retries\\\": -1, \\\"nova::network::neutron::ovs_bridge\\\": \\\"br-int\\\", \\\"nova::compute::sync_power_state_interval\\\": 600, \\\"nova_is_additional_cell\\\": false, \\\"nova::cross_az_attach\\\": true, \\\"nova::cache::enabled\\\": true, \\\"nova::cache::tls_enabled\\\": true, \\\"nova::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"nova::rabbit_heartbeat_in_pthread\\\": false, \\\"nova::ovsdb_connection\\\": \\\"\\\", \\\"vhostuser_socket_group\\\": \\\"qemu\\\", \\\"nova_libvirt_opt_volumes\\\": [], \\\"ContainerNovaLibvirtImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"nova::compute::libvirt::log_outputs\\\": \\\"1:file:/var/log/libvirt/libvirtd.log\\\", \\\"nova::compute::libvirt::virtlogd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtlogd.log\\\", \\\"nova::compute::libvirt::virtsecretd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtsecretd.log\\\", \\\"nova::compute::libvirt::virtnodedevd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtnodedevd.log\\\", \\\"nova::compute::libvirt::virtqemud::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtqemud.log\\\", \\\"nova::compute::libvirt::virtproxyd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtproxyd.log\\\", \\\"nova::compute::libvirt::virtstoraged::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtstoraged.log\\\", \\\"nova::compute::libvirt::qemu::memory_backing_dir\\\": \\\"\\\", \\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\\\": true, \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\\\": \\\"/var/lib/container-config-scripts/virtlogd_wrapper\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::debug\\\": true, \\\"nova::compute::libvirt::migration_support\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": \\\"/etc/ceph/ceph.conf\\\", \\\"nova::compute::rbd::libvirt_rbd_user\\\": \\\"openstack\\\", \\\"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"nova::compute::rbd::rbd_keyring\\\": \\\"client.openstack\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": \\\"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": \\\"3740e1ef-a43e-4451-a74a-f194469d07d9\\\", \\\"tripleo::profile::base::nova::migration::client::libvirt_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": 2022, \\\"nova::compute::libvirt::services::libvirt_virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::enabled_perf_events\\\": [], \\\"nova::compute::libvirt::qemu::configure_qemu\\\": true, \\\"nova::compute::libvirt::qemu::max_files\\\": 32768, \\\"nova::compute::libvirt::qemu::max_processes\\\": 131072, \\\"nova::migration::qemu::configure_qemu\\\": true, \\\"nova::migration::qemu::migration_port_min\\\": 61152, \\\"nova::migration::qemu::migration_port_max\\\": 61215, \\\"nova::compute::libvirt::vncserver_listen\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::compute::libvirt::log_filters\\\": \\\"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\\\", \\\"nova::compute::libvirt::virtlogd::log_filters\\\": \\\"1:logging 4:object 4:json 4:event 1:util\\\", \\\"rbd_persistent_storage\\\": false, \\\"rbd_disk_cachemodes\\\": [\\\"network=writeback\\\"], \\\"nova::compute::libvirt::virtsecretd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtnodedevd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtstoraged::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtqemud::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtproxyd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"tripleo::profile::base::nova::libvirt::modular_libvirt\\\": true, \\\"nova::compute::libvirt::services::modular_libvirt\\\": true, \\\"nova::compute::libvirt::modular_libvirt\\\": true, \\\"nova::migration::libvirt::modular_libvirt\\\": true, \\\"tripleo::profile::base::nova::migration::client::libvirt_tls\\\": true, \\\"tripleo::profile::base::nova::libvirt::tls_password\\\": \\\"5ddvoJoZfFm0QTmzFPr7SuD7p\\\", \\\"nova::compute::libvirt::qemu::default_tls_verify\\\": true, \\\"nova::compute::libvirt::tls_priority\\\": \\\"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\\\", \\\"nova::migration::libvirt::listen_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::migration::libvirt::live_migration_inbound_addr\\\": \\\"%{hiera(\'fqdn_internal_api\')}\\\", \\\"nova::compute::libvirt::qemu::vnc_tls\\\": true, \\\"nova::compute::libvirt::qemu::vnc_tls_verify\\\": true, \\\"nova::compute::libvirt::qemu::nbd_tls\\\": true, \\\"nova::migration::libvirt::live_migration_with_native_tls\\\": true}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::libvirt\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_virtlogd.json\\\": {\\\"command\\\": \\\"/usr/local/bin/virtlogd_wrapper\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtsecretd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtnodedevd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtstoraged.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtqemud.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtproxyd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}}, \\\"container_config_scripts\\\": {\\\"nova_libvirt_init_secret.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -e\\\\n\\\\nCEPH_INFO=($*)\\\\n\\\\nif [ -z \\\\\\\"$CEPH_INFO\\\\\\\" ]; then\\\\n    echo \\\\\\\"error: At least one CLUSTER:CLIENT tuple must be specified\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\necho \\\\\\\"------------------------------------------------\\\\\\\"\\\\necho \\\\\\\"Initializing virsh secrets for: ${CEPH_INFO[@]}\\\\\\\"\\\\n\\\\nfor INFO in ${CEPH_INFO[@]}; do\\\\n    IFS=: read CLUSTER CLIENT <<< $INFO\\\\n    if [ ! -f /etc/ceph/${CLUSTER}.conf ]; then\\\\n        echo \\\\\\\"Error: /etc/ceph/${CLUSTER}.conf was not found\\\\\\\"\\\\n        echo \\\\\\\"Path to nova_libvirt_init_secret was ${CEPH_INFO}\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\n    FSID=$(awk \'$1 == \\\\\\\"fsid\\\\\\\" {print $3}\' /etc/ceph/${CLUSTER}.conf)\\\\n    if [ -z \\\\\\\"${FSID}\\\\\\\" ]; then\\\\n        echo \\\\\\\"Error: /etc/ceph/${CLUSTER}.conf contained an empty fsid definition\\\\\\\"\\\\n        echo \\\\\\\"Check your ceph configuration\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\n\\\\n    echo \\\\\\\"--------\\\\\\\"\\\\n    echo \\\\\\\"Initializing the virsh secret for \'$CLUSTER\' cluster ($FSID) \'$CLIENT\' client\\\\\\\"\\\\n\\\\n    # Ensure the secret XML file exists. Puppet should have created a secret.xml\\\\n    # file for the first cluster\'s secret, so detect when to use that file.\\\\n    if grep -q $FSID /etc/nova/secret.xml; then\\\\n        SECRET_FILE=\\\\\\\"/etc/nova/secret.xml\\\\\\\"\\\\n        SECRET_NAME=\\\\\\\"client.${CLIENT} secret\\\\\\\"\\\\n    else\\\\n        SECRET_FILE=\\\\\\\"/etc/nova/${CLUSTER}-secret.xml\\\\\\\"\\\\n        SECRET_NAME=\\\\\\\"${CLUSTER}.client.${CLIENT} secret\\\\\\\"\\\\n    fi\\\\n\\\\n    if [ ! -f $SECRET_FILE ]; then\\\\n        echo \\\\\\\"Creating $SECRET_FILE\\\\\\\"\\\\n        cat <<EOF > $SECRET_FILE\\\\n<secret ephemeral=\'no\' private=\'no\'>\\\\n  <usage type=\'ceph\'>\\\\n    <name>${SECRET_NAME}</name>\\\\n  </usage>\\\\n  <uuid>${FSID}</uuid>\\\\n</secret>\\\\nEOF\\\\n    else\\\\n        echo \\\\\\\"The $SECRET_FILE file already exists\\\\\\\"\\\\n    fi\\\\n\\\\n    # Ensure the libvirt secret is defined\\\\n    if /usr/bin/virsh secret-list | grep -q $FSID; then\\\\n        echo \\\\\\\"The virsh secret for $FSID has already been defined\\\\\\\"\\\\n    else\\\\n        /usr/bin/virsh secret-define --file $SECRET_FILE\\\\n    fi\\\\n\\\\n    # Fetch the key from the keyring and ensure the secret is set\\\\n    KEY=$(awk \'$1 == \\\\\\\"key\\\\\\\" {print $3}\' /etc/ceph/${CLUSTER}.client.${CLIENT}.keyring)\\\\n    if /usr/bin/virsh secret-get-value $FSID 2>/dev/null | grep -q $KEY; then\\\\n        echo \\\\\\\"The virsh secret for $FSID has already been set\\\\\\\"\\\\n    else\\\\n        /usr/bin/virsh secret-set-value --secret $FSID --base64 $KEY\\\\n    fi\\\\ndone\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"nova_virtqemud_init_logs\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R tss:tss /var/log/swtpm\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781509833\\\"}}, \\\"create_virtlogd_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::nova::virtlogd_wrapper\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781509833\\\"}}}, \\\"step_3\\\": {\\\"nova_virtlogd_wrapper\\\": {\\\"start_order\\\": 0, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"nova_virtsecretd\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtnodedevd\\\": {\\\"start_order\\\": 2, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtstoraged\\\": {\\\"start_order\\\": 3, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtqemud\\\": {\\\"start_order\\\": 4, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\\\"]}, \\\"nova_virtproxyd\\\": {\\\"start_order\\\": 5, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Ensure recovery of containerized virtqemud\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"become\\\": true, \\\"block\\\": [{\\\"name\\\": \\\"Create virtqemud recovery script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/libexec/recover_tripleo_nova_virtqemud.sh\\\", \\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/bin/bash\\\\npgrep -f /sbin/virtqemud\\\\n[ $? -eq 0 ] && exit 0\\\\nkill -9 $(cat /run/nova_virtqemud.pid)\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger service\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud\\\\nAfter=tripleo_nova_virtqemud.service\\\\nRequisite=tripleo_nova_virtqemud.service\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger timer\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\\\nPartOf=tripleo_nova_virtqemud.service\\\\n[Timer]\\\\nOnCalendar=*:5/10\\\\nOnActiveSec=120\\\\nOnUnitActiveSec=60\\\\nRandomizedDelaySec=1m\\\\n[Install]\\\\nWantedBy=timers.target\\\\n\\\"}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.service\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger timer\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.timer\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"register\\\": \\\"virtqemud_recover_timer_result\\\"}, {\\\"name\\\": \\\"Really enable virtqemud recovery trigger timer\\\", \\\"shell\\\": {\\\"cmd\\\": \\\"systemctl enable --now tripleo_nova_virtqemud_recover.timer\\\"}, \\\"when\\\": \\\"virtqemud_recover_timer_result.status.UnitFileState != \\\\\\\"enabled\\\\\\\"\\\"}]}, {\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create dirs for certificates and keys\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"directory\\\", \\\"serole\\\": \\\"object_r\\\", \\\"setype\\\": \\\"cert_t\\\", \\\"seuser\\\": \\\"system_u\\\"}, \\\"with_items\\\": [\\\"/etc/pki/libvirt\\\", \\\"/etc/pki/libvirt/private\\\", \\\"/etc/pki/qemu\\\"]}, {\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"libvirt-server-cert\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"libvirt/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/ipa/ca.crt /etc/pki/CA/cacert.pem\\\\nchown root:root /etc/pki/CA/cacert.pem\\\\nchmod 644 /etc/pki/CA/cacert.pem\\\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"libvirt-client-cert\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"libvirt/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-server-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"qemu/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp /etc/ipa/ca.crt /etc/pki/qemu/ca-cert.pem\\\\nchown root:root /etc/pki/qemu/ca-cert.pem\\\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\\\nchgrp qemu /etc/pki/qemu/server-*\\\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\\\nchmod 0640 /etc/pki/qemu/server-key.pem\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-client-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"qemu/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\\\nchgrp qemu /etc/pki/qemu/client-*\\\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\\\nchmod 0640 /etc/pki/qemu/client-key.pem\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}, {\\\"name\\\": \\\"Set up systemd target for libvirt services\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create systemd file\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt.target\\\", \\\"mode\\\": \\\"0644\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"content\\\": \\\"[Unit]\\\\nWants=tripleo_nova_virtsecretd.service\\\\nWants=tripleo_nova_virtnodedevd.service\\\\nWants=tripleo_nova_virtstoraged.service\\\\nWants=tripleo_nova_virtproxyd.service\\\\nWants=tripleo_nova_virtqemud.service\\\\nAfter=tripleo_nova_virtsecretd.service\\\\nAfter=tripleo_nova_virtnodedevd.service\\\\nAfter=tripleo_nova_virtstoraged.service\\\\nAfter=tripleo_nova_virtproxyd.service\\\\nAfter=tripleo_nova_virtqemud.service\\\\n\\\"}, \\\"become\\\": true, \\\"register\\\": \\\"libvirt_target_result\\\"}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt.target\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"become\\\": true, \\\"when\\\": \\\"libvirt_target_result.changed\\\"}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\", \\\"mode\\\": \\\"{{ item.mode | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/secrets\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/qemu\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/cache/libvirt\\\"}, {\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/run/libvirt\\\"}, {\\\"path\\\": \\\"/var/log/containers/libvirt/swtpm\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0770\\\"}]}, {\\\"name\\\": \\\"ensure qemu group is present on the host\\\", \\\"group\\\": {\\\"name\\\": \\\"qemu\\\", \\\"gid\\\": 107, \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"ensure qemu user is present on the host\\\", \\\"user\\\": {\\\"name\\\": \\\"qemu\\\", \\\"uid\\\": 107, \\\"group\\\": \\\"qemu\\\", \\\"state\\\": \\\"present\\\", \\\"shell\\\": \\\"/sbin/nologin\\\", \\\"comment\\\": \\\"qemu user\\\"}}, {\\\"name\\\": \\\"create directory for vhost-user sockets with qemu ownership\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/vhost_sockets\\\", \\\"state\\\": \\\"directory\\\", \\\"owner\\\": \\\"qemu\\\", \\\"group\\\": \\\"qemu\\\", \\\"setype\\\": \\\"virt_cache_t\\\", \\\"seuser\\\": \\\"system_u\\\"}}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"with_items\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": \\\"libvirt_installed.rc == 0\\\"}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"Enable os_enable_vtpm SELinux boolean for vTPM\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"os_enable_vtpm\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, [{\\\"name\\\": \\\"remove gnutls-qemu.config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/crypto-policies/local.d/gnutls-qemu.config\\\", \\\"state\\\": \\\"absent\\\"}, \\\"register\\\": \\\"update_gnutls_config\\\"}], {\\\"name\\\": \\\"update crypto policies\\\", \\\"command\\\": \\\"update-crypto-policies\\\", \\\"when\\\": \\\"update_gnutls_config.changed\\\"}], \\\"metadata_settings\\\": [{\\\"service\\\": \\\"libvirt\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"qemu\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"libvirt-vnc\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Fail if we are on RHEL8 as this is monolithic libvirt deployment\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\\\"}}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Get container virtlogd image\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"always\\\", \\\"set_fact\\\": {\\\"virtlogd_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}}, {\\\"name\\\": \\\"Force pull image novalibvirt\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ virtlogd_image }}\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Diff OS release in container image and baremetal\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\\\n\\\", \\\"args\\\": {\\\"executable\\\": \\\"/bin/bash\\\"}, \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_ubi_diff\\\"}, {\\\"name\\\": \\\"Fail if UBI of the container does not match RHEL of running host\\\", \\\"when\\\": [\\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"step|int == 1\\\", \\\"libvirt_ubi_diff.rc == 1\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"The host operating system versus container UBI does not match.\\\\n{{ libvirt_ubi_diff.stdout }}\\\\nMost likely container passed to NovaLibvirt was EL8 one.\\\\nYou have to pass the correct container for container-image-prepare.\\\\nIf you would continue all running workloads would get destroyed.\\\\n\\\"}}, {\\\"name\\\": \\\"Switch virtlogd image before system upgrade\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get running image version\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"old_virtlogd_image\\\"}, {\\\"name\\\": \\\"Switch running image to new image in wrapper script\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\\\n\\\", \\\"when\\\": [\\\"old_virtlogd_image.stdout != virtlogd_image\\\", \\\"old_virtlogd_image.stdout != \'\'\\\"]}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"check systemd-container package present or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\"}, {\\\"name\\\": \\\"download systemd-container package if not present\\\", \\\"yum\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\", \\\"download_only\\\": true, \\\"download_dir\\\": \\\"/var/tmp/\\\"}, \\\"when\\\": \\\"is_systemd_container_package.changed\\\"}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]}, {\\\"service_name\\\": \\\"nova_libvirt_guests\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\\\": false, \\\"nova::compute::libvirt_guests::shutdown_timeout\\\": \\\"300\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::compute::libvirt_guests\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}}, {\\\"service_name\\\": \\\"nova_migration_target\\\", \\\"firewall_rules\\\": {\\\"113 nova_migration_target accept libvirt subnet 172.17.0.0/24\\\": {\\\"source\\\": \\\"172.17.0.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 2022}, \\\"113 nova_migration_target accept api subnet 172.17.0.0/24\\\": {\\\"source\\\": \\\"172.17.0.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 2022}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::sshd::bannertext\\\": \\\"\\\", \\\"tripleo::profile::base::sshd::motd\\\": \\\"\\\", \\\"tripleo::profile::base::sshd::options\\\": {\\\"HostKey\\\": [\\\"/etc/ssh/ssh_host_rsa_key\\\", \\\"/etc/ssh/ssh_host_ecdsa_key\\\", \\\"/etc/ssh/ssh_host_ed25519_key\\\"], \\\"SyslogFacility\\\": \\\"AUTHPRIV\\\", \\\"AuthorizedKeysFile\\\": \\\".ssh/authorized_keys\\\", \\\"ChallengeResponseAuthentication\\\": \\\"no\\\", \\\"GSSAPIAuthentication\\\": \\\"no\\\", \\\"GSSAPICleanupCredentials\\\": \\\"no\\\", \\\"UsePAM\\\": \\\"yes\\\", \\\"UseDNS\\\": \\\"no\\\", \\\"PrintMotd\\\": \\\"no\\\", \\\"X11Forwarding\\\": \\\"yes\\\", \\\"AcceptEnv\\\": [\\\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\\\", \\\"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\\\", \\\"LC_IDENTIFICATION LC_ALL LANGUAGE\\\", \\\"XMODIFIERS\\\"], \\\"Subsystem\\\": \\\"sftp  /usr/libexec/openssh/sftp-server\\\"}, \\\"tripleo::profile::base::sshd::password_authentication\\\": \\\"yes\\\", \\\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\\\": [\\\"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\\\"], \\\"tripleo::profile::base::nova::migration::target::ssh_localaddrs\\\": [\\\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\\\", \\\"%{hiera(\'live_migration_ssh_inbound_addr\')}\\\"], \\\"live_migration_ssh_inbound_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"cold_migration_ssh_inbound_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::sshd::port\\\": [22]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::sshd\\\\ninclude tripleo::profile::base::nova::migration::target\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova-migration-target.json\\\": {\\\"command\\\": \\\"dumb-init --single-child -- /usr/sbin/sshd -D -p 2022\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/host-ssh/ssh_host_*_key\\\", \\\"dest\\\": \\\"/etc/ssh/\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0600\\\"}]}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"loop\\\": [{\\\"path\\\": \\\"/run/libvirt\\\", \\\"setype\\\": \\\"virt_var_run_t\\\"}]}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}], \\\"docker_config\\\": {\\\"step_4\\\": {\\\"nova_migration_target\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/ssh:/host-ssh:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"validate nova-migration-target container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_migration_target\\\"}, \\\"register\\\": \\\"nova_migration_target_infos\\\", \\\"failed_when\\\": [\\\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 5\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]}, {\\\"service_name\\\": \\\"logrotate_crond\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::logging::logrotate::maxsize\\\": \\\"10M\\\", \\\"tripleo::profile::base::logging::logrotate::rotation\\\": \\\"daily\\\", \\\"tripleo::profile::base::logging::logrotate::rotate\\\": \\\"14\\\", \\\"tripleo::profile::base::logging::logrotate::purge_after_days\\\": \\\"14\\\", \\\"tripleo::profile::base::logging::logrotate::dateext\\\": false}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"allow logrotate to read inside containers\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"logrotate_read_inside_containers\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"configure tmpwatch on the host\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Push script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"mode\\\": 493, \\\"content\\\": \\\"#!/bin/sh\\\\ntmpwatch --nodirs \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*err\\\\\\\" \\\\\\\\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\\\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\\\n\\\"}, \\\"vars\\\": {\\\"LogrotatePurgeAfterDays\\\": \\\"14\\\"}}, {\\\"name\\\": \\\"Insert cronjob in root crontab\\\", \\\"cron\\\": {\\\"name\\\": \\\"Remove old logs\\\", \\\"special_time\\\": \\\"daily\\\", \\\"user\\\": \\\"root\\\", \\\"job\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"crond\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::logrotate\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/logrotate-crond.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -s -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"logrotate_crond\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop logrotate container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"logrotate_crond\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}, {\\\"service_name\\\": \\\"podman\\\", \\\"config_settings\\\": {}, \\\"step_config\\\": \\\"\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Install and configure Podman\\\", \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, [{\\\"name\\\": \\\"Configure tripleo_container_manage to generate systemd drop-in dependencies\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/sysconfig/podman_drop_in\\\", \\\"content\\\": \\\"This file makes tripleo_container_manage generate additional systemd\\\\ndependencies for containers that have special\\\\nstart/stop ordering constraints. It ensures that\\\\nthose constraints are enforced on reboot/shutdown.\\\\n\\\"}}]], \\\"deploy_steps_tasks\\\": [{\\\"when\\\": [\\\"(step|int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"service_config_settings\\\": {}, \\\"workaround_upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"tags\\\": [\\\"setup_packages\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, {\\\"name\\\": \\\"Comment infra_image in container.conf\\\", \\\"lineinfile\\\": {\\\"dest\\\": \\\"/usr/share/containers/containers.conf\\\", \\\"regexp\\\": \\\"(?i)^(infra_image.*)\\\", \\\"line\\\": \\\"#\\\\\\\\1\\\", \\\"backrefs\\\": true, \\\"state\\\": \\\"present\\\"}, \\\"tags\\\": [\\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Force pre-fetch of container images\\\", \\\"when\\\": [\\\"(step|int) == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": \\\"Undercloud\\\"}}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": \\\"Undercloud\\\"}}]}, {\\\"service_name\\\": \\\"rsyslog\\\", \\\"config_settings\\\": {\\\"rsyslog::server::global_config\\\": {\\\"WorkDirectory\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": \\\"/var/lib/rsyslog\\\"}, \\\"MaxMessageSize\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": \\\"32k\\\"}}, \\\"rsyslog::confdir\\\": \\\"/etc/rsyslog.d\\\", \\\"rsyslog::package_name\\\": \\\"rsyslog\\\", \\\"rsyslog::package_version\\\": \\\"installed\\\", \\\"rsyslog::manage_package\\\": true, \\\"rsyslog::manage_confdir\\\": true, \\\"rsyslog::purge_config_files\\\": true, \\\"rsyslog::override_default_config\\\": true, \\\"rsyslog::config_file\\\": \\\"/etc/rsyslog.conf\\\", \\\"rsyslog::manage_service\\\": true, \\\"rsyslog::service_name\\\": \\\"rsyslog\\\", \\\"rsyslog::service_status\\\": \\\"running\\\", \\\"rsyslog::service_enabled\\\": true, \\\"rsyslog::external_service\\\": false, \\\"rsyslog::use_upstream_repo\\\": false, \\\"rsyslog::feature_packages\\\": [\\\"rsyslog-elasticsearch\\\", \\\"rsyslog-mmnormalize\\\"], \\\"rsyslog::global_config_priority\\\": 10, \\\"rsyslog::module_load_priority\\\": 20, \\\"rsyslog::input_priority\\\": 30, \\\"rsyslog::main_queue_priority\\\": 40, \\\"rsyslog::parser_priority\\\": 45, \\\"rsyslog::template_priority\\\": 50, \\\"rsyslog::filter_priority\\\": 55, \\\"rsyslog::action_priority\\\": 60, \\\"rsyslog::ruleset_priority\\\": 65, \\\"rsyslog::lookup_table_priority\\\": 70, \\\"rsyslog::legacy_config_priority\\\": 80, \\\"rsyslog::custom_priority\\\": 90, \\\"rsyslog::target_file\\\": \\\"50_openstack_logs.conf\\\", \\\"rsyslog::server::modules\\\": {\\\"imfile\\\": {}, \\\"omelasticsearch\\\": {}, \\\"omamqp1\\\": {}}, \\\"rsyslog::server::templates\\\": {\\\"rsyslog-node-index\\\": {\\\"type\\\": \\\"list\\\", \\\"list_descriptions\\\": [{\\\"constant\\\": {\\\"value\\\": \\\"%{hiera(\'fqdn_canonical\')}-\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"year\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"month\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"day\\\"}}]}, \\\"rsyslog-record\\\": {\\\"type\\\": \\\"list\\\", \\\"options\\\": {\\\"jsonf\\\": \\\"on\\\"}, \\\"list_descriptions\\\": [{\\\"property\\\": {\\\"outname\\\": \\\"@timestamp\\\", \\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"rfc3339\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"host\\\", \\\"name\\\": \\\"hostname\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"severity\\\", \\\"name\\\": \\\"syslogseverity\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"facility\\\", \\\"name\\\": \\\"syslogfacility-text\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"tag\\\", \\\"name\\\": \\\"syslogtag\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"source\\\", \\\"name\\\": \\\"app-name\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"message\\\", \\\"name\\\": \\\"msg\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"file\\\", \\\"name\\\": \\\"$!metadata!filename\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"cloud\\\", \\\"value\\\": \\\"overcloud.ooo.test\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"region\\\", \\\"value\\\": \\\"regionOne\\\", \\\"format\\\": \\\"jsonf\\\"}}]}}, \\\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\\\": \\\"on\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rsyslog\\\", \\\"puppet_tags\\\": \\\"rsyslog::generate_concat,concat::fragment\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::rsyslog\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rsyslog.json\\\": {\\\"command\\\": \\\"/usr/sbin/rsyslogd -n -iNONE\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"rsyslog\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:ro\\\", \\\"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\\\", \\\"/var/log:/var/log/host:ro\\\", \\\"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/log/containers/rsyslog\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}}, {\\\"name\\\": \\\"create persistent state directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/rsyslog.container\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}]}, {\\\"service_name\\\": \\\"snmp\\\", \\\"firewall_rules\\\": {\\\"124 snmp 192.168.122.0/24\\\": {\\\"dport\\\": 161, \\\"proto\\\": \\\"udp\\\", \\\"source\\\": \\\"192.168.122.0/24\\\"}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::snmp::snmpd_user\\\": \\\"ro_snmp_user\\\", \\\"tripleo::profile::base::snmp::snmpd_password\\\": \\\"89Vk5RNyVwiA8aj5GHvgz6wY\\\", \\\"snmp::agentaddress\\\": [\\\"udp:161\\\", \\\"udp6:[::1]:161\\\"], \\\"snmp::snmpd_options\\\": \\\"-LS0-5d\\\"}, \\\"step_config\\\": \\\"include tripleo::profile::base::snmp\\\\n\\\", \\\"upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check if snmpd is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet snmpd\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"snmpd_enabled_result\\\"}, {\\\"name\\\": \\\"Set fact snmpd_enabled\\\", \\\"set_fact\\\": {\\\"snmpd_enabled\\\": \\\"{{ snmpd_enabled_result.rc == 0 }}\\\"}}]}, {\\\"name\\\": \\\"Stop snmp service\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"snmpd_enabled|bool\\\"], \\\"service\\\": \\\"name=snmpd state=stopped\\\"}]}, {\\\"service_name\\\": \\\"sshd\\\", \\\"firewall_rules\\\": {\\\"003 accept ssh from all\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22, \\\"extras\\\": {\\\"ensure\\\": \\\"present\\\"}}}, \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_sshd\\\"}, \\\"vars\\\": {\\\"tripleo_sshd_server_options\\\": {\\\"HostKey\\\": [\\\"/etc/ssh/ssh_host_rsa_key\\\", \\\"/etc/ssh/ssh_host_ecdsa_key\\\", \\\"/etc/ssh/ssh_host_ed25519_key\\\"], \\\"SyslogFacility\\\": \\\"AUTHPRIV\\\", \\\"AuthorizedKeysFile\\\": \\\".ssh/authorized_keys\\\", \\\"ChallengeResponseAuthentication\\\": \\\"no\\\", \\\"GSSAPIAuthentication\\\": \\\"no\\\", \\\"GSSAPICleanupCredentials\\\": \\\"no\\\", \\\"UsePAM\\\": \\\"yes\\\", \\\"UseDNS\\\": \\\"no\\\", \\\"PrintMotd\\\": \\\"no\\\", \\\"X11Forwarding\\\": \\\"yes\\\", \\\"AcceptEnv\\\": [\\\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\\\", \\\"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\\\", \\\"LC_IDENTIFICATION LC_ALL LANGUAGE\\\", \\\"XMODIFIERS\\\"], \\\"Subsystem\\\": \\\"sftp  /usr/libexec/openssh/sftp-server\\\"}, \\\"tripleo_sshd_password_authentication\\\": \\\"yes\\\", \\\"tripleo_sshd_banner_enabled\\\": false, \\\"tripleo_sshd_banner_text\\\": \\\"\\\", \\\"tripleo_sshd_motd_enabled\\\": false, \\\"tripleo_sshd_message_of_the_day\\\": \\\"\\\"}}]}, {\\\"service_name\\\": \\\"chrony\\\", \\\"firewall_rules\\\": {\\\"105 ntp\\\": {\\\"dport\\\": 123, \\\"proto\\\": \\\"udp\\\"}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Check for NTP service\\\", \\\"shell\\\": \\\"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\\\", \\\"failed_when\\\": false, \\\"become\\\": true, \\\"register\\\": \\\"ntp_service_check\\\"}, {\\\"name\\\": \\\"Disable NTP before configuring Chrony\\\", \\\"service\\\": {\\\"name\\\": \\\"ntpd\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"when\\\": [\\\"ntp_service_check.rc is defined\\\", \\\"ntp_service_check.rc == 0\\\"]}, {\\\"name\\\": \\\"Install, Configure and Run Chrony\\\", \\\"include_role\\\": {\\\"name\\\": \\\"chrony\\\"}}, {\\\"name\\\": \\\"Force NTP sync\\\", \\\"command\\\": \\\"chronyc makestep\\\"}, {\\\"name\\\": \\\"Ensure system is NTP time synced\\\", \\\"command\\\": \\\"chronyc waitsync 30\\\"}], \\\"ansible_group_vars\\\": {\\\"chrony_role_action\\\": \\\"all\\\", \\\"chrony_ntp_servers\\\": [\\\"pool.ntp.org\\\"], \\\"chrony_ntp_pools\\\": [], \\\"chrony_global_server_settings\\\": \\\"iburst minpoll 6 maxpoll 10\\\", \\\"chrony_global_pool_settings\\\": \\\"iburst minpoll 6 maxpoll 10\\\", \\\"chrony_manage_package\\\": true, \\\"chrony_acl_rules\\\": [\\\"deny all\\\"]}}, {\\\"service_name\\\": \\\"timezone\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Run timezone role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_timezone\\\"}, \\\"vars\\\": {\\\"tripleo_timezone\\\": \\\"UTC\\\"}}]}, {\\\"service_name\\\": \\\"tripleo_firewall\\\", \\\"config_settings\\\": {\\\"tripleo::firewall::manage_firewall\\\": false, \\\"tripleo::firewall::purge_firewall_rules\\\": false}, \\\"ansible_group_vars\\\": {\\\"tripleo_nftables_debug\\\": true}, \\\"firewall_rules\\\": {\\\"003 accept ssh from ctlplane subnet 192.168.122.0/24\\\": {\\\"source\\\": \\\"192.168.122.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Notice - ctlplane subnet is set\\\", \\\"debug\\\": {\\\"msg\\\": \\\"CIDRs found in the ctlplane network tags.\\\\n\\\"}}], \\\"host_firewall_tasks\\\": [{\\\"name\\\": \\\"Run firewall role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_firewall\\\"}}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}, {\\\"when\\\": [\\\"(step | int) == 3\\\"], \\\"block\\\": [{\\\"name\\\": \\\"blank ipv6 rule before activating ipv6 firewall.\\\", \\\"shell\\\": \\\"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\\\", \\\"args\\\": {\\\"creates\\\": \\\"/etc/sysconfig/ip6tables.n-o-upgrade\\\"}}, {\\\"name\\\": \\\"cleanup unmanaged rules pushed by iptables-services\\\", \\\"shell\\\": \\\"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\n\\\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -d fe80::\\\\\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\"}]}]}, {\\\"service_name\\\": \\\"tripleo_packages\\\", \\\"config_settings\\\": {\\\"tripleo::packages::enable_install\\\": true}, \\\"step_config\\\": \\\"include ::tripleo::packages\\\\n\\\", \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Gather missing facts\\\", \\\"setup\\\": {\\\"gather_subset\\\": [\\\"!all\\\", \\\"!min\\\", \\\"distribution\\\"]}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"Set leapp facts\\\", \\\"set_fact\\\": {\\\"upgrade_leapp_enabled\\\": \\\"{{ _upgradeLeappEnabled | bool and\\\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\\\", \\\"upgrade_leapp_debug\\\": false, \\\"upgrade_leapp_devel_skip\\\": \\\"\\\", \\\"upgrade_leapp_command_options\\\": \\\"\\\", \\\"upgrade_leapp_reboot_timeout\\\": 3600, \\\"upgrade_leapp_post_reboot_delay\\\": 120}, \\\"vars\\\": {\\\"_upgradeLeappEnabled\\\": false}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"system_upgrade_prepare step 3\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappRepoInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Remove firewalld bindings\\\", \\\"package\\\": {\\\"name\\\": \\\"python3-firewall\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"install leapp\\\", \\\"package\\\": {\\\"name\\\": \\\"leapp-repository-openstack\\\", \\\"state\\\": \\\"latest\\\"}}, {\\\"name\\\": \\\"Run LeappInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Remove vdo\\\", \\\"package\\\": {\\\"name\\\": \\\"vdo\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"add packages into Leapp\'s to_remove file\\\", \\\"vars\\\": {\\\"pkg_to_remove\\\": []}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_remove\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_remove }}\\\"}, {\\\"name\\\": \\\"add packages into Leapp\'s to_install file\\\", \\\"vars\\\": {\\\"pkg_to_install\\\": []}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_install\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_install }}\\\"}, {\\\"name\\\": \\\"check sshd_config file\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\"}, \\\"register\\\": \\\"sshd_config_result\\\"}, {\\\"name\\\": \\\"add PermitRootLogin option for leapp\\\", \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\", \\\"regexp\\\": \\\"^(# *)?PermitRootLogin\\\", \\\"line\\\": \\\"PermitRootLogin without-password\\\"}}, {\\\"name\\\": \\\"Remove paunch-services\\\", \\\"package\\\": {\\\"name\\\": \\\"paunch-services\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"tripleo_container_manage reconfiguration\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_manage\\\", \\\"tasks_from\\\": \\\"shutdown.yml\\\"}}]}, {\\\"name\\\": \\\"system_upgrade_prepare step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\\\", \\\"vars\\\": {\\\"modules_to_unload\\\": []}, \\\"shell\\\": \\\"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\\\\\"{{ item }}\\\\\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\\\n\\\", \\\"loop\\\": \\\"{{ modules_to_unload }}\\\"}, {\\\"name\\\": \\\"Remove leapp actors to prevent them inhibiting the upgrade\\\", \\\"vars\\\": {\\\"actors_to_remove\\\": []}, \\\"command\\\": {\\\"cmd\\\": \\\"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\\\\\"{}\\\\\\\" +\\\"}, \\\"loop\\\": \\\"{{ actors_to_remove }}\\\"}, {\\\"name\\\": \\\"set leapp required answers\\\", \\\"shell\\\": \\\"leapp answer --add --section check_vdo.confirm=True\\\\n\\\"}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}, {\\\"name\\\": \\\"Keep nics with prefix in NICsPrefixesToUdev from renaming\\\", \\\"vars\\\": {\\\"nics_prefixes_to_keep\\\": []}, \\\"shell\\\": \\\"ip -j link show | \\\\\\\\ jq -r --arg prefix \\\\\\\"{{ item }}\\\\\\\" \'.[] |\\\\n  select((.ifname | startswith($prefix)) and\\\\n  (.ifname | test(\\\\\\\"^.*v[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*_[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*\\\\\\\\\\\\\\\\..*$\\\\\\\") | not)) |\\\\n  if .permaddr? then .address=.permaddr else . end |\\\\n  \\\\\\\"SUBSYSTEM==\\\\\\\\\\\\\\\"net\\\\\\\\\\\\\\\",ACTION==\\\\\\\\\\\\\\\"add\\\\\\\\\\\\\\\",DRIVERS==\\\\\\\\\\\\\\\"?*\\\\\\\\\\\\\\\",\\\\\\\" + \\\\\\\"NAME=\\\\\\\\\\\\\\\"\\\\\\\" + .ifname +\\\\\\\"\\\\\\\\\\\\\\\" ,ATTR{address}==\\\\\\\\\\\\\\\"\\\\\\\" + .address + \\\\\\\"\\\\\\\\\\\\\\\"\\\\\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\\\n\\\", \\\"loop\\\": \\\"{{ nics_prefixes_to_keep|list }}\\\"}, {\\\"name\\\": \\\"run leapp upgrade (download packages)\\\", \\\"shell\\\": \\\"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\\\n\\\", \\\"when\\\": \\\"upgrade_leapp_enabled\\\"}]}, {\\\"name\\\": \\\"system_upgrade_run step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_reboot\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\", \\\"\'Undercloud\' not in group_names\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappPreRebootCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Check that nova_libvirt is running\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"is_virtlogd_image_running\\\"}, {\\\"name\\\": \\\"Remove systemd files to disable them\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/{{ item }}\\\", \\\"state\\\": \\\"absent\\\"}, \\\"with_items\\\": [\\\"tripleo_nova_libvirt.service\\\", \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_libvirt.target\\\"], \\\"when\\\": \\\"is_virtlogd_image_running.stdout != \'\'\\\"}, {\\\"name\\\": \\\"reboot to perform the upgrade\\\", \\\"reboot\\\": {\\\"reboot_timeout\\\": \\\"{{upgrade_leapp_reboot_timeout}}\\\", \\\"test_command\\\": \\\"source /etc/os-release; [ \\\\\\\"${VERSION_ID%.*}\\\\\\\" -ge \\\\\\\"8\\\\\\\" ] && systemctl is-system-running | grep -qE \\\\\\\"running|degraded\\\\\\\" || exit 1\\\", \\\"post_reboot_delay\\\": \\\"{{ upgrade_leapp_post_reboot_delay }}\\\"}}, {\\\"name\\\": \\\"Set selinux back to enforcing after leapp reboot\\\", \\\"selinux\\\": {\\\"policy\\\": \\\"targeted\\\", \\\"state\\\": \\\"enforcing\\\"}}, {\\\"name\\\": \\\"Run LeappPostRebootCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}]}, {\\\"name\\\": \\\"Host packages setup step0\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Package and repo update tasks\\\", \\\"block\\\": [{\\\"name\\\": \\\"Run UpgradeInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\nif [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Run UpgradeInitCommonCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": []}, \\\"dnf\\\": {\\\"name\\\": \\\"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed\\\", \\\"package\\\": {\\\"name\\\": [\\\"jq\\\", \\\"lvm2\\\", \\\"openstack-selinux\\\", \\\"os-net-config\\\", \\\"puppet-tripleo\\\", \\\"python3-heat-agent*\\\", \\\"rsync\\\"], \\\"state\\\": \\\"present\\\"}, \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\\\", \\\"vars\\\": {\\\"base_tripleo_packages\\\": []}, \\\"package\\\": {\\\"name\\\": \\\"{{ base_tripleo_packages }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\", \\\"base_tripleo_packages|length > 0\\\"]}, {\\\"name\\\": \\\"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\\\", \\\"shell\\\": \\\"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\\\ndo\\\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\\\\\"signatures\\\\\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\\\ndone\\\\n\\\", \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}]}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"loop\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": [\\\"libvirt_installed.rc == 0\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step2\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_upgrade.changed|bool\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step3\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for os-net-config upgrade\\\", \\\"shell\\\": \\\"yum check-upgrade | awk \'/os-net-config/{print}\'\\\", \\\"register\\\": \\\"os_net_config_need_upgrade\\\"}, {\\\"name\\\": \\\"Check that os-net-config has legacy configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.json\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_json\\\"}, {\\\"name\\\": \\\"Check that os-net-config has new configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.yaml\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_yaml\\\"}, {\\\"name\\\": \\\"Slurp the os-net-config config.json\\\", \\\"slurp\\\": {\\\"src\\\": \\\"/etc/os-net-config/config.json\\\"}, \\\"register\\\": \\\"os_config_json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Write updated /etc/os-net-config/config.yaml\\\", \\\"copy\\\": {\\\"content\\\": \\\"{{ os_config_json.content | b64decode | from_json | to_yaml }}\\\", \\\"dest\\\": \\\"/etc/os-net-config/config.yaml\\\"}, \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Remove legacy os-net-config configuration\\\", \\\"command\\\": \\\"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\"]}, {\\\"block\\\": [{\\\"name\\\": \\\"Upgrade os-net-config\\\", \\\"package\\\": \\\"name=os-net-config state=latest\\\"}, {\\\"name\\\": \\\"take new os-net-config parameters into account now\\\", \\\"command\\\": \\\"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\\\", \\\"register\\\": \\\"os_net_config_upgrade\\\", \\\"failed_when\\\": \\\"os_net_config_upgrade.rc not in [0,2]\\\", \\\"changed_when\\\": \\\"os_net_config_upgrade.rc == 2\\\"}], \\\"when\\\": [\\\"os_net_config_need_upgrade.stdout\\\", \\\"stat_config_yaml.stat.exists or stat_config_json.stat.exists\\\"]}, {\\\"name\\\": \\\"Update all packages\\\", \\\"when\\\": [\\\"not skip_package_update|bool\\\"], \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}, \\\"vars\\\": {\\\"skip_package_update\\\": false}}, {\\\"name\\\": \\\"Check whether openvswitch exits\\\", \\\"command\\\": \\\"systemctl status openvswitch.service\\\", \\\"register\\\": \\\"ovs_service\\\", \\\"ignore_errors\\\": true}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_service.stderr != \\\\\\\"Unit openvswitch.service could not be found.\\\\\\\"\\\"]}]}], \\\"external_upgrade_tasks\\\": [{\\\"name\\\": \\\"Clean up upgrade artifacts\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_cleanup\\\"], \\\"block\\\": [{\\\"name\\\": \\\"cleanup tripleo_persist\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_persist\\\", \\\"tasks_from\\\": \\\"cleanup.yml\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Enforce RHOSP rules regarding subscription.\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_redhat_enforce\\\"}, \\\"vars\\\": {\\\"skip_rhel_enforcement\\\": false}, \\\"when\\\": [\\\"step|int == 0\\\", \\\"ansible_facts[\'distribution\'] == \'RedHat\'\\\", \\\"not (skip_rhel_enforcement | bool)\\\"]}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream enabled\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": []}, \\\"tripleo_dnf_stream\\\": {\\\"name\\\": \\\"{{ item.module }}:{{ item.stream }}\\\", \\\"state\\\": \\\"enabled\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Check for existing yum.pid\\\", \\\"stat\\\": \\\"path=/run/yum.pid\\\", \\\"register\\\": \\\"yum_pid_file\\\", \\\"when\\\": \\\"step|int == 0 or step|int == 3\\\"}, {\\\"name\\\": \\\"Exit if existing yum process\\\", \\\"fail\\\": \\\"msg=\\\\\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\\\\\"\\\", \\\"when\\\": \\\"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\\\"}, {\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"when\\\": [\\\"step|int == 2\\\"], \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"step|int == 2\\\", \\\"ovs_upgrade.changed|bool\\\"]}, {\\\"name\\\": \\\"Update packages and EFI grub.cfg\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"not skip_package_update|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update all packages\\\", \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}], \\\"vars\\\": {\\\"skip_package_update\\\": false}}, {\\\"name\\\": \\\"Ensure openvswitch is running after update\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"ignore_errors\\\": true}]}, {\\\"service_name\\\": \\\"tuned\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}}], \\\"ansible_group_vars\\\": {\\\"tuned_profile\\\": \\\"throughput-performance\\\", \\\"tuned_custom_profile\\\": \\\"\\\"}}, {\\\"service_name\\\": \\\"ovn_controller\\\", \\\"firewall_rules\\\": {\\\"118 neutron vxlan networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 4789, \\\"state\\\": []}, \\\"119 neutron geneve networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"state\\\": []}, \\\"120 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"OUTPUT\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}, \\\"121 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"PREROUTING\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}}, \\\"config_settings\\\": {\\\"ovn::controller::ovn_bridge_mappings\\\": [\\\"datacentre:br-ex\\\"], \\\"ovn::controller::ovn_cms_options\\\": \\\"\\\", \\\"ovn::controller::ovn_encap_tos\\\": \\\"0\\\", \\\"vswitch::ovs::enable_hw_offload\\\": false, \\\"container_cpuset_cpus\\\": \\\"\\\", \\\"ContainerOvnControllerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ContainerOvnControllerConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ovn::southbound::port\\\": 6642, \\\"ovn::controller::ovn_encap_ip\\\": \\\"%{hiera(\'tenant\')}\\\", \\\"ovn::controller::ovn_encap_type\\\": \\\"geneve\\\", \\\"ovn::controller::ovn_bridge\\\": \\\"br-int\\\", \\\"ovn::controller::hostname\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ovn::controller::ovn_remote_probe_interval\\\": 60000, \\\"ovn::controller::ovn_openflow_probe_interval\\\": 60, \\\"ovn::controller::ovn_ofctrl_wait_before_clear\\\": 8000, \\\"ovn::controller::garp_max_timeout_sec\\\": 0, \\\"ovn::controller::ovn_monitor_all\\\": true, \\\"tripleo::profile::base::neutron::agents::ovn::protocol\\\": \\\"ssl\\\"}, \\\"service_config_settings\\\": {}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"vs_config,exec\\\", \\\"config_volume\\\": \\\"ovn_controller\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::agents::ovn\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/etc/sysconfig/modules:/etc/sysconfig/modules\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_controller.json\\\": {\\\"command\\\": \\\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock -p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C /etc/ipa/ca.crt\\\", \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/openvswitch\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/ovn\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"ovn_controller\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"docker_config\\\": {\\\"step_4\\\": {\\\"configure_cms_options\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\\\\\"$CMS_OPTS\\\\\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781509833\\\"}}, \\\"ovn_controller\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"openvswitch.service\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck 6642\\\"}, \\\"volumes\\\": [\\\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/var/lib/openvswitch/ovn:/run/ovn:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/openvswitch:z\\\", \\\"/var/log/containers/openvswitch:/var/log/ovn:z\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\\\", \\\"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_controller\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"ovn_controller/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_controller\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/openvswitch\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/openvswitch/ovn\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Copy in cleanup script\\\", \\\"copy\\\": {\\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Cleanup neutron OVS bridges. To be called on startup to avoid\\\\n# \\\\\\\"difficult-to-debug\\\\\\\" issues with partially configured resources.\\\\n\\\\nNEUTRON_OVS_CONF=/var/lib/config-data/puppet-generated/neutron/etc/neutron/plugins/ml2/openvswitch_agent.ini\\\\n\\\\nif [ -e ${NEUTRON_OVS_CONF} ];\\\\nthen\\\\n    INT_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs integration_bridge`\\\\n    TUN_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs tunnel_bridge`\\\\nfi\\\\n\\\\nfor port in `ovs-vsctl list-ports ${INT_BRIDGE:-\\\\\\\"br-int\\\\\\\"}`;\\\\ndo\\\\n    skip_cleanup=`ovs-vsctl --if-exists get Interface $port external_ids:skip_cleanup`\\\\n    if ! [[ \\\\\\\"x$skip_cleanup\\\\\\\" == \\\\\\\"x\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\" ]];\\\\n    then\\\\n        ovs-vsctl del-port ${INT_BRIDGE:-\\\\\\\"br-int\\\\\\\"} $port\\\\n    fi\\\\ndone\\\\n\\\\novs-vsctl --if-exists del-br ${TUN_BRIDGE:-\\\\\\\"br-tun\\\\\\\"}\\\\n\\\\n# Clean up trunk port bridges\\\\nfor br in $(ovs-vsctl list-br | egrep \'tbr-[0-9a-f\\\\\\\\-]+\'); do\\\\n    ovs-vsctl --if-exists del-br $br\\\\ndone\\\\n\\\", \\\"dest\\\": \\\"/usr/libexec/neutron-cleanup\\\", \\\"force\\\": true, \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"Copy in cleanup service\\\", \\\"copy\\\": {\\\"content\\\": \\\"[Unit]\\\\nDescription=Neutron cleanup on startup\\\\nAfter=openvswitch.service network.target\\\\nBefore=tripleo_neutron_ovs_agent.service tripleo_neutron_dhcp.service tripleo_neutron_l3_agent.service tripleo_nova_compute.service\\\\nRefuseManualStop=yes\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/libexec/neutron-cleanup\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\", \\\"dest\\\": \\\"/usr/lib/systemd/system/neutron-cleanup.service\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Enabling the cleanup service\\\", \\\"service\\\": {\\\"name\\\": \\\"neutron-cleanup\\\", \\\"enabled\\\": true}, \\\"when\\\": \\\"not (ansible_check_mode|bool)\\\"}], \\\"external_deploy_tasks\\\": [{\\\"when\\\": [\\\"step|int == 0\\\"], \\\"name\\\": \\\"ovn_controller_external_deploy_init\\\", \\\"block\\\": [{\\\"name\\\": \\\"create ovn mac address for Compute role nodes\\\", \\\"tripleo_ovn_mac_addresses\\\": {\\\"playbook_dir\\\": \\\"{{ playbook_dir }}\\\", \\\"stack_name\\\": \\\"overcloud\\\", \\\"role_name\\\": \\\"Compute\\\", \\\"server_resource_names\\\": \\\"{{ groups[\\\\\\\"Compute\\\\\\\"] }}\\\", \\\"ovn_bridge_mappings\\\": [\\\"datacentre:br-ex\\\"], \\\"ovn_static_bridge_mac_mappings\\\": {}}}]}], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_controller image pull successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_image_update\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"OVN Container image used\\\", \\\"debug\\\": {\\\"msg\\\": \\\"ovn container will be using {{ image }}\\\"}, \\\"vars\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"vars\\\": {\\\"timeout\\\": 8000}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovs_vsctl\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Was the update of OVN OVS related parameter successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovs_vsctl\\\"], \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\"], \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovs_vsctl.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"set_fact\\\": {\\\"any_ovn_host\\\": \\\"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\\\"}, \\\"tags\\\": \\\"ovn\\\", \\\"when\\\": \\\"step|int == 1\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"delegate_to\\\": \\\"{{ any_ovn_host }}\\\", \\\"when\\\": \\\"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\\\", \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\", \\\"query\\\": \\\"results[?item == \'{{item}}\'].stdout\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_update\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"conmon_pidfile\\\": \\\"{{ pidfile | json_query(query) | first }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Was the ovn_controller successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_update\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Fetch running ovn_controller image\\\", \\\"shell\\\": \\\"set -e\\\\npodman inspect --format \\\\\\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\\\\\" ovn_controller\\\\n\\\", \\\"register\\\": \\\"running_ovn_image\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"]}, {\\\"name\\\": \\\"Run ovn_controller upgrade\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"vars\\\": {\\\"ovn_controller_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\"}, \\\"when\\\": [\\\"step|int == 4\\\", \\\"running_ovn_image.stdout != ovn_controller_image\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"vars\\\": {\\\"timeout\\\": 8000}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"]}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"conmon_pidfile\\\": \\\"{{ pidfile.stdout }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}]}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": \\\"overcloud\\\"}, \\\"block\\\": [{\\\"name\\\": \\\"Get neutron agents ID\\\", \\\"command\\\": \\\"openstack network agent list --column ID --column Host --column Binary --format yaml\\\", \\\"register\\\": \\\"neutron_agents_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"Filter only current host\\\", \\\"set_fact\\\": {\\\"neutron_agents\\\": \\\"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Deleting OVN agents\\\", \\\"block\\\": [{\\\"name\\\": \\\"Stop OVN containers\\\", \\\"loop\\\": [\\\"tripleo_ovn_controller\\\", \\\"tripleo_ovn_metadata_agent\\\"], \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_containers\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete neutron agents\\\", \\\"loop\\\": \\\"{{ neutron_agents }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"agent\\\", \\\"label\\\": \\\"{{ agent.Host }}/{{ agent.Binary }}\\\"}, \\\"command\\\": \\\"openstack network agent delete {{ agent.ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}, {\\\"service_name\\\": \\\"ovn_metadata\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ovn-metadata\\\", \\\"config_settings\\\": {\\\"neutron::notification_driver\\\": [\\\"noop\\\"], \\\"neutron::core_plugin\\\": \\\"ml2\\\", \\\"neutron::service_plugins\\\": [\\\"qos\\\", \\\"ovn-router\\\", \\\"trunk\\\", \\\"segments\\\", \\\"port_forwarding\\\", \\\"log\\\"], \\\"neutron::report_interval\\\": 300, \\\"neutron::logging::debug\\\": true, \\\"neutron::purge_config\\\": false, \\\"neutron::allow_overlapping_ips\\\": true, \\\"neutron::dhcp_agent_notification\\\": false, \\\"neutron::dns_domain\\\": \\\"ooo.test\\\", \\\"neutron::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"neutron::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"neutron::db::database_db_max_retries\\\": -1, \\\"neutron::db::database_max_retries\\\": -1, \\\"neutron::db::sync::db_sync_timeout\\\": 900, \\\"neutron::global_physnet_mtu\\\": 1350, \\\"neutron::db::sync::extra_params\\\": \\\"\\\", \\\"neutron::vlan_transparent\\\": false, \\\"neutron::rabbit_heartbeat_in_pthread\\\": false, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\\\": true, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\\\": \\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper\\\", \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\\\": true, \\\"tripleo::profile::base::neutron::container_cli\\\": \\\"podman\\\", \\\"neutron::agents::ovn_metadata::shared_secret\\\": \\\"NFzMNmBHe4LKwprV3ucg9SrGP\\\", \\\"neutron::agents::ovn_metadata::auth_password\\\": \\\"OorljNRFSWJ6uLOrYiwbnwsqY\\\", \\\"neutron::agents::ovn_metadata::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"neutron::agents::ovn_metadata::auth_tenant\\\": \\\"service\\\", \\\"neutron::agents::ovn_metadata::metadata_host\\\": \\\"overcloud.internalapi.ooo.test\\\", \\\"neutron::agents::ovn_metadata::ovsdb_connection_timeout\\\": 180, \\\"neutron::agents::ovn_metadata::ovsdb_probe_interval\\\": 60000, \\\"neutron::agents::ovn_metadata::hwol_qos_enabled\\\": false, \\\"ovn::northbound::port\\\": 6641, \\\"ovn::southbound::port\\\": 6642, \\\"neutron::agents::ovn_metadata::debug\\\": true, \\\"neutron::agents::ovn_metadata::metadata_protocol\\\": \\\"https\\\", \\\"neutron::agents::ovn_metadata::metadata_workers\\\": \\\"1\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::protocol\\\": \\\"ssl\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\"}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"neutron_config,ovn_metadata_agent_config\\\", \\\"config_volume\\\": \\\"neutron\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::ovn_metadata\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\\\", \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_metadata_agent.json\\\": {\\\"command\\\": \\\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini --log-file=/var/log/neutron/ovn-metadata-agent.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"create_haproxy_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\"]}}, \\\"step_4\\\": {\\\"setup_ovs_manager\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"exec\\\", \\\"include tripleo::profile::base::neutron::ovn_metadata\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781509833\\\"}}, \\\"ovn_metadata_agent\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"cgroupns\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/neutron:/var/log/neutron:z\\\", \\\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\", \\\"/run/netns:/run/netns:shared\\\", \\\"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\\\", \\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\\\", \\\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"ovn_metadata\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_metadata\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"ovn_metadata/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_metadata_agent\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/neutron\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"create /run/netns with temp namespace\\\", \\\"command\\\": \\\"ip netns add ns_temp\\\", \\\"register\\\": \\\"ipnetns_add_result\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"remove temp namespace\\\", \\\"command\\\": \\\"ip netns delete ns_temp\\\", \\\"failed_when\\\": false, \\\"when\\\": [\\\"ipnetns_add_result.rc is defined\\\", \\\"ipnetns_add_result.rc == 0\\\"]}, {\\\"name\\\": \\\"create /var/lib/neutron\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}, {\\\"name\\\": \\\"set conditions\\\", \\\"set_fact\\\": {\\\"haproxy_wrapper_enabled\\\": true, \\\"debug_enabled\\\": true, \\\"docker_additional_sockets\\\": [\\\"/var/lib/openstack/docker.sock\\\"]}}, {\\\"name\\\": \\\"create kill_scripts directory within /var/lib/neutron\\\", \\\"file\\\": {\\\"state\\\": \\\"directory\\\", \\\"path\\\": \\\"/var/lib/neutron/kill_scripts\\\"}}, {\\\"name\\\": \\\"create haproxy kill script\\\", \\\"when\\\": \\\"haproxy_wrapper_enabled|bool\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/var/lib/neutron/kill_scripts/haproxy-kill\\\", \\\"mode\\\": 493, \\\"content\\\": \\\"#!/bin/bash\\\\n{% if debug_enabled|bool -%}\\\\nset -x\\\\n{% endif -%}\\\\nadd_date() {\\\\n  echo \\\\\\\"$(date) $@\\\\\\\"\\\\n}\\\\n\\\\n# Set up script logging for debugging purpose.\\\\n# It will be taken care of by logrotate since there is the .log\\\\n# suffix.\\\\nexec 3>&1 4>&2\\\\ntrap \'exec 2>&4 1>&3\' 0 1 2 3\\\\nexec 1>>/var/log/neutron/kill-script.log 2>&1\\\\n\\\\nSIG=$1\\\\nPID=$2\\\\nNETNS=$(ip netns identify ${PID})\\\\n\\\\nif [ \\\\\\\"x${NETNS}\\\\\\\" == \\\\\\\"x\\\\\\\" ]; then\\\\n  CLI=\\\\\\\"nsenter --all --preserve-credentials -t 1 podman\\\\\\\"\\\\n  SIG=9\\\\nelse\\\\n  CLI=\\\\\\\"nsenter --net=/run/netns/${NETNS} --preserve-credentials -m -t 1 podman\\\\\\\"\\\\nfi\\\\n\\\\nkill_container() {\\\\n  add_date \\\\\\\"Killing container $1 ($2)\\\\\\\"\\\\n  signal_container $1 $2 9\\\\n}\\\\n\\\\nstop_container() {\\\\n  add_date \\\\\\\"Stopping container $1 ($2)\\\\\\\"\\\\n  $CLI stop $2\\\\n}\\\\n\\\\nsignal_container() {\\\\n  SIGNAL=$3\\\\n  if [ -z \\\\\\\"$SIGNAL\\\\\\\" ]; then\\\\n      SIGNAL=\\\\\\\"HUP\\\\\\\"\\\\n  fi\\\\n  add_date \\\\\\\"Sending signal \'$SIGNAL\' to $1 ($2)\\\\\\\"\\\\n  $CLI kill --signal $SIGNAL $2\\\\n}\\\\n\\\\ndelete_container() {\\\\n  add_date \\\\\\\"Deleting container $1 ($2)\\\\\\\"\\\\n  $CLI rm $2 || echo \\\\\\\"Deleting container $1 ($2) failed\\\\\\\"\\\\n}\\\\n\\\\n\\\\n{% raw -%}\\\\nif [ -f /proc/$PID/cgroup ]; then\\\\n  # Get container ID based on process cgroups\\\\n  CT_ID=$(awk \'BEGIN {FS=\\\\\\\".scope|-\\\\\\\"} /\\\\\\\\/libpod-/ {if ($(NF-1)) print $(NF-1);exit}\' /proc/$PID/cgroup)\\\\n  CT_NAME=$($CLI inspect -f \'{{.Name}}\' $CT_ID)\\\\n\\\\n  case $SIG in\\\\n    HUP)\\\\n      signal_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    9)\\\\n      kill_container $CT_NAME $CT_ID\\\\n      delete_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    15)\\\\n      stop_container $CT_NAME $CT_ID\\\\n      delete_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    *)\\\\n      add_date \\\\\\\"Unknown action ${SIG} for ${CT_NAME} ${CT_ID}\\\\\\\"\\\\n      exit 1\\\\n      ;;\\\\n  esac\\\\n\\\\nelse\\\\n  add_date \\\\\\\"No such PID: ${PID}\\\\\\\"\\\\n  exit 1\\\\nfi\\\\n{% endraw %}\\\\n\\\"}}], \\\"upgrade_tasks\\\": [], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Check if python3-openvswitch3.1 workaround is needed\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\\\n\\\", \\\"register\\\": \\\"metadata_python_ovs_3_1\\\", \\\"failed_when\\\": false, \\\"loop\\\": \\\"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}, {\\\"name\\\": \\\"Update ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_metadata_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_metadata_agent image pull successful.\\\", \\\"when\\\": [\\\"\'results\' in ovn_metadata_image_update\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_metadata_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"tags\\\": [\\\"ovn_metadata_parallel\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0}]}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"never\\\", \\\"ovn_metadata_serial\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"loop_control\\\": {\\\"pause\\\": 1}}]}]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(175,'2026-06-15 07:51:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"sWxK580w74dwlHOIwwPlLwNi9\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(176,'2026-06-15 07:51:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"sWxK580w74dwlHOIwwPlLwNi9\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(177,'2026-06-15 07:51:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (178,'2026-06-15 07:51:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service for pacemaker\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"monitoring_subscription\"]}, \"ansible_group_vars\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"ansible_group_vars\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::mysql_clustercheck\": true, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, {\"haproxy_docker\": true, \"tripleo::profile::pacemaker::haproxy_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping_init_bundle\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_certs_directory\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_keys_directory\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::haproxy_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"class tripleo::firewall(){}; define tripleo::firewall::rule( $port = undef, $dport = undef, $sport = undef, $proto = undef, $action = undef, $state = undef, $source = undef, $iniface = undef, $chain = undef, $destination = undef, $extras = undef){}\", \"[\'pcmk_bundle\', \'pcmk_resource\', \'pcmk_property\', \'pcmk_constraint\', \'pcmk_resource_default\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::pacemaker::haproxy_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"yaql\": {\"expression\": \"$.data.select($+\\\":\\\"+$+\\\":ro\\\")\", \"data\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}}}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"register\": \"puppet_host_outputs\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"if hiera(\'enable_load_balancer\', true) { class {\'::tripleo::haproxy\': use_internal_certificates => false, manage_firewall => hiera(\'tripleo::firewall::manage_firewall\', true), }}\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}]]}, \"metadata_settings\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container managed by Pacemaker\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"HAproxy tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"HAproxy HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}, []]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"haproxy temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"haproxy-bundle\", \"tripleo_ha_image_update_new_image\": \"{{haproxy_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_haproxy_image}}\"}, \"when\": [\"(pcmk_haproxy_image != \\\"\\\")\", \"(pcmk_haproxy_image != haproxy_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of haproxy container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_haproxy_image == haproxy_image_latest\", \"fail_msg\": \"haproxy image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Set HAProxy upgrade facts\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_haproxy_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}]}, {\"name\": \"Mount TLS cert if needed\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node\"], \"block\": [{\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Disable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": \"haproxy_cert_mounted.rc == 6 and haproxy_public_tls_enabled|bool\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}]}, {\"name\": \"Haproxy fetch and retag container image for pacemaker\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 2\"], \"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Wait for 10s to settle connections on new VIPs\", \"wait_for\": {\"timeout\": 10}, \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"]}, {\"name\": \"Block local INPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"# server controller-0.storage.redhat.local 172.17.3.93:8080 check fall 5 inter 2000 rise 2\\n# server controller-0.internalapi.redhat.local fd00:fd00:fd00:2000::176:9292 check fall 5 inter 2000 rise 2\\nset -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\necho \\\"insert rule $PROTOCOL filter INPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time\\\"\\ndone | xargs -i nft {} $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\"\\n\"}, {\"name\": \"Generate block for other nodes OUTPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\n echo \\\"nft insert rule $PROTOCOL \\\\$TABLE OUTPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\\\\\" \\\"\\ndone\\n\", \"register\": \"haproxy_iptables_block\"}, {\"name\": \"Block OUTPUT SYN packets to this node on other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"delegate_to\": \"{{ item }}\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | head -n 1 \\\\\\nawk \'{print $3}\' | while read BACKEND; do\\n    IP=${BACKEND%:*}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\ndone\\nTABLE=$(nft list tables | grep -q \\\"$PROTOCOL raw\\\" && echo raw || echo filter )\\necho \\\"{{ haproxy_iptables_block.stdout}}\\\" | while read i; do bash -c \\\"$i\\\"; done\\n\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\"}], \"post_update_tasks\": [{\"name\": \"HAProxy bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}, {\"name\": \"Cleanup local SYN DROP rules\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"shell\": \"nft -a list chain filter INPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule filter INPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}, {\"name\": \"Cleanup SYN DROP rules from other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"delegate_to\": \"{{ item }}\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\", \"shell\": \"nft -a list chain raw OUTPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule raw OUTPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Prepare switch of haproxy image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get haproxy image id currently used by pacemaker\", \"shell\": \"pcs resource config haproxy-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"haproxy_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for haproxy\", \"set_fact\": {\"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"haproxy_image_current\": \"{{haproxy_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current haproxy image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image_current}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\", \"pull_image\": false}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}, {\"name\": \"Create haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"touch\"}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set upgrade haproxy facts\", \"set_fact\": {\"is_haproxy_bootstrap_node\": \"{{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}}, {\"name\": \"Check for haproxy retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\"}, \"register\": \"haproxy_retag_state_file\"}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node|bool\", \"haproxy_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the haproxy cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Expose HAProxy stats socket on the host and mount TLS cert if needed\", \"block\": [{\"name\": \"Check haproxy stats socket configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-var-lib\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_stats_exposed\"}, {\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Add a bind mount for stats socket in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-var-lib source-dir=/var/lib/haproxy target-dir=/var/lib/haproxy options=rw\", \"when\": \"haproxy_stats_exposed.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": [\"haproxy_cert_mounted.rc == 6\", \"haproxy_public_tls_enabled|bool\"]}]}, {\"name\": \"Update the haproxy bundle to use the new container image name\", \"command\": \"pcs resource bundle update haproxy-bundle container image={{haproxy_image_latest}}\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"absent\"}}]}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"step|int == 3\"], \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Ensure config works for the new config\", \"shell\": \"set -o pipefail\\nawk -i inplace -v INPLACE_SUFFIX=.bak \'/  rsprep/ {print \\\"  http-response replace-header Location \\\" $3\\\" \\\"$5; next;}; {print} \' /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(179,'2026-06-15 07:51:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(180,'2026-06-15 07:51:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(181,'2026-06-15 07:51:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"CertmongerCA\": {\"type\": \"string\", \"default\": \"\", \"description\": \"CA to use for certmonger\"}, \"HAProxyCertificateDNSNames\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Override the default HAProxy Certificate DNS Names\"}, \"HAProxyCertificatePrincipal\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the default HAProxy Certificate Principal\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}, \"principal_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificatePrincipal\"}, \"\"]}}, \"dnsnames_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateDNSNames\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_public_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::service_certificate\": {\"get_param\": \"DeployedSSLCertificatePath\"}}, \"certificates_specs\": {\"haproxy-external\": {\"service_pem\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}, \"metadata_settings\": [{\"service\": \"haproxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"type\": \"vip\"}], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"certmonger_ca\": {\"get_param\": \"CertmongerCA\"}}, \"block\": [{\"name\": \"make sure certmonger is installed\", \"package\": {\"name\": \"certmonger\", \"state\": \"present\"}}, {\"name\": \"make sure certmonger service is started\", \"systemd\": {\"state\": \"started\", \"enabled\": true, \"masked\": false, \"name\": \"certmonger.service\"}}, {\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"name\": \"Extract and trust certmonger\'s local CA\", \"shell\": \"set -e\\nca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\nopenssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\nchmod 0644 ${ca_pem}\\nupdate-ca-trust extract\\ntest -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n\", \"retries\": 5, \"delay\": 1, \"register\": \"local_ca_extract_result\", \"until\": \"local_ca_extract_result.rc == 0\", \"when\": \"certmonger_ca != \'IPA\' and (ipa_realm is not defined)\"}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"haproxy-external-cert\", \"dns\": {\"if\": [\"dnsnames_override_set\", {\"get_param\": \"HAProxyCertificateDNSNames\"}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"ip\": {\"if\": [\"dnsnames_override_set\", {\"str_replace\": {\"template\": \"{{DNSNAMES|ipaddr}}\", \"params\": {\"DNSNAMES\": {\"get_param\": \"HAProxyCertificateDNSNames\"}}}}, {\"str_replace\": {\"template\": \"{{[cloud_names.cloud_name_NETWORK]|ipaddr}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"principal\": {\"if\": [\"principal_override_set\", {\"get_param\": \"HAProxyCertificatePrincipal\"}, {\"str_replace\": {\"template\": \"haproxy/{{cloud_names.cloud_name_NETWORK}}@{{idm_realm|default(\'UNDERCLOUD\')}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-external-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-external-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\n\\nca_type=CATYPE\\nif [ \\\"$ca_type\\\" = \\\"self-sign\\\" ]; then\\n  # refresh the ca cert just in case the ca cert has been renewed\\n  ca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\n  openssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\n  chmod 0644 ${ca_pem}\\n  update-ca-trust extract\\n  test -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n  openssl x509 -in ${ca_pem} -out /tmp/cm-local-ca.pem\\n  ca_path=\\\"/tmp/cm-local-ca.pem\\\"\\nelse\\n  ca_path=\\\"/etc/ipa/ca.crt\\\"\\nfi\\n\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\nservice_pem=\\\"PEMPATH\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CATYPE\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\", \"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"PEMPATH\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(182,'2026-06-15 07:51:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Horizon service\\n\", \"parameters\": {\"ContainerHorizonImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"ContainerHorizonConfigImage\": {\"description\": \"The container image to use for the horizon config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HorizonDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Horizon service.\", \"type\": \"boolean\"}, \"HorizonAllowedHosts\": {\"default\": \"*\", \"description\": \"A list of IP/Hostname for the server Horizon is running on. Used for header checks.\", \"type\": \"comma_delimited_list\"}, \"HorizonPasswordValidator\": {\"description\": \"Regex for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonPasswordValidatorHelp\": {\"description\": \"Help text for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonSecret\": {\"description\": \"Secret key for Django\", \"type\": \"string\", \"hidden\": true, \"default\": \"zKZUPZrGKS\"}, \"HorizonSecureCookies\": {\"description\": \"Set CSRF_COOKIE_SECURE / SESSION_COOKIE_SECURE in Horizon\", \"type\": \"boolean\", \"default\": false}, \"HorizonSessionTimeout\": {\"description\": \"Set session timeout for horizon in seconds\", \"type\": \"number\", \"default\": 1800}, \"MemcachedIPv6\": {\"default\": false, \"description\": \"Enable IPv6 features in Memcached.\", \"type\": \"boolean\"}, \"MonitoringSubscriptionHorizon\": {\"default\": \"overcloud-horizon\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HorizonVhostExtraParams\": {\"default\": {\"add_listen\": true, \"priority\": 10, \"access_log_format\": \"%a %l %u %t \\\\\\\"%r\\\\\\\" %>s %b \\\\\\\"%%{}{Referer}i\\\\\\\" \\\\\\\"%%{}{User-Agent}i\\\\\\\"\", \"options\": [\"FollowSymLinks\", \"MultiViews\"]}, \"description\": \"Extra parameters for Horizon vhost configuration\", \"type\": \"json\"}, \"HorizonCustomizationModule\": {\"default\": \"\", \"description\": \"Horizon has a global overrides mechanism available to perform customizations\", \"type\": \"string\"}, \"HorizonHelpURL\": {\"default\": \"http://docs.openstack.org\", \"description\": \"On top of dashboard there is a Help button. This button could be used to re-direct user to vendor documentation or dedicated help portal.\", \"type\": \"string\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}, \"WebSSOEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable support for Web Single Sign-On\"}, \"WebSSOInitialChoice\": {\"default\": \"OIDC\", \"type\": \"string\", \"description\": \"The initial authentication choice to select by default\"}, \"WebSSOChoicesHideKeystone\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Hide Keystone crednetials login when WebSSO is enabled.\"}, \"WebSSOChoices\": {\"default\": [[\"OIDC\", \"OpenID Connect\"]], \"type\": \"json\", \"description\": \"Specifies the list of SSO authentication choices to present. Each item is a list of an SSO choice identifier and a display message.\"}, \"WebSSOIDPMapping\": {\"default\": {\"OIDC\": [\"myidp\", \"openid\"]}, \"type\": \"json\", \"description\": \"Specifies a mapping from SSO authentication choice to identity provider and protocol.  The identity provider and protocol names must match the resources defined in keystone.\"}, \"HorizonDomainChoices\": {\"default\": [], \"type\": \"json\", \"description\": \"Specifies available domains to choose from. We expect an array of hashes, and the hashes should have two items each (name, display) containing Keystone domain name and a human-readable description of the domain respectively.\"}, \"HorizonLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.horizon\", \"file\": \"/var/log/containers/horizon/horizon.log\"}}, \"HorizonHstsHeaderValue\": {\"default\": [], \"description\": \"Enables HTTP Strict-Transport-Security header in response.\", \"type\": \"comma_delimited_list\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MemcachedIPv6\"]}], \"conditions\": {\"horizon_domain_choices_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonDomainChoices\"}, []]}}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}]}, 6]}, \"horizon_logger_debug\": {\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"HorizonDebug\"}]}, \"horizon_hsts_header_value_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonHstsHeaderValue\"}, []]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHorizonImage\": \"ContainerHorizonImage\", \"ContainerHorizonConfigImage\": \"ContainerHorizonConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHorizonImage\": {\"get_param\": \"ContainerHorizonImage\"}, \"ContainerHorizonConfigImage\": {\"get_param\": \"ContainerHorizonConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Horizon API role.\", \"value\": {\"service_name\": \"horizon\", \"firewall_rules\": {\"126 horizon\": {\"dport\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, 443, 80]}]}}, \"firewall_frontend_rules\": {\"100 horizon_haproxy_frontend\": {\"dport\": [80]}}, \"firewall_ssl_frontend_rules\": {\"100 horizon_haproxy_frontend_ssl\": {\"dport\": [443]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHorizon\"}, \"config_settings\": {\"map_merge\": [{\"horizon::allowed_hosts\": {\"get_param\": \"HorizonAllowedHosts\"}, \"horizon::enable_secure_proxy_ssl_header\": true, \"horizon::secure_proxy_addr_header\": \"HTTP_X_FORWARDED_FOR\", \"horizon::disable_password_reveal\": true, \"horizon::enforce_password_check\": true, \"horizon::disallow_iframe_embed\": true, \"horizon::cache_backend\": \"django.core.cache.backends.memcached.MemcachedCache\", \"horizon::django_session_engine\": \"django.contrib.sessions.backends.cache\", \"horizon::vhost_extra_params\": {\"get_param\": \"HorizonVhostExtraParams\"}, \"horizon::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Public\", \"uri\"]}, \"horizon::password_validator\": {\"get_param\": [\"HorizonPasswordValidator\"]}, \"horizon::password_validator_help\": {\"get_param\": [\"HorizonPasswordValidatorHelp\"]}, \"horizon::secret_key\": {\"get_param\": \"HorizonSecret\"}, \"horizon::secure_cookies\": {\"get_param\": [\"HorizonSecureCookies\"]}, \"horizon::session_timeout\": {\"get_param\": \"HorizonSessionTimeout\"}, \"memcached_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"horizon::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::listen_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"horizon::customization_module\": {\"get_param\": \"HorizonCustomizationModule\"}, \"horizon::timezone\": {\"get_param\": \"TimeZone\"}, \"horizon::file_upload_temp_dir\": \"/var/tmp\", \"horizon::help_url\": {\"get_param\": \"HorizonHelpURL\"}, \"horizon::enable_user_pass\": \"UNSET\"}, {\"if\": [{\"get_param\": \"WebSSOEnable\"}, {\"horizon::websso_enabled\": {\"get_param\": \"WebSSOEnable\"}, \"horizon::websso_initial_choice\": {\"get_param\": \"WebSSOInitialChoice\"}, \"horizon::websso_choices\": {\"get_param\": \"WebSSOChoices\"}, \"horizon::websso_idp_mapping\": {\"get_param\": \"WebSSOIDPMapping\"}, \"horizon::websso_choices_hide_keystone\": {\"get_param\": \"WebSSOChoicesHideKeystone\"}}]}, {\"if\": [{\"get_param\": \"HorizonDebug\"}, {\"horizon::django_debug\": true}, {\"horizon::django_debug\": {\"get_param\": \"Debug\"}}]}, {\"if\": [\"horizon_logger_debug\", {\"horizon::log_level\": \"DEBUG\"}]}, {\"if\": [\"horizon_domain_choices_set\", {\"horizon::keystone_domain_choices\": {\"get_param\": \"HorizonDomainChoices\"}}]}]}, \"ansible_group_vars\": {\"keystone_enable_member\": true}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_horizon\": {\"yaql\": {\"expression\": \"$.data.sources.flatten()\", \"data\": {\"sources\": [{\"get_param\": \"HorizonLoggingSource\"}]}}}}, \"haproxy\": {\"if\": [\"horizon_hsts_header_value_set\", {\"tripleo::profile::base::horizon::hsts_header_value\": {\"get_param\": \"HorizonHstsHeaderValue\"}}]}}, \"puppet_config\": {\"config_volume\": \"horizon\", \"puppet_tags\": \"horizon_config\", \"step_config\": \"include tripleo::profile::base::horizon\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/horizon.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/horizon/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/etc/openstack-dashboard/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/\", \"owner\": \"apache:apache\", \"recurse\": false}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/local_settings.d/\", \"owner\": \"apache:apache\", \"recurse\": false}]}}, \"docker_config\": {\"step_2\": {\"horizon_fix_perms\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"touch /var/log/horizon/horizon.log ; chown -R apache:apache /var/log/horizon && chmod -R a+rx /etc/openstack-dashboard\"], \"volumes\": [\"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/lib/config-data/puppet-generated/horizon/etc/openstack-dashboard:/etc/openstack-dashboard\"]}}, \"step_3\": {\"horizon\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/horizon.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/horizon:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/tmp/horizon:/var/tmp:z\", \"/var/www:/var/www:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"ENABLE_DESIGNATE\": \"yes\", \"ENABLE_HEAT\": \"yes\", \"ENABLE_IRONIC\": \"yes\", \"ENABLE_MANILA\": \"yes\", \"ENABLE_OCTAVIA\": \"yes\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/www\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/tmp/horizon\", \"setype\": \"container_file_t\", \"mode\": \"01777\"}]}, {\"name\": \"ensure /var/tmp/horizon exists on boot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/var-tmp-horizon.conf\", \"content\": \"d /var/tmp/horizon 01777 root root - -\\n\"}}], \"upgrade_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"update_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop horizon container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"horizon\"], \"tripleo_delegate_to\": \"{{ groups[\'horizon\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(183,'2026-06-15 07:51:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(184,'2026-06-15 07:51:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(185,'2026-06-15 07:51:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyStatsPassword\": {\"description\": \"Password for HAProxy stats endpoint\", \"hidden\": true, \"type\": \"string\", \"default\": \"YhvZhTMF0VPio5Bhs4itldE4k\"}, \"HAProxyStatsUser\": {\"description\": \"User for HAProxy stats endpoint\", \"default\": \"admin\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\"}, \"MonitoringSubscriptionHaproxy\": {\"default\": \"overcloud-haproxy\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"EnableLoadBalancer\": {\"default\": true, \"description\": \"Whether to deploy a LoadBalancer, set to false when an external load balancer is used.\", \"type\": \"boolean\"}, \"HAProxyStatsEnabled\": {\"default\": true, \"description\": \"Whether or not to enable the HAProxy stats interface.\", \"type\": \"boolean\"}, \"InternalTLSCRLPEMFile\": {\"default\": \"/etc/pki/CA/crl/overcloud-crl.pem\", \"type\": \"string\", \"description\": \"Specifies the default CRL PEM file to use for revocation if TLS is used for services in the internal network.\"}, \"InternalTLSCRLPEMDir\": {\"default\": \"/etc/pki/CA/crl/\", \"type\": \"string\", \"description\": \"The directory of the CRL PEM file to be mounted.\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyLogging\": {\"type\": \"OS::TripleO::Services::Logging::HAProxy\"}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"107 haproxy stats\": {\"dport\": 1993}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHaproxy\"}, \"ansible_group_vars\": {\"tripleo_firewall_frontend_enabled\": true, \"tripleo_firewall_ssl_frontend_enabled\": {\"if\": [\"public_tls_enabled\", true]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}, \"tripleo::haproxy::haproxy_stats_user\": {\"get_param\": \"HAProxyStatsUser\"}, \"tripleo::haproxy::haproxy_stats_password\": {\"get_param\": \"HAProxyStatsPassword\"}, \"tripleo::haproxy::haproxy_stats_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HaproxyNetwork\"]}}}}, \"tripleo::haproxy::redis_password\": {\"get_param\": \"RedisPassword\"}, \"tripleo::haproxy::crl_file\": null, \"tripleo::haproxy::haproxy_stats\": {\"get_param\": \"HAProxyStatsEnabled\"}, \"enable_load_balancer\": {\"get_param\": \"EnableLoadBalancer\"}, \"tripleo::profile::base::haproxy::certificates_specs\": {\"map_merge\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"certificates_specs\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"certificates_specs\"]}]}, \"tripleo::haproxy::service_certificate\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"DeployedSSLCertificatePath\"}]}, \"tripleo::haproxy::ca_bundle\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}, {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": \"class {\'tripleo::profile::base::haproxy\': manage_firewall => false}\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"get_param\": \"DeployedSSLCertificatePath\"}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro,shared\"]]}, {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro,shared\"]]}]]}]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true, \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"docker_config\", \"step_1\"]}, {\"haproxy\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HAProxyLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/haproxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/haproxy:/var/lib/kolla/config_files/src:ro\", \"/var/lib/haproxy:/var/lib/haproxy:rw,z\"], {\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"list_join\": [\"\", [\"/var/lib/kolla/config_files/src-tls\", {\"get_param\": \"DeployedSSLCertificatePath\"}]]}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro\"]]}]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"when\": \"step|int == 1\", \"register\": \"puppet_host_outputs\", \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"include tripleo::profile::base::haproxy\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"upgrade_tasks\": [{\"name\": \"ensure we have haproxy log dir with the correct setype\", \"file\": {\"path\": \"/var/log/containers/haproxy\", \"state\": \"directory\", \"setype\": \"var_log_t\", \"recurse\": true}, \"when\": \"step|int == 1\"}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop haproxy container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"haproxy\"], \"tripleo_delegate_to\": \"{{ groups[\'haproxy\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/haproxy\", \"setype\": \"var_log_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/haproxy\", \"setype\": \"container_file_t\"}]}]]}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"metadata_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"metadata_settings\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (186,'2026-06-15 07:51:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(187,'2026-06-15 07:51:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(188,'2026-06-15 07:51:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"HAProxyNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellController\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"Compute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"internal_api\"]}}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"CephStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}, \"Networker\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"internal_api\"]}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy internal TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_internal_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::use_internal_certificates\": true}, \"certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"haproxy-NETWORK\": {\"service_pem\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/overcloud-haproxy-NETWORK.pem\"]]}}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}, \"metadata_settings\": {\"repeat\": {\"template\": [{\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"vip\"}, {\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"haproxy-NETWORK-cert\", \"dns\": [\"{{fqdn_NETWORK}}\", \"{{cloud_names.cloud_name_NETWORK}}\"], \"principal\": \"haproxy/{{fqdn_NETWORK}}@{{idm_realm}}\", \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-NETWORK-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-NETWORK-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\n\\nca_path=\\\"/etc/ipa/ca.crt\\\"\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\nservice_pem=\\\"CERTSDIR/overcloud-haproxy-NETWORK.pem\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(190,'2026-06-15 07:51:46',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-0\", \"NodeIndex\": \"0\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"71990642-319e-497c-b4d1-b147b6ad3a13\"}}, \"1\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-1\", \"NodeIndex\": \"1\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"71990642-319e-497c-b4d1-b147b6ad3a13\"}}, \"2\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-2\", \"NodeIndex\": \"2\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"71990642-319e-497c-b4d1-b147b6ad3a13\"}}}, \"outputs\": {\"ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"ip_address\"]}, {\"get_attr\": [\"1\", \"ip_address\"]}, {\"get_attr\": [\"2\", \"ip_address\"]}]}, \"blacklist_hostname\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_hostname\"]}, {\"get_attr\": [\"1\", \"blacklist_hostname\"]}, {\"get_attr\": [\"2\", \"blacklist_hostname\"]}]}, \"nova_server_resource\": {\"value\": [{\"get_attr\": [\"0\", \"nova_server_resource\"]}, {\"get_attr\": [\"1\", \"nova_server_resource\"]}, {\"get_attr\": [\"2\", \"nova_server_resource\"]}]}, \"ansible_host_vars_map\": {\"value\": [{\"get_attr\": [\"0\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"1\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"2\", \"ansible_host_vars_map\"]}]}, \"storage_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_ip_address\"]}, {\"get_attr\": [\"1\", \"storage_ip_address\"]}, {\"get_attr\": [\"2\", \"storage_ip_address\"]}]}, \"internal_api_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"1\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"2\", \"internal_api_ip_address\"]}]}, \"attributes, nova_server_resource\": {\"value\": {\"0\": {\"get_attr\": [\"0\", \"nova_server_resource\"]}, \"1\": {\"get_attr\": [\"1\", \"nova_server_resource\"]}, \"2\": {\"get_attr\": [\"2\", \"nova_server_resource\"]}}}, \"blacklist_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"1\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"2\", \"blacklist_ip_address\"]}]}, \"tenant_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"tenant_ip_address\"]}, {\"get_attr\": [\"1\", \"tenant_ip_address\"]}, {\"get_attr\": [\"2\", \"tenant_ip_address\"]}]}, \"hostname\": {\"value\": [{\"get_attr\": [\"0\", \"hostname\"]}, {\"get_attr\": [\"1\", \"hostname\"]}, {\"get_attr\": [\"2\", \"hostname\"]}]}, \"hostname_map\": {\"value\": [{\"get_attr\": [\"0\", \"hostname_map\"]}, {\"get_attr\": [\"1\", \"hostname_map\"]}, {\"get_attr\": [\"2\", \"hostname_map\"]}]}, \"hosts_entry\": {\"value\": [{\"get_attr\": [\"0\", \"hosts_entry\"]}, {\"get_attr\": [\"1\", \"hosts_entry\"]}, {\"get_attr\": [\"2\", \"hosts_entry\"]}]}, \"refs_map\": {\"value\": {\"0\": {\"get_resource\": \"0\"}, \"1\": {\"get_resource\": \"1\"}, \"2\": {\"get_resource\": \"2\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(191,'2026-06-15 07:51:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(192,'2026-06-15 07:51:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(193,'2026-06-15 07:51:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"HAProxyNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellController\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"Compute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"internal_api\"]}}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"CephStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}, \"Networker\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"internal_api\"]}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy internal TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_internal_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::use_internal_certificates\": true}, \"certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"haproxy-NETWORK\": {\"service_pem\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/overcloud-haproxy-NETWORK.pem\"]]}}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}, \"metadata_settings\": {\"repeat\": {\"template\": [{\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"vip\"}, {\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"haproxy-NETWORK-cert\", \"dns\": [\"{{fqdn_NETWORK}}\", \"{{cloud_names.cloud_name_NETWORK}}\"], \"principal\": \"haproxy/{{fqdn_NETWORK}}@{{idm_realm}}\", \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-NETWORK-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-NETWORK-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\n\\nca_path=\\\"/etc/ipa/ca.crt\\\"\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\nservice_pem=\\\"CERTSDIR/overcloud-haproxy-NETWORK.pem\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(194,'2026-06-15 07:51:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (195,'2026-06-15 07:51:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Compute node configured by Puppet\", \"parameters\": {\"OvercloudComputeFlavor\": {\"description\": \"Flavor for the Compute node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"NovaImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"DEPRECATED Use ComputeImage instead\"}, \"ComputeImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeIPs\": {\"default\": {}, \"type\": \"json\"}, \"NovaComputeIPs\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeIPs instead\", \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"NovaComputeServerMetadata\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeServerMetadata instead\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {\"ipa_enroll\": true}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"NovaImage\", \"NovaComputeServerMetadata\", \"NovaComputeIPs\"]}], \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"deprecated_param_image_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaImage\"}, \"overcloud-full\"]}}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"Compute_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"NovaCompute\": {\"type\": \"OS::TripleO::ComputeServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"if\": [\"deprecated_param_image_set\", {\"get_param\": \"NovaImage\"}, {\"get_param\": \"ComputeImage\"}]}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, {\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"NovaComputeServerMetadata\"}, {\"get_param\": \"ComputeServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeSchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::Compute::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::Compute::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::Compute::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"NovaCompute\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::Compute::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"ComputeExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"NovaComputeAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"NovaComputeAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for Compute server\", \"value\": {\"get_resource\": \"NovaCompute\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-2\", \"CloudDomain\": \"ooo.test\", \"ComputeSchedulerHints\": {}, \"NodeIndex\": 2, \"ServiceNames\": \"boot_params_service,ca_certs,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,ipaservice,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"71990642-319e-497c-b4d1-b147b6ad3a13\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(196,'2026-06-15 07:51:46',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"71990642-319e-497c-b4d1-b147b6ad3a13\", \"name\": \"np0000073848\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {\"ipa_enroll\": true, \"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(197,'2026-06-15 07:51:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(198,'2026-06-15 07:51:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(199,'2026-06-15 07:51:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(200,'2026-06-15 07:51:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAProxy API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_1\": {}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": null}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(201,'2026-06-15 07:51:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Compute node configured by Puppet\", \"parameters\": {\"OvercloudComputeFlavor\": {\"description\": \"Flavor for the Compute node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"NovaImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"DEPRECATED Use ComputeImage instead\"}, \"ComputeImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeIPs\": {\"default\": {}, \"type\": \"json\"}, \"NovaComputeIPs\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeIPs instead\", \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"NovaComputeServerMetadata\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeServerMetadata instead\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {\"ipa_enroll\": true}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"NovaImage\", \"NovaComputeServerMetadata\", \"NovaComputeIPs\"]}], \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"deprecated_param_image_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaImage\"}, \"overcloud-full\"]}}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"Compute_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"NovaCompute\": {\"type\": \"OS::TripleO::ComputeServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"if\": [\"deprecated_param_image_set\", {\"get_param\": \"NovaImage\"}, {\"get_param\": \"ComputeImage\"}]}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, {\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"NovaComputeServerMetadata\"}, {\"get_param\": \"ComputeServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeSchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::Compute::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::Compute::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::Compute::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"NovaCompute\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::Compute::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"ComputeExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"NovaComputeAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"NovaComputeAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for Compute server\", \"value\": {\"get_resource\": \"NovaCompute\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-1\", \"CloudDomain\": \"ooo.test\", \"ComputeSchedulerHints\": {}, \"NodeIndex\": 1, \"ServiceNames\": \"boot_params_service,ca_certs,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,ipaservice,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"71990642-319e-497c-b4d1-b147b6ad3a13\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(202,'2026-06-15 07:51:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"ContainerKeystoneConfigImage\": {\"description\": \"The container image to use for the keystone config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781509833, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"XITaEkVaorHTSEBU67xsjmkmx\"}, \"KeystoneTokenProvider\": {\"description\": \"The keystone token format\", \"type\": \"string\", \"default\": \"fernet\", \"constraints\": [{\"allowed_values\": [\"fernet\"]}]}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"PublicTLSCAFile\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the public network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"KeystoneSSLCertificate\": {\"default\": \"\", \"description\": \"Keystone certificate for verifying token validity.\", \"type\": \"string\"}, \"KeystoneSSLCertificateKey\": {\"default\": \"\", \"description\": \"Keystone key for signing tokens.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneNotificationFormat\": {\"description\": \"The Keystone notification format\", \"default\": \"basic\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"basic\", \"cadf\"]}]}, \"KeystoneNotificationTopics\": {\"description\": \"Keystone notification topics to enable\", \"default\": [], \"type\": \"comma_delimited_list\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"KeystoneDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Keystone service.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"AdminToken\": {\"description\": \"The keystone auth secret and db password.\", \"type\": \"string\", \"hidden\": true, \"default\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\"}, \"TokenExpiration\": {\"default\": 3600, \"description\": \"Set a token expiration time in seconds.\", \"type\": \"number\"}, \"KeystoneWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for keystone::wsgi::apache\", \"default\": 1}, \"MonitoringSubscriptionKeystone\": {\"default\": \"overcloud-keystone\", \"type\": \"string\"}, \"KeystoneCredential0\": {\"type\": \"string\", \"description\": \"The first Keystone credential key. Must be a valid key.\", \"default\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\"}, \"KeystoneCredential1\": {\"type\": \"string\", \"description\": \"The second Keystone credential key. Must be a valid key.\", \"default\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\"}, \"KeystoneFernetKeys\": {\"type\": \"json\", \"description\": \"Mapping containing keystone\'s fernet keys and their paths.\", \"default\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}}, \"KeystoneFernetMaxActiveKeys\": {\"type\": \"number\", \"description\": \"The maximum active keys in the keystone fernet key repository.\", \"default\": 5}, \"ManageKeystoneFernetKeys\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether TripleO should manage the keystone fernet keys or not. If set to true, the fernet keys will get the values from the saved keys repository in mistral (the KeystoneFernetKeys variable). If set to false, only the stack creation initializes the keys, but subsequent updates won\'t touch them.\"}, \"KeystoneLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.keystone\", \"file\": \"/var/log/containers/keystone/keystone.log\"}}, \"KeystonePolicies\": {\"description\": \"A hash of policies to configure for Keystone.\\ne.g. { keystone-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"KeystoneLDAPDomainEnable\": {\"description\": \"Trigger to call ldap_backend puppet keystone define.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneLDAPBackendConfigs\": {\"description\": \"Hash containing the configurations for the LDAP backends configured in keystone.\", \"type\": \"json\", \"default\": {}, \"hidden\": true}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"KeystoneNotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Driver or drivers to handle sending notifications. This parameter is\\nspecific to Keystone.\\n\"}, \"KeystoneEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Keystone database.\\n\", \"type\": \"boolean\"}, \"KeystoneCronTrustFlushEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Ensure\\n\", \"default\": \"present\"}, \"KeystoneCronTrustFlushMinute\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Minute\\n\", \"default\": \"1\"}, \"KeystoneCronTrustFlushHour\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Hour\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonth\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Week Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMaxDelay\": {\"type\": \"number\", \"description\": \"Cron to purge expired or soft-deleted trusts - Max Delay\\n\", \"default\": 0}, \"KeystoneCronTrustFlushDestination\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Log destination\\n\", \"default\": \"/var/log/keystone/keystone-trustflush.log\"}, \"KeystoneCronTrustFlushUser\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - User\\n\", \"default\": \"keystone\"}, \"KeystoneChangePasswordUponFirstUse\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Enabling this option requires users to change their password when the user is created, or upon administrative reset.\", \"constraints\": [{\"allowed_values\": [\"\", \"true\", \"True\", \"TRUE\", \"false\", \"False\", \"FALSE\"]}]}, \"KeystoneDisableUserAccountDaysInactive\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of days a user can go without authenticating before being considered \\\"inactive\\\" and automatically disabled (locked).\"}, \"KeystoneLockoutDuration\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of seconds a user account will be locked when the maximum number of failed authentication attempts (as specified by KeystoneLockoutFailureAttempts) is exceeded.\"}, \"KeystoneLockoutFailureAttempts\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of times that a user can fail to authenticate before the user account is locked for the number of seconds specified by KeystoneLockoutDuration.\"}, \"KeystoneMinimumPasswordAge\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days that a password must be used before the user can change it. This prevents users from changing their passwords immediately in order to wipe out their password history and reuse an old password.\"}, \"KeystonePasswordExpiresDays\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days for which a password will be considered valid before requiring it to be changed.\"}, \"KeystonePasswordRegex\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The regular expression used to validate password strength requirements.\"}, \"KeystonePasswordRegexDescription\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Describe your password regular expression here in language for humans.\"}, \"KeystoneUniqueLastPasswordCount\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This controls the number of previous user password iterations to keep in history, in order to enforce that newly created passwords are unique.\"}, \"KeystoneCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"KeystoneEnableMember\": {\"description\": \"Create the _member_ role, useful for undercloud deployment.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneFederationEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for federated authentication.\"}, \"KeystoneTrustedDashboards\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of dashboard URLs trusted for single sign-on.\"}, \"KeystoneAuthMethods\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of methods used for authentication.\"}, \"KeystoneOpenIdcEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for OpenIDC federation.\"}, \"KeystoneOpenIdcIdpName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The name associated with the IdP in Keystone.\"}, \"KeystoneOpenIdcProviderMetadataUrl\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The url that points to your OpenID Connect provider metadata\"}, \"KeystoneOpenIdcClientId\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client ID to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcClientSecret\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client secret to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcCryptoPassphrase\": {\"type\": \"string\", \"default\": \"openstack\", \"description\": \"Passphrase to use when encrypting data for OpenID Connect handshake.\"}, \"KeystoneOpenIdcOutgoingProxy\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The outgoing proxy to use for OpenID connections.\"}, \"KeystoneOpenIdcResponseType\": {\"type\": \"string\", \"default\": \"id_token\", \"description\": \"Response type to be expected from the OpenID Connect provider.\"}, \"KeystoneOpenIdcRemoteIdAttribute\": {\"type\": \"string\", \"default\": \"OIDC-iss\", \"description\": \"Attribute to be used to obtain the entity ID of the Identity Provider from the environment.\"}, \"KeystoneOpenIdcEnableOAuth\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable OAuth 2.0 integration.\"}, \"KeystoneOpenIdcIntrospectionEndpoint\": {\"type\": \"string\", \"default\": \"\", \"description\": \"OAuth 2.0 introspection endpoint for mod_auth_openidc\"}, \"KeystoneOpenIdcClaimDelimiter\": {\"type\": \"string\", \"default\": \";\", \"description\": \"The delimiter to use when setting multi-valued claims.\"}, \"KeystoneOpenIdcPassUserInfoAs\": {\"type\": \"string\", \"default\": \"claims\", \"description\": \"Define the way(s) in which the claims resolved from the userinfo endpoint are passed to the application according to OIDCPassClaimsAs.\", \"constraints\": [{\"allowed_values\": [\"claims\", \"json\", \"jwt\"]}]}, \"KeystoneOpenIdcPassClaimsAs\": {\"type\": \"string\", \"default\": \"both\", \"description\": \"Define the way in which the claims and tokens are passed to the application environment: \\\"none\\\": no claims/tokens are passed \\\"environment\\\": claims/tokens are passed as environment variables \\\"headers\\\": claims/tokens are passed in headers (also useful in reverse proxy scenario\'s) \\\"both\\\": claims/tokens are passed as both headers as well as environment variables (default)\", \"constraints\": [{\"allowed_values\": [\"none\", \"environment\", \"headers\", \"both\"]}]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"KeystoneLogging\": {\"type\": \"OS::TripleO::Services::Logging::Keystone\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\", \"ContainerKeystoneConfigImage\": \"ContainerKeystoneConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}, \"ContainerKeystoneConfigImage\": {\"get_param\": \"ContainerKeystoneConfigImage\"}}}]}}}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}, \"keystone_fernet_tokens\": {\"equals\": [{\"get_param\": \"KeystoneTokenProvider\"}, \"fernet\"]}, \"nontls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"not\": {\"get_param\": \"MemcachedTLS\"}}]}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"keystone_outgoing_proxy\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}, \"\"]}}, {\"get_param\": \"KeystoneOpenIdcEnable\"}]}, \"change_password_upon_first_use_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}, \"\"]}}, \"disable_user_account_days_inactive_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}, \"\"]}}, \"lockout_duration_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutDuration\"}, \"\"]}}, \"lockout_failure_attempts_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutFailureAttempts\"}, \"\"]}}, \"minimum_password_age_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneMinimumPasswordAge\"}, \"\"]}}, \"password_expires_days_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordExpiresDays\"}, \"\"]}}, \"password_regex_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegex\"}, \"\"]}}, \"password_regex_description_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegexDescription\"}, \"\"]}}, \"unique_last_password_count_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneUniqueLastPasswordCount\"}, \"\"]}}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneCorsAllowedOrigin\"}, \"\"]}}, \"keystone_notification_driver_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneNotificationDriver\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Keystone API role.\", \"value\": {\"service_name\": \"keystone\", \"firewall_rules\": {\"111 keystone\": {\"dport\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 keystone_public_haproxy_frontend\": {\"dport\": [5000]}, \"100 keystone_admin_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_ssl_frontend_rules\": {\"100 keystone_public_haproxy_frontend_ssl\": {\"dport\": [13000]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionKeystone\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"if\": [\"cors_allowed_origin_set\", {\"keystone::cors::allowed_origin\": {\"get_param\": \"KeystoneCorsAllowedOrigin\"}}]}, {\"keystone::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"keystone\", \"password\": {\"get_param\": \"AdminToken\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/keystone\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"keystone\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"keystone::token_expiration\": {\"get_param\": \"TokenExpiration\"}, \"keystone::policy::policies\": {\"get_param\": \"KeystonePolicies\"}, \"keystone_ssl_certificate\": {\"get_param\": \"KeystoneSSLCertificate\"}, \"keystone_ssl_certificate_key\": {\"get_param\": \"KeystoneSSLCertificateKey\"}, \"keystone::token_provider\": {\"get_param\": \"KeystoneTokenProvider\"}, \"keystone::enable_fernet_setup\": {\"if\": [\"keystone_fernet_tokens\", true, false]}, \"keystone::fernet_max_active_keys\": {\"get_param\": \"KeystoneFernetMaxActiveKeys\"}, \"keystone::enable_proxy_headers_parsing\": true, \"keystone::enable_credential_setup\": true, \"keystone::credential_keys\": {\"/etc/keystone/credential-keys/0\": {\"content\": {\"get_param\": \"KeystoneCredential0\"}}, \"/etc/keystone/credential-keys/1\": {\"content\": {\"get_param\": \"KeystoneCredential1\"}}}, \"keystone::fernet_keys\": {\"get_param\": \"KeystoneFernetKeys\"}, \"keystone::fernet_replace_keys\": {\"get_param\": \"ManageKeystoneFernetKeys\"}, \"keystone::logging::debug\": {\"if\": [{\"get_param\": \"KeystoneDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"keystone::notification_driver\": {\"if\": [\"keystone_notification_driver_set\", {\"get_param\": \"KeystoneNotificationDriver\"}, {\"get_param\": \"NotificationDriver\"}]}, \"keystone::notification_format\": {\"get_param\": \"KeystoneNotificationFormat\"}, \"tripleo::profile::base::keystone::extra_notification_topics\": {\"get_param\": \"KeystoneNotificationTopics\"}, \"keystone_enable_db_purge\": {\"get_param\": \"KeystoneEnableDBPurge\"}, \"keystone::cron::trust_flush::ensure\": {\"get_param\": \"KeystoneCronTrustFlushEnsure\"}, \"keystone::cron::trust_flush::minute\": {\"get_param\": \"KeystoneCronTrustFlushMinute\"}, \"keystone::cron::trust_flush::hour\": {\"get_param\": \"KeystoneCronTrustFlushHour\"}, \"keystone::cron::trust_flush::monthday\": {\"get_param\": \"KeystoneCronTrustFlushMonthday\"}, \"keystone::cron::trust_flush::month\": {\"get_param\": \"KeystoneCronTrustFlushMonth\"}, \"keystone::cron::trust_flush::weekday\": {\"get_param\": \"KeystoneCronTrustFlushWeekday\"}, \"keystone::cron::trust_flush::maxdelay\": {\"get_param\": \"KeystoneCronTrustFlushMaxDelay\"}, \"keystone::cron::trust_flush::destination\": {\"get_param\": \"KeystoneCronTrustFlushDestination\"}, \"keystone::cron::trust_flush::user\": {\"get_param\": \"KeystoneCronTrustFlushUser\"}, \"keystone::rabbit_heartbeat_timeout_threshold\": 60, \"keystone::rabbit_heartbeat_in_pthread\": false, \"keystone::service_name\": \"httpd\", \"keystone::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::api_port\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}], \"keystone::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, \"keystone::wsgi::apache::workers\": {\"get_param\": \"KeystoneWorkers\"}, \"keystone::wsgi::apache::threads\": 1, \"keystone::db::database_db_max_retries\": -1, \"keystone::db::database_max_retries\": -1, \"keystone::wsgi::apache::bind_host\": [{\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}}}]}, {\"keystone::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"keystone::cache::backend_argument\": [{\"str_replace\": {\"template\": \"memcached_expire_time: $EXPIRATION\", \"params\": {\"$EXPIRATION\": {\"get_param\": \"TokenExpiration\"}}}}], \"keystone::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"keystone::cache::backend\": \"dogpile.cache.pymemcache\", \"keystone::token_caching\": true}, {\"keystone::cache::backend\": \"dogpile.cache.memcached\"}]}, {\"if\": [{\"get_param\": \"KeystoneFederationEnable\"}, {\"keystone_federation_enabled\": true, \"keystone::federation::trusted_dashboards\": {\"get_param\": \"KeystoneTrustedDashboards\"}}]}, {\"if\": [{\"get_param\": \"KeystoneOpenIdcEnable\"}, {\"keystone_openidc_enabled\": true, \"keystone::federation::openidc::methods\": {\"get_param\": \"KeystoneAuthMethods\"}, \"keystone::federation::openidc::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::federation::openidc::idp_name\": {\"get_param\": \"KeystoneOpenIdcIdpName\"}, \"keystone::federation::openidc::openidc_provider_metadata_url\": {\"get_param\": \"KeystoneOpenIdcProviderMetadataUrl\"}, \"keystone::federation::openidc::openidc_client_id\": {\"get_param\": \"KeystoneOpenIdcClientId\"}, \"keystone::federation::openidc::openidc_client_secret\": {\"get_param\": \"KeystoneOpenIdcClientSecret\"}, \"keystone::federation::openidc::openidc_crypto_passphrase\": {\"get_param\": \"KeystoneOpenIdcCryptoPassphrase\"}, \"keystone::federation::openidc::openidc_response_type\": {\"get_param\": \"KeystoneOpenIdcResponseType\"}, \"keystone::federation::openidc::remote_id_attribute\": {\"get_param\": \"KeystoneOpenIdcRemoteIdAttribute\"}, \"keystone::federation::openidc::openidc_enable_oauth\": {\"get_param\": \"KeystoneOpenIdcEnableOAuth\"}, \"keystone::federation::openidc::openidc_introspection_endpoint\": {\"get_param\": \"KeystoneOpenIdcIntrospectionEndpoint\"}, \"keystone::federation::openidc::openidc_pass_userinfo_as\": {\"get_param\": \"KeystoneOpenIdcPassUserInfoAs\"}, \"keystone::federation::openidc::openidc_pass_claim_as\": {\"get_param\": \"KeystoneOpenIdcPassClaimsAs\"}, \"keystone::federation::openidc::openidc_claim_delimiter\": {\"get_param\": \"KeystoneOpenIdcClaimDelimiter\"}, \"keystone::federation::openidc::openidc_cache_type\": {\"if\": [\"nontls_cache_enabled\", \"memcache\"]}}]}, {\"if\": [\"keystone_outgoing_proxy\", {\"keystone::federation::openidc::openidc_outgoing_proxy\": {\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}}]}, {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"tripleo::profile::base::keystone::ldap_backend_enable\": true, \"keystone::using_domain_config\": true, \"tripleo::profile::base::keystone::ldap_backends_config\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}]}, {\"if\": [\"change_password_upon_first_use_set\", {\"keystone::security_compliance::change_password_upon_first_use\": {\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}}]}, {\"if\": [\"disable_user_account_days_inactive_set\", {\"keystone::security_compliance::disable_user_account_days_inactive\": {\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}}]}, {\"if\": [\"lockout_duration_set\", {\"keystone::security_compliance::lockout_duration\": {\"get_param\": \"KeystoneLockoutDuration\"}}]}, {\"if\": [\"lockout_failure_attempts_set\", {\"keystone::security_compliance::lockout_failure_attempts\": {\"get_param\": \"KeystoneLockoutFailureAttempts\"}}]}, {\"if\": [\"minimum_password_age_set\", {\"keystone::security_compliance::minimum_password_age\": {\"get_param\": \"KeystoneMinimumPasswordAge\"}}]}, {\"if\": [\"password_expires_days_set\", {\"keystone::security_compliance::password_expires_days\": {\"get_param\": \"KeystonePasswordExpiresDays\"}}]}, {\"if\": [\"password_regex_set\", {\"keystone::security_compliance::password_regex\": {\"get_param\": \"KeystonePasswordRegex\"}}]}, {\"if\": [\"password_regex_description_set\", {\"keystone::security_compliance::password_regex_description\": {\"get_param\": \"KeystonePasswordRegexDescription\"}}]}, {\"if\": [\"unique_last_password_count_set\", {\"keystone::security_compliance::unique_last_password_count\": {\"get_param\": \"KeystoneUniqueLastPasswordCount\"}}]}, {\"apache::default_vhost\": false}, {\"get_attr\": [\"KeystoneLogging\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_keystone\": {\"get_param\": \"KeystoneLoggingSource\"}}, \"mysql\": {\"keystone::db::mysql::password\": {\"get_param\": \"AdminToken\"}, \"keystone::db::mysql::user\": \"keystone\", \"keystone::db::mysql::host\": \"%\", \"keystone::db::mysql::dbname\": \"keystone\"}, \"pacemaker\": {\"keystone::endpoint::public_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::endpoint::internal_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"keystone::endpoint::admin_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"keystone::endpoint::region\": {\"get_param\": \"KeystoneRegion\"}, \"keystone::admin_password\": {\"get_param\": \"AdminPassword\"}}, \"horizon\": {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"horizon::keystone_multidomain_support\": true, \"horizon::keystone_default_domain\": \"Default\"}]}}, \"puppet_config\": {\"config_volume\": \"keystone\", \"puppet_tags\": \"keystone_config,keystone_domain_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Keystone_user\', \'Keystone_endpoint\', \'Keystone_domain\', \'Keystone_tenant\', \'Keystone_user_role\', \'Keystone_role\', \'Keystone_service\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::keystone\\n\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/keystone.json\": {\"command\": \"/usr/sbin/httpd\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/keystone/fernet-keys\", \"dest\": \"/etc/keystone/fernet-keys\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/keystone_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"KeystoneLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"keystone_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"KeystoneLogging\", \"environment\"]}, {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}]}, \"command\": [\"/usr/bin/bootstrap_host_exec\", \"keystone\", \"/usr/local/bin/kolla_start\"]}, \"keystone\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"keystone_bootstrap\": {\"start_order\": 3, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"/usr/bin/bootstrap_host_exec\", \"keystone\", \"keystone-manage\", \"bootstrap\"], \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"OS_BOOTSTRAP_PASSWORD\": {\"get_param\": \"AdminPassword\"}, \"OS_BOOTSTRAP_USERNAME\": \"admin\", \"OS_BOOTSTRAP_PROJECT_NAME\": \"admin\", \"OS_BOOTSTRAP_ROLE_NAME\": \"admin\", \"OS_BOOTSTRAP_SERVICE_NAME\": \"keystone\", \"OS_BOOTSTRAP_ADMIN_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_PUBLIC_URL\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_INTERNAL_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_REGION_ID\": {\"get_param\": \"KeystoneRegion\"}}}, \"keystone_cron\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"user\": \"root\", \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron keystone\"}, \"command\": [\"/bin/bash\", \"-c\", \"/usr/local/bin/kolla_set_configs && /usr/sbin/crond -n\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/keystone_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"keystone_refresh\": {\"start_order\": 1, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"pkill\", \"--signal\", \"USR1\", \"httpd\"]}}}, \"external_deploy_tasks\": [{\"name\": \"Manage clouds.yaml files\", \"when\": [\"step|int == 1\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Create /etc/openstack directory if it does not exist\", \"become\": true, \"file\": {\"mode\": \"0755\", \"owner\": \"root\", \"path\": \"/etc/openstack\", \"state\": \"directory\"}}, {\"name\": \"Configure /etc/openstack/clouds.yaml\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"clouds\"}, \"vars\": {\"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_cloud_config\": {\"auth\": {\"auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"password\": {\"get_param\": \"AdminPassword\"}, \"project_domain_name\": \"Default\", \"project_name\": \"admin\", \"user_domain_name\": \"Default\", \"username\": \"admin\"}, \"cacert\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"PublicTLSCAFile\"}, \"\"]}, \"identity_api_version\": \"3\", \"volume_api_version\": \"3\", \"region_name\": {\"get_param\": \"KeystoneRegion\"}}}}]}, {\"name\": \"Manage Keystone resources\", \"become\": true, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Manage Keystone resources for OpenStack services\", \"include_role\": {\"name\": \"tripleo_keystone_resources\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_service_project\": \"service\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_region\": {\"get_param\": \"KeystoneRegion\"}, \"tripleo_keystone_resources_admin_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_public_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_internal_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_admin_password\": {\"get_param\": \"AdminPassword\"}, \"tripleo_keystone_resources_member_role_enabled\": {\"get_param\": \"KeystoneEnableMember\"}}}, {\"name\": \"is Keystone LDAP enabled\", \"set_fact\": {\"keystone_ldap_domain_enabled\": {\"get_param\": \"KeystoneLDAPDomainEnable\"}}}, {\"name\": \"Set fact for tripleo_keystone_ldap_domains\", \"set_fact\": {\"tripleo_keystone_ldap_domains\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}, \"when\": \"keystone_ldap_domain_enabled|bool\"}, {\"name\": \"Manage Keystone domains from LDAP config\", \"when\": \"keystone_ldap_domain_enabled|bool\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"domains\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"batched_tripleo_keystone_resources_domains\": \"{{ tripleo_keystone_ldap_domains | list }}\"}}]}], \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"validate keystone container state\", \"containers.podman.podman_container_info\": {\"name\": \"keystone\"}, \"register\": \"keystone_infos\", \"failed_when\": [\"keystone_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in keystone_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-keystone\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 4\"]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"KeystoneLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check if file certs_valid exist\", \"stat\": {\"path\": \"/etc/openldap/certs/certs_valid\"}, \"register\": \"certs_valid_stat\"}, {\"name\": \"Check if file cert9.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/cert9.db\"}, \"register\": \"cert9_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"name\": \"Check if file key4.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/key4.db\"}, \"register\": \"key4_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"fail\": {\"msg\": \"Keys and/or certificates were found in /etc/openldap/certs but these conflicts with keystone python LDAP calls.  If you know those certificates are valid and not causing any conflicts, you can touch /etc/openldap/certs/certs_valid in order to skip this failure and retry or you can delete the files located in /etc/openldap/certs and retry.\\n\"}, \"when\": \"( cert9_stat.stat.exists or key4_stat.stat.exists ) and not certs_valid_stat.stat.exists\"}]]}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop keystone container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"keystone\", \"keystone_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'keystone\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (203,'2026-06-15 07:51:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(204,'2026-06-15 07:51:47',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"71990642-319e-497c-b4d1-b147b6ad3a13\", \"name\": \"np0000073847\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {\"ipa_enroll\": true, \"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(205,'2026-06-15 07:51:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000073848-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(206,'2026-06-15 07:51:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000073847-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(207,'2026-06-15 07:51:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(208,'2026-06-15 07:51:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"CertmongerCA\": {\"type\": \"string\", \"default\": \"\", \"description\": \"CA to use for certmonger\"}, \"HAProxyCertificateDNSNames\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Override the default HAProxy Certificate DNS Names\"}, \"HAProxyCertificatePrincipal\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the default HAProxy Certificate Principal\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}, \"principal_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificatePrincipal\"}, \"\"]}}, \"dnsnames_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateDNSNames\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_public_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::service_certificate\": {\"get_param\": \"DeployedSSLCertificatePath\"}}, \"certificates_specs\": {\"haproxy-external\": {\"service_pem\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}, \"metadata_settings\": [{\"service\": \"haproxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"type\": \"vip\"}], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"certmonger_ca\": {\"get_param\": \"CertmongerCA\"}}, \"block\": [{\"name\": \"make sure certmonger is installed\", \"package\": {\"name\": \"certmonger\", \"state\": \"present\"}}, {\"name\": \"make sure certmonger service is started\", \"systemd\": {\"state\": \"started\", \"enabled\": true, \"masked\": false, \"name\": \"certmonger.service\"}}, {\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"name\": \"Extract and trust certmonger\'s local CA\", \"shell\": \"set -e\\nca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\nopenssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\nchmod 0644 ${ca_pem}\\nupdate-ca-trust extract\\ntest -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n\", \"retries\": 5, \"delay\": 1, \"register\": \"local_ca_extract_result\", \"until\": \"local_ca_extract_result.rc == 0\", \"when\": \"certmonger_ca != \'IPA\' and (ipa_realm is not defined)\"}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"haproxy-external-cert\", \"dns\": {\"if\": [\"dnsnames_override_set\", {\"get_param\": \"HAProxyCertificateDNSNames\"}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"ip\": {\"if\": [\"dnsnames_override_set\", {\"str_replace\": {\"template\": \"{{DNSNAMES|ipaddr}}\", \"params\": {\"DNSNAMES\": {\"get_param\": \"HAProxyCertificateDNSNames\"}}}}, {\"str_replace\": {\"template\": \"{{[cloud_names.cloud_name_NETWORK]|ipaddr}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"principal\": {\"if\": [\"principal_override_set\", {\"get_param\": \"HAProxyCertificatePrincipal\"}, {\"str_replace\": {\"template\": \"haproxy/{{cloud_names.cloud_name_NETWORK}}@{{idm_realm|default(\'UNDERCLOUD\')}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-external-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-external-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\n\\nca_type=CATYPE\\nif [ \\\"$ca_type\\\" = \\\"self-sign\\\" ]; then\\n  # refresh the ca cert just in case the ca cert has been renewed\\n  ca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\n  openssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\n  chmod 0644 ${ca_pem}\\n  update-ca-trust extract\\n  test -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n  openssl x509 -in ${ca_pem} -out /tmp/cm-local-ca.pem\\n  ca_path=\\\"/tmp/cm-local-ca.pem\\\"\\nelse\\n  ca_path=\\\"/etc/ipa/ca.crt\\\"\\nfi\\n\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\nservice_pem=\\\"PEMPATH\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CATYPE\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\", \"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"PEMPATH\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(209,'2026-06-15 07:51:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Compute node configured by Puppet\", \"parameters\": {\"OvercloudComputeFlavor\": {\"description\": \"Flavor for the Compute node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"NovaImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"DEPRECATED Use ComputeImage instead\"}, \"ComputeImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeIPs\": {\"default\": {}, \"type\": \"json\"}, \"NovaComputeIPs\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeIPs instead\", \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"NovaComputeServerMetadata\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeServerMetadata instead\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {\"ipa_enroll\": true}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"NovaImage\", \"NovaComputeServerMetadata\", \"NovaComputeIPs\"]}], \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"deprecated_param_image_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaImage\"}, \"overcloud-full\"]}}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"Compute_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"NovaCompute\": {\"type\": \"OS::TripleO::ComputeServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"if\": [\"deprecated_param_image_set\", {\"get_param\": \"NovaImage\"}, {\"get_param\": \"ComputeImage\"}]}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, {\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"NovaComputeServerMetadata\"}, {\"get_param\": \"ComputeServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeSchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::Compute::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::Compute::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::Compute::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"NovaCompute\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::Compute::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"ComputeExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"NovaComputeAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"NovaComputeAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for Compute server\", \"value\": {\"get_resource\": \"NovaCompute\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-0\", \"CloudDomain\": \"ooo.test\", \"ComputeSchedulerHints\": {}, \"NodeIndex\": 0, \"ServiceNames\": \"boot_params_service,ca_certs,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,ipaservice,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"71990642-319e-497c-b4d1-b147b6ad3a13\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(210,'2026-06-15 07:51:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(211,'2026-06-15 07:51:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"keystone_init_log\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R keystone:keystone /var/log/keystone\"], \"volumes\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}}}}, \"environment\": {\"description\": \"Extra environment variables needed for the service to log to files.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(212,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"71990642-319e-497c-b4d1-b147b6ad3a13\", \"name\": \"np0000073846\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {\"ipa_enroll\": true, \"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (213,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"14e29fd3-bf07-411e-b409-6b5db200dcb3\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(214,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Tenant network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"TenantDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Tenant network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000073848_Tenant\", \"DnsName\": \"np0000073848\", \"ControlPlaneIP\": \"192.168.122.108\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"tenant_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 2, \"Role\": \"Compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(215,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000073848_Storage\", \"DnsName\": \"np0000073848\", \"ControlPlaneIP\": \"192.168.122.108\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 2, \"Role\": \"Compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(216,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"InternalApiDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000073848_InternalApi\", \"DnsName\": \"np0000073848\", \"ControlPlaneIP\": \"192.168.122.108\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 2, \"Role\": \"Compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(217,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Tenant network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"TenantDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"tenant\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Tenant network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Tenant network IP\", \"value\": {\"get_attr\": [\"TenantDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000073847_Tenant\", \"DnsName\": \"np0000073847\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"tenant_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 1, \"Role\": \"Compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(218,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Noop Extra Pre-Deployment Config\", \"parameters\": {\"server\": {\"type\": \"string\"}}, \"outputs\": {\"deploy_stdout\": {\"value\": \"None\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"server\": \"1ad19eb7-9183-4e85-8aa4-8a8bc5ddc243\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(219,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"StorageDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"storage\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network IP\", \"value\": {\"get_attr\": [\"StorageDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000073847_Storage\", \"DnsName\": \"np0000073847\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 1, \"Role\": \"Compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(220,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"NodePortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"DefaultRoute\": {\"description\": \"Whether this interface is used for the default route\\n\", \"type\": \"boolean\", \"default\": false}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"resources\": {\"InternalApiDeployedPort\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ip_address\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address\"]}, \"ip_address_uri\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_address_uri\"]}, \"ip_subnet\": {\"get_param\": [\"NodePortMap\", {\"get_param\": \"DnsName\"}, \"internal_api\", \"ip_subnet\"]}}}}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network IP (with brackets for IPv6 URLs)\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network IP\", \"value\": {\"get_attr\": [\"InternalApiDeployedPort\", \"value\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"np0000073847_InternalApi\", \"DnsName\": \"np0000073847\", \"ControlPlaneIP\": \"192.168.122.107\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IPPool\": {}, \"NodeIndex\": 1, \"Role\": \"Compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(221,'2026-06-15 07:51:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat CloudWatch API service, disabled by default since Pike\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the disabled Heat CloudWatch API\", \"value\": {\"service_name\": \"heat_api_cloudwatch_disabled\", \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(222,'2026-06-15 07:51:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API CFN service\\n\", \"parameters\": {\"ContainerHeatApiCfnImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"ContainerHeatApiCfnConfigImage\": {\"description\": \"The container image to use for the heat_api_cfn config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"HeatApiCfnLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api.cfn\", \"file\": \"/var/log/containers/heat/heat_api_cfn.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"lRfTtulpjIZx2SuWRPc7LPTx6\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApiCnf\": {\"default\": \"overcloud-heat-api-cfn\", \"type\": \"string\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiCfnLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApiCfn\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiCfnImage\": \"ContainerHeatApiCfnImage\", \"ContainerHeatApiCfnConfigImage\": \"ContainerHeatApiCfnConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiCfnImage\": {\"get_param\": \"ContainerHeatApiCfnImage\"}, \"ContainerHeatApiCfnConfigImage\": {\"get_param\": \"ContainerHeatApiCfnConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API CFN role.\", \"value\": {\"service_name\": \"heat_api_cfn\", \"firewall_rules\": {\"125 heat_cfn\": {\"dport\": [8000]}}, \"firewall_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend\": {\"dport\": [8000]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend_ssl\": {\"dport\": [13005]}}, \"keystone_resources\": {\"heat-cfn\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"uri\"]}}, \"users\": {\"heat-cfn\": {\"password\": {\"get_param\": \"HeatPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"cloudformation\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApiCnf\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::api_cfn::service_name\": \"httpd\", \"heat::wsgi::apache_api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api_cfn::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api_cfn\": [{\"get_param\": \"HeatApiCfnLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api_cfn\", \"puppet_tags\": \"heat_config,file,concat,file_line\", \"step_config\": \"include tripleo::profile::base::heat::api_cfn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api_cfn.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiCfnLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api_cfn\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cfn.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api_cfn:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiCfnLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat cfn container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api_cfn\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api_cfn\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.154\", \"host_nobrackets\": \"172.21.0.154\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.154:2049\", \"uri_no_suffix\": \"nfs://172.21.0.154:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.239\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.239\", \"storage_mgmt\": \"172.20.0.213\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.213\", \"internal_api\": \"172.17.0.148\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.148\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.154\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.154\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000073843\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073844\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073845\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073846\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073847\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000073848\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.154\", \"ip_address_uri\": \"172.21.0.154\", \"ip_subnet\": \"172.21.0.154/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.148\", \"ip_address_uri\": \"172.17.0.148\", \"ip_subnet\": \"172.17.0.148/24\"}, \"storage\": {\"ip_address\": \"172.18.0.239\", \"ip_address_uri\": \"172.18.0.239\", \"ip_subnet\": \"172.18.0.239/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.213\", \"ip_address_uri\": \"172.20.0.213\", \"ip_subnet\": \"172.20.0.213/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"XITaEkVaorHTSEBU67xsjmkmx\", \"AdminToken\": \"NIWZjrF4l5wBK2l3SFmT2u3eC\", \"CeilometerMeteringSecret\": \"MGRnIM4wMti8nqhqt2uJkphYX\", \"CeilometerPassword\": \"lAltaQRZMJ8lMeTuITOttJN7X\", \"CephClientKey\": \"AQDJri9qAAAAABAA1Cz/2ZdGcWSUuz31HjxFJw==\", \"CephClusterFSID\": \"3740e1ef-a43e-4451-a74a-f194469d07d9\", \"CinderPassword\": \"puJEUVV5bncg9PX1nMb3Jnk25\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781509833, \"GlancePassword\": \"sWxK580w74dwlHOIwwPlLwNi9\", \"HAProxyStatsPassword\": \"YhvZhTMF0VPio5Bhs4itldE4k\", \"HeatAuthEncryptionKey\": \"zRQt4t8J9AACy5dUlrQeNTXvuCkj42L8\", \"HeatPassword\": \"lRfTtulpjIZx2SuWRPc7LPTx6\", \"HeatStackDomainAdminPassword\": \"376BfcZQI6aGoCYfKxTIQgXSQ\", \"HorizonSecret\": \"zKZUPZrGKS\", \"KeystoneCredential0\": \"dhEBFKp_KDKBN8xx6NTbNKNfGruDy4xoxN7ETXxa9yE=\", \"KeystoneCredential1\": \"drMZDQajGExen3ZvXVhiZhgL8qOAKE0R29S2RFdEF5c=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"lv-noFg61zpzmmUPrYFlb1lvxkIfM3tLbBH6YtXUfz0=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"PhFJdE-7UUkMuw5wonu4RQNapLQKNOb-7mMINriCACQ=\"}}, \"LibvirtTLSPassword\": \"5ddvoJoZfFm0QTmzFPr7SuD7p\", \"ManilaPassword\": \"DE9oMda8VcAYdfCX9tn5JskdJ\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEA4RpksRWMMTBNsSv6In+i/kQNXKcFFu1IWMDcJWQvvb3Uf9lk\\nAuTH5yD/ahT2dF7B0UqZexzwojgbVnVfxgRA+aGyI5mQ0Ncp+4yqdMbmwhhxuLo3\\nO9/ihiod0oF2buam11pQcez+E7am+CS9JF+6nz2U5oxSsZzMRyV0V1Jv+madR46e\\nehrDkHL0k3pOD3ddoy04+oS3ObdSgXZO0kueUMllA55ZPZ7OjuvaYABZhcWWXtBO\\nhXuUbZTJMwfHHwUicHBGLKsTA0oOMAlSW1fug9/uscP9h+6f1hojbxmzFQ+IkXtG\\nbH2jbJPdd9nBpheSDfY0GNT2FaWzmrJ1g/SYrwIDAQABAoIBACnb+ZuAkUhYXioz\\nLlmZ+Jpl10JCgMzJpSlz+7wsTEBxe4Gm0FVFa/MMDNMSQN5U/J/Jyo69S/Yujs7e\\nFshA5EBHlFPQa8CaMmFnwA7lKeYwG32piznkIUCntlH95yMqWx4y2kDFPF44GgaM\\n9ms8Lf0Mu5K/x2Tl7orQaTkPyGj8sLXNV1pkNJXIncQMaOlHxQXxb+c5kF4JR4/e\\nBby+SFwbexnb8UbtVJK1+H4qi8ZFHt8DYrckWzZhgjiAjYRCazWDbLPLglxLkZxU\\nXd4KNF+nCgVstvSDd32AGzI5sC6O0tAdGWQ9RRissu3x6Qfpt2G4BhPE9JClGAqs\\nHDvdcJECgYEA9hNvlAK9/pxwnqSilKmIeFnnx5LjxaBm9RapLI5c6W09B8IntltF\\nymSaHl/O41Umw64j2PZe1MNzNIGWEx+S2H+ubZiweDpTuY9zN0B6jHzv3tuFTuXV\\n//0HZHC6ALPE9u83Y+/0VNdptZvQOuDHVcs90Ol3Ck9/Mri/NurNM3cCgYEA6i5t\\nc/bF4kG6IGVQEYD5f07kJX8KYaHZit7+gZhwapp+KOwy/n549LQ7sd98buz7usLx\\niFkq23YFa5As6HmI3EUFGke5BUobyUaTfzthavqJGOw5AKgjFdba5cOEeEBVMKvo\\npSRRfKvFe3iJAyajtP5xOTLKSKvAxyxvKSwz4okCgYAnCNY+SGETLoW+5KbVpj77\\nuGdIBUkUZGlwn3OemcarUKTJwkbCaqAbhvHbt579+Nf5WnpdRFeusIJp5dSEnBGT\\nPk3RHNOBft8hJFxGe3f1KSxz0abH6TWVMfImQKuAyQOJmFDVDY9YlgMyx9C0RkvY\\nlDDuHtq/S/UFesD6WSzL6QKBgQC+LwZk7zy2C3sFZEIqdPwrD/7pFMtxjugFiCRZ\\nS1vAt8dNpMWlOUEyOk1gn4eG7p9hhYByozfTE35DZMuT4V/sw4DpXuY8DXuTcuXG\\nporvPpiozO9eQS59RghwIOEsZ9LHvFUsCNrEzRuMss9S58Z770g0k7MEYbgmCUgd\\nv/BDQQKBgQDdtrCZMrfKOkHaCq9WMaqBO79fi5zTWNovIVNwFI9fmHhWS0zZAQAr\\n5CiilaIMm6PkCP4aGR6VuwRV6A6x5HyzreOESKcOQGySrCEjvt8vz6C1Uu6BOX7U\\nJ66J2Mc6Bea02bdESSWsv7DSn8wgbdbUY3DNt769m8OTwvFhQlOUHg==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDhGmSxFYwxME2xK/oif6L+RA1cpwUW7UhYwNwlZC+9vdR/2WQC5MfnIP9qFPZ0XsHRSpl7HPCiOBtWdV/GBED5obIjmZDQ1yn7jKp0xubCGHG4ujc73+KGKh3SgXZu5qbXWlBx7P4Ttqb4JL0kX7qfPZTmjFKxnMxHJXRXUm/6Zp1Hjp56GsOQcvSTek4Pd12jLTj6hLc5t1KBdk7SS55QyWUDnlk9ns6O69pgAFmFxZZe0E6Fe5RtlMkzB8cfBSJwcEYsqxMDSg4wCVJbV+6D3+6xw/2H7p/WGiNvGbMVD4iRe0ZsfaNsk9132cGmF5IN9jQY1PYVpbOasnWD9Jiv Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"wPypJaa7B9wxCHWkqAtXwO5K7\", \"MysqlMariabackupPassword\": \"ts8QsdqrZ4skNFMUjxVNJoGJS\", \"MysqlRootPassword\": \"gXmAIg0MPC\", \"NeutronMetadataProxySharedSecret\": \"NFzMNmBHe4LKwprV3ucg9SrGP\", \"NeutronPassword\": \"OorljNRFSWJ6uLOrYiwbnwsqY\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"eljGPqsTubd1MRdmVjF5MppaC\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"GcDGAXx843831JzI\", \"PlacementPassword\": \"9ppduM3vEiUPQ7DOtXGTm17h0\", \"RabbitCookie\": \"ydzQyGJ8QXIfNYdFckiy\", \"RabbitPassword\": \"HKoXlX4loYww6E5tSxVAmuZQM\", \"RedisPassword\": \"JDaTXcJCyBDjrUGXoIFUsKtgP\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"g4OAR74RG5LH2J2YxZliAet7B\", \"SnmpdReadonlyUserPassword\": \"89Vk5RNyVwiA8aj5GHvgz6wY\", \"SwiftHashSuffix\": \"CDbRjrWUgg3eHZDN6yjWZGVU4\", \"SwiftPassword\": \"IUDmRSxaMd50Qh6OwAjgCQhv8\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (223,'2026-06-15 07:51:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"np0000073843-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073844-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073845-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073846-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073847-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000073848-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000073846-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000073843\", \"overcloud-controller-1\": \"np0000073844\", \"overcloud-controller-2\": \"np0000073845\", \"overcloud-novacompute-0\": \"np0000073846\", \"overcloud-novacompute-1\": \"np0000073847\", \"overcloud-novacompute-2\": \"np0000073848\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\"